/*!
 * https://github.com/es-shims/es5-shim
 * @license es5-shim Copyright 2009-2015 by contributors, MIT License
 * see https://github.com/es-shims/es5-shim/blob/master/LICENSE
 */

// vim: ts=4 sts=4 sw=4 expandtab

// Add semicolon to prevent IIFE from being passed as argument to concatenated code.
;

// UMD (Universal Module Definition)
// see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
(function (root, factory) {
    'use strict';

    /* global define, exports, module */
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals (root is window)
        root.returnExports = factory();
    }
}(this, function () {

/**
 * Brings an environment as close to ECMAScript 5 compliance
 * as is possible with the facilities of erstwhile engines.
 *
 * Annotated ES5: http://es5.github.com/ (specific links below)
 * ES5 Spec: http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf
 * Required reading: http://javascriptweblog.wordpress.com/2011/12/05/extending-javascript-natives/
 */

// Shortcut to an often accessed properties, in order to avoid multiple
// dereference that costs universally. This also holds a reference to known-good
// functions.
var $Array = Array;
var ArrayPrototype = $Array.prototype;
var $Object = Object;
var ObjectPrototype = $Object.prototype;
var $Function = Function;
var FunctionPrototype = $Function.prototype;
var $String = String;
var StringPrototype = $String.prototype;
var $Number = Number;
var NumberPrototype = $Number.prototype;
var array_slice = ArrayPrototype.slice;
var array_splice = ArrayPrototype.splice;
var array_push = ArrayPrototype.push;
var array_unshift = ArrayPrototype.unshift;
var array_concat = ArrayPrototype.concat;
var array_join = ArrayPrototype.join;
var call = FunctionPrototype.call;
var apply = FunctionPrototype.apply;
var max = Math.max;
var min = Math.min;

// Having a toString local variable name breaks in Opera so use to_string.
var to_string = ObjectPrototype.toString;

/* global Symbol */
/* eslint-disable one-var-declaration-per-line, no-redeclare */
var hasToStringTag = typeof Symbol === 'function' && typeof Symbol.toStringTag === 'symbol';
var isCallable; /* inlined from https://npmjs.com/is-callable */ var fnToStr = Function.prototype.toString, constructorRegex = /^\s*class /, isES6ClassFn = function isES6ClassFn(value) { try { var fnStr = fnToStr.call(value); var singleStripped = fnStr.replace(/\/\/.*\n/g, ''); var multiStripped = singleStripped.replace(/\/\*[.\s\S]*\*\//g, ''); var spaceStripped = multiStripped.replace(/\n/mg, ' ').replace(/ {2}/g, ' '); return constructorRegex.test(spaceStripped); } catch (e) { return false; /* not a function */ } }, tryFunctionObject = function tryFunctionObject(value) { try { if (isES6ClassFn(value)) { return false; } fnToStr.call(value); return true; } catch (e) { return false; } }, fnClass = '[object Function]', genClass = '[object GeneratorFunction]', isCallable = function isCallable(value) { if (!value) { return false; } if (typeof value !== 'function' && typeof value !== 'object') { return false; } if (hasToStringTag) { return tryFunctionObject(value); } if (isES6ClassFn(value)) { return false; } var strClass = to_string.call(value); return strClass === fnClass || strClass === genClass; };

var isRegex; /* inlined from https://npmjs.com/is-regex */ var regexExec = RegExp.prototype.exec, tryRegexExec = function tryRegexExec(value) { try { regexExec.call(value); return true; } catch (e) { return false; } }, regexClass = '[object RegExp]'; isRegex = function isRegex(value) { if (typeof value !== 'object') { return false; } return hasToStringTag ? tryRegexExec(value) : to_string.call(value) === regexClass; };
var isString; /* inlined from https://npmjs.com/is-string */ var strValue = String.prototype.valueOf, tryStringObject = function tryStringObject(value) { try { strValue.call(value); return true; } catch (e) { return false; } }, stringClass = '[object String]'; isString = function isString(value) { if (typeof value === 'string') { return true; } if (typeof value !== 'object') { return false; } return hasToStringTag ? tryStringObject(value) : to_string.call(value) === stringClass; };
/* eslint-enable one-var-declaration-per-line, no-redeclare */

/* inlined from http://npmjs.com/define-properties */
var supportsDescriptors = $Object.defineProperty && (function () {
    try {
        var obj = {};
        $Object.defineProperty(obj, 'x', { enumerable: false, value: obj });
        for (var _ in obj) { return false; }
        return obj.x === obj;
    } catch (e) { /* this is ES3 */
        return false;
    }
}());
var defineProperties = (function (has) {
  // Define configurable, writable, and non-enumerable props
  // if they don't exist.
  var defineProperty;
  if (supportsDescriptors) {
      defineProperty = function (object, name, method, forceAssign) {
          if (!forceAssign && (name in object)) { return; }
          $Object.defineProperty(object, name, {
              configurable: true,
              enumerable: false,
              writable: true,
              value: method
          });
      };
  } else {
      defineProperty = function (object, name, method, forceAssign) {
          if (!forceAssign && (name in object)) { return; }
          object[name] = method;
      };
  }
  return function defineProperties(object, map, forceAssign) {
      for (var name in map) {
          if (has.call(map, name)) {
            defineProperty(object, name, map[name], forceAssign);
          }
      }
  };
}(ObjectPrototype.hasOwnProperty));

//
// Util
// ======
//

/* replaceable with https://npmjs.com/package/es-abstract /helpers/isPrimitive */
var isPrimitive = function isPrimitive(input) {
    var type = typeof input;
    return input === null || (type !== 'object' && type !== 'function');
};

var isActualNaN = $Number.isNaN || function (x) { return x !== x; };

var ES = {
    // ES5 9.4
    // http://es5.github.com/#x9.4
    // http://jsperf.com/to-integer
    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToInteger */
    ToInteger: function ToInteger(num) {
        var n = +num;
        if (isActualNaN(n)) {
            n = 0;
        } else if (n !== 0 && n !== (1 / 0) && n !== -(1 / 0)) {
            n = (n > 0 || -1) * Math.floor(Math.abs(n));
        }
        return n;
    },

    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToPrimitive */
    ToPrimitive: function ToPrimitive(input) {
        var val, valueOf, toStr;
        if (isPrimitive(input)) {
            return input;
        }
        valueOf = input.valueOf;
        if (isCallable(valueOf)) {
            val = valueOf.call(input);
            if (isPrimitive(val)) {
                return val;
            }
        }
        toStr = input.toString;
        if (isCallable(toStr)) {
            val = toStr.call(input);
            if (isPrimitive(val)) {
                return val;
            }
        }
        throw new TypeError();
    },

    // ES5 9.9
    // http://es5.github.com/#x9.9
    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToObject */
    ToObject: function (o) {
        if (o == null) { // this matches both null and undefined
            throw new TypeError("can't convert " + o + ' to object');
        }
        return $Object(o);
    },

    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToUint32 */
    ToUint32: function ToUint32(x) {
        return x >>> 0;
    }
};

//
// Function
// ========
//

// ES-5 15.3.4.5
// http://es5.github.com/#x15.3.4.5

var Empty = function Empty() {};

defineProperties(FunctionPrototype, {
    bind: function bind(that) { // .length is 1
        // 1. Let Target be the this value.
        var target = this;
        // 2. If IsCallable(Target) is false, throw a TypeError exception.
        if (!isCallable(target)) {
            throw new TypeError('Function.prototype.bind called on incompatible ' + target);
        }
        // 3. Let A be a new (possibly empty) internal list of all of the
        //   argument values provided after thisArg (arg1, arg2 etc), in order.
        // XXX slicedArgs will stand in for "A" if used
        var args = array_slice.call(arguments, 1); // for normal call
        // 4. Let F be a new native ECMAScript object.
        // 11. Set the [[Prototype]] internal property of F to the standard
        //   built-in Function prototype object as specified in 15.3.3.1.
        // 12. Set the [[Call]] internal property of F as described in
        //   15.3.4.5.1.
        // 13. Set the [[Construct]] internal property of F as described in
        //   15.3.4.5.2.
        // 14. Set the [[HasInstance]] internal property of F as described in
        //   15.3.4.5.3.
        var bound;
        var binder = function () {

            if (this instanceof bound) {
                // 15.3.4.5.2 [[Construct]]
                // When the [[Construct]] internal method of a function object,
                // F that was created using the bind function is called with a
                // list of arguments ExtraArgs, the following steps are taken:
                // 1. Let target be the value of F's [[TargetFunction]]
                //   internal property.
                // 2. If target has no [[Construct]] internal method, a
                //   TypeError exception is thrown.
                // 3. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Construct]] internal
                //   method of target providing args as the arguments.

                var result = apply.call(
                    target,
                    this,
                    array_concat.call(args, array_slice.call(arguments))
                );
                if ($Object(result) === result) {
                    return result;
                }
                return this;

            } else {
                // 15.3.4.5.1 [[Call]]
                // When the [[Call]] internal method of a function object, F,
                // which was created using the bind function is called with a
                // this value and a list of arguments ExtraArgs, the following
                // steps are taken:
                // 1. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 2. Let boundThis be the value of F's [[BoundThis]] internal
                //   property.
                // 3. Let target be the value of F's [[TargetFunction]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Call]] internal method
                //   of target providing boundThis as the this value and
                //   providing args as the arguments.

                // equiv: target.call(this, ...boundArgs, ...args)
                return apply.call(
                    target,
                    that,
                    array_concat.call(args, array_slice.call(arguments))
                );

            }

        };

        // 15. If the [[Class]] internal property of Target is "Function", then
        //     a. Let L be the length property of Target minus the length of A.
        //     b. Set the length own property of F to either 0 or L, whichever is
        //       larger.
        // 16. Else set the length own property of F to 0.

        var boundLength = max(0, target.length - args.length);

        // 17. Set the attributes of the length own property of F to the values
        //   specified in 15.3.5.1.
        var boundArgs = [];
        for (var i = 0; i < boundLength; i++) {
            array_push.call(boundArgs, '$' + i);
        }

        // XXX Build a dynamic function with desired amount of arguments is the only
        // way to set the length property of a function.
        // In environments where Content Security Policies enabled (Chrome extensions,
        // for ex.) all use of eval or Function costructor throws an exception.
        // However in all of these environments Function.prototype.bind exists
        // and so this code will never be executed.
        bound = $Function('binder', 'return function (' + array_join.call(boundArgs, ',') + '){ return binder.apply(this, arguments); }')(binder);

        if (target.prototype) {
            Empty.prototype = target.prototype;
            bound.prototype = new Empty();
            // Clean up dangling references.
            Empty.prototype = null;
        }

        // TODO
        // 18. Set the [[Extensible]] internal property of F to true.

        // TODO
        // 19. Let thrower be the [[ThrowTypeError]] function Object (13.2.3).
        // 20. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "caller", PropertyDescriptor {[[Get]]: thrower, [[Set]]:
        //   thrower, [[Enumerable]]: false, [[Configurable]]: false}, and
        //   false.
        // 21. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "arguments", PropertyDescriptor {[[Get]]: thrower,
        //   [[Set]]: thrower, [[Enumerable]]: false, [[Configurable]]: false},
        //   and false.

        // TODO
        // NOTE Function objects created using Function.prototype.bind do not
        // have a prototype property or the [[Code]], [[FormalParameters]], and
        // [[Scope]] internal properties.
        // XXX can't delete prototype in pure-js.

        // 22. Return F.
        return bound;
    }
});

// _Please note: Shortcuts are defined after `Function.prototype.bind` as we
// use it in defining shortcuts.
var owns = call.bind(ObjectPrototype.hasOwnProperty);
var toStr = call.bind(ObjectPrototype.toString);
var arraySlice = call.bind(array_slice);
var arraySliceApply = apply.bind(array_slice);
var strSlice = call.bind(StringPrototype.slice);
var strSplit = call.bind(StringPrototype.split);
var strIndexOf = call.bind(StringPrototype.indexOf);
var pushCall = call.bind(array_push);
var isEnum = call.bind(ObjectPrototype.propertyIsEnumerable);
var arraySort = call.bind(ArrayPrototype.sort);

//
// Array
// =====
//

var isArray = $Array.isArray || function isArray(obj) {
    return toStr(obj) === '[object Array]';
};

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.13
// Return len+argCount.
// [bugfix, ielt8]
// IE < 8 bug: [].unshift(0) === undefined but should be "1"
var hasUnshiftReturnValueBug = [].unshift(0) !== 1;
defineProperties(ArrayPrototype, {
    unshift: function () {
        array_unshift.apply(this, arguments);
        return this.length;
    }
}, hasUnshiftReturnValueBug);

// ES5 15.4.3.2
// http://es5.github.com/#x15.4.3.2
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/isArray
defineProperties($Array, { isArray: isArray });

// The IsCallable() check in the Array functions
// has been replaced with a strict check on the
// internal class of the object to trap cases where
// the provided function was actually a regular
// expression literal, which in V8 and
// JavaScriptCore is a typeof "function".  Only in
// V8 are regular expression literals permitted as
// reduce parameters, so it is desirable in the
// general case for the shim to match the more
// strict and common behavior of rejecting regular
// expressions.

// ES5 15.4.4.18
// http://es5.github.com/#x15.4.4.18
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/array/forEach

// Check failure of by-index access of string characters (IE < 9)
// and failure of `0 in boxedString` (Rhino)
var boxedString = $Object('a');
var splitString = boxedString[0] !== 'a' || !(0 in boxedString);

var properlyBoxesContext = function properlyBoxed(method) {
    // Check node 0.6.21 bug where third parameter is not boxed
    var properlyBoxesNonStrict = true;
    var properlyBoxesStrict = true;
    var threwException = false;
    if (method) {
        try {
            method.call('foo', function (_, __, context) {
                if (typeof context !== 'object') { properlyBoxesNonStrict = false; }
            });

            method.call([1], function () {
                'use strict';

                properlyBoxesStrict = typeof this === 'string';
            }, 'x');
        } catch (e) {
            threwException = true;
        }
    }
    return !!method && !threwException && properlyBoxesNonStrict && properlyBoxesStrict;
};

defineProperties(ArrayPrototype, {
    forEach: function forEach(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var i = -1;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
          T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.forEach callback must be a function');
        }

        while (++i < length) {
            if (i in self) {
                // Invoke the callback function with call, passing arguments:
                // context, property value, property key, thisArg object
                if (typeof T === 'undefined') {
                    callbackfn(self[i], i, object);
                } else {
                    callbackfn.call(T, self[i], i, object);
                }
            }
        }
    }
}, !properlyBoxesContext(ArrayPrototype.forEach));

// ES5 15.4.4.19
// http://es5.github.com/#x15.4.4.19
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/map
defineProperties(ArrayPrototype, {
    map: function map(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var result = $Array(length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.map callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                if (typeof T === 'undefined') {
                    result[i] = callbackfn(self[i], i, object);
                } else {
                    result[i] = callbackfn.call(T, self[i], i, object);
                }
            }
        }
        return result;
    }
}, !properlyBoxesContext(ArrayPrototype.map));

// ES5 15.4.4.20
// http://es5.github.com/#x15.4.4.20
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/filter
defineProperties(ArrayPrototype, {
    filter: function filter(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var result = [];
        var value;
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.filter callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                value = self[i];
                if (typeof T === 'undefined' ? callbackfn(value, i, object) : callbackfn.call(T, value, i, object)) {
                    pushCall(result, value);
                }
            }
        }
        return result;
    }
}, !properlyBoxesContext(ArrayPrototype.filter));

// ES5 15.4.4.16
// http://es5.github.com/#x15.4.4.16
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/every
defineProperties(ArrayPrototype, {
    every: function every(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.every callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self && !(typeof T === 'undefined' ? callbackfn(self[i], i, object) : callbackfn.call(T, self[i], i, object))) {
                return false;
            }
        }
        return true;
    }
}, !properlyBoxesContext(ArrayPrototype.every));

// ES5 15.4.4.17
// http://es5.github.com/#x15.4.4.17
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/some
defineProperties(ArrayPrototype, {
    some: function some(callbackfn/*, thisArg */) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.some callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self && (typeof T === 'undefined' ? callbackfn(self[i], i, object) : callbackfn.call(T, self[i], i, object))) {
                return true;
            }
        }
        return false;
    }
}, !properlyBoxesContext(ArrayPrototype.some));

// ES5 15.4.4.21
// http://es5.github.com/#x15.4.4.21
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduce
var reduceCoercesToObject = false;
if (ArrayPrototype.reduce) {
    reduceCoercesToObject = typeof ArrayPrototype.reduce.call('es5', function (_, __, ___, list) { return list; }) === 'object';
}
defineProperties(ArrayPrototype, {
    reduce: function reduce(callbackfn/*, initialValue*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.reduce callback must be a function');
        }

        // no value to return if no initial value and an empty array
        if (length === 0 && arguments.length === 1) {
            throw new TypeError('reduce of empty array with no initial value');
        }

        var i = 0;
        var result;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i++];
                    break;
                }

                // if array contains no values, no initial value to return
                if (++i >= length) {
                    throw new TypeError('reduce of empty array with no initial value');
                }
            } while (true);
        }

        for (; i < length; i++) {
            if (i in self) {
                result = callbackfn(result, self[i], i, object);
            }
        }

        return result;
    }
}, !reduceCoercesToObject);

// ES5 15.4.4.22
// http://es5.github.com/#x15.4.4.22
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduceRight
var reduceRightCoercesToObject = false;
if (ArrayPrototype.reduceRight) {
    reduceRightCoercesToObject = typeof ArrayPrototype.reduceRight.call('es5', function (_, __, ___, list) { return list; }) === 'object';
}
defineProperties(ArrayPrototype, {
    reduceRight: function reduceRight(callbackfn/*, initial*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.reduceRight callback must be a function');
        }

        // no value to return if no initial value, empty array
        if (length === 0 && arguments.length === 1) {
            throw new TypeError('reduceRight of empty array with no initial value');
        }

        var result;
        var i = length - 1;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i--];
                    break;
                }

                // if array contains no values, no initial value to return
                if (--i < 0) {
                    throw new TypeError('reduceRight of empty array with no initial value');
                }
            } while (true);
        }

        if (i < 0) {
            return result;
        }

        do {
            if (i in self) {
                result = callbackfn(result, self[i], i, object);
            }
        } while (i--);

        return result;
    }
}, !reduceRightCoercesToObject);

// ES5 15.4.4.14
// http://es5.github.com/#x15.4.4.14
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/indexOf
var hasFirefox2IndexOfBug = ArrayPrototype.indexOf && [0, 1].indexOf(1, 2) !== -1;
defineProperties(ArrayPrototype, {
    indexOf: function indexOf(searchElement/*, fromIndex */) {
        var self = splitString && isString(this) ? strSplit(this, '') : ES.ToObject(this);
        var length = ES.ToUint32(self.length);

        if (length === 0) {
            return -1;
        }

        var i = 0;
        if (arguments.length > 1) {
            i = ES.ToInteger(arguments[1]);
        }

        // handle negative indices
        i = i >= 0 ? i : max(0, length + i);
        for (; i < length; i++) {
            if (i in self && self[i] === searchElement) {
                return i;
            }
        }
        return -1;
    }
}, hasFirefox2IndexOfBug);

// ES5 15.4.4.15
// http://es5.github.com/#x15.4.4.15
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/lastIndexOf
var hasFirefox2LastIndexOfBug = ArrayPrototype.lastIndexOf && [0, 1].lastIndexOf(0, -3) !== -1;
defineProperties(ArrayPrototype, {
    lastIndexOf: function lastIndexOf(searchElement/*, fromIndex */) {
        var self = splitString && isString(this) ? strSplit(this, '') : ES.ToObject(this);
        var length = ES.ToUint32(self.length);

        if (length === 0) {
            return -1;
        }
        var i = length - 1;
        if (arguments.length > 1) {
            i = min(i, ES.ToInteger(arguments[1]));
        }
        // handle negative indices
        i = i >= 0 ? i : length - Math.abs(i);
        for (; i >= 0; i--) {
            if (i in self && searchElement === self[i]) {
                return i;
            }
        }
        return -1;
    }
}, hasFirefox2LastIndexOfBug);

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.12
var spliceNoopReturnsEmptyArray = (function () {
    var a = [1, 2];
    var result = a.splice();
    return a.length === 2 && isArray(result) && result.length === 0;
}());
defineProperties(ArrayPrototype, {
    // Safari 5.0 bug where .splice() returns undefined
    splice: function splice(start, deleteCount) {
        if (arguments.length === 0) {
            return [];
        } else {
            return array_splice.apply(this, arguments);
        }
    }
}, !spliceNoopReturnsEmptyArray);

var spliceWorksWithEmptyObject = (function () {
    var obj = {};
    ArrayPrototype.splice.call(obj, 0, 0, 1);
    return obj.length === 1;
}());
defineProperties(ArrayPrototype, {
    splice: function splice(start, deleteCount) {
        if (arguments.length === 0) { return []; }
        var args = arguments;
        this.length = max(ES.ToInteger(this.length), 0);
        if (arguments.length > 0 && typeof deleteCount !== 'number') {
            args = arraySlice(arguments);
            if (args.length < 2) {
                pushCall(args, this.length - start);
            } else {
                args[1] = ES.ToInteger(deleteCount);
            }
        }
        return array_splice.apply(this, args);
    }
}, !spliceWorksWithEmptyObject);
var spliceWorksWithLargeSparseArrays = (function () {
    // Per https://github.com/es-shims/es5-shim/issues/295
    // Safari 7/8 breaks with sparse arrays of size 1e5 or greater
    var arr = new $Array(1e5);
    // note: the index MUST be 8 or larger or the test will false pass
    arr[8] = 'x';
    arr.splice(1, 1);
    // note: this test must be defined *after* the indexOf shim
    // per https://github.com/es-shims/es5-shim/issues/313
    return arr.indexOf('x') === 7;
}());
var spliceWorksWithSmallSparseArrays = (function () {
    // Per https://github.com/es-shims/es5-shim/issues/295
    // Opera 12.15 breaks on this, no idea why.
    var n = 256;
    var arr = [];
    arr[n] = 'a';
    arr.splice(n + 1, 0, 'b');
    return arr[n] === 'a';
}());
defineProperties(ArrayPrototype, {
    splice: function splice(start, deleteCount) {
        var O = ES.ToObject(this);
        var A = [];
        var len = ES.ToUint32(O.length);
        var relativeStart = ES.ToInteger(start);
        var actualStart = relativeStart < 0 ? max((len + relativeStart), 0) : min(relativeStart, len);
        var actualDeleteCount = min(max(ES.ToInteger(deleteCount), 0), len - actualStart);

        var k = 0;
        var from;
        while (k < actualDeleteCount) {
            from = $String(actualStart + k);
            if (owns(O, from)) {
                A[k] = O[from];
            }
            k += 1;
        }

        var items = arraySlice(arguments, 2);
        var itemCount = items.length;
        var to;
        if (itemCount < actualDeleteCount) {
            k = actualStart;
            var maxK = len - actualDeleteCount;
            while (k < maxK) {
                from = $String(k + actualDeleteCount);
                to = $String(k + itemCount);
                if (owns(O, from)) {
                    O[to] = O[from];
                } else {
                    delete O[to];
                }
                k += 1;
            }
            k = len;
            var minK = len - actualDeleteCount + itemCount;
            while (k > minK) {
                delete O[k - 1];
                k -= 1;
            }
        } else if (itemCount > actualDeleteCount) {
            k = len - actualDeleteCount;
            while (k > actualStart) {
                from = $String(k + actualDeleteCount - 1);
                to = $String(k + itemCount - 1);
                if (owns(O, from)) {
                    O[to] = O[from];
                } else {
                    delete O[to];
                }
                k -= 1;
            }
        }
        k = actualStart;
        for (var i = 0; i < items.length; ++i) {
            O[k] = items[i];
            k += 1;
        }
        O.length = len - actualDeleteCount + itemCount;

        return A;
    }
}, !spliceWorksWithLargeSparseArrays || !spliceWorksWithSmallSparseArrays);

var originalJoin = ArrayPrototype.join;
var hasStringJoinBug;
try {
    hasStringJoinBug = Array.prototype.join.call('123', ',') !== '1,2,3';
} catch (e) {
    hasStringJoinBug = true;
}
if (hasStringJoinBug) {
    defineProperties(ArrayPrototype, {
        join: function join(separator) {
            var sep = typeof separator === 'undefined' ? ',' : separator;
            return originalJoin.call(isString(this) ? strSplit(this, '') : this, sep);
        }
    }, hasStringJoinBug);
}

var hasJoinUndefinedBug = [1, 2].join(undefined) !== '1,2';
if (hasJoinUndefinedBug) {
    defineProperties(ArrayPrototype, {
        join: function join(separator) {
            var sep = typeof separator === 'undefined' ? ',' : separator;
            return originalJoin.call(this, sep);
        }
    }, hasJoinUndefinedBug);
}

var pushShim = function push(item) {
    var O = ES.ToObject(this);
    var n = ES.ToUint32(O.length);
    var i = 0;
    while (i < arguments.length) {
        O[n + i] = arguments[i];
        i += 1;
    }
    O.length = n + i;
    return n + i;
};

var pushIsNotGeneric = (function () {
    var obj = {};
    var result = Array.prototype.push.call(obj, undefined);
    return result !== 1 || obj.length !== 1 || typeof obj[0] !== 'undefined' || !owns(obj, 0);
}());
defineProperties(ArrayPrototype, {
    push: function push(item) {
        if (isArray(this)) {
            return array_push.apply(this, arguments);
        }
        return pushShim.apply(this, arguments);
    }
}, pushIsNotGeneric);

// This fixes a very weird bug in Opera 10.6 when pushing `undefined
var pushUndefinedIsWeird = (function () {
    var arr = [];
    var result = arr.push(undefined);
    return result !== 1 || arr.length !== 1 || typeof arr[0] !== 'undefined' || !owns(arr, 0);
}());
defineProperties(ArrayPrototype, { push: pushShim }, pushUndefinedIsWeird);

// ES5 15.2.3.14
// http://es5.github.io/#x15.4.4.10
// Fix boxed string bug
defineProperties(ArrayPrototype, {
    slice: function (start, end) {
        var arr = isString(this) ? strSplit(this, '') : this;
        return arraySliceApply(arr, arguments);
    }
}, splitString);

var sortIgnoresNonFunctions = (function () {
    try {
        [1, 2].sort(null);
        [1, 2].sort({});
        return true;
    } catch (e) { /**/ }
    return false;
}());
var sortThrowsOnRegex = (function () {
    // this is a problem in Firefox 4, in which `typeof /a/ === 'function'`
    try {
        [1, 2].sort(/a/);
        return false;
    } catch (e) { /**/ }
    return true;
}());
var sortIgnoresUndefined = (function () {
    // applies in IE 8, for one.
    try {
        [1, 2].sort(undefined);
        return true;
    } catch (e) { /**/ }
    return false;
}());
defineProperties(ArrayPrototype, {
    sort: function sort(compareFn) {
        if (typeof compareFn === 'undefined') {
            return arraySort(this);
        }
        if (!isCallable(compareFn)) {
            throw new TypeError('Array.prototype.sort callback must be a function');
        }
        return arraySort(this, compareFn);
    }
}, sortIgnoresNonFunctions || !sortIgnoresUndefined || !sortThrowsOnRegex);

//
// Object
// ======
//

// ES5 15.2.3.14
// http://es5.github.com/#x15.2.3.14

// http://whattheheadsaid.com/2010/10/a-safer-object-keys-compatibility-implementation
var hasDontEnumBug = !({ 'toString': null }).propertyIsEnumerable('toString');
var hasProtoEnumBug = function () {}.propertyIsEnumerable('prototype');
var hasStringEnumBug = !owns('x', '0');
var equalsConstructorPrototype = function (o) {
    var ctor = o.constructor;
    return ctor && ctor.prototype === o;
};
var blacklistedKeys = {
    $window: true,
    $console: true,
    $parent: true,
    $self: true,
    $frame: true,
    $frames: true,
    $frameElement: true,
    $webkitIndexedDB: true,
    $webkitStorageInfo: true,
    $external: true
};
var hasAutomationEqualityBug = (function () {
    /* globals window */
    if (typeof window === 'undefined') { return false; }
    for (var k in window) {
        try {
            if (!blacklistedKeys['$' + k] && owns(window, k) && window[k] !== null && typeof window[k] === 'object') {
                equalsConstructorPrototype(window[k]);
            }
        } catch (e) {
            return true;
        }
    }
    return false;
}());
var equalsConstructorPrototypeIfNotBuggy = function (object) {
    if (typeof window === 'undefined' || !hasAutomationEqualityBug) { return equalsConstructorPrototype(object); }
    try {
        return equalsConstructorPrototype(object);
    } catch (e) {
        return false;
    }
};
var dontEnums = [
    'toString',
    'toLocaleString',
    'valueOf',
    'hasOwnProperty',
    'isPrototypeOf',
    'propertyIsEnumerable',
    'constructor'
];
var dontEnumsLength = dontEnums.length;

// taken directly from https://github.com/ljharb/is-arguments/blob/master/index.js
// can be replaced with require('is-arguments') if we ever use a build process instead
var isStandardArguments = function isArguments(value) {
    return toStr(value) === '[object Arguments]';
};
var isLegacyArguments = function isArguments(value) {
    return value !== null &&
        typeof value === 'object' &&
        typeof value.length === 'number' &&
        value.length >= 0 &&
        !isArray(value) &&
        isCallable(value.callee);
};
var isArguments = isStandardArguments(arguments) ? isStandardArguments : isLegacyArguments;

defineProperties($Object, {
    keys: function keys(object) {
        var isFn = isCallable(object);
        var isArgs = isArguments(object);
        var isObject = object !== null && typeof object === 'object';
        var isStr = isObject && isString(object);

        if (!isObject && !isFn && !isArgs) {
            throw new TypeError('Object.keys called on a non-object');
        }

        var theKeys = [];
        var skipProto = hasProtoEnumBug && isFn;
        if ((isStr && hasStringEnumBug) || isArgs) {
            for (var i = 0; i < object.length; ++i) {
                pushCall(theKeys, $String(i));
            }
        }

        if (!isArgs) {
            for (var name in object) {
                if (!(skipProto && name === 'prototype') && owns(object, name)) {
                    pushCall(theKeys, $String(name));
                }
            }
        }

        if (hasDontEnumBug) {
            var skipConstructor = equalsConstructorPrototypeIfNotBuggy(object);
            for (var j = 0; j < dontEnumsLength; j++) {
                var dontEnum = dontEnums[j];
                if (!(skipConstructor && dontEnum === 'constructor') && owns(object, dontEnum)) {
                    pushCall(theKeys, dontEnum);
                }
            }
        }
        return theKeys;
    }
});

var keysWorksWithArguments = $Object.keys && (function () {
    // Safari 5.0 bug
    return $Object.keys(arguments).length === 2;
}(1, 2));
var keysHasArgumentsLengthBug = $Object.keys && (function () {
    var argKeys = $Object.keys(arguments);
    return arguments.length !== 1 || argKeys.length !== 1 || argKeys[0] !== 1;
}(1));
var originalKeys = $Object.keys;
defineProperties($Object, {
    keys: function keys(object) {
        if (isArguments(object)) {
            return originalKeys(arraySlice(object));
        } else {
            return originalKeys(object);
        }
    }
}, !keysWorksWithArguments || keysHasArgumentsLengthBug);

//
// Date
// ====
//

var hasNegativeMonthYearBug = new Date(-3509827329600292).getUTCMonth() !== 0;
var aNegativeTestDate = new Date(-1509842289600292);
var aPositiveTestDate = new Date(1449662400000);
var hasToUTCStringFormatBug = aNegativeTestDate.toUTCString() !== 'Mon, 01 Jan -45875 11:59:59 GMT';
var hasToDateStringFormatBug;
var hasToStringFormatBug;
var timeZoneOffset = aNegativeTestDate.getTimezoneOffset();
if (timeZoneOffset < -720) {
    hasToDateStringFormatBug = aNegativeTestDate.toDateString() !== 'Tue Jan 02 -45875';
    hasToStringFormatBug = !(/^Thu Dec 10 2015 \d\d:\d\d:\d\d GMT[-\+]\d\d\d\d(?: |$)/).test(aPositiveTestDate.toString());
} else {
    hasToDateStringFormatBug = aNegativeTestDate.toDateString() !== 'Mon Jan 01 -45875';
    hasToStringFormatBug = !(/^Wed Dec 09 2015 \d\d:\d\d:\d\d GMT[-\+]\d\d\d\d(?: |$)/).test(aPositiveTestDate.toString());
}

var originalGetFullYear = call.bind(Date.prototype.getFullYear);
var originalGetMonth = call.bind(Date.prototype.getMonth);
var originalGetDate = call.bind(Date.prototype.getDate);
var originalGetUTCFullYear = call.bind(Date.prototype.getUTCFullYear);
var originalGetUTCMonth = call.bind(Date.prototype.getUTCMonth);
var originalGetUTCDate = call.bind(Date.prototype.getUTCDate);
var originalGetUTCDay = call.bind(Date.prototype.getUTCDay);
var originalGetUTCHours = call.bind(Date.prototype.getUTCHours);
var originalGetUTCMinutes = call.bind(Date.prototype.getUTCMinutes);
var originalGetUTCSeconds = call.bind(Date.prototype.getUTCSeconds);
var originalGetUTCMilliseconds = call.bind(Date.prototype.getUTCMilliseconds);
var dayName = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
var monthName = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
var daysInMonth = function daysInMonth(month, year) {
    return originalGetDate(new Date(year, month, 0));
};

defineProperties(Date.prototype, {
    getFullYear: function getFullYear() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        if (year < 0 && originalGetMonth(this) > 11) {
            return year + 1;
        }
        return year;
    },
    getMonth: function getMonth() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        var month = originalGetMonth(this);
        if (year < 0 && month > 11) {
            return 0;
        }
        return month;
    },
    getDate: function getDate() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        var month = originalGetMonth(this);
        var date = originalGetDate(this);
        if (year < 0 && month > 11) {
            if (month === 12) {
                return date;
            }
            var days = daysInMonth(0, year + 1);
            return (days - date) + 1;
        }
        return date;
    },
    getUTCFullYear: function getUTCFullYear() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        if (year < 0 && originalGetUTCMonth(this) > 11) {
            return year + 1;
        }
        return year;
    },
    getUTCMonth: function getUTCMonth() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        var month = originalGetUTCMonth(this);
        if (year < 0 && month > 11) {
            return 0;
        }
        return month;
    },
    getUTCDate: function getUTCDate() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        var month = originalGetUTCMonth(this);
        var date = originalGetUTCDate(this);
        if (year < 0 && month > 11) {
            if (month === 12) {
                return date;
            }
            var days = daysInMonth(0, year + 1);
            return (days - date) + 1;
        }
        return date;
    }
}, hasNegativeMonthYearBug);

defineProperties(Date.prototype, {
    toUTCString: function toUTCString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = originalGetUTCDay(this);
        var date = originalGetUTCDate(this);
        var month = originalGetUTCMonth(this);
        var year = originalGetUTCFullYear(this);
        var hour = originalGetUTCHours(this);
        var minute = originalGetUTCMinutes(this);
        var second = originalGetUTCSeconds(this);
        return dayName[day] + ', ' +
            (date < 10 ? '0' + date : date) + ' ' +
            monthName[month] + ' ' +
            year + ' ' +
            (hour < 10 ? '0' + hour : hour) + ':' +
            (minute < 10 ? '0' + minute : minute) + ':' +
            (second < 10 ? '0' + second : second) + ' GMT';
    }
}, hasNegativeMonthYearBug || hasToUTCStringFormatBug);

// Opera 12 has `,`
defineProperties(Date.prototype, {
    toDateString: function toDateString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = this.getDay();
        var date = this.getDate();
        var month = this.getMonth();
        var year = this.getFullYear();
        return dayName[day] + ' ' +
            monthName[month] + ' ' +
            (date < 10 ? '0' + date : date) + ' ' +
            year;
    }
}, hasNegativeMonthYearBug || hasToDateStringFormatBug);

// can't use defineProperties here because of toString enumeration issue in IE <= 8
if (hasNegativeMonthYearBug || hasToStringFormatBug) {
    Date.prototype.toString = function toString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = this.getDay();
        var date = this.getDate();
        var month = this.getMonth();
        var year = this.getFullYear();
        var hour = this.getHours();
        var minute = this.getMinutes();
        var second = this.getSeconds();
        var timezoneOffset = this.getTimezoneOffset();
        var hoursOffset = Math.floor(Math.abs(timezoneOffset) / 60);
        var minutesOffset = Math.floor(Math.abs(timezoneOffset) % 60);
        return dayName[day] + ' ' +
            monthName[month] + ' ' +
            (date < 10 ? '0' + date : date) + ' ' +
            year + ' ' +
            (hour < 10 ? '0' + hour : hour) + ':' +
            (minute < 10 ? '0' + minute : minute) + ':' +
            (second < 10 ? '0' + second : second) + ' GMT' +
            (timezoneOffset > 0 ? '-' : '+') +
            (hoursOffset < 10 ? '0' + hoursOffset : hoursOffset) +
            (minutesOffset < 10 ? '0' + minutesOffset : minutesOffset);
    };
    if (supportsDescriptors) {
        $Object.defineProperty(Date.prototype, 'toString', {
            configurable: true,
            enumerable: false,
            writable: true
        });
    }
}

// ES5 15.9.5.43
// http://es5.github.com/#x15.9.5.43
// This function returns a String value represent the instance in time
// represented by this Date object. The format of the String is the Date Time
// string format defined in 15.9.1.15. All fields are present in the String.
// The time zone is always UTC, denoted by the suffix Z. If the time value of
// this object is not a finite Number a RangeError exception is thrown.
var negativeDate = -62198755200000;
var negativeYearString = '-000001';
var hasNegativeDateBug = Date.prototype.toISOString && new Date(negativeDate).toISOString().indexOf(negativeYearString) === -1;
var hasSafari51DateBug = Date.prototype.toISOString && new Date(-1).toISOString() !== '1969-12-31T23:59:59.999Z';

var getTime = call.bind(Date.prototype.getTime);

defineProperties(Date.prototype, {
    toISOString: function toISOString() {
        if (!isFinite(this) || !isFinite(getTime(this))) {
            // Adope Photoshop requires the second check.
            throw new RangeError('Date.prototype.toISOString called on non-finite value.');
        }

        var year = originalGetUTCFullYear(this);

        var month = originalGetUTCMonth(this);
        // see https://github.com/es-shims/es5-shim/issues/111
        year += Math.floor(month / 12);
        month = (month % 12 + 12) % 12;

        // the date time string format is specified in 15.9.1.15.
        var result = [month + 1, originalGetUTCDate(this), originalGetUTCHours(this), originalGetUTCMinutes(this), originalGetUTCSeconds(this)];
        year = (
            (year < 0 ? '-' : (year > 9999 ? '+' : '')) +
            strSlice('00000' + Math.abs(year), (0 <= year && year <= 9999) ? -4 : -6)
        );

        for (var i = 0; i < result.length; ++i) {
          // pad months, days, hours, minutes, and seconds to have two digits.
          result[i] = strSlice('00' + result[i], -2);
        }
        // pad milliseconds to have three digits.
        return (
            year + '-' + arraySlice(result, 0, 2).join('-') +
            'T' + arraySlice(result, 2).join(':') + '.' +
            strSlice('000' + originalGetUTCMilliseconds(this), -3) + 'Z'
        );
    }
}, hasNegativeDateBug || hasSafari51DateBug);

// ES5 15.9.5.44
// http://es5.github.com/#x15.9.5.44
// This function provides a String representation of a Date object for use by
// JSON.stringify (15.12.3).
var dateToJSONIsSupported = (function () {
    try {
        return Date.prototype.toJSON &&
            new Date(NaN).toJSON() === null &&
            new Date(negativeDate).toJSON().indexOf(negativeYearString) !== -1 &&
            Date.prototype.toJSON.call({ // generic
                toISOString: function () { return true; }
            });
    } catch (e) {
        return false;
    }
}());
if (!dateToJSONIsSupported) {
    Date.prototype.toJSON = function toJSON(key) {
        // When the toJSON method is called with argument key, the following
        // steps are taken:

        // 1.  Let O be the result of calling ToObject, giving it the this
        // value as its argument.
        // 2. Let tv be ES.ToPrimitive(O, hint Number).
        var O = $Object(this);
        var tv = ES.ToPrimitive(O);
        // 3. If tv is a Number and is not finite, return null.
        if (typeof tv === 'number' && !isFinite(tv)) {
            return null;
        }
        // 4. Let toISO be the result of calling the [[Get]] internal method of
        // O with argument "toISOString".
        var toISO = O.toISOString;
        // 5. If IsCallable(toISO) is false, throw a TypeError exception.
        if (!isCallable(toISO)) {
            throw new TypeError('toISOString property is not callable');
        }
        // 6. Return the result of calling the [[Call]] internal method of
        //  toISO with O as the this value and an empty argument list.
        return toISO.call(O);

        // NOTE 1 The argument is ignored.

        // NOTE 2 The toJSON function is intentionally generic; it does not
        // require that its this value be a Date object. Therefore, it can be
        // transferred to other kinds of objects for use as a method. However,
        // it does require that any such object have a toISOString method. An
        // object is free to use the argument key to filter its
        // stringification.
    };
}

// ES5 15.9.4.2
// http://es5.github.com/#x15.9.4.2
// based on work shared by Daniel Friesen (dantman)
// http://gist.github.com/303249
var supportsExtendedYears = Date.parse('+033658-09-27T01:46:40.000Z') === 1e15;
var acceptsInvalidDates = !isNaN(Date.parse('2012-04-04T24:00:00.500Z')) || !isNaN(Date.parse('2012-11-31T23:59:59.000Z')) || !isNaN(Date.parse('2012-12-31T23:59:60.000Z'));
var doesNotParseY2KNewYear = isNaN(Date.parse('2000-01-01T00:00:00.000Z'));
if (doesNotParseY2KNewYear || acceptsInvalidDates || !supportsExtendedYears) {
    // XXX global assignment won't work in embeddings that use
    // an alternate object for the context.
    /* global Date: true */
    /* eslint-disable no-undef */
    var maxSafeUnsigned32Bit = Math.pow(2, 31) - 1;
    var hasSafariSignedIntBug = isActualNaN(new Date(1970, 0, 1, 0, 0, 0, maxSafeUnsigned32Bit + 1).getTime());
    /* eslint-disable no-implicit-globals */
    Date = (function (NativeDate) {
    /* eslint-enable no-implicit-globals */
    /* eslint-enable no-undef */
        // Date.length === 7
        var DateShim = function Date(Y, M, D, h, m, s, ms) {
            var length = arguments.length;
            var date;
            if (this instanceof NativeDate) {
                var seconds = s;
                var millis = ms;
                if (hasSafariSignedIntBug && length >= 7 && ms > maxSafeUnsigned32Bit) {
                    // work around a Safari 8/9 bug where it treats the seconds as signed
                    var msToShift = Math.floor(ms / maxSafeUnsigned32Bit) * maxSafeUnsigned32Bit;
                    var sToShift = Math.floor(msToShift / 1e3);
                    seconds += sToShift;
                    millis -= sToShift * 1e3;
                }
                date = length === 1 && $String(Y) === Y ? // isString(Y)
                    // We explicitly pass it through parse:
                    new NativeDate(DateShim.parse(Y)) :
                    // We have to manually make calls depending on argument
                    // length here
                    length >= 7 ? new NativeDate(Y, M, D, h, m, seconds, millis) :
                    length >= 6 ? new NativeDate(Y, M, D, h, m, seconds) :
                    length >= 5 ? new NativeDate(Y, M, D, h, m) :
                    length >= 4 ? new NativeDate(Y, M, D, h) :
                    length >= 3 ? new NativeDate(Y, M, D) :
                    length >= 2 ? new NativeDate(Y, M) :
                    length >= 1 ? new NativeDate(Y instanceof NativeDate ? +Y : Y) :
                                  new NativeDate();
            } else {
                date = NativeDate.apply(this, arguments);
            }
            if (!isPrimitive(date)) {
              // Prevent mixups with unfixed Date object
              defineProperties(date, { constructor: DateShim }, true);
            }
            return date;
        };

        // 15.9.1.15 Date Time String Format.
        var isoDateExpression = new RegExp('^' +
            '(\\d{4}|[+-]\\d{6})' + // four-digit year capture or sign +
                                      // 6-digit extended year
            '(?:-(\\d{2})' + // optional month capture
            '(?:-(\\d{2})' + // optional day capture
            '(?:' + // capture hours:minutes:seconds.milliseconds
                'T(\\d{2})' + // hours capture
                ':(\\d{2})' + // minutes capture
                '(?:' + // optional :seconds.milliseconds
                    ':(\\d{2})' + // seconds capture
                    '(?:(\\.\\d{1,}))?' + // milliseconds capture
                ')?' +
            '(' + // capture UTC offset component
                'Z|' + // UTC capture
                '(?:' + // offset specifier +/-hours:minutes
                    '([-+])' + // sign capture
                    '(\\d{2})' + // hours offset capture
                    ':(\\d{2})' + // minutes offset capture
                ')' +
            ')?)?)?)?' +
        '$');

        var months = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365];

        var dayFromMonth = function dayFromMonth(year, month) {
            var t = month > 1 ? 1 : 0;
            return (
                months[month] +
                Math.floor((year - 1969 + t) / 4) -
                Math.floor((year - 1901 + t) / 100) +
                Math.floor((year - 1601 + t) / 400) +
                365 * (year - 1970)
            );
        };

        var toUTC = function toUTC(t) {
            var s = 0;
            var ms = t;
            if (hasSafariSignedIntBug && ms > maxSafeUnsigned32Bit) {
                // work around a Safari 8/9 bug where it treats the seconds as signed
                var msToShift = Math.floor(ms / maxSafeUnsigned32Bit) * maxSafeUnsigned32Bit;
                var sToShift = Math.floor(msToShift / 1e3);
                s += sToShift;
                ms -= sToShift * 1e3;
            }
            return $Number(new NativeDate(1970, 0, 1, 0, 0, s, ms));
        };

        // Copy any custom methods a 3rd party library may have added
        for (var key in NativeDate) {
            if (owns(NativeDate, key)) {
                DateShim[key] = NativeDate[key];
            }
        }

        // Copy "native" methods explicitly; they may be non-enumerable
        defineProperties(DateShim, {
            now: NativeDate.now,
            UTC: NativeDate.UTC
        }, true);
        DateShim.prototype = NativeDate.prototype;
        defineProperties(DateShim.prototype, {
            constructor: DateShim
        }, true);

        // Upgrade Date.parse to handle simplified ISO 8601 strings
        var parseShim = function parse(string) {
            var match = isoDateExpression.exec(string);
            if (match) {
                // parse months, days, hours, minutes, seconds, and milliseconds
                // provide default values if necessary
                // parse the UTC offset component
                var year = $Number(match[1]),
                    month = $Number(match[2] || 1) - 1,
                    day = $Number(match[3] || 1) - 1,
                    hour = $Number(match[4] || 0),
                    minute = $Number(match[5] || 0),
                    second = $Number(match[6] || 0),
                    millisecond = Math.floor($Number(match[7] || 0) * 1000),
                    // When time zone is missed, local offset should be used
                    // (ES 5.1 bug)
                    // see https://bugs.ecmascript.org/show_bug.cgi?id=112
                    isLocalTime = Boolean(match[4] && !match[8]),
                    signOffset = match[9] === '-' ? 1 : -1,
                    hourOffset = $Number(match[10] || 0),
                    minuteOffset = $Number(match[11] || 0),
                    result;
                var hasMinutesOrSecondsOrMilliseconds = minute > 0 || second > 0 || millisecond > 0;
                if (
                    hour < (hasMinutesOrSecondsOrMilliseconds ? 24 : 25) &&
                    minute < 60 && second < 60 && millisecond < 1000 &&
                    month > -1 && month < 12 && hourOffset < 24 &&
                    minuteOffset < 60 && // detect invalid offsets
                    day > -1 &&
                    day < (dayFromMonth(year, month + 1) - dayFromMonth(year, month))
                ) {
                    result = (
                        (dayFromMonth(year, month) + day) * 24 +
                        hour +
                        hourOffset * signOffset
                    ) * 60;
                    result = (
                        (result + minute + minuteOffset * signOffset) * 60 +
                        second
                    ) * 1000 + millisecond;
                    if (isLocalTime) {
                        result = toUTC(result);
                    }
                    if (-8.64e15 <= result && result <= 8.64e15) {
                        return result;
                    }
                }
                return NaN;
            }
            return NativeDate.parse.apply(this, arguments);
        };
        defineProperties(DateShim, { parse: parseShim });

        return DateShim;
    }(Date));
    /* global Date: false */
}

// ES5 15.9.4.4
// http://es5.github.com/#x15.9.4.4
if (!Date.now) {
    Date.now = function now() {
        return new Date().getTime();
    };
}

//
// Number
// ======
//

// ES5.1 15.7.4.5
// http://es5.github.com/#x15.7.4.5
var hasToFixedBugs = NumberPrototype.toFixed && (
  (0.00008).toFixed(3) !== '0.000' ||
  (0.9).toFixed(0) !== '1' ||
  (1.255).toFixed(2) !== '1.25' ||
  (1000000000000000128).toFixed(0) !== '1000000000000000128'
);

var toFixedHelpers = {
  base: 1e7,
  size: 6,
  data: [0, 0, 0, 0, 0, 0],
  multiply: function multiply(n, c) {
      var i = -1;
      var c2 = c;
      while (++i < toFixedHelpers.size) {
          c2 += n * toFixedHelpers.data[i];
          toFixedHelpers.data[i] = c2 % toFixedHelpers.base;
          c2 = Math.floor(c2 / toFixedHelpers.base);
      }
  },
  divide: function divide(n) {
      var i = toFixedHelpers.size;
      var c = 0;
      while (--i >= 0) {
          c += toFixedHelpers.data[i];
          toFixedHelpers.data[i] = Math.floor(c / n);
          c = (c % n) * toFixedHelpers.base;
      }
  },
  numToString: function numToString() {
      var i = toFixedHelpers.size;
      var s = '';
      while (--i >= 0) {
          if (s !== '' || i === 0 || toFixedHelpers.data[i] !== 0) {
              var t = $String(toFixedHelpers.data[i]);
              if (s === '') {
                  s = t;
              } else {
                  s += strSlice('0000000', 0, 7 - t.length) + t;
              }
          }
      }
      return s;
  },
  pow: function pow(x, n, acc) {
      return (n === 0 ? acc : (n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc)));
  },
  log: function log(x) {
      var n = 0;
      var x2 = x;
      while (x2 >= 4096) {
          n += 12;
          x2 /= 4096;
      }
      while (x2 >= 2) {
          n += 1;
          x2 /= 2;
      }
      return n;
  }
};

var toFixedShim = function toFixed(fractionDigits) {
    var f, x, s, m, e, z, j, k;

    // Test for NaN and round fractionDigits down
    f = $Number(fractionDigits);
    f = isActualNaN(f) ? 0 : Math.floor(f);

    if (f < 0 || f > 20) {
        throw new RangeError('Number.toFixed called with invalid number of decimals');
    }

    x = $Number(this);

    if (isActualNaN(x)) {
        return 'NaN';
    }

    // If it is too big or small, return the string value of the number
    if (x <= -1e21 || x >= 1e21) {
        return $String(x);
    }

    s = '';

    if (x < 0) {
        s = '-';
        x = -x;
    }

    m = '0';

    if (x > 1e-21) {
        // 1e-21 < x < 1e21
        // -70 < log2(x) < 70
        e = toFixedHelpers.log(x * toFixedHelpers.pow(2, 69, 1)) - 69;
        z = (e < 0 ? x * toFixedHelpers.pow(2, -e, 1) : x / toFixedHelpers.pow(2, e, 1));
        z *= 0x10000000000000; // Math.pow(2, 52);
        e = 52 - e;

        // -18 < e < 122
        // x = z / 2 ^ e
        if (e > 0) {
            toFixedHelpers.multiply(0, z);
            j = f;

            while (j >= 7) {
                toFixedHelpers.multiply(1e7, 0);
                j -= 7;
            }

            toFixedHelpers.multiply(toFixedHelpers.pow(10, j, 1), 0);
            j = e - 1;

            while (j >= 23) {
                toFixedHelpers.divide(1 << 23);
                j -= 23;
            }

            toFixedHelpers.divide(1 << j);
            toFixedHelpers.multiply(1, 1);
            toFixedHelpers.divide(2);
            m = toFixedHelpers.numToString();
        } else {
            toFixedHelpers.multiply(0, z);
            toFixedHelpers.multiply(1 << (-e), 0);
            m = toFixedHelpers.numToString() + strSlice('0.00000000000000000000', 2, 2 + f);
        }
    }

    if (f > 0) {
        k = m.length;

        if (k <= f) {
            m = s + strSlice('0.0000000000000000000', 0, f - k + 2) + m;
        } else {
            m = s + strSlice(m, 0, k - f) + '.' + strSlice(m, k - f);
        }
    } else {
        m = s + m;
    }

    return m;
};
defineProperties(NumberPrototype, { toFixed: toFixedShim }, hasToFixedBugs);

var hasToPrecisionUndefinedBug = (function () {
    try {
        return 1.0.toPrecision(undefined) === '1';
    } catch (e) {
        return true;
    }
}());
var originalToPrecision = NumberPrototype.toPrecision;
defineProperties(NumberPrototype, {
    toPrecision: function toPrecision(precision) {
        return typeof precision === 'undefined' ? originalToPrecision.call(this) : originalToPrecision.call(this, precision);
    }
}, hasToPrecisionUndefinedBug);

//
// String
// ======
//

// ES5 15.5.4.14
// http://es5.github.com/#x15.5.4.14

// [bugfix, IE lt 9, firefox 4, Konqueror, Opera, obscure browsers]
// Many browsers do not split properly with regular expressions or they
// do not perform the split correctly under obscure conditions.
// See http://blog.stevenlevithan.com/archives/cross-browser-split
// I've tested in many browsers and this seems to cover the deviant ones:
//    'ab'.split(/(?:ab)*/) should be ["", ""], not [""]
//    '.'.split(/(.?)(.?)/) should be ["", ".", "", ""], not ["", ""]
//    'tesst'.split(/(s)*/) should be ["t", undefined, "e", "s", "t"], not
//       [undefined, "t", undefined, "e", ...]
//    ''.split(/.?/) should be [], not [""]
//    '.'.split(/()()/) should be ["."], not ["", "", "."]

if (
    'ab'.split(/(?:ab)*/).length !== 2 ||
    '.'.split(/(.?)(.?)/).length !== 4 ||
    'tesst'.split(/(s)*/)[1] === 't' ||
    'test'.split(/(?:)/, -1).length !== 4 ||
    ''.split(/.?/).length ||
    '.'.split(/()()/).length > 1
) {
    (function () {
        var compliantExecNpcg = typeof (/()??/).exec('')[1] === 'undefined'; // NPCG: nonparticipating capturing group
        var maxSafe32BitInt = Math.pow(2, 32) - 1;

        StringPrototype.split = function (separator, limit) {
            var string = String(this);
            if (typeof separator === 'undefined' && limit === 0) {
                return [];
            }

            // If `separator` is not a regex, use native split
            if (!isRegex(separator)) {
                return strSplit(this, separator, limit);
            }

            var output = [];
            var flags = (separator.ignoreCase ? 'i' : '') +
                        (separator.multiline ? 'm' : '') +
                        (separator.unicode ? 'u' : '') + // in ES6
                        (separator.sticky ? 'y' : ''), // Firefox 3+ and ES6
                lastLastIndex = 0,
                // Make `global` and avoid `lastIndex` issues by working with a copy
                separator2, match, lastIndex, lastLength;
            var separatorCopy = new RegExp(separator.source, flags + 'g');
            if (!compliantExecNpcg) {
                // Doesn't need flags gy, but they don't hurt
                separator2 = new RegExp('^' + separatorCopy.source + '$(?!\\s)', flags);
            }
            /* Values for `limit`, per the spec:
             * If undefined: 4294967295 // maxSafe32BitInt
             * If 0, Infinity, or NaN: 0
             * If positive number: limit = Math.floor(limit); if (limit > 4294967295) limit -= 4294967296;
             * If negative number: 4294967296 - Math.floor(Math.abs(limit))
             * If other: Type-convert, then use the above rules
             */
            var splitLimit = typeof limit === 'undefined' ? maxSafe32BitInt : ES.ToUint32(limit);
            match = separatorCopy.exec(string);
            while (match) {
                // `separatorCopy.lastIndex` is not reliable cross-browser
                lastIndex = match.index + match[0].length;
                if (lastIndex > lastLastIndex) {
                    pushCall(output, strSlice(string, lastLastIndex, match.index));
                    // Fix browsers whose `exec` methods don't consistently return `undefined` for
                    // nonparticipating capturing groups
                    if (!compliantExecNpcg && match.length > 1) {
                        /* eslint-disable no-loop-func */
                        match[0].replace(separator2, function () {
                            for (var i = 1; i < arguments.length - 2; i++) {
                                if (typeof arguments[i] === 'undefined') {
                                    match[i] = void 0;
                                }
                            }
                        });
                        /* eslint-enable no-loop-func */
                    }
                    if (match.length > 1 && match.index < string.length) {
                        array_push.apply(output, arraySlice(match, 1));
                    }
                    lastLength = match[0].length;
                    lastLastIndex = lastIndex;
                    if (output.length >= splitLimit) {
                        break;
                    }
                }
                if (separatorCopy.lastIndex === match.index) {
                    separatorCopy.lastIndex++; // Avoid an infinite loop
                }
                match = separatorCopy.exec(string);
            }
            if (lastLastIndex === string.length) {
                if (lastLength || !separatorCopy.test('')) {
                    pushCall(output, '');
                }
            } else {
                pushCall(output, strSlice(string, lastLastIndex));
            }
            return output.length > splitLimit ? arraySlice(output, 0, splitLimit) : output;
        };
    }());

// [bugfix, chrome]
// If separator is undefined, then the result array contains just one String,
// which is the this value (converted to a String). If limit is not undefined,
// then the output array is truncated so that it contains no more than limit
// elements.
// "0".split(undefined, 0) -> []
} else if ('0'.split(void 0, 0).length) {
    StringPrototype.split = function split(separator, limit) {
        if (typeof separator === 'undefined' && limit === 0) { return []; }
        return strSplit(this, separator, limit);
    };
}

var str_replace = StringPrototype.replace;
var replaceReportsGroupsCorrectly = (function () {
    var groups = [];
    'x'.replace(/x(.)?/g, function (match, group) {
        pushCall(groups, group);
    });
    return groups.length === 1 && typeof groups[0] === 'undefined';
}());

if (!replaceReportsGroupsCorrectly) {
    StringPrototype.replace = function replace(searchValue, replaceValue) {
        var isFn = isCallable(replaceValue);
        var hasCapturingGroups = isRegex(searchValue) && (/\)[*?]/).test(searchValue.source);
        if (!isFn || !hasCapturingGroups) {
            return str_replace.call(this, searchValue, replaceValue);
        } else {
            var wrappedReplaceValue = function (match) {
                var length = arguments.length;
                var originalLastIndex = searchValue.lastIndex;
                searchValue.lastIndex = 0;
                var args = searchValue.exec(match) || [];
                searchValue.lastIndex = originalLastIndex;
                pushCall(args, arguments[length - 2], arguments[length - 1]);
                return replaceValue.apply(this, args);
            };
            return str_replace.call(this, searchValue, wrappedReplaceValue);
        }
    };
}

// ECMA-262, 3rd B.2.3
// Not an ECMAScript standard, although ECMAScript 3rd Edition has a
// non-normative section suggesting uniform semantics and it should be
// normalized across all browsers
// [bugfix, IE lt 9] IE < 9 substr() with negative value not working in IE
var string_substr = StringPrototype.substr;
var hasNegativeSubstrBug = ''.substr && '0b'.substr(-1) !== 'b';
defineProperties(StringPrototype, {
    substr: function substr(start, length) {
        var normalizedStart = start;
        if (start < 0) {
            normalizedStart = max(this.length + start, 0);
        }
        return string_substr.call(this, normalizedStart, length);
    }
}, hasNegativeSubstrBug);

// ES5 15.5.4.20
// whitespace from: http://es5.github.io/#x15.5.4.20
var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003' +
    '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028' +
    '\u2029\uFEFF';
var zeroWidth = '\u200b';
var wsRegexChars = '[' + ws + ']';
var trimBeginRegexp = new RegExp('^' + wsRegexChars + wsRegexChars + '*');
var trimEndRegexp = new RegExp(wsRegexChars + wsRegexChars + '*$');
var hasTrimWhitespaceBug = StringPrototype.trim && (ws.trim() || !zeroWidth.trim());
defineProperties(StringPrototype, {
    // http://blog.stevenlevithan.com/archives/faster-trim-javascript
    // http://perfectionkills.com/whitespace-deviations/
    trim: function trim() {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        return $String(this).replace(trimBeginRegexp, '').replace(trimEndRegexp, '');
    }
}, hasTrimWhitespaceBug);
var trim = call.bind(String.prototype.trim);

var hasLastIndexBug = StringPrototype.lastIndexOf && 'abcあい'.lastIndexOf('あい', 2) !== -1;
defineProperties(StringPrototype, {
    lastIndexOf: function lastIndexOf(searchString) {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        var S = $String(this);
        var searchStr = $String(searchString);
        var numPos = arguments.length > 1 ? $Number(arguments[1]) : NaN;
        var pos = isActualNaN(numPos) ? Infinity : ES.ToInteger(numPos);
        var start = min(max(pos, 0), S.length);
        var searchLen = searchStr.length;
        var k = start + searchLen;
        while (k > 0) {
            k = max(0, k - searchLen);
            var index = strIndexOf(strSlice(S, k, start + searchLen), searchStr);
            if (index !== -1) {
                return k + index;
            }
        }
        return -1;
    }
}, hasLastIndexBug);

var originalLastIndexOf = StringPrototype.lastIndexOf;
defineProperties(StringPrototype, {
    lastIndexOf: function lastIndexOf(searchString) {
        return originalLastIndexOf.apply(this, arguments);
    }
}, StringPrototype.lastIndexOf.length !== 1);

// ES-5 15.1.2.2
/* eslint-disable radix */
if (parseInt(ws + '08') !== 8 || parseInt(ws + '0x16') !== 22) {
/* eslint-enable radix */
    /* global parseInt: true */
    parseInt = (function (origParseInt) {
        var hexRegex = /^[\-+]?0[xX]/;
        return function parseInt(str, radix) {
            var string = trim(str);
            var defaultedRadix = $Number(radix) || (hexRegex.test(string) ? 16 : 10);
            return origParseInt(string, defaultedRadix);
        };
    }(parseInt));
}

// https://es5.github.io/#x15.1.2.3
if (1 / parseFloat('-0') !== -Infinity) {
    /* global parseFloat: true */
    parseFloat = (function (origParseFloat) {
        return function parseFloat(string) {
            var inputString = trim(string);
            var result = origParseFloat(inputString);
            return result === 0 && strSlice(inputString, 0, 1) === '-' ? -0 : result;
        };
    }(parseFloat));
}

if (String(new RangeError('test')) !== 'RangeError: test') {
    var errorToStringShim = function toString() {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        var name = this.name;
        if (typeof name === 'undefined') {
            name = 'Error';
        } else if (typeof name !== 'string') {
            name = $String(name);
        }
        var msg = this.message;
        if (typeof msg === 'undefined') {
            msg = '';
        } else if (typeof msg !== 'string') {
            msg = $String(msg);
        }
        if (!name) {
            return msg;
        }
        if (!msg) {
            return name;
        }
        return name + ': ' + msg;
    };
    // can't use defineProperties here because of toString enumeration issue in IE <= 8
    Error.prototype.toString = errorToStringShim;
}

if (supportsDescriptors) {
    var ensureNonEnumerable = function (obj, prop) {
        if (isEnum(obj, prop)) {
            var desc = Object.getOwnPropertyDescriptor(obj, prop);
            desc.enumerable = false;
            Object.defineProperty(obj, prop, desc);
        }
    };
    ensureNonEnumerable(Error.prototype, 'message');
    if (Error.prototype.message !== '') {
      Error.prototype.message = '';
    }
    ensureNonEnumerable(Error.prototype, 'name');
}

if (String(/a/mig) !== '/a/gim') {
    var regexToString = function toString() {
        var str = '/' + this.source + '/';
        if (this.global) {
            str += 'g';
        }
        if (this.ignoreCase) {
            str += 'i';
        }
        if (this.multiline) {
            str += 'm';
        }
        return str;
    };
    // can't use defineProperties here because of toString enumeration issue in IE <= 8
    RegExp.prototype.toString = regexToString;
}

}));

/*!
 * https://github.com/es-shims/es5-shim
 * @license es5-shim Copyright 2009-2015 by contributors, MIT License
 * see https://github.com/es-shims/es5-shim/blob/master/LICENSE
 */

// vim: ts=4 sts=4 sw=4 expandtab

// Add semicolon to prevent IIFE from being passed as argument to concatenated code.
;

// UMD (Universal Module Definition)
// see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
(function (root, factory) {
    'use strict';

    /* global define, exports, module */
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals (root is window)
        root.returnExports = factory();
    }
}(this, function () {

    var call = Function.call;
    var prototypeOfObject = Object.prototype;
    var owns = call.bind(prototypeOfObject.hasOwnProperty);
    var isEnumerable = call.bind(prototypeOfObject.propertyIsEnumerable);
    var toStr = call.bind(prototypeOfObject.toString);

    // If JS engine supports accessors creating shortcuts.
    var defineGetter;
    var defineSetter;
    var lookupGetter;
    var lookupSetter;
    var supportsAccessors = owns(prototypeOfObject, '__defineGetter__');
    if (supportsAccessors) {
        /* eslint-disable no-underscore-dangle, no-restricted-properties */
        defineGetter = call.bind(prototypeOfObject.__defineGetter__);
        defineSetter = call.bind(prototypeOfObject.__defineSetter__);
        lookupGetter = call.bind(prototypeOfObject.__lookupGetter__);
        lookupSetter = call.bind(prototypeOfObject.__lookupSetter__);
        /* eslint-enable no-underscore-dangle, no-restricted-properties */
    }

    var isPrimitive = function isPrimitive(o) {
        return o == null || (typeof o !== 'object' && typeof o !== 'function');
    };

    // ES5 15.2.3.2
    // http://es5.github.com/#x15.2.3.2
    if (!Object.getPrototypeOf) {
        // https://github.com/es-shims/es5-shim/issues#issue/2
        // http://ejohn.org/blog/objectgetprototypeof/
        // recommended by fschaefer on github
        //
        // sure, and webreflection says ^_^
        // ... this will nerever possibly return null
        // ... Opera Mini breaks here with infinite loops
        Object.getPrototypeOf = function getPrototypeOf(object) {
            // eslint-disable-next-line no-proto
            var proto = object.__proto__;
            if (proto || proto === null) {
                return proto;
            } else if (toStr(object.constructor) === '[object Function]') {
                return object.constructor.prototype;
            } else if (object instanceof Object) {
                return prototypeOfObject;
            } else {
                // Correctly return null for Objects created with `Object.create(null)`
                // (shammed or native) or `{ __proto__: null}`.  Also returns null for
                // cross-realm objects on browsers that lack `__proto__` support (like
                // IE <11), but that's the best we can do.
                return null;
            }
        };
    }

    // ES5 15.2.3.3
    // http://es5.github.com/#x15.2.3.3

    var doesGetOwnPropertyDescriptorWork = function doesGetOwnPropertyDescriptorWork(object) {
        try {
            object.sentinel = 0;
            return Object.getOwnPropertyDescriptor(object, 'sentinel').value === 0;
        } catch (exception) {
            return false;
        }
    };

    // check whether getOwnPropertyDescriptor works if it's given. Otherwise, shim partially.
    if (Object.defineProperty) {
        var getOwnPropertyDescriptorWorksOnObject = doesGetOwnPropertyDescriptorWork({});
        var getOwnPropertyDescriptorWorksOnDom = typeof document === 'undefined' ||
            doesGetOwnPropertyDescriptorWork(document.createElement('div'));
        if (!getOwnPropertyDescriptorWorksOnDom || !getOwnPropertyDescriptorWorksOnObject) {
            var getOwnPropertyDescriptorFallback = Object.getOwnPropertyDescriptor;
        }
    }

    if (!Object.getOwnPropertyDescriptor || getOwnPropertyDescriptorFallback) {
        var ERR_NON_OBJECT = 'Object.getOwnPropertyDescriptor called on a non-object: ';

        /* eslint-disable no-proto */
        Object.getOwnPropertyDescriptor = function getOwnPropertyDescriptor(object, property) {
            if (isPrimitive(object)) {
                throw new TypeError(ERR_NON_OBJECT + object);
            }

            // make a valiant attempt to use the real getOwnPropertyDescriptor
            // for I8's DOM elements.
            if (getOwnPropertyDescriptorFallback) {
                try {
                    return getOwnPropertyDescriptorFallback.call(Object, object, property);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            var descriptor;

            // If object does not owns property return undefined immediately.
            if (!owns(object, property)) {
                return descriptor;
            }

            // If object has a property then it's for sure `configurable`, and
            // probably `enumerable`. Detect enumerability though.
            descriptor = {
                enumerable: isEnumerable(object, property),
                configurable: true
            };

            // If JS engine supports accessor properties then property may be a
            // getter or setter.
            if (supportsAccessors) {
                // Unfortunately `__lookupGetter__` will return a getter even
                // if object has own non getter property along with a same named
                // inherited getter. To avoid misbehavior we temporary remove
                // `__proto__` so that `__lookupGetter__` will return getter only
                // if it's owned by an object.
                var prototype = object.__proto__;
                var notPrototypeOfObject = object !== prototypeOfObject;
                // avoid recursion problem, breaking in Opera Mini when
                // Object.getOwnPropertyDescriptor(Object.prototype, 'toString')
                // or any other Object.prototype accessor
                if (notPrototypeOfObject) {
                    object.__proto__ = prototypeOfObject;
                }

                var getter = lookupGetter(object, property);
                var setter = lookupSetter(object, property);

                if (notPrototypeOfObject) {
                    // Once we have getter and setter we can put values back.
                    object.__proto__ = prototype;
                }

                if (getter || setter) {
                    if (getter) {
                        descriptor.get = getter;
                    }
                    if (setter) {
                        descriptor.set = setter;
                    }
                    // If it was accessor property we're done and return here
                    // in order to avoid adding `value` to the descriptor.
                    return descriptor;
                }
            }

            // If we got this far we know that object has an own property that is
            // not an accessor so we set it as a value and return descriptor.
            descriptor.value = object[property];
            descriptor.writable = true;
            return descriptor;
        };
        /* eslint-enable no-proto */
    }

    // ES5 15.2.3.4
    // http://es5.github.com/#x15.2.3.4
    if (!Object.getOwnPropertyNames) {
        Object.getOwnPropertyNames = function getOwnPropertyNames(object) {
            return Object.keys(object);
        };
    }

    // ES5 15.2.3.5
    // http://es5.github.com/#x15.2.3.5
    if (!Object.create) {

        // Contributed by Brandon Benvie, October, 2012
        var createEmpty;
        var supportsProto = !({ __proto__: null } instanceof Object);
        // the following produces false positives
        // in Opera Mini => not a reliable check
        // Object.prototype.__proto__ === null

        // Check for document.domain and active x support
        // No need to use active x approach when document.domain is not set
        // see https://github.com/es-shims/es5-shim/issues/150
        // variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
        /* global ActiveXObject */
        var shouldUseActiveX = function shouldUseActiveX() {
            // return early if document.domain not set
            if (!document.domain) {
                return false;
            }

            try {
                return !!new ActiveXObject('htmlfile');
            } catch (exception) {
                return false;
            }
        };

        // This supports IE8 when document.domain is used
        // see https://github.com/es-shims/es5-shim/issues/150
        // variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
        var getEmptyViaActiveX = function getEmptyViaActiveX() {
            var empty;
            var xDoc;

            xDoc = new ActiveXObject('htmlfile');

            var script = 'script';
            xDoc.write('<' + script + '></' + script + '>');
            xDoc.close();

            empty = xDoc.parentWindow.Object.prototype;
            xDoc = null;

            return empty;
        };

        // The original implementation using an iframe
        // before the activex approach was added
        // see https://github.com/es-shims/es5-shim/issues/150
        var getEmptyViaIFrame = function getEmptyViaIFrame() {
            var iframe = document.createElement('iframe');
            var parent = document.body || document.documentElement;
            var empty;

            iframe.style.display = 'none';
            parent.appendChild(iframe);
            // eslint-disable-next-line no-script-url
            iframe.src = 'javascript:';

            empty = iframe.contentWindow.Object.prototype;
            parent.removeChild(iframe);
            iframe = null;

            return empty;
        };

        /* global document */
        if (supportsProto || typeof document === 'undefined') {
            createEmpty = function () {
                return { __proto__: null };
            };
        } else {
            // In old IE __proto__ can't be used to manually set `null`, nor does
            // any other method exist to make an object that inherits from nothing,
            // aside from Object.prototype itself. Instead, create a new global
            // object and *steal* its Object.prototype and strip it bare. This is
            // used as the prototype to create nullary objects.
            createEmpty = function () {
                // Determine which approach to use
                // see https://github.com/es-shims/es5-shim/issues/150
                var empty = shouldUseActiveX() ? getEmptyViaActiveX() : getEmptyViaIFrame();

                delete empty.constructor;
                delete empty.hasOwnProperty;
                delete empty.propertyIsEnumerable;
                delete empty.isPrototypeOf;
                delete empty.toLocaleString;
                delete empty.toString;
                delete empty.valueOf;

                var Empty = function Empty() {};
                Empty.prototype = empty;
                // short-circuit future calls
                createEmpty = function () {
                    return new Empty();
                };
                return new Empty();
            };
        }

        Object.create = function create(prototype, properties) {

            var object;
            var Type = function Type() {}; // An empty constructor.

            if (prototype === null) {
                object = createEmpty();
            } else {
                if (prototype !== null && isPrimitive(prototype)) {
                    // In the native implementation `parent` can be `null`
                    // OR *any* `instanceof Object`  (Object|Function|Array|RegExp|etc)
                    // Use `typeof` tho, b/c in old IE, DOM elements are not `instanceof Object`
                    // like they are in modern browsers. Using `Object.create` on DOM elements
                    // is...err...probably inappropriate, but the native version allows for it.
                    throw new TypeError('Object prototype may only be an Object or null'); // same msg as Chrome
                }
                Type.prototype = prototype;
                object = new Type();
                // IE has no built-in implementation of `Object.getPrototypeOf`
                // neither `__proto__`, but this manually setting `__proto__` will
                // guarantee that `Object.getPrototypeOf` will work as expected with
                // objects created using `Object.create`
                // eslint-disable-next-line no-proto
                object.__proto__ = prototype;
            }

            if (properties !== void 0) {
                Object.defineProperties(object, properties);
            }

            return object;
        };
    }

    // ES5 15.2.3.6
    // http://es5.github.com/#x15.2.3.6

    // Patch for WebKit and IE8 standard mode
    // Designed by hax <hax.github.com>
    // related issue: https://github.com/es-shims/es5-shim/issues#issue/5
    // IE8 Reference:
    //     http://msdn.microsoft.com/en-us/library/dd282900.aspx
    //     http://msdn.microsoft.com/en-us/library/dd229916.aspx
    // WebKit Bugs:
    //     https://bugs.webkit.org/show_bug.cgi?id=36423

    var doesDefinePropertyWork = function doesDefinePropertyWork(object) {
        try {
            Object.defineProperty(object, 'sentinel', {});
            return 'sentinel' in object;
        } catch (exception) {
            return false;
        }
    };

    // check whether defineProperty works if it's given. Otherwise,
    // shim partially.
    if (Object.defineProperty) {
        var definePropertyWorksOnObject = doesDefinePropertyWork({});
        var definePropertyWorksOnDom = typeof document === 'undefined' ||
            doesDefinePropertyWork(document.createElement('div'));
        if (!definePropertyWorksOnObject || !definePropertyWorksOnDom) {
            var definePropertyFallback = Object.defineProperty,
                definePropertiesFallback = Object.defineProperties;
        }
    }

    if (!Object.defineProperty || definePropertyFallback) {
        var ERR_NON_OBJECT_DESCRIPTOR = 'Property description must be an object: ';
        var ERR_NON_OBJECT_TARGET = 'Object.defineProperty called on non-object: ';
        var ERR_ACCESSORS_NOT_SUPPORTED = 'getters & setters can not be defined on this javascript engine';

        Object.defineProperty = function defineProperty(object, property, descriptor) {
            if (isPrimitive(object)) {
                throw new TypeError(ERR_NON_OBJECT_TARGET + object);
            }
            if (isPrimitive(descriptor)) {
                throw new TypeError(ERR_NON_OBJECT_DESCRIPTOR + descriptor);
            }
            // make a valiant attempt to use the real defineProperty
            // for I8's DOM elements.
            if (definePropertyFallback) {
                try {
                    return definePropertyFallback.call(Object, object, property, descriptor);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            // If it's a data property.
            if ('value' in descriptor) {
                // fail silently if 'writable', 'enumerable', or 'configurable'
                // are requested but not supported
                /*
                // alternate approach:
                if ( // can't implement these features; allow false but not true
                    ('writable' in descriptor && !descriptor.writable) ||
                    ('enumerable' in descriptor && !descriptor.enumerable) ||
                    ('configurable' in descriptor && !descriptor.configurable)
                ))
                    throw new RangeError(
                        'This implementation of Object.defineProperty does not support configurable, enumerable, or writable.'
                    );
                */

                if (supportsAccessors && (lookupGetter(object, property) || lookupSetter(object, property))) {
                    // As accessors are supported only on engines implementing
                    // `__proto__` we can safely override `__proto__` while defining
                    // a property to make sure that we don't hit an inherited
                    // accessor.
                    /* eslint-disable no-proto */
                    var prototype = object.__proto__;
                    object.__proto__ = prototypeOfObject;
                    // Deleting a property anyway since getter / setter may be
                    // defined on object itself.
                    delete object[property];
                    object[property] = descriptor.value;
                    // Setting original `__proto__` back now.
                    object.__proto__ = prototype;
                    /* eslint-enable no-proto */
                } else {
                    object[property] = descriptor.value;
                }
            } else {
                var hasGetter = 'get' in descriptor;
                var hasSetter = 'set' in descriptor;
                if (!supportsAccessors && (hasGetter || hasSetter)) {
                    throw new TypeError(ERR_ACCESSORS_NOT_SUPPORTED);
                }
                // If we got that far then getters and setters can be defined !!
                if (hasGetter) {
                    defineGetter(object, property, descriptor.get);
                }
                if (hasSetter) {
                    defineSetter(object, property, descriptor.set);
                }
            }
            return object;
        };
    }

    // ES5 15.2.3.7
    // http://es5.github.com/#x15.2.3.7
    if (!Object.defineProperties || definePropertiesFallback) {
        Object.defineProperties = function defineProperties(object, properties) {
            // make a valiant attempt to use the real defineProperties
            if (definePropertiesFallback) {
                try {
                    return definePropertiesFallback.call(Object, object, properties);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            Object.keys(properties).forEach(function (property) {
                if (property !== '__proto__') {
                    Object.defineProperty(object, property, properties[property]);
                }
            });
            return object;
        };
    }

    // ES5 15.2.3.8
    // http://es5.github.com/#x15.2.3.8
    if (!Object.seal) {
        Object.seal = function seal(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.seal can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // ES5 15.2.3.9
    // http://es5.github.com/#x15.2.3.9
    if (!Object.freeze) {
        Object.freeze = function freeze(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.freeze can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // detect a Rhino bug and patch it
    try {
        Object.freeze(function () {});
    } catch (exception) {
        Object.freeze = (function (freezeObject) {
            return function freeze(object) {
                if (typeof object === 'function') {
                    return object;
                } else {
                    return freezeObject(object);
                }
            };
        }(Object.freeze));
    }

    // ES5 15.2.3.10
    // http://es5.github.com/#x15.2.3.10
    if (!Object.preventExtensions) {
        Object.preventExtensions = function preventExtensions(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.preventExtensions can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // ES5 15.2.3.11
    // http://es5.github.com/#x15.2.3.11
    if (!Object.isSealed) {
        Object.isSealed = function isSealed(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.isSealed can only be called on Objects.');
            }
            return false;
        };
    }

    // ES5 15.2.3.12
    // http://es5.github.com/#x15.2.3.12
    if (!Object.isFrozen) {
        Object.isFrozen = function isFrozen(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.isFrozen can only be called on Objects.');
            }
            return false;
        };
    }

    // ES5 15.2.3.13
    // http://es5.github.com/#x15.2.3.13
    if (!Object.isExtensible) {
        Object.isExtensible = function isExtensible(object) {
            // 1. If Type(O) is not Object throw a TypeError exception.
            if (Object(object) !== object) {
                throw new TypeError('Object.isExtensible can only be called on Objects.');
            }
            // 2. Return the Boolean value of the [[Extensible]] internal property of O.
            var name = '';
            while (owns(object, name)) {
                name += '?';
            }
            object[name] = true;
            var returnValue = owns(object, name);
            delete object[name];
            return returnValue;
        };
    }

}));
/*!
 * jQuery JavaScript Library v1.11.3
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2015-04-28T16:19Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper window is present,
		// execute the factory and get jQuery
		// For environments that do not inherently posses a window with a document
		// (such as Node.js), expose a jQuery-making factory as module.exports
		// This accentuates the need for the creation of a real window
		// e.g. var jQuery = require("jquery")(window);
		// See ticket #14549 for more info
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Can't do this because several apps including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
// Support: Firefox 18+
//

var deletedIds = [];

var slice = deletedIds.slice;

var concat = deletedIds.concat;

var push = deletedIds.push;

var indexOf = deletedIds.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	version = "1.11.3",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1, IE<9
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: deletedIds.sort,
	splice: deletedIds.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var src, copyIsArray, copy, name, options, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		/* jshint eqeqeq: false */
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		// adding 1 corrects loss of precision from parseFloat (#15100)
		return !jQuery.isArray( obj ) && (obj - parseFloat( obj ) + 1) >= 0;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	isPlainObject: function( obj ) {
		var key;

		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!hasOwn.call(obj, "constructor") &&
				!hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Support: IE<9
		// Handle iteration over inherited properties before own properties.
		if ( support.ownLast ) {
			for ( key in obj ) {
				return hasOwn.call( obj, key );
			}
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.
		for ( key in obj ) {}

		return key === undefined || hasOwn.call( obj, key );
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && jQuery.trim( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1, IE<9
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		var len;

		if ( arr ) {
			if ( indexOf ) {
				return indexOf.call( arr, elem, i );
			}

			len = arr.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in arr && arr[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		while ( j < len ) {
			first[ i++ ] = second[ j++ ];
		}

		// Support: IE<9
		// Workaround casting of .length to NaN on otherwise arraylike objects (e.g., NodeLists)
		if ( len !== len ) {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var args, proxy, tmp;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: function() {
		return +( new Date() );
	},

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {

	// Support: iOS 8.2 (not reproducible in simulator)
	// `in` check used to prevent JIT error (gh-2145)
	// hasOwn isn't used here due to false negatives
	// regarding Nodelist length in IE
	var length = "length" in obj && obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v2.2.0-pre
 * http://sizzlejs.com/
 *
 * Copyright 2008, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-12-16
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + 1 * new Date(),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf as it's faster than native
	// http://jsperf.com/thor-indexof-vs-for/5
	indexOf = function( list, elem ) {
		var i = 0,
			len = list.length;
		for ( ; i < len; i++ ) {
			if ( list[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rwhitespace = new RegExp( whitespace + "+", "g" ),
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	},

	// Used for iframes
	// See setDocument()
	// Removing the function wrapper causes a "Permission Denied"
	// error in IE
	unloadHandler = function() {
		setDocument();
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];
	nodeType = context.nodeType;

	if ( typeof selector !== "string" || !selector ||
		nodeType !== 1 && nodeType !== 9 && nodeType !== 11 ) {

		return results;
	}

	if ( !seed && documentIsHTML ) {

		// Try to shortcut find operations when possible (e.g., not under DocumentFragment)
		if ( nodeType !== 11 && (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType !== 1 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== "undefined" && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare, parent,
		doc = node ? node.ownerDocument || node : preferredDoc;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;
	parent = doc.defaultView;

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", unloadHandler, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", unloadHandler );
		}
	}

	/* Support tests
	---------------------------------------------------------------------- */
	documentIsHTML = !isXML( doc );

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties
	// (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Support: IE<9
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName );

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== "undefined" && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( tag );

			// DocumentFragment nodes don't have gEBTN
			} else if ( support.qsa ) {
				return context.querySelectorAll( tag );
			}
		} :

		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				// By happy coincidence, a (broken) gEBTN appears on DocumentFragment nodes too
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			docElem.appendChild( div ).innerHTML = "<a id='" + expando + "'></a>" +
				"<select id='" + expando + "-\f]' msallowcapture=''>" +
				"<option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowcapture^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Support: Chrome<29, Android<4.2+, Safari<7.0+, iOS<7.0+, PhantomJS<1.9.7+
			if ( !div.querySelectorAll( "[id~=" + expando + "-]" ).length ) {
				rbuggyQSA.push("~=");
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}

			// Support: Safari 8+, iOS 8+
			// https://bugs.webkit.org/show_bug.cgi?id=136851
			// In-page `selector#id sibing-combinator selector` fails
			if ( !div.querySelectorAll( "a#" + expando + "+*" ).length ) {
				rbuggyQSA.push(".#.+[+~]");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch (e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== "undefined" && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result.replace( rwhitespace, " " ) + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					// Don't keep the element (issue #299)
					input[0] = null;
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			text = text.replace( runescape, funescape );
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			var ret = ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
			// Avoid hanging onto element (issue #299)
			checkContext = null;
			return ret;
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome 14-35+
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			ret = [],
			self = this,
			len = self.length;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var i,
			targets = jQuery( target, this ),
			len = targets.length;

		return this.filter(function() {
			for ( i = 0; i < len; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.first().prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	do {
		cur = cur[ dir ];
	} while ( cur && cur.nodeType !== 1 );

	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				ret = jQuery.unique( ret );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				ret = ret.reverse();
			}
		}

		return this.pushStack( ret );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Flag to know if list is currently firing
		firing,
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );

					} else if ( !(--remaining) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// if we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( !document.body ) {
			return setTimeout( jQuery.ready );
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * Clean-up method for dom ready events
 */
function detach() {
	if ( document.addEventListener ) {
		document.removeEventListener( "DOMContentLoaded", completed, false );
		window.removeEventListener( "load", completed, false );

	} else {
		document.detachEvent( "onreadystatechange", completed );
		window.detachEvent( "onload", completed );
	}
}

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	// readyState === "complete" is good enough for us to call the dom ready in oldIE
	if ( document.addEventListener || event.type === "load" || document.readyState === "complete" ) {
		detach();
		jQuery.ready();
	}
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// we once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		// Standards-based browsers support DOMContentLoaded
		} else if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );

		// If IE event model is used
		} else {
			// Ensure firing before onload, maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", completed );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", completed );

			// If IE and not a frame
			// continually check to see if the document is ready
			var top = false;

			try {
				top = window.frameElement == null && document.documentElement;
			} catch(e) {}

			if ( top && top.doScroll ) {
				(function doScrollCheck() {
					if ( !jQuery.isReady ) {

						try {
							// Use the trick by Diego Perini
							// http://javascript.nwbox.com/IEContentLoaded/
							top.doScroll("left");
						} catch(e) {
							return setTimeout( doScrollCheck, 50 );
						}

						// detach all dom ready events
						detach();

						// and execute any waiting functions
						jQuery.ready();
					}
				})();
			}
		}
	}
	return readyList.promise( obj );
};


var strundefined = typeof undefined;



// Support: IE<9
// Iteration over object's inherited properties before its own
var i;
for ( i in jQuery( support ) ) {
	break;
}
support.ownLast = i !== "0";

// Note: most support tests are defined in their respective modules.
// false until the test is run
support.inlineBlockNeedsLayout = false;

// Execute ASAP in case we need to set body.style.zoom
jQuery(function() {
	// Minified: var a,b,c,d
	var val, div, body, container;

	body = document.getElementsByTagName( "body" )[ 0 ];
	if ( !body || !body.style ) {
		// Return for frameset docs that don't have a body
		return;
	}

	// Setup
	div = document.createElement( "div" );
	container = document.createElement( "div" );
	container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
	body.appendChild( container ).appendChild( div );

	if ( typeof div.style.zoom !== strundefined ) {
		// Support: IE<8
		// Check if natively block-level elements act like inline-block
		// elements when setting their display to 'inline' and giving
		// them layout
		div.style.cssText = "display:inline;margin:0;border:0;padding:1px;width:1px;zoom:1";

		support.inlineBlockNeedsLayout = val = div.offsetWidth === 3;
		if ( val ) {
			// Prevent IE 6 from affecting layout for positioned elements #11048
			// Prevent IE from shrinking the body in IE 7 mode #12869
			// Support: IE<8
			body.style.zoom = 1;
		}
	}

	body.removeChild( container );
});




(function() {
	var div = document.createElement( "div" );

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( elem ) {
	var noData = jQuery.noData[ (elem.nodeName + " ").toLowerCase() ],
		nodeType = +elem.nodeType || 1;

	// Do not set data on non-element DOM nodes because it will not be cleared (#8335).
	return nodeType !== 1 && nodeType !== 9 ?
		false :

		// Nodes accept data unless otherwise specified; rejection can be conditional
		!noData || noData !== true && elem.getAttribute("classid") === noData;
};


var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	var name;
	for ( name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}

function internalData( elem, name, data, pvt /* Internal Use Only */ ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var ret, thisCache,
		internalKey = jQuery.expando,

		// We have to handle DOM nodes and JS objects differently because IE6-7
		// can't GC object references properly across the DOM-JS boundary
		isNode = elem.nodeType,

		// Only DOM nodes need the global jQuery cache; JS object data is
		// attached directly to the object so GC can occur automatically
		cache = isNode ? jQuery.cache : elem,

		// Only defining an ID for JS objects if its cache already exists allows
		// the code to shortcut on the same path as a DOM node with no cache
		id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey;

	// Avoid doing any more work than we need to when trying to get data on an
	// object that has no data at all
	if ( (!id || !cache[id] || (!pvt && !cache[id].data)) && data === undefined && typeof name === "string" ) {
		return;
	}

	if ( !id ) {
		// Only DOM nodes need a new unique ID for each element since their data
		// ends up in the global cache
		if ( isNode ) {
			id = elem[ internalKey ] = deletedIds.pop() || jQuery.guid++;
		} else {
			id = internalKey;
		}
	}

	if ( !cache[ id ] ) {
		// Avoid exposing jQuery metadata on plain JS objects when the object
		// is serialized using JSON.stringify
		cache[ id ] = isNode ? {} : { toJSON: jQuery.noop };
	}

	// An object can be passed to jQuery.data instead of a key/value pair; this gets
	// shallow copied over onto the existing cache
	if ( typeof name === "object" || typeof name === "function" ) {
		if ( pvt ) {
			cache[ id ] = jQuery.extend( cache[ id ], name );
		} else {
			cache[ id ].data = jQuery.extend( cache[ id ].data, name );
		}
	}

	thisCache = cache[ id ];

	// jQuery data() is stored in a separate object inside the object's internal data
	// cache in order to avoid key collisions between internal data and user-defined
	// data.
	if ( !pvt ) {
		if ( !thisCache.data ) {
			thisCache.data = {};
		}

		thisCache = thisCache.data;
	}

	if ( data !== undefined ) {
		thisCache[ jQuery.camelCase( name ) ] = data;
	}

	// Check for both converted-to-camel and non-converted data property names
	// If a data property was specified
	if ( typeof name === "string" ) {

		// First Try to find as-is property data
		ret = thisCache[ name ];

		// Test for null|undefined property data
		if ( ret == null ) {

			// Try to find the camelCased property
			ret = thisCache[ jQuery.camelCase( name ) ];
		}
	} else {
		ret = thisCache;
	}

	return ret;
}

function internalRemoveData( elem, name, pvt ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var thisCache, i,
		isNode = elem.nodeType,

		// See jQuery.data for more information
		cache = isNode ? jQuery.cache : elem,
		id = isNode ? elem[ jQuery.expando ] : jQuery.expando;

	// If there is already no cache entry for this object, there is no
	// purpose in continuing
	if ( !cache[ id ] ) {
		return;
	}

	if ( name ) {

		thisCache = pvt ? cache[ id ] : cache[ id ].data;

		if ( thisCache ) {

			// Support array or space separated string names for data keys
			if ( !jQuery.isArray( name ) ) {

				// try the string as a key before any manipulation
				if ( name in thisCache ) {
					name = [ name ];
				} else {

					// split the camel cased version by spaces unless a key with the spaces exists
					name = jQuery.camelCase( name );
					if ( name in thisCache ) {
						name = [ name ];
					} else {
						name = name.split(" ");
					}
				}
			} else {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = name.concat( jQuery.map( name, jQuery.camelCase ) );
			}

			i = name.length;
			while ( i-- ) {
				delete thisCache[ name[i] ];
			}

			// If there is no data left in the cache, we want to continue
			// and let the cache object itself get destroyed
			if ( pvt ? !isEmptyDataObject(thisCache) : !jQuery.isEmptyObject(thisCache) ) {
				return;
			}
		}
	}

	// See jQuery.data for more information
	if ( !pvt ) {
		delete cache[ id ].data;

		// Don't destroy the parent cache unless the internal data object
		// had been the only thing left in it
		if ( !isEmptyDataObject( cache[ id ] ) ) {
			return;
		}
	}

	// Destroy the cache
	if ( isNode ) {
		jQuery.cleanData( [ elem ], true );

	// Use delete when supported for expandos or `cache` is not a window per isWindow (#10080)
	/* jshint eqeqeq: false */
	} else if ( support.deleteExpando || cache != cache.window ) {
		/* jshint eqeqeq: true */
		delete cache[ id ];

	// When all else fails, null
	} else {
		cache[ id ] = null;
	}
}

jQuery.extend({
	cache: {},

	// The following elements (space-suffixed to avoid Object.prototype collisions)
	// throw uncatchable exceptions if you attempt to set expando properties
	noData: {
		"applet ": true,
		"embed ": true,
		// ...but Flash objects (which have this classid) *can* handle expandos
		"object ": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data ) {
		return internalData( elem, name, data );
	},

	removeData: function( elem, name ) {
		return internalRemoveData( elem, name );
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return internalData( elem, name, data, true );
	},

	_removeData: function( elem, name ) {
		return internalRemoveData( elem, name, true );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[0],
			attrs = elem && elem.attributes;

		// Special expections of .data basically thwart jQuery.access,
		// so implement the relevant behavior ourselves

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		return arguments.length > 1 ?

			// Sets one value
			this.each(function() {
				jQuery.data( this, key, value );
			}) :

			// Gets one value
			// Try to fetch any internally stored data first
			elem ? dataAttr( elem, key, jQuery.data( elem, key ) ) : undefined;
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray(data) ) {
					queue = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// not intended for public consumption - generates a queueHooks object, or returns the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return jQuery._data( elem, key ) || jQuery._data( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				jQuery._removeData( elem, type + "queue" );
				jQuery._removeData( elem, key );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = jQuery._data( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};



// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		length = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < length; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			length ? fn( elems[0], key ) : emptyGet;
};
var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	// Minified: var a,b,c
	var input = document.createElement( "input" ),
		div = document.createElement( "div" ),
		fragment = document.createDocumentFragment();

	// Setup
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";

	// IE strips leading whitespace when .innerHTML is used
	support.leadingWhitespace = div.firstChild.nodeType === 3;

	// Make sure that tbody elements aren't automatically inserted
	// IE will insert them into empty tables
	support.tbody = !div.getElementsByTagName( "tbody" ).length;

	// Make sure that link elements get serialized correctly by innerHTML
	// This requires a wrapper element in IE
	support.htmlSerialize = !!div.getElementsByTagName( "link" ).length;

	// Makes sure cloning an html5 element does not cause problems
	// Where outerHTML is undefined, this still works
	support.html5Clone =
		document.createElement( "nav" ).cloneNode( true ).outerHTML !== "<:nav></:nav>";

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	input.type = "checkbox";
	input.checked = true;
	fragment.appendChild( input );
	support.appendChecked = input.checked;

	// Make sure textarea (and checkbox) defaultValue is properly cloned
	// Support: IE6-IE11+
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;

	// #11217 - WebKit loses check when the name is after the checked attribute
	fragment.appendChild( div );
	div.innerHTML = "<input type='radio' checked='checked' name='t'/>";

	// Support: Safari 5.1, iOS 5.1, Android 4.x, Android 2.3
	// old WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<9
	// Opera does not clone events (and typeof div.attachEvent === undefined).
	// IE9-10 clones events bound via attachEvent, but they don't trigger with .click()
	support.noCloneEvent = true;
	if ( div.attachEvent ) {
		div.attachEvent( "onclick", function() {
			support.noCloneEvent = false;
		});

		div.cloneNode( true ).click();
	}

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}
})();


(function() {
	var i, eventName,
		div = document.createElement( "div" );

	// Support: IE<9 (lack submit/change bubble), Firefox 23+ (lack focusin event)
	for ( i in { submit: true, change: true, focusin: true }) {
		eventName = "on" + i;

		if ( !(support[ i + "Bubbles" ] = eventName in window) ) {
			// Beware of CSP restrictions (https://developer.mozilla.org/en/Security/CSP)
			div.setAttribute( eventName, "t" );
			support[ i + "Bubbles" ] = div.attributes[ eventName ].expando === false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


var rformElems = /^(?:input|select|textarea)$/i,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {
		var tmp, events, t, handleObjIn,
			special, eventHandle, handleObj,
			handlers, type, namespaces, origType,
			elemData = jQuery._data( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {
		var j, handleObj, tmp,
			origCount, t, events,
			special, handlers, type,
			namespaces, origType,
			elemData = jQuery.hasData( elem ) && jQuery._data( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery._removeData( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		var handle, ontype, cur,
			bubbleType, special, tmp, i,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && elem[ type ] && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					try {
						elem[ type ]();
					} catch ( e ) {
						// IE<9 dies on focus/blur to hidden element (#1486,#12518)
						// only reproducible on winXP IE8 native, not IE9 in IE8 mode
					}
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, ret, handleObj, matched, j,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( jQuery._data( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var sel, handleObj, matches, i,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			/* jshint eqeqeq: false */
			for ( ; cur != this; cur = cur.parentNode || this ) {
				/* jshint eqeqeq: true */

				// Don't check non-elements (#13208)
				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.nodeType === 1 && (cur.disabled !== true || event.type !== "click") ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: IE<9
		// Fix target property (#1925)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Support: Chrome 23+, Safari?
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// Support: IE<9
		// For mouse/key events, metaKey==false if it's undefined (#3368, #11328)
		event.metaKey = !!event.metaKey;

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var body, eventDoc, doc,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					try {
						this.focus();
						return false;
					} catch ( e ) {
						// Support: IE<9
						// If we error on focus to hidden element (#1486, #12518),
						// let .trigger() run the handlers
					}
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( jQuery.nodeName( this, "input" ) && this.type === "checkbox" && this.click ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		var name = "on" + type;

		if ( elem.detachEvent ) {

			// #8545, #7054, preventing memory leaks for custom events in IE6-8
			// detachEvent needed property on element, by name of that event, to properly expose it to GC
			if ( typeof elem[ name ] === strundefined ) {
				elem[ name ] = null;
			}

			elem.detachEvent( name, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: IE < 9, Android < 4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;
		if ( !e ) {
			return;
		}

		// If preventDefault exists, run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// Support: IE
		// Otherwise set the returnValue property of the original event to false
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;
		if ( !e ) {
			return;
		}
		// If stopPropagation exists, run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}

		// Support: IE
		// Set the cancelBubble property of the original event to true
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !jQuery._data( form, "submitBubbles" ) ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					jQuery._data( form, "submitBubbles", true );
				}
			});
			// return undefined since we don't need an event listener
		},

		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
						}
						// Allow triggered, simulated change events (#11500)
						jQuery.event.simulate( "change", this, event, true );
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !jQuery._data( elem, "changeBubbles" ) ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					jQuery._data( elem, "changeBubbles", true );
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return !rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				jQuery._data( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					jQuery._removeData( doc, fix );
				} else {
					jQuery._data( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var type, origFn;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
		safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:null|\d+)"/g,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		area: [ 1, "<map>", "</map>" ],
		param: [ 1, "<object>", "</object>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		// IE6-8 can't serialize link, script, style, or any html5 (NoScope) tags,
		// unless wrapped in a div with non-breaking characters in front of it.
		_default: support.htmlSerialize ? [ 0, "", "" ] : [ 1, "X<div>", "</div>"  ]
	},
	safeFragment = createSafeFragment( document ),
	fragmentDiv = safeFragment.appendChild( document.createElement("div") );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

function getAll( context, tag ) {
	var elems, elem,
		i = 0,
		found = typeof context.getElementsByTagName !== strundefined ? context.getElementsByTagName( tag || "*" ) :
			typeof context.querySelectorAll !== strundefined ? context.querySelectorAll( tag || "*" ) :
			undefined;

	if ( !found ) {
		for ( found = [], elems = context.childNodes || context; (elem = elems[i]) != null; i++ ) {
			if ( !tag || jQuery.nodeName( elem, tag ) ) {
				found.push( elem );
			} else {
				jQuery.merge( found, getAll( elem, tag ) );
			}
		}
	}

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], found ) :
		found;
}

// Used in buildFragment, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( rcheckableType.test( elem.type ) ) {
		elem.defaultChecked = elem.checked;
	}
}

// Support: IE<8
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (jQuery.find.attr( elem, "type" ) !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );
	if ( match ) {
		elem.type = match[1];
	} else {
		elem.removeAttribute("type");
	}
	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var elem,
		i = 0;
	for ( ; (elem = elems[i]) != null; i++ ) {
		jQuery._data( elem, "globalEval", !refElements || jQuery._data( refElements[i], "globalEval" ) );
	}
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function fixCloneNodeIssues( src, dest ) {
	var nodeName, e, data;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 copies events bound via attachEvent when using cloneNode.
	if ( !support.noCloneEvent && dest[ jQuery.expando ] ) {
		data = jQuery._data( dest );

		for ( e in data.events ) {
			jQuery.removeEvent( dest, e, data.handle );
		}

		// Event data gets referenced instead of copied if the expando gets copied too
		dest.removeAttribute( jQuery.expando );
	}

	// IE blanks contents when cloning scripts, and tries to evaluate newly-set text
	if ( nodeName === "script" && dest.text !== src.text ) {
		disableScript( dest ).text = src.text;
		restoreScript( dest );

	// IE6-10 improperly clones children of object elements using classid.
	// IE10 throws NoModificationAllowedError if parent is null, #12132.
	} else if ( nodeName === "object" ) {
		if ( dest.parentNode ) {
			dest.outerHTML = src.outerHTML;
		}

		// This path appears unavoidable for IE9. When cloning an object
		// element in IE9, the outerHTML strategy above is not sufficient.
		// If the src has innerHTML and the destination does not,
		// copy the src.innerHTML into the dest.innerHTML. #10324
		if ( support.html5Clone && ( src.innerHTML && !jQuery.trim(dest.innerHTML) ) ) {
			dest.innerHTML = src.innerHTML;
		}

	} else if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set

		dest.defaultChecked = dest.checked = src.checked;

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.defaultSelected = dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var destElements, node, clone, i, srcElements,
			inPage = jQuery.contains( elem.ownerDocument, elem );

		if ( support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ) {
			clone = elem.cloneNode( true );

		// IE<=8 does not properly clone detached, unknown element nodes
		} else {
			fragmentDiv.innerHTML = elem.outerHTML;
			fragmentDiv.removeChild( clone = fragmentDiv.firstChild );
		}

		if ( (!support.noCloneEvent || !support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			// Fix all IE cloning issues
			for ( i = 0; (node = srcElements[i]) != null; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					fixCloneNodeIssues( node, destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0; (node = srcElements[i]) != null; i++ ) {
					cloneCopyEvent( node, destElements[i] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		destElements = srcElements = node = null;

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var j, elem, contains,
			tmp, tag, tbody, wrap,
			l = elems.length,

			// Ensure a safe fragment
			safe = createSafeFragment( context ),

			nodes = [],
			i = 0;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || safe.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = (rtagName.exec( elem ) || [ "", "" ])[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;

					tmp.innerHTML = wrap[1] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[2];

					// Descend through wrappers to the right content
					j = wrap[0];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Manually add leading whitespace removed by IE
					if ( !support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						nodes.push( context.createTextNode( rleadingWhitespace.exec( elem )[0] ) );
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						elem = tag === "table" && !rtbody.test( elem ) ?
							tmp.firstChild :

							// String was a bare <thead> or <tfoot>
							wrap[1] === "<table>" && !rtbody.test( elem ) ?
								tmp :
								0;

						j = elem && elem.childNodes.length;
						while ( j-- ) {
							if ( jQuery.nodeName( (tbody = elem.childNodes[j]), "tbody" ) && !tbody.childNodes.length ) {
								elem.removeChild( tbody );
							}
						}
					}

					jQuery.merge( nodes, tmp.childNodes );

					// Fix #12392 for WebKit and IE > 9
					tmp.textContent = "";

					// Fix #12392 for oldIE
					while ( tmp.firstChild ) {
						tmp.removeChild( tmp.firstChild );
					}

					// Remember the top-level container for proper cleanup
					tmp = safe.lastChild;
				}
			}
		}

		// Fix #11356: Clear elements from fragment
		if ( tmp ) {
			safe.removeChild( tmp );
		}

		// Reset defaultChecked for any radios and checkboxes
		// about to be appended to the DOM in IE 6/7 (#8060)
		if ( !support.appendChecked ) {
			jQuery.grep( getAll( nodes, "input" ), fixDefaultChecked );
		}

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( safe.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		tmp = null;

		return safe;
	},

	cleanData: function( elems, /* internal */ acceptData ) {
		var elem, type, id, data,
			i = 0,
			internalKey = jQuery.expando,
			cache = jQuery.cache,
			deleteExpando = support.deleteExpando,
			special = jQuery.event.special;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( acceptData || jQuery.acceptData( elem ) ) {

				id = elem[ internalKey ];
				data = id && cache[ id ];

				if ( data ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}

					// Remove cache only if it was not already removed by jQuery.event.remove
					if ( cache[ id ] ) {

						delete cache[ id ];

						// IE does not allow us to delete expando properties from nodes,
						// nor does it have a removeAttribute function on Document nodes;
						// we must handle all of these cases
						if ( deleteExpando ) {
							delete elem[ internalKey ];

						} else if ( typeof elem.removeAttribute !== strundefined ) {
							elem.removeAttribute( internalKey );

						} else {
							elem[ internalKey ] = null;
						}

						deletedIds.push( id );
					}
				}
			}
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {

			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem, false ) );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}

			// If this is a select, ensure that it displays empty (#12336)
			// Support: IE<9
			if ( elem.options && jQuery.nodeName( elem, "select" ) ) {
				elem.options.length = 0;
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					undefined;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( support.htmlSerialize || !rnoshimcache.test( value )  ) &&
				( support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ (rtagName.exec( value ) || [ "", "" ])[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var first, node, hasScripts,
			scripts, doc, fragment,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[0],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[0] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[i], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!jQuery._data( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( ( node.text || node.textContent || node.innerHTML || "" ).replace( rcleanScript, "" ) );
							}
						}
					}
				}

				// Fix #11809: Avoid leaking memory
				fragment = first = null;
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			i = 0,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone(true);
			jQuery( insert[i] )[ original ]( elems );

			// Modern browsers can apply jQuery collections as arrays, but oldIE needs a .get()
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optmization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = ( iframe[ 0 ].contentWindow || iframe[ 0 ].contentDocument ).document;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}


(function() {
	var shrinkWrapBlocksVal;

	support.shrinkWrapBlocks = function() {
		if ( shrinkWrapBlocksVal != null ) {
			return shrinkWrapBlocksVal;
		}

		// Will be changed later if needed.
		shrinkWrapBlocksVal = false;

		// Minified: var b,c,d
		var div, body, container;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		// Support: IE6
		// Check if elements with layout shrink-wrap their children
		if ( typeof div.style.zoom !== strundefined ) {
			// Reset CSS: box-sizing; display; margin; border
			div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;" +
				"padding:1px;width:1px;zoom:1";
			div.appendChild( document.createElement( "div" ) ).style.width = "5px";
			shrinkWrapBlocksVal = div.offsetWidth !== 3;
		}

		body.removeChild( container );

		return shrinkWrapBlocksVal;
	};

})();
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );



var getStyles, curCSS,
	rposition = /^(top|right|bottom|left)$/;

if ( window.getComputedStyle ) {
	getStyles = function( elem ) {
		// Support: IE<=11+, Firefox<=30+ (#15098, #14150)
		// IE throws on elements created in popups
		// FF meanwhile throws on frame elements through "defaultView.getComputedStyle"
		if ( elem.ownerDocument.defaultView.opener ) {
			return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
		}

		return window.getComputedStyle( elem, null );
	};

	curCSS = function( elem, name, computed ) {
		var width, minWidth, maxWidth, ret,
			style = elem.style;

		computed = computed || getStyles( elem );

		// getPropertyValue is only needed for .css('filter') in IE9, see #12537
		ret = computed ? computed.getPropertyValue( name ) || computed[ name ] : undefined;

		if ( computed ) {

			if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
				ret = jQuery.style( elem, name );
			}

			// A tribute to the "awesome hack by Dean Edwards"
			// Chrome < 17 and Safari 5.0 uses "computed value" instead of "used value" for margin-right
			// Safari 5.1.7 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
			// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
			if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

				// Remember the original values
				width = style.width;
				minWidth = style.minWidth;
				maxWidth = style.maxWidth;

				// Put in the new values to get a computed value out
				style.minWidth = style.maxWidth = style.width = ret;
				ret = computed.width;

				// Revert the changed values
				style.width = width;
				style.minWidth = minWidth;
				style.maxWidth = maxWidth;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "";
	};
} else if ( document.documentElement.currentStyle ) {
	getStyles = function( elem ) {
		return elem.currentStyle;
	};

	curCSS = function( elem, name, computed ) {
		var left, rs, rsLeft, ret,
			style = elem.style;

		computed = computed || getStyles( elem );
		ret = computed ? computed[ name ] : undefined;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && style[ name ] ) {
			ret = style[ name ];
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		// but not position css attributes, as those are proportional to the parent element instead
		// and we can't measure the parent instead because it might trigger a "stacking dolls" problem
		if ( rnumnonpx.test( ret ) && !rposition.test( name ) ) {

			// Remember the original values
			left = style.left;
			rs = elem.runtimeStyle;
			rsLeft = rs && rs.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				rs.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				rs.left = rsLeft;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "" || "auto";
	};
}




function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			var condition = conditionFn();

			if ( condition == null ) {
				// The test was not ready at this point; screw the hook this time
				// but check again when needed next time.
				return;
			}

			if ( condition ) {
				// Hook not needed (or it's not possible to use it due to missing dependency),
				// remove it.
				// Since there are no other hooks for marginRight, remove the whole object.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.

			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	// Minified: var b,c,d,e,f,g, h,i
	var div, style, a, pixelPositionVal, boxSizingReliableVal,
		reliableHiddenOffsetsVal, reliableMarginRightVal;

	// Setup
	div = document.createElement( "div" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName( "a" )[ 0 ];
	style = a && a.style;

	// Finish early in limited (non-browser) environments
	if ( !style ) {
		return;
	}

	style.cssText = "float:left;opacity:.5";

	// Support: IE<9
	// Make sure that element opacity exists (as opposed to filter)
	support.opacity = style.opacity === "0.5";

	// Verify style float existence
	// (IE uses styleFloat instead of cssFloat)
	support.cssFloat = !!style.cssFloat;

	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	// Support: Firefox<29, Android 2.3
	// Vendor-prefix box-sizing
	support.boxSizing = style.boxSizing === "" || style.MozBoxSizing === "" ||
		style.WebkitBoxSizing === "";

	jQuery.extend(support, {
		reliableHiddenOffsets: function() {
			if ( reliableHiddenOffsetsVal == null ) {
				computeStyleTests();
			}
			return reliableHiddenOffsetsVal;
		},

		boxSizingReliable: function() {
			if ( boxSizingReliableVal == null ) {
				computeStyleTests();
			}
			return boxSizingReliableVal;
		},

		pixelPosition: function() {
			if ( pixelPositionVal == null ) {
				computeStyleTests();
			}
			return pixelPositionVal;
		},

		// Support: Android 2.3
		reliableMarginRight: function() {
			if ( reliableMarginRightVal == null ) {
				computeStyleTests();
			}
			return reliableMarginRightVal;
		}
	});

	function computeStyleTests() {
		// Minified: var b,c,d,j
		var div, body, container, contents;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";

		// Support: IE<9
		// Assume reasonable values in the absence of getComputedStyle
		pixelPositionVal = boxSizingReliableVal = false;
		reliableMarginRightVal = true;

		// Check for getComputedStyle so that this code is not run in IE<9.
		if ( window.getComputedStyle ) {
			pixelPositionVal = ( window.getComputedStyle( div, null ) || {} ).top !== "1%";
			boxSizingReliableVal =
				( window.getComputedStyle( div, null ) || { width: "4px" } ).width === "4px";

			// Support: Android 2.3
			// Div with explicit width and no margin-right incorrectly
			// gets computed margin-right based on width of container (#3333)
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			contents = div.appendChild( document.createElement( "div" ) );

			// Reset CSS: box-sizing; display; margin; border; padding
			contents.style.cssText = div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
			contents.style.marginRight = contents.style.width = "0";
			div.style.width = "1px";

			reliableMarginRightVal =
				!parseFloat( ( window.getComputedStyle( contents, null ) || {} ).marginRight );

			div.removeChild( contents );
		}

		// Support: IE8
		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		div.innerHTML = "<table><tr><td></td><td>t</td></tr></table>";
		contents = div.getElementsByTagName( "td" );
		contents[ 0 ].style.cssText = "margin:0;border:0;padding:0;display:none";
		reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		if ( reliableHiddenOffsetsVal ) {
			contents[ 0 ].style.display = "";
			contents[ 1 ].style.display = "none";
			reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		}

		body.removeChild( container );
	}

})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
		ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity\s*=\s*([^)]*)/,

	// swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// see here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];


// return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// check for vendor prefixed names
	var capName = name.charAt(0).toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = jQuery._data( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = jQuery._data( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display && display !== "none" || !hidden ) {
				jQuery._data( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// at this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// at this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// at this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// we need the check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox && ( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set. See: #7116
			if ( value == null || value !== value ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Fixes #8908, it can be done more correctly by specifing setters in cssHooks,
			// but it would mean to define eight (for every problematic property) identical functions
			if ( !support.clearCloneStyle && value === "" && name.indexOf("background") === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {

				// Support: IE
				// Swallow errors from 'invalid' CSS values (#5509)
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var num, val, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		//convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Return, converting to number if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				// certain elements can have dimension info if we invisibly show them
				// however, it must have a current display style that would benefit from this
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

if ( !support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( 0.01 * parseFloat( RegExp.$1 ) ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			// if value === "", then remove inline opacity #12685
			if ( ( value >= 1 || value === "" ) &&
					jQuery.trim( filter.replace( ralpha, "" ) ) === "" &&
					style.removeAttribute ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there is no filter style applied in a css rule or unset inline opacity, we are done
				if ( value === "" || currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			// Work around by temporarily setting element display to inline-block
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails
			// so, simple values such as "10px" are parsed to Float.
			// complex values such as "rotate(1rad)" are returned as is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// use step hook for back compat - use cssHook if its there - use .style if its
			// available and use plain properties where available
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE <=9
// Panic based approach to setting things on disconnected nodes

Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*
					// Use a string for doubling factor so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur()
				// And breaking the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		attrs = { height: type },
		i = 0;

	// if we include width, step value is 1 to do all cssExpand values,
	// if we don't include width, step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// we're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = jQuery._data( elem, "fxshow" );

	// handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// doing this makes sure that the complete handler will be called
			// before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE does not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			jQuery._data( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {

			// inline-level elements accept inline-block;
			// block-level elements need to be inline with layout
			if ( !support.inlineBlockNeedsLayout || defaultDisplay( elem.nodeName ) === "inline" ) {
				style.display = "inline-block";
			} else {
				style.zoom = 1;
			}
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		if ( !support.shrinkWrapBlocks() ) {
			anim.always(function() {
				style.overflow = opts.overflow[ 0 ];
				style.overflowX = opts.overflow[ 1 ];
				style.overflowY = opts.overflow[ 2 ];
			});
		}
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = jQuery._data( elem, "fxshow", {} );
		}

		// store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;
			jQuery._removeData( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// not quite $.extend, this wont overwrite keys already present.
			// also - reusing 'index' from above because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// archaic crash bug won't allow us to use 1 - ( 0.5 || 0 ) (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// if we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// resolve when we played the last frame
				// otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {
	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || jQuery._data( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = jQuery._data( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = jQuery._data( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// enable finishing flag on private data
			data.finish = true;

			// empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		timers = jQuery.timers,
		i = 0;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	// Minified: var a,b,c,d,e
	var input, div, select, a, opt;

	// Setup
	div = document.createElement( "div" );
	div.setAttribute( "className", "t" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName("a")[ 0 ];

	// First batch of tests.
	select = document.createElement("select");
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName("input")[ 0 ];

	a.style.cssText = "top:1px";

	// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
	support.getSetAttribute = div.className !== "t";

	// Get the style information from getAttribute
	// (IE uses .cssText instead)
	support.style = /top/.test( a.getAttribute("style") );

	// Make sure that URLs aren't manipulated
	// (IE normalizes it by default)
	support.hrefNormalized = a.getAttribute("href") === "/a";

	// Check the default checkbox/radio value ("" on WebKit; "on" elsewhere)
	support.checkOn = !!input.value;

	// Make sure that a selected-by-default option has a working selected property.
	// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
	support.optSelected = opt.selected;

	// Tests for enctype support on a form (#6743)
	support.enctype = !!document.createElement("form").enctype;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE8 only
	// Check if we can trust getAttribute("value")
	input = document.createElement( "input" );
	input.setAttribute( "value", "" );
	support.input = input.getAttribute( "value" ) === "";

	// Check if an input maintains its value after becoming a radio
	input.value = "t";
	input.setAttribute( "type", "radio" );
	support.radioValue = input.value === "t";
})();


var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// oldIE doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];

					if ( jQuery.inArray( jQuery.valHooks.option.get( option ), values ) >= 0 ) {

						// Support: IE6
						// When new option element is added to select box we need to
						// force reflow of newly added node in order to workaround delay
						// of initialization properties
						try {
							option.selected = optionSet = true;

						} catch ( _ ) {

							// Will be executed only in IE6
							option.scrollHeight;
						}

					} else {
						option.selected = false;
					}
				}

				// Force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}

				return options;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			// Support: Webkit
			// "" is returned instead of "on" if a value isn't specified
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle,
	ruseDefault = /^(?:checked|selected)$/i,
	getSetAttribute = support.getSetAttribute,
	getSetInput = support.input;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
						elem[ propName ] = false;
					// Support: IE<9
					// Also clear defaultChecked/defaultSelected (if appropriate)
					} else {
						elem[ jQuery.camelCase( "default-" + name ) ] =
							elem[ propName ] = false;
					}

				// See #9699 for explanation of this approach (setting first, then removal)
				} else {
					jQuery.attr( elem, name, "" );
				}

				elem.removeAttribute( getSetAttribute ? name : propName );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to default in case type is set after value during creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hook for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
			// IE<8 needs the *property* name
			elem.setAttribute( !getSetAttribute && jQuery.propFix[ name ] || name, name );

		// Use defaultChecked and defaultSelected for oldIE
		} else {
			elem[ jQuery.camelCase( "default-" + name ) ] = elem[ name ] = true;
		}

		return name;
	}
};

// Retrieve booleans specially
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {

	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = getSetInput && getSetAttribute || !ruseDefault.test( name ) ?
		function( elem, name, isXML ) {
			var ret, handle;
			if ( !isXML ) {
				// Avoid an infinite loop by temporarily removing this function from the getter
				handle = attrHandle[ name ];
				attrHandle[ name ] = ret;
				ret = getter( elem, name, isXML ) != null ?
					name.toLowerCase() :
					null;
				attrHandle[ name ] = handle;
			}
			return ret;
		} :
		function( elem, name, isXML ) {
			if ( !isXML ) {
				return elem[ jQuery.camelCase( "default-" + name ) ] ?
					name.toLowerCase() :
					null;
			}
		};
});

// fix oldIE attroperties
if ( !getSetInput || !getSetAttribute ) {
	jQuery.attrHooks.value = {
		set: function( elem, value, name ) {
			if ( jQuery.nodeName( elem, "input" ) ) {
				// Does not return so that setAttribute is also used
				elem.defaultValue = value;
			} else {
				// Use nodeHook if defined (#1954); otherwise setAttribute is fine
				return nodeHook && nodeHook.set( elem, value, name );
			}
		}
	};
}

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = {
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				elem.setAttributeNode(
					(ret = elem.ownerDocument.createAttribute( name ))
				);
			}

			ret.value = value += "";

			// Break association with cloned elements by also using setAttribute (#9646)
			if ( name === "value" || value === elem.getAttribute( name ) ) {
				return value;
			}
		}
	};

	// Some attributes are constructed with empty-string values when not defined
	attrHandle.id = attrHandle.name = attrHandle.coords =
		function( elem, name, isXML ) {
			var ret;
			if ( !isXML ) {
				return (ret = elem.getAttributeNode( name )) && ret.value !== "" ?
					ret.value :
					null;
			}
		};

	// Fixing value retrieval on a button requires this module
	jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret = elem.getAttributeNode( name );
			if ( ret && ret.specified ) {
				return ret.value;
			}
		},
		set: nodeHook.set
	};

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		set: function( elem, value, name ) {
			nodeHook.set( elem, value === "" ? false : value, name );
		}
	};

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		};
	});
}

if ( !support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Note: IE uppercases css property names, but if we were to .toLowerCase()
			// .cssText, that would destroy case senstitivity in URL's, like in "background"
			return elem.style.cssText || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = value + "" );
		}
	};
}




var rfocusable = /^(?:input|select|textarea|button|object)$/i,
	rclickable = /^(?:a|area)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				// Use proper attribute retrieval(#12072)
				var tabindex = jQuery.find.attr( elem, "tabindex" );

				return tabindex ?
					parseInt( tabindex, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						-1;
			}
		}
	}
});

// Some attributes require a special call on IE
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !support.hrefNormalized ) {
	// href/src property should get the full normalized URL (#10299/#12915)
	jQuery.each([ "href", "src" ], function( i, name ) {
		jQuery.propHooks[ name ] = {
			get: function( elem ) {
				return elem.getAttribute( name, 4 );
			}
		};
	});
}

// Support: Safari, IE9+
// mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});

// IE6/7 call enctype encoding
if ( !support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = arguments.length === 0 || typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed "false",
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



var rvalidtokens = /(,)|(\[|{)|(}|])|"(?:[^"\\\r\n]|\\["\\\/bfnrt]|\\u[\da-fA-F]{4})*"\s*:?|true|false|null|-?(?!0\d)\d+(?:\.\d+|)(?:[eE][+-]?\d+|)/g;

jQuery.parseJSON = function( data ) {
	// Attempt to parse using the native JSON parser first
	if ( window.JSON && window.JSON.parse ) {
		// Support: Android 2.3
		// Workaround failure to string-cast null input
		return window.JSON.parse( data + "" );
	}

	var requireNonComma,
		depth = null,
		str = jQuery.trim( data + "" );

	// Guard against invalid (and possibly dangerous) input by ensuring that nothing remains
	// after removing valid tokens
	return str && !jQuery.trim( str.replace( rvalidtokens, function( token, comma, open, close ) {

		// Force termination if we see a misplaced comma
		if ( requireNonComma && comma ) {
			depth = 0;
		}

		// Perform no more replacements after returning to outermost depth
		if ( depth === 0 ) {
			return token;
		}

		// Commas must not follow "[", "{", or ","
		requireNonComma = open || comma;

		// Determine new depth
		// array/object open ("[" or "{"): depth += true - false (increment)
		// array/object close ("]" or "}"): depth += false - true (decrement)
		// other cases ("," or primitive): depth += true - true (numeric cast)
		depth += !close - !open;

		// Remove this token
		return "";
	}) ) ?
		( Function( "return " + str ) )() :
		jQuery.error( "Invalid JSON: " + data );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	try {
		if ( window.DOMParser ) { // Standard
			tmp = new DOMParser();
			xml = tmp.parseFromString( data, "text/xml" );
		} else { // IE
			xml = new ActiveXObject( "Microsoft.XMLDOM" );
			xml.async = "false";
			xml.loadXML( data );
		}
	} catch( e ) {
		xml = undefined;
	}
	if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	// Document location
	ajaxLocParts,
	ajaxLocation,

	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat("*");

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType.charAt( 0 ) === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var deep, key,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {
	var firstDataType, ct, finalDataType, type,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

			// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Cross-domain detection vars
			parts,
			// Loop variable
			i,
			// URL without anti-cache param
			cacheURL,
			// Response headers as string
			responseHeadersString,
			// timeout handle
			timeoutTimer,

			// To know if global events are to be dispatched
			fireGlobals,

			transport,
			// Response headers
			responseHeaders,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		// Don't fire events if jQuery.event is undefined in an AMD-usage scenario (#15118)
		fireGlobals = jQuery.event && s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0 ||
		(!support.reliableHiddenOffsets() &&
			((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
};

jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;
			// Use .is(":disabled") so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject !== undefined ?
	// Support: IE6+
	function() {

		// XHR cannot access local files, always use ActiveX for that case
		return !this.isLocal &&

			// Support: IE7-8
			// oldIE XHR does not support non-RFC2616 methods (#13240)
			// See http://msdn.microsoft.com/en-us/library/ie/ms536648(v=vs.85).aspx
			// and http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html#sec9
			// Although this check for six methods instead of eight
			// since IE also does not support "trace" and "connect"
			/^(get|post|head|put|delete|options)$/i.test( this.type ) &&

			createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

var xhrId = 0,
	xhrCallbacks = {},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE<10
// Open requests must be manually aborted on unload (#5280)
// See https://support.microsoft.com/kb/2856746 for more info
if ( window.attachEvent ) {
	window.attachEvent( "onunload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]( undefined, true );
		}
	});
}

// Determine support properties
support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
xhrSupported = support.ajax = !!xhrSupported;

// Create transport if the browser can provide an xhr
if ( xhrSupported ) {

	jQuery.ajaxTransport(function( options ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !options.crossDomain || support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {
					var i,
						xhr = options.xhr(),
						id = ++xhrId;

					// Open the socket
					xhr.open( options.type, options.url, options.async, options.username, options.password );

					// Apply custom fields if provided
					if ( options.xhrFields ) {
						for ( i in options.xhrFields ) {
							xhr[ i ] = options.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( options.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( options.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !options.crossDomain && !headers["X-Requested-With"] ) {
						headers["X-Requested-With"] = "XMLHttpRequest";
					}

					// Set headers
					for ( i in headers ) {
						// Support: IE<9
						// IE's ActiveXObject throws a 'Type Mismatch' exception when setting
						// request header to a null-value.
						//
						// To keep consistent with other XHR implementations, cast the value
						// to string and ignore `undefined`.
						if ( headers[ i ] !== undefined ) {
							xhr.setRequestHeader( i, headers[ i ] + "" );
						}
					}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( options.hasContent && options.data ) || null );

					// Listener
					callback = function( _, isAbort ) {
						var status, statusText, responses;

						// Was never called and is aborted or complete
						if ( callback && ( isAbort || xhr.readyState === 4 ) ) {
							// Clean up
							delete xhrCallbacks[ id ];
							callback = undefined;
							xhr.onreadystatechange = jQuery.noop;

							// Abort manually if needed
							if ( isAbort ) {
								if ( xhr.readyState !== 4 ) {
									xhr.abort();
								}
							} else {
								responses = {};
								status = xhr.status;

								// Support: IE<10
								// Accessing binary-data responseText throws an exception
								// (#11426)
								if ( typeof xhr.responseText === "string" ) {
									responses.text = xhr.responseText;
								}

								// Firefox throws an exception when accessing
								// statusText for faulty cross-domain requests
								try {
									statusText = xhr.statusText;
								} catch( e ) {
									// We normalize with Webkit giving an empty statusText
									statusText = "";
								}

								// Filter status for non standard behaviors

								// If the request is local and we have data: assume a success
								// (success with no data won't get notified, that's the best we
								// can do given current implementations)
								if ( !status && options.isLocal && !options.crossDomain ) {
									status = responses.text ? 200 : 404;
								// IE - #1450: sometimes returns 1223 when it should be 204
								} else if ( status === 1223 ) {
									status = 204;
								}
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, xhr.getAllResponseHeaders() );
						}
					};

					if ( !options.async ) {
						// if we're in sync mode we fire the callback
						callback();
					} else if ( xhr.readyState === 4 ) {
						// (IE6 & IE7) if it's in cache and has been
						// retrieved directly we need to fire the callback
						setTimeout( callback );
					} else {
						// Add to the list of active xhr callbacks
						xhr.onreadystatechange = xhrCallbacks[ id ] = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback( undefined, true );
					}
				}
			};
		}
	});
}

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject( "Microsoft.XMLHTTP" );
	} catch( e ) {}
}




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || jQuery("head")[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement("script");

				script.async = true;

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( script.parentNode ) {
							script.parentNode.removeChild( script );
						}

						// Dereference the script
						script = null;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};

				// Circumvent IE6 bugs with base elements (#2709 and #4378) by prepending
				// Use native DOM manipulation to avoid our domManip AJAX trickery
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( undefined, true );
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, response, type,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off, url.length ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};





var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			jQuery.inArray("auto", [ curCSSTop, curCSSLeft ] ) > -1;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			box = { top: 0, left: 0 },
			elem = this[ 0 ],
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// If we don't have gBCR, just use 0,0 rather than error
		// BlackBerry 5, iOS 3 (original iPhone)
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top  + ( win.pageYOffset || docElem.scrollTop )  - ( docElem.clientTop  || 0 ),
			left: box.left + ( win.pageXOffset || docElem.scrollLeft ) - ( docElem.clientLeft || 0 )
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			parentOffset = { top: 0, left: 0 },
			elem = this[ 0 ];

		// fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// we assume that getBoundingClientRect is available when computed position is fixed
			offset = elem.getBoundingClientRect();
		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top  += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		return {
			top:  offset.top  - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true)
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					win.document.documentElement[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// getComputedStyle returns percent when specified for top/left/bottom/right
// rather than make the css module depend on the offset module, we just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// if curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height], whichever is greatest
					// unfortunately, this causes bug #3838 in IE6/8 only, but there is currently no good, small way to fix it.
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in
// AMD (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));

//     Underscore.js 1.8.3
//     http://underscorejs.org
//     (c) 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
//     Underscore may be freely distributed under the MIT license.

(function() {

  // Baseline setup
  // --------------

  // Establish the root object, `window` (`self`) in the browser, or `global` on the server.
  // We use `self` instead of `window` for `WebWorker` support.
  var root = typeof self === 'object' && self.self === self && self ||
            typeof global === 'object' && global.global === global && global;

  // Save the previous value of the `_` variable.
  var previousUnderscore = root._;

  // Save bytes in the minified (but not gzipped) version:
  var ArrayProto = Array.prototype, ObjProto = Object.prototype;

  // Create quick reference variables for speed access to core prototypes.
  var
    push = ArrayProto.push,
    slice = ArrayProto.slice,
    toString = ObjProto.toString,
    hasOwnProperty = ObjProto.hasOwnProperty;

  // All **ECMAScript 5** native function implementations that we hope to use
  // are declared here.
  var
    nativeIsArray = Array.isArray,
    nativeKeys = Object.keys,
    nativeCreate = Object.create;

  // Naked function reference for surrogate-prototype-swapping.
  var Ctor = function(){};

  // Create a safe reference to the Underscore object for use below.
  var _ = function(obj) {
    if (obj instanceof _) return obj;
    if (!(this instanceof _)) return new _(obj);
    this._wrapped = obj;
  };

  // Export the Underscore object for **Node.js**, with
  // backwards-compatibility for their old module API. If we're in
  // the browser, add `_` as a global object.
  if (typeof exports !== 'undefined') {
    if (typeof module !== 'undefined' && module.exports) {
      exports = module.exports = _;
    }
    exports._ = _;
  } else {
    root._ = _;
  }

  // Current version.
  _.VERSION = '1.8.3';

  // Internal function that returns an efficient (for current engines) version
  // of the passed-in callback, to be repeatedly applied in other Underscore
  // functions.
  var optimizeCb = function(func, context, argCount) {
    if (context === void 0) return func;
    switch (argCount == null ? 3 : argCount) {
      case 1: return function(value) {
        return func.call(context, value);
      };
      case 2: return function(value, other) {
        return func.call(context, value, other);
      };
      case 3: return function(value, index, collection) {
        return func.call(context, value, index, collection);
      };
      case 4: return function(accumulator, value, index, collection) {
        return func.call(context, accumulator, value, index, collection);
      };
    }
    return function() {
      return func.apply(context, arguments);
    };
  };

  // A mostly-internal function to generate callbacks that can be applied
  // to each element in a collection, returning the desired result — either
  // identity, an arbitrary callback, a property matcher, or a property accessor.
  var cb = function(value, context, argCount) {
    if (value == null) return _.identity;
    if (_.isFunction(value)) return optimizeCb(value, context, argCount);
    if (_.isObject(value)) return _.matcher(value);
    return _.property(value);
  };
  _.iteratee = function(value, context) {
    return cb(value, context, Infinity);
  };

  // Similar to ES6's rest param (http://ariya.ofilabs.com/2013/03/es6-and-rest-parameter.html)
  // This accumulates the arguments passed into an array, after a given index.
  var restArgs = function(func, startIndex) {
    startIndex = startIndex == null ? func.length - 1 : +startIndex;
    return function() {
      var length = Math.max(arguments.length - startIndex, 0);
      var rest = Array(length);
      var index;
      for (index = 0; index < length; index++) {
        rest[index] = arguments[index + startIndex];
      }
      switch (startIndex) {
        case 0: return func.call(this, rest);
        case 1: return func.call(this, arguments[0], rest);
        case 2: return func.call(this, arguments[0], arguments[1], rest);
      }
      var args = Array(startIndex + 1);
      for (index = 0; index < startIndex; index++) {
        args[index] = arguments[index];
      }
      args[startIndex] = rest;
      return func.apply(this, args);
    };
  };

  // An internal function for creating a new object that inherits from another.
  var baseCreate = function(prototype) {
    if (!_.isObject(prototype)) return {};
    if (nativeCreate) return nativeCreate(prototype);
    Ctor.prototype = prototype;
    var result = new Ctor;
    Ctor.prototype = null;
    return result;
  };

  var property = function(key) {
    return function(obj) {
      return obj == null ? void 0 : obj[key];
    };
  };

  // Helper for collection methods to determine whether a collection
  // should be iterated as an array or as an object
  // Related: http://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength
  // Avoids a very nasty iOS 8 JIT bug on ARM-64. #2094
  var MAX_ARRAY_INDEX = Math.pow(2, 53) - 1;
  var getLength = property('length');
  var isArrayLike = function(collection) {
    var length = getLength(collection);
    return typeof length == 'number' && length >= 0 && length <= MAX_ARRAY_INDEX;
  };

  // Collection Functions
  // --------------------

  // The cornerstone, an `each` implementation, aka `forEach`.
  // Handles raw objects in addition to array-likes. Treats all
  // sparse array-likes as if they were dense.
  _.each = _.forEach = function(obj, iteratee, context) {
    iteratee = optimizeCb(iteratee, context);
    var i, length;
    if (isArrayLike(obj)) {
      for (i = 0, length = obj.length; i < length; i++) {
        iteratee(obj[i], i, obj);
      }
    } else {
      var keys = _.keys(obj);
      for (i = 0, length = keys.length; i < length; i++) {
        iteratee(obj[keys[i]], keys[i], obj);
      }
    }
    return obj;
  };

  // Return the results of applying the iteratee to each element.
  _.map = _.collect = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length,
        results = Array(length);
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      results[index] = iteratee(obj[currentKey], currentKey, obj);
    }
    return results;
  };

  // Create a reducing function iterating left or right.
  var createReduce = function(dir) {
    // Optimized iterator function as using arguments.length
    // in the main function will deoptimize the, see #1991.
    var reducer = function(obj, iteratee, memo, initial) {
      var keys = !isArrayLike(obj) && _.keys(obj),
          length = (keys || obj).length,
          index = dir > 0 ? 0 : length - 1;
      if (!initial) {
        memo = obj[keys ? keys[index] : index];
        index += dir;
      }
      for (; index >= 0 && index < length; index += dir) {
        var currentKey = keys ? keys[index] : index;
        memo = iteratee(memo, obj[currentKey], currentKey, obj);
      }
      return memo;
    };

    return function(obj, iteratee, memo, context) {
      var initial = arguments.length >= 3;
      return reducer(obj, optimizeCb(iteratee, context, 4), memo, initial);
    };
  };

  // **Reduce** builds up a single result from a list of values, aka `inject`,
  // or `foldl`.
  _.reduce = _.foldl = _.inject = createReduce(1);

  // The right-associative version of reduce, also known as `foldr`.
  _.reduceRight = _.foldr = createReduce(-1);

  // Return the first value which passes a truth test. Aliased as `detect`.
  _.find = _.detect = function(obj, predicate, context) {
    var key;
    if (isArrayLike(obj)) {
      key = _.findIndex(obj, predicate, context);
    } else {
      key = _.findKey(obj, predicate, context);
    }
    if (key !== void 0 && key !== -1) return obj[key];
  };

  // Return all the elements that pass a truth test.
  // Aliased as `select`.
  _.filter = _.select = function(obj, predicate, context) {
    var results = [];
    predicate = cb(predicate, context);
    _.each(obj, function(value, index, list) {
      if (predicate(value, index, list)) results.push(value);
    });
    return results;
  };

  // Return all the elements for which a truth test fails.
  _.reject = function(obj, predicate, context) {
    return _.filter(obj, _.negate(cb(predicate)), context);
  };

  // Determine whether all of the elements match a truth test.
  // Aliased as `all`.
  _.every = _.all = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length;
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      if (!predicate(obj[currentKey], currentKey, obj)) return false;
    }
    return true;
  };

  // Determine if at least one element in the object matches a truth test.
  // Aliased as `any`.
  _.some = _.any = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length;
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      if (predicate(obj[currentKey], currentKey, obj)) return true;
    }
    return false;
  };

  // Determine if the array or object contains a given item (using `===`).
  // Aliased as `includes` and `include`.
  _.contains = _.includes = _.include = function(obj, item, fromIndex, guard) {
    if (!isArrayLike(obj)) obj = _.values(obj);
    if (typeof fromIndex != 'number' || guard) fromIndex = 0;
    return _.indexOf(obj, item, fromIndex) >= 0;
  };

  // Invoke a method (with arguments) on every item in a collection.
  _.invoke = restArgs(function(obj, method, args) {
    var isFunc = _.isFunction(method);
    return _.map(obj, function(value) {
      var func = isFunc ? method : value[method];
      return func == null ? func : func.apply(value, args);
    });
  });

  // Convenience version of a common use case of `map`: fetching a property.
  _.pluck = function(obj, key) {
    return _.map(obj, _.property(key));
  };

  // Convenience version of a common use case of `filter`: selecting only objects
  // containing specific `key:value` pairs.
  _.where = function(obj, attrs) {
    return _.filter(obj, _.matcher(attrs));
  };

  // Convenience version of a common use case of `find`: getting the first object
  // containing specific `key:value` pairs.
  _.findWhere = function(obj, attrs) {
    return _.find(obj, _.matcher(attrs));
  };

  // Return the maximum element (or element-based computation).
  _.max = function(obj, iteratee, context) {
    var result = -Infinity, lastComputed = -Infinity,
        value, computed;
    if (iteratee == null && obj != null) {
      obj = isArrayLike(obj) ? obj : _.values(obj);
      for (var i = 0, length = obj.length; i < length; i++) {
        value = obj[i];
        if (value > result) {
          result = value;
        }
      }
    } else {
      iteratee = cb(iteratee, context);
      _.each(obj, function(v, index, list) {
        computed = iteratee(v, index, list);
        if (computed > lastComputed || computed === -Infinity && result === -Infinity) {
          result = v;
          lastComputed = computed;
        }
      });
    }
    return result;
  };

  // Return the minimum element (or element-based computation).
  _.min = function(obj, iteratee, context) {
    var result = Infinity, lastComputed = Infinity,
        value, computed;
    if (iteratee == null && obj != null) {
      obj = isArrayLike(obj) ? obj : _.values(obj);
      for (var i = 0, length = obj.length; i < length; i++) {
        value = obj[i];
        if (value < result) {
          result = value;
        }
      }
    } else {
      iteratee = cb(iteratee, context);
      _.each(obj, function(v, index, list) {
        computed = iteratee(v, index, list);
        if (computed < lastComputed || computed === Infinity && result === Infinity) {
          result = v;
          lastComputed = computed;
        }
      });
    }
    return result;
  };

  // Shuffle a collection.
  _.shuffle = function(obj) {
    return _.sample(obj, Infinity);
  };

  // Sample **n** random values from a collection using the modern version of the
  // [Fisher-Yates shuffle](http://en.wikipedia.org/wiki/Fisher–Yates_shuffle).
  // If **n** is not specified, returns a single random element.
  // The internal `guard` argument allows it to work with `map`.
  _.sample = function(obj, n, guard) {
    if (n == null || guard) {
      if (!isArrayLike(obj)) obj = _.values(obj);
      return obj[_.random(obj.length - 1)];
    }
    var sample = isArrayLike(obj) ? _.clone(obj) : _.values(obj);
    var length = getLength(sample);
    n = Math.max(Math.min(n, length), 0);
    var last = length - 1;
    for (var index = 0; index < n; index++) {
      var rand = _.random(index, last);
      var temp = sample[index];
      sample[index] = sample[rand];
      sample[rand] = temp;
    }
    return sample.slice(0, n);
  };

  // Sort the object's values by a criterion produced by an iteratee.
  _.sortBy = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    return _.pluck(_.map(obj, function(value, index, list) {
      return {
        value: value,
        index: index,
        criteria: iteratee(value, index, list)
      };
    }).sort(function(left, right) {
      var a = left.criteria;
      var b = right.criteria;
      if (a !== b) {
        if (a > b || a === void 0) return 1;
        if (a < b || b === void 0) return -1;
      }
      return left.index - right.index;
    }), 'value');
  };

  // An internal function used for aggregate "group by" operations.
  var group = function(behavior, partition) {
    return function(obj, iteratee, context) {
      var result = partition ? [[], []] : {};
      iteratee = cb(iteratee, context);
      _.each(obj, function(value, index) {
        var key = iteratee(value, index, obj);
        behavior(result, value, key);
      });
      return result;
    };
  };

  // Groups the object's values by a criterion. Pass either a string attribute
  // to group by, or a function that returns the criterion.
  _.groupBy = group(function(result, value, key) {
    if (_.has(result, key)) result[key].push(value); else result[key] = [value];
  });

  // Indexes the object's values by a criterion, similar to `groupBy`, but for
  // when you know that your index values will be unique.
  _.indexBy = group(function(result, value, key) {
    result[key] = value;
  });

  // Counts instances of an object that group by a certain criterion. Pass
  // either a string attribute to count by, or a function that returns the
  // criterion.
  _.countBy = group(function(result, value, key) {
    if (_.has(result, key)) result[key]++; else result[key] = 1;
  });

  // Safely create a real, live array from anything iterable.
  _.toArray = function(obj) {
    if (!obj) return [];
    if (_.isArray(obj)) return slice.call(obj);
    if (isArrayLike(obj)) return _.map(obj, _.identity);
    return _.values(obj);
  };

  // Return the number of elements in an object.
  _.size = function(obj) {
    if (obj == null) return 0;
    return isArrayLike(obj) ? obj.length : _.keys(obj).length;
  };

  // Split a collection into two arrays: one whose elements all satisfy the given
  // predicate, and one whose elements all do not satisfy the predicate.
  _.partition = group(function(result, value, pass) {
    result[pass ? 0 : 1].push(value);
  }, true);

  // Array Functions
  // ---------------

  // Get the first element of an array. Passing **n** will return the first N
  // values in the array. Aliased as `head` and `take`. The **guard** check
  // allows it to work with `_.map`.
  _.first = _.head = _.take = function(array, n, guard) {
    if (array == null) return void 0;
    if (n == null || guard) return array[0];
    return _.initial(array, array.length - n);
  };

  // Returns everything but the last entry of the array. Especially useful on
  // the arguments object. Passing **n** will return all the values in
  // the array, excluding the last N.
  _.initial = function(array, n, guard) {
    return slice.call(array, 0, Math.max(0, array.length - (n == null || guard ? 1 : n)));
  };

  // Get the last element of an array. Passing **n** will return the last N
  // values in the array.
  _.last = function(array, n, guard) {
    if (array == null) return void 0;
    if (n == null || guard) return array[array.length - 1];
    return _.rest(array, Math.max(0, array.length - n));
  };

  // Returns everything but the first entry of the array. Aliased as `tail` and `drop`.
  // Especially useful on the arguments object. Passing an **n** will return
  // the rest N values in the array.
  _.rest = _.tail = _.drop = function(array, n, guard) {
    return slice.call(array, n == null || guard ? 1 : n);
  };

  // Trim out all falsy values from an array.
  _.compact = function(array) {
    return _.filter(array, _.identity);
  };

  // Internal implementation of a recursive `flatten` function.
  var flatten = function(input, shallow, strict, output) {
    output = output || [];
    var idx = output.length;
    for (var i = 0, length = getLength(input); i < length; i++) {
      var value = input[i];
      if (isArrayLike(value) && (_.isArray(value) || _.isArguments(value))) {
        //flatten current level of array or arguments object
        if (shallow) {
          var j = 0, len = value.length;
          while (j < len) output[idx++] = value[j++];
        } else {
          flatten(value, shallow, strict, output);
          idx = output.length;
        }
      } else if (!strict) {
        output[idx++] = value;
      }
    }
    return output;
  };

  // Flatten out an array, either recursively (by default), or just one level.
  _.flatten = function(array, shallow) {
    return flatten(array, shallow, false);
  };

  // Return a version of the array that does not contain the specified value(s).
  _.without = restArgs(function(array, otherArrays) {
    return _.difference(array, otherArrays);
  });

  // Produce a duplicate-free version of the array. If the array has already
  // been sorted, you have the option of using a faster algorithm.
  // Aliased as `unique`.
  _.uniq = _.unique = function(array, isSorted, iteratee, context) {
    if (!_.isBoolean(isSorted)) {
      context = iteratee;
      iteratee = isSorted;
      isSorted = false;
    }
    if (iteratee != null) iteratee = cb(iteratee, context);
    var result = [];
    var seen = [];
    for (var i = 0, length = getLength(array); i < length; i++) {
      var value = array[i],
          computed = iteratee ? iteratee(value, i, array) : value;
      if (isSorted) {
        if (!i || seen !== computed) result.push(value);
        seen = computed;
      } else if (iteratee) {
        if (!_.contains(seen, computed)) {
          seen.push(computed);
          result.push(value);
        }
      } else if (!_.contains(result, value)) {
        result.push(value);
      }
    }
    return result;
  };

  // Produce an array that contains the union: each distinct element from all of
  // the passed-in arrays.
  _.union = restArgs(function(arrays) {
    return _.uniq(flatten(arrays, true, true));
  });

  // Produce an array that contains every item shared between all the
  // passed-in arrays.
  _.intersection = function(array) {
    var result = [];
    var argsLength = arguments.length;
    for (var i = 0, length = getLength(array); i < length; i++) {
      var item = array[i];
      if (_.contains(result, item)) continue;
      var j;
      for (j = 1; j < argsLength; j++) {
        if (!_.contains(arguments[j], item)) break;
      }
      if (j === argsLength) result.push(item);
    }
    return result;
  };

  // Take the difference between one array and a number of other arrays.
  // Only the elements present in just the first array will remain.
  _.difference = restArgs(function(array, rest) {
    rest = flatten(rest, true, true);
    return _.filter(array, function(value){
      return !_.contains(rest, value);
    });
  });

  // Complement of _.zip. Unzip accepts an array of arrays and groups
  // each array's elements on shared indices
  _.unzip = function(array) {
    var length = array && _.max(array, getLength).length || 0;
    var result = Array(length);

    for (var index = 0; index < length; index++) {
      result[index] = _.pluck(array, index);
    }
    return result;
  };

  // Zip together multiple lists into a single array -- elements that share
  // an index go together.
  _.zip = restArgs(_.unzip);

  // Converts lists into objects. Pass either a single array of `[key, value]`
  // pairs, or two parallel arrays of the same length -- one of keys, and one of
  // the corresponding values.
  _.object = function(list, values) {
    var result = {};
    for (var i = 0, length = getLength(list); i < length; i++) {
      if (values) {
        result[list[i]] = values[i];
      } else {
        result[list[i][0]] = list[i][1];
      }
    }
    return result;
  };

  // Generator function to create the findIndex and findLastIndex functions
  var createPredicateIndexFinder = function(dir) {
    return function(array, predicate, context) {
      predicate = cb(predicate, context);
      var length = getLength(array);
      var index = dir > 0 ? 0 : length - 1;
      for (; index >= 0 && index < length; index += dir) {
        if (predicate(array[index], index, array)) return index;
      }
      return -1;
    };
  };

  // Returns the first index on an array-like that passes a predicate test
  _.findIndex = createPredicateIndexFinder(1);
  _.findLastIndex = createPredicateIndexFinder(-1);

  // Use a comparator function to figure out the smallest index at which
  // an object should be inserted so as to maintain order. Uses binary search.
  _.sortedIndex = function(array, obj, iteratee, context) {
    iteratee = cb(iteratee, context, 1);
    var value = iteratee(obj);
    var low = 0, high = getLength(array);
    while (low < high) {
      var mid = Math.floor((low + high) / 2);
      if (iteratee(array[mid]) < value) low = mid + 1; else high = mid;
    }
    return low;
  };

  // Generator function to create the indexOf and lastIndexOf functions
  var createIndexFinder = function(dir, predicateFind, sortedIndex) {
    return function(array, item, idx) {
      var i = 0, length = getLength(array);
      if (typeof idx == 'number') {
        if (dir > 0) {
          i = idx >= 0 ? idx : Math.max(idx + length, i);
        } else {
          length = idx >= 0 ? Math.min(idx + 1, length) : idx + length + 1;
        }
      } else if (sortedIndex && idx && length) {
        idx = sortedIndex(array, item);
        return array[idx] === item ? idx : -1;
      }
      if (item !== item) {
        idx = predicateFind(slice.call(array, i, length), _.isNaN);
        return idx >= 0 ? idx + i : -1;
      }
      for (idx = dir > 0 ? i : length - 1; idx >= 0 && idx < length; idx += dir) {
        if (array[idx] === item) return idx;
      }
      return -1;
    };
  };

  // Return the position of the first occurrence of an item in an array,
  // or -1 if the item is not included in the array.
  // If the array is large and already in sort order, pass `true`
  // for **isSorted** to use binary search.
  _.indexOf = createIndexFinder(1, _.findIndex, _.sortedIndex);
  _.lastIndexOf = createIndexFinder(-1, _.findLastIndex);

  // Generate an integer Array containing an arithmetic progression. A port of
  // the native Python `range()` function. See
  // [the Python documentation](http://docs.python.org/library/functions.html#range).
  _.range = function(start, stop, step) {
    if (stop == null) {
      stop = start || 0;
      start = 0;
    }
    step = step || 1;

    var length = Math.max(Math.ceil((stop - start) / step), 0);
    var range = Array(length);

    for (var idx = 0; idx < length; idx++, start += step) {
      range[idx] = start;
    }

    return range;
  };

  // Function (ahem) Functions
  // ------------------

  // Determines whether to execute a function as a constructor
  // or a normal function with the provided arguments
  var executeBound = function(sourceFunc, boundFunc, context, callingContext, args) {
    if (!(callingContext instanceof boundFunc)) return sourceFunc.apply(context, args);
    var self = baseCreate(sourceFunc.prototype);
    var result = sourceFunc.apply(self, args);
    if (_.isObject(result)) return result;
    return self;
  };

  // Create a function bound to a given object (assigning `this`, and arguments,
  // optionally). Delegates to **ECMAScript 5**'s native `Function.bind` if
  // available.
  _.bind = restArgs(function(func, context, args) {
    if (!_.isFunction(func)) throw new TypeError('Bind must be called on a function');
    var bound = restArgs(function(callArgs) {
      return executeBound(func, bound, context, this, args.concat(callArgs));
    });
    return bound;
  });

  // Partially apply a function by creating a version that has had some of its
  // arguments pre-filled, without changing its dynamic `this` context. _ acts
  // as a placeholder by default, allowing any combination of arguments to be
  // pre-filled. Set `_.partial.placeholder` for a custom placeholder argument.
  _.partial = restArgs(function(func, boundArgs) {
    var placeholder = _.partial.placeholder;
    var bound = function() {
      var position = 0, length = boundArgs.length;
      var args = Array(length);
      for (var i = 0; i < length; i++) {
        args[i] = boundArgs[i] === placeholder ? arguments[position++] : boundArgs[i];
      }
      while (position < arguments.length) args.push(arguments[position++]);
      return executeBound(func, bound, this, this, args);
    };
    return bound;
  });

  _.partial.placeholder = _;

  // Bind a number of an object's methods to that object. Remaining arguments
  // are the method names to be bound. Useful for ensuring that all callbacks
  // defined on an object belong to it.
  _.bindAll = restArgs(function(obj, keys) {
    keys = flatten(keys, false, false);
    var index = keys.length;
    if (index < 1) throw new Error('bindAll must be passed function names');
    while (index--) {
      var key = keys[index];
      obj[key] = _.bind(obj[key], obj);
    }
  });

  // Memoize an expensive function by storing its results.
  _.memoize = function(func, hasher) {
    var memoize = function(key) {
      var cache = memoize.cache;
      var address = '' + (hasher ? hasher.apply(this, arguments) : key);
      if (!_.has(cache, address)) cache[address] = func.apply(this, arguments);
      return cache[address];
    };
    memoize.cache = {};
    return memoize;
  };

  // Delays a function for the given number of milliseconds, and then calls
  // it with the arguments supplied.
  _.delay = restArgs(function(func, wait, args) {
    return setTimeout(function(){
      return func.apply(null, args);
    }, wait);
  });

  // Defers a function, scheduling it to run after the current call stack has
  // cleared.
  _.defer = _.partial(_.delay, _, 1);

  // Returns a function, that, when invoked, will only be triggered at most once
  // during a given window of time. Normally, the throttled function will run
  // as much as it can, without ever going more than once per `wait` duration;
  // but if you'd like to disable the execution on the leading edge, pass
  // `{leading: false}`. To disable execution on the trailing edge, ditto.
  _.throttle = function(func, wait, options) {
    var context, args, result;
    var timeout = null;
    var previous = 0;
    if (!options) options = {};
    var later = function() {
      previous = options.leading === false ? 0 : _.now();
      timeout = null;
      result = func.apply(context, args);
      if (!timeout) context = args = null;
    };
    return function() {
      var now = _.now();
      if (!previous && options.leading === false) previous = now;
      var remaining = wait - (now - previous);
      context = this;
      args = arguments;
      if (remaining <= 0 || remaining > wait) {
        if (timeout) {
          clearTimeout(timeout);
          timeout = null;
        }
        previous = now;
        result = func.apply(context, args);
        if (!timeout) context = args = null;
      } else if (!timeout && options.trailing !== false) {
        timeout = setTimeout(later, remaining);
      }
      return result;
    };
  };

  // Returns a function, that, as long as it continues to be invoked, will not
  // be triggered. The function will be called after it stops being called for
  // N milliseconds. If `immediate` is passed, trigger the function on the
  // leading edge, instead of the trailing.
  _.debounce = function(func, wait, immediate) {
    var timeout, args, context, timestamp, result;

    var later = function() {
      var last = _.now() - timestamp;

      if (last < wait && last >= 0) {
        timeout = setTimeout(later, wait - last);
      } else {
        timeout = null;
        if (!immediate) {
          result = func.apply(context, args);
          if (!timeout) context = args = null;
        }
      }
    };

    return function() {
      context = this;
      args = arguments;
      timestamp = _.now();
      var callNow = immediate && !timeout;
      if (!timeout) timeout = setTimeout(later, wait);
      if (callNow) {
        result = func.apply(context, args);
        context = args = null;
      }

      return result;
    };
  };

  // Returns the first function passed as an argument to the second,
  // allowing you to adjust arguments, run code before and after, and
  // conditionally execute the original function.
  _.wrap = function(func, wrapper) {
    return _.partial(wrapper, func);
  };

  // Returns a negated version of the passed-in predicate.
  _.negate = function(predicate) {
    return function() {
      return !predicate.apply(this, arguments);
    };
  };

  // Returns a function that is the composition of a list of functions, each
  // consuming the return value of the function that follows.
  _.compose = function() {
    var args = arguments;
    var start = args.length - 1;
    return function() {
      var i = start;
      var result = args[start].apply(this, arguments);
      while (i--) result = args[i].call(this, result);
      return result;
    };
  };

  // Returns a function that will only be executed on and after the Nth call.
  _.after = function(times, func) {
    return function() {
      if (--times < 1) {
        return func.apply(this, arguments);
      }
    };
  };

  // Returns a function that will only be executed up to (but not including) the Nth call.
  _.before = function(times, func) {
    var memo;
    return function() {
      if (--times > 0) {
        memo = func.apply(this, arguments);
      }
      if (times <= 1) func = null;
      return memo;
    };
  };

  // Returns a function that will be executed at most one time, no matter how
  // often you call it. Useful for lazy initialization.
  _.once = _.partial(_.before, 2);

  _.restArgs = restArgs;

  // Object Functions
  // ----------------

  // Keys in IE < 9 that won't be iterated by `for key in ...` and thus missed.
  var hasEnumBug = !{toString: null}.propertyIsEnumerable('toString');
  var nonEnumerableProps = ['valueOf', 'isPrototypeOf', 'toString',
                      'propertyIsEnumerable', 'hasOwnProperty', 'toLocaleString'];

  var collectNonEnumProps = function(obj, keys) {
    var nonEnumIdx = nonEnumerableProps.length;
    var constructor = obj.constructor;
    var proto = _.isFunction(constructor) && constructor.prototype || ObjProto;

    // Constructor is a special case.
    var prop = 'constructor';
    if (_.has(obj, prop) && !_.contains(keys, prop)) keys.push(prop);

    while (nonEnumIdx--) {
      prop = nonEnumerableProps[nonEnumIdx];
      if (prop in obj && obj[prop] !== proto[prop] && !_.contains(keys, prop)) {
        keys.push(prop);
      }
    }
  };

  // Retrieve the names of an object's own properties.
  // Delegates to **ECMAScript 5**'s native `Object.keys`
  _.keys = function(obj) {
    if (!_.isObject(obj)) return [];
    if (nativeKeys) return nativeKeys(obj);
    var keys = [];
    for (var key in obj) if (_.has(obj, key)) keys.push(key);
    // Ahem, IE < 9.
    if (hasEnumBug) collectNonEnumProps(obj, keys);
    return keys;
  };

  // Retrieve all the property names of an object.
  _.allKeys = function(obj) {
    if (!_.isObject(obj)) return [];
    var keys = [];
    for (var key in obj) keys.push(key);
    // Ahem, IE < 9.
    if (hasEnumBug) collectNonEnumProps(obj, keys);
    return keys;
  };

  // Retrieve the values of an object's properties.
  _.values = function(obj) {
    var keys = _.keys(obj);
    var length = keys.length;
    var values = Array(length);
    for (var i = 0; i < length; i++) {
      values[i] = obj[keys[i]];
    }
    return values;
  };

  // Returns the results of applying the iteratee to each element of the object
  // In contrast to _.map it returns an object
  _.mapObject = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    var keys = _.keys(obj),
      length = keys.length,
      results = {};
    for (var index = 0; index < length; index++) {
      var currentKey = keys[index];
      results[currentKey] = iteratee(obj[currentKey], currentKey, obj);
    }
    return results;
  };

  // Convert an object into a list of `[key, value]` pairs.
  _.pairs = function(obj) {
    var keys = _.keys(obj);
    var length = keys.length;
    var pairs = Array(length);
    for (var i = 0; i < length; i++) {
      pairs[i] = [keys[i], obj[keys[i]]];
    }
    return pairs;
  };

  // Invert the keys and values of an object. The values must be serializable.
  _.invert = function(obj) {
    var result = {};
    var keys = _.keys(obj);
    for (var i = 0, length = keys.length; i < length; i++) {
      result[obj[keys[i]]] = keys[i];
    }
    return result;
  };

  // Return a sorted list of the function names available on the object.
  // Aliased as `methods`
  _.functions = _.methods = function(obj) {
    var names = [];
    for (var key in obj) {
      if (_.isFunction(obj[key])) names.push(key);
    }
    return names.sort();
  };

  // An internal function for creating assigner functions.
  var createAssigner = function(keysFunc, undefinedOnly) {
    return function(obj) {
      var length = arguments.length;
      if (length < 2 || obj == null) return obj;
      for (var index = 1; index < length; index++) {
        var source = arguments[index],
            keys = keysFunc(source),
            l = keys.length;
        for (var i = 0; i < l; i++) {
          var key = keys[i];
          if (!undefinedOnly || obj[key] === void 0) obj[key] = source[key];
        }
      }
      return obj;
    };
  };

  // Extend a given object with all the properties in passed-in object(s).
  _.extend = createAssigner(_.allKeys);

  // Assigns a given object with all the own properties in the passed-in object(s)
  // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
  _.extendOwn = _.assign = createAssigner(_.keys);

  // Returns the first key on an object that passes a predicate test
  _.findKey = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = _.keys(obj), key;
    for (var i = 0, length = keys.length; i < length; i++) {
      key = keys[i];
      if (predicate(obj[key], key, obj)) return key;
    }
  };

  // Internal pick helper function to determine if `obj` has key `key`.
  var keyInObj = function(value, key, obj) {
    return key in obj;
  };

  // Return a copy of the object only containing the whitelisted properties.
  _.pick = restArgs(function(obj, keys) {
    var result = {}, iteratee = keys[0];
    if (obj == null) return result;
    if (_.isFunction(iteratee)) {
      if (keys.length > 1) iteratee = optimizeCb(iteratee, keys[1]);
      keys = _.allKeys(obj);
    } else {
      iteratee = keyInObj;
      keys = flatten(keys, false, false);
      obj = Object(obj);
    }
    for (var i = 0, length = keys.length; i < length; i++) {
      var key = keys[i];
      var value = obj[key];
      if (iteratee(value, key, obj)) result[key] = value;
    }
    return result;
  });

   // Return a copy of the object without the blacklisted properties.
  _.omit = restArgs(function(obj, keys) {
    var iteratee = keys[0], context;
    if (_.isFunction(iteratee)) {
      iteratee = _.negate(iteratee);
      if (keys.length > 1) context = keys[1];
    } else {
      keys = _.map(flatten(keys, false, false), String);
      iteratee = function(value, key) {
        return !_.contains(keys, key);
      };
    }
    return _.pick(obj, iteratee, context);
  });

  // Fill in a given object with default properties.
  _.defaults = createAssigner(_.allKeys, true);

  // Creates an object that inherits from the given prototype object.
  // If additional properties are provided then they will be added to the
  // created object.
  _.create = function(prototype, props) {
    var result = baseCreate(prototype);
    if (props) _.extendOwn(result, props);
    return result;
  };

  // Create a (shallow-cloned) duplicate of an object.
  _.clone = function(obj) {
    if (!_.isObject(obj)) return obj;
    return _.isArray(obj) ? obj.slice() : _.extend({}, obj);
  };

  // Invokes interceptor with the obj, and then returns obj.
  // The primary purpose of this method is to "tap into" a method chain, in
  // order to perform operations on intermediate results within the chain.
  _.tap = function(obj, interceptor) {
    interceptor(obj);
    return obj;
  };

  // Returns whether an object has a given set of `key:value` pairs.
  _.isMatch = function(object, attrs) {
    var keys = _.keys(attrs), length = keys.length;
    if (object == null) return !length;
    var obj = Object(object);
    for (var i = 0; i < length; i++) {
      var key = keys[i];
      if (attrs[key] !== obj[key] || !(key in obj)) return false;
    }
    return true;
  };


  // Internal recursive comparison function for `isEqual`.
  var eq, deepEq;
  eq = function(a, b, aStack, bStack) {
    // Identical objects are equal. `0 === -0`, but they aren't identical.
    // See the [Harmony `egal` proposal](http://wiki.ecmascript.org/doku.php?id=harmony:egal).
    if (a === b) return a !== 0 || 1 / a === 1 / b;
    // A strict comparison is necessary because `null == undefined`.
    if (a == null || b == null) return a === b;
    // `NaN`s are equivalent, but non-reflexive.
    if (a !== a) return b !== b;
    // Exhaust primitive checks
    var type = typeof a;
    if (type !== 'function' && type !== 'object' && typeof b !== 'object') return false;
    return deepEq(a, b, aStack, bStack);
  };

  // Internal recursive comparison function for `isEqual`.
  deepEq = function(a, b, aStack, bStack) {
    // Unwrap any wrapped objects.
    if (a instanceof _) a = a._wrapped;
    if (b instanceof _) b = b._wrapped;
    // Compare `[[Class]]` names.
    var className = toString.call(a);
    if (className !== toString.call(b)) return false;
    switch (className) {
      // Strings, numbers, regular expressions, dates, and booleans are compared by value.
      case '[object RegExp]':
      // RegExps are coerced to strings for comparison (Note: '' + /a/i === '/a/i')
      case '[object String]':
        // Primitives and their corresponding object wrappers are equivalent; thus, `"5"` is
        // equivalent to `new String("5")`.
        return '' + a === '' + b;
      case '[object Number]':
        // `NaN`s are equivalent, but non-reflexive.
        // Object(NaN) is equivalent to NaN
        if (+a !== +a) return +b !== +b;
        // An `egal` comparison is performed for other numeric values.
        return +a === 0 ? 1 / +a === 1 / b : +a === +b;
      case '[object Date]':
      case '[object Boolean]':
        // Coerce dates and booleans to numeric primitive values. Dates are compared by their
        // millisecond representations. Note that invalid dates with millisecond representations
        // of `NaN` are not equivalent.
        return +a === +b;
    }

    var areArrays = className === '[object Array]';
    if (!areArrays) {
      if (typeof a != 'object' || typeof b != 'object') return false;

      // Objects with different constructors are not equivalent, but `Object`s or `Array`s
      // from different frames are.
      var aCtor = a.constructor, bCtor = b.constructor;
      if (aCtor !== bCtor && !(_.isFunction(aCtor) && aCtor instanceof aCtor &&
                               _.isFunction(bCtor) && bCtor instanceof bCtor)
                          && ('constructor' in a && 'constructor' in b)) {
        return false;
      }
    }
    // Assume equality for cyclic structures. The algorithm for detecting cyclic
    // structures is adapted from ES 5.1 section 15.12.3, abstract operation `JO`.

    // Initializing stack of traversed objects.
    // It's done here since we only need them for objects and arrays comparison.
    aStack = aStack || [];
    bStack = bStack || [];
    var length = aStack.length;
    while (length--) {
      // Linear search. Performance is inversely proportional to the number of
      // unique nested structures.
      if (aStack[length] === a) return bStack[length] === b;
    }

    // Add the first object to the stack of traversed objects.
    aStack.push(a);
    bStack.push(b);

    // Recursively compare objects and arrays.
    if (areArrays) {
      // Compare array lengths to determine if a deep comparison is necessary.
      length = a.length;
      if (length !== b.length) return false;
      // Deep compare the contents, ignoring non-numeric properties.
      while (length--) {
        if (!eq(a[length], b[length], aStack, bStack)) return false;
      }
    } else {
      // Deep compare objects.
      var keys = _.keys(a), key;
      length = keys.length;
      // Ensure that both objects contain the same number of properties before comparing deep equality.
      if (_.keys(b).length !== length) return false;
      while (length--) {
        // Deep compare each member
        key = keys[length];
        if (!(_.has(b, key) && eq(a[key], b[key], aStack, bStack))) return false;
      }
    }
    // Remove the first object from the stack of traversed objects.
    aStack.pop();
    bStack.pop();
    return true;
  };

  // Perform a deep comparison to check if two objects are equal.
  _.isEqual = function(a, b) {
    return eq(a, b);
  };

  // Is a given array, string, or object empty?
  // An "empty" object has no enumerable own-properties.
  _.isEmpty = function(obj) {
    if (obj == null) return true;
    if (isArrayLike(obj) && (_.isArray(obj) || _.isString(obj) || _.isArguments(obj))) return obj.length === 0;
    return _.keys(obj).length === 0;
  };

  // Is a given value a DOM element?
  _.isElement = function(obj) {
    return !!(obj && obj.nodeType === 1);
  };

  // Is a given value an array?
  // Delegates to ECMA5's native Array.isArray
  _.isArray = nativeIsArray || function(obj) {
    return toString.call(obj) === '[object Array]';
  };

  // Is a given variable an object?
  _.isObject = function(obj) {
    var type = typeof obj;
    return type === 'function' || type === 'object' && !!obj;
  };

  // Add some isType methods: isArguments, isFunction, isString, isNumber, isDate, isRegExp, isError.
  _.each(['Arguments', 'Function', 'String', 'Number', 'Date', 'RegExp', 'Error'], function(name) {
    _['is' + name] = function(obj) {
      return toString.call(obj) === '[object ' + name + ']';
    };
  });

  // Define a fallback version of the method in browsers (ahem, IE < 9), where
  // there isn't any inspectable "Arguments" type.
  if (!_.isArguments(arguments)) {
    _.isArguments = function(obj) {
      return _.has(obj, 'callee');
    };
  }

  // Optimize `isFunction` if appropriate. Work around some typeof bugs in old v8,
  // IE 11 (#1621), and in Safari 8 (#1929).
  if (typeof /./ != 'function' && typeof Int8Array != 'object') {
    _.isFunction = function(obj) {
      return typeof obj == 'function' || false;
    };
  }

  // Is a given object a finite number?
  _.isFinite = function(obj) {
    return isFinite(obj) && !isNaN(parseFloat(obj));
  };

  // Is the given value `NaN`? (NaN is the only number which does not equal itself).
  _.isNaN = function(obj) {
    return _.isNumber(obj) && obj !== +obj;
  };

  // Is a given value a boolean?
  _.isBoolean = function(obj) {
    return obj === true || obj === false || toString.call(obj) === '[object Boolean]';
  };

  // Is a given value equal to null?
  _.isNull = function(obj) {
    return obj === null;
  };

  // Is a given variable undefined?
  _.isUndefined = function(obj) {
    return obj === void 0;
  };

  // Shortcut function for checking if an object has a given property directly
  // on itself (in other words, not on a prototype).
  _.has = function(obj, key) {
    return obj != null && hasOwnProperty.call(obj, key);
  };

  // Utility Functions
  // -----------------

  // Run Underscore.js in *noConflict* mode, returning the `_` variable to its
  // previous owner. Returns a reference to the Underscore object.
  _.noConflict = function() {
    root._ = previousUnderscore;
    return this;
  };

  // Keep the identity function around for default iteratees.
  _.identity = function(value) {
    return value;
  };

  // Predicate-generating functions. Often useful outside of Underscore.
  _.constant = function(value) {
    return function() {
      return value;
    };
  };

  _.noop = function(){};

  _.property = property;

  // Generates a function for a given object that returns a given property.
  _.propertyOf = function(obj) {
    return obj == null ? function(){} : function(key) {
      return obj[key];
    };
  };

  // Returns a predicate for checking whether an object has a given set of
  // `key:value` pairs.
  _.matcher = _.matches = function(attrs) {
    attrs = _.extendOwn({}, attrs);
    return function(obj) {
      return _.isMatch(obj, attrs);
    };
  };

  // Run a function **n** times.
  _.times = function(n, iteratee, context) {
    var accum = Array(Math.max(0, n));
    iteratee = optimizeCb(iteratee, context, 1);
    for (var i = 0; i < n; i++) accum[i] = iteratee(i);
    return accum;
  };

  // Return a random integer between min and max (inclusive).
  _.random = function(min, max) {
    if (max == null) {
      max = min;
      min = 0;
    }
    return min + Math.floor(Math.random() * (max - min + 1));
  };

  // A (possibly faster) way to get the current timestamp as an integer.
  _.now = Date.now || function() {
    return new Date().getTime();
  };

   // List of HTML entities for escaping.
  var escapeMap = {
    '&': '&amp;',
    '<': '&lt;',
    '>': '&gt;',
    '"': '&quot;',
    "'": '&#x27;',
    '`': '&#x60;'
  };
  var unescapeMap = _.invert(escapeMap);

  // Functions for escaping and unescaping strings to/from HTML interpolation.
  var createEscaper = function(map) {
    var escaper = function(match) {
      return map[match];
    };
    // Regexes for identifying a key that needs to be escaped
    var source = '(?:' + _.keys(map).join('|') + ')';
    var testRegexp = RegExp(source);
    var replaceRegexp = RegExp(source, 'g');
    return function(string) {
      string = string == null ? '' : '' + string;
      return testRegexp.test(string) ? string.replace(replaceRegexp, escaper) : string;
    };
  };
  _.escape = createEscaper(escapeMap);
  _.unescape = createEscaper(unescapeMap);

  // If the value of the named `property` is a function then invoke it with the
  // `object` as context; otherwise, return it.
  _.result = function(object, prop, fallback) {
    var value = object == null ? void 0 : object[prop];
    if (value === void 0) {
      value = fallback;
    }
    return _.isFunction(value) ? value.call(object) : value;
  };

  // Generate a unique integer id (unique within the entire client session).
  // Useful for temporary DOM ids.
  var idCounter = 0;
  _.uniqueId = function(prefix) {
    var id = ++idCounter + '';
    return prefix ? prefix + id : id;
  };

  // By default, Underscore uses ERB-style template delimiters, change the
  // following template settings to use alternative delimiters.
  _.templateSettings = {
    evaluate: /<%([\s\S]+?)%>/g,
    interpolate: /<%=([\s\S]+?)%>/g,
    escape: /<%-([\s\S]+?)%>/g
  };

  // When customizing `templateSettings`, if you don't want to define an
  // interpolation, evaluation or escaping regex, we need one that is
  // guaranteed not to match.
  var noMatch = /(.)^/;

  // Certain characters need to be escaped so that they can be put into a
  // string literal.
  var escapes = {
    "'": "'",
    '\\': '\\',
    '\r': 'r',
    '\n': 'n',
    '\u2028': 'u2028',
    '\u2029': 'u2029'
  };

  var escapeRegExp = /\\|'|\r|\n|\u2028|\u2029/g;

  var escapeChar = function(match) {
    return '\\' + escapes[match];
  };

  // JavaScript micro-templating, similar to John Resig's implementation.
  // Underscore templating handles arbitrary delimiters, preserves whitespace,
  // and correctly escapes quotes within interpolated code.
  // NB: `oldSettings` only exists for backwards compatibility.
  _.template = function(text, settings, oldSettings) {
    if (!settings && oldSettings) settings = oldSettings;
    settings = _.defaults({}, settings, _.templateSettings);

    // Combine delimiters into one regular expression via alternation.
    var matcher = RegExp([
      (settings.escape || noMatch).source,
      (settings.interpolate || noMatch).source,
      (settings.evaluate || noMatch).source
    ].join('|') + '|$', 'g');

    // Compile the template source, escaping string literals appropriately.
    var index = 0;
    var source = "__p+='";
    text.replace(matcher, function(match, escape, interpolate, evaluate, offset) {
      source += text.slice(index, offset).replace(escapeRegExp, escapeChar);
      index = offset + match.length;

      if (escape) {
        source += "'+\n((__t=(" + escape + "))==null?'':_.escape(__t))+\n'";
      } else if (interpolate) {
        source += "'+\n((__t=(" + interpolate + "))==null?'':__t)+\n'";
      } else if (evaluate) {
        source += "';\n" + evaluate + "\n__p+='";
      }

      // Adobe VMs need the match returned to produce the correct offest.
      return match;
    });
    source += "';\n";

    // If a variable is not specified, place data values in local scope.
    if (!settings.variable) source = 'with(obj||{}){\n' + source + '}\n';

    source = "var __t,__p='',__j=Array.prototype.join," +
      "print=function(){__p+=__j.call(arguments,'');};\n" +
      source + 'return __p;\n';

    var render;
    try {
      render = new Function(settings.variable || 'obj', '_', source);
    } catch (e) {
      e.source = source;
      throw e;
    }

    var template = function(data) {
      return render.call(this, data, _);
    };

    // Provide the compiled source as a convenience for precompilation.
    var argument = settings.variable || 'obj';
    template.source = 'function(' + argument + '){\n' + source + '}';

    return template;
  };

  // Add a "chain" function. Start chaining a wrapped Underscore object.
  _.chain = function(obj) {
    var instance = _(obj);
    instance._chain = true;
    return instance;
  };

  // OOP
  // ---------------
  // If Underscore is called as a function, it returns a wrapped object that
  // can be used OO-style. This wrapper holds altered versions of all the
  // underscore functions. Wrapped objects may be chained.

  // Helper function to continue chaining intermediate results.
  var chainResult = function(instance, obj) {
    return instance._chain ? _(obj).chain() : obj;
  };

  // Add your own custom functions to the Underscore object.
  _.mixin = function(obj) {
    _.each(_.functions(obj), function(name) {
      var func = _[name] = obj[name];
      _.prototype[name] = function() {
        var args = [this._wrapped];
        push.apply(args, arguments);
        return chainResult(this, func.apply(_, args));
      };
    });
  };

  // Add all of the Underscore functions to the wrapper object.
  _.mixin(_);

  // Add all mutator Array functions to the wrapper.
  _.each(['pop', 'push', 'reverse', 'shift', 'sort', 'splice', 'unshift'], function(name) {
    var method = ArrayProto[name];
    _.prototype[name] = function() {
      var obj = this._wrapped;
      method.apply(obj, arguments);
      if ((name === 'shift' || name === 'splice') && obj.length === 0) delete obj[0];
      return chainResult(this, obj);
    };
  });

  // Add all accessor Array functions to the wrapper.
  _.each(['concat', 'join', 'slice'], function(name) {
    var method = ArrayProto[name];
    _.prototype[name] = function() {
      return chainResult(this, method.apply(this._wrapped, arguments));
    };
  });

  // Extracts the result from a wrapped and chained object.
  _.prototype.value = function() {
    return this._wrapped;
  };

  // Provide unwrapping proxy for some methods used in engine operations
  // such as arithmetic and JSON stringification.
  _.prototype.valueOf = _.prototype.toJSON = _.prototype.value;

  _.prototype.toString = function() {
    return '' + this._wrapped;
  };

  // AMD registration happens at the end for compatibility with AMD loaders
  // that may not enforce next-turn semantics on modules. Even though general
  // practice for AMD registration is to be anonymous, underscore registers
  // as a named module because, like jQuery, it is a base library that is
  // popular enough to be bundled in a third party lib, but not be part of
  // an AMD load request. Those cases could generate an error when an
  // anonymous define() is called outside of a loader request.
  if (typeof define === 'function' && define.amd) {
    define('underscore', [], function() {
      return _;
    });
  }
}());

;(function () {
	'use strict';

	/**
	 * @preserve FastClick: polyfill to remove click delays on browsers with touch UIs.
	 *
	 * @codingstandard ftlabs-jsv2
	 * @copyright The Financial Times Limited [All Rights Reserved]
	 * @license MIT License (see LICENSE.txt)
	 */

	/*jslint browser:true, node:true*/
	/*global define, Event, Node*/


	/**
	 * Instantiate fast-clicking listeners on the specified layer.
	 *
	 * @constructor
	 * @param {Element} layer The layer to listen on
	 * @param {Object} [options={}] The options to override the defaults
	 */
	function FastClick(layer, options) {
		var oldOnClick;

		options = options || {};

		/**
		 * Whether a click is currently being tracked.
		 *
		 * @type boolean
		 */
		this.trackingClick = false;


		/**
		 * Timestamp for when click tracking started.
		 *
		 * @type number
		 */
		this.trackingClickStart = 0;


		/**
		 * The element being tracked for a click.
		 *
		 * @type EventTarget
		 */
		this.targetElement = null;


		/**
		 * X-coordinate of touch start event.
		 *
		 * @type number
		 */
		this.touchStartX = 0;


		/**
		 * Y-coordinate of touch start event.
		 *
		 * @type number
		 */
		this.touchStartY = 0;


		/**
		 * ID of the last touch, retrieved from Touch.identifier.
		 *
		 * @type number
		 */
		this.lastTouchIdentifier = 0;


		/**
		 * Touchmove boundary, beyond which a click will be cancelled.
		 *
		 * @type number
		 */
		this.touchBoundary = options.touchBoundary || 10;


		/**
		 * The FastClick layer.
		 *
		 * @type Element
		 */
		this.layer = layer;

		/**
		 * The minimum time between tap(touchstart and touchend) events
		 *
		 * @type number
		 */
		this.tapDelay = options.tapDelay || 200;

		/**
		 * The maximum time for a tap
		 *
		 * @type number
		 */
		this.tapTimeout = options.tapTimeout || 700;

		if (FastClick.notNeeded(layer)) {
			return;
		}

		// Some old versions of Android don't have Function.prototype.bind
		function bind(method, context) {
			return function() { return method.apply(context, arguments); };
		}


		var methods = ['onMouse', 'onClick', 'onTouchStart', 'onTouchMove', 'onTouchEnd', 'onTouchCancel'];
		var context = this;
		for (var i = 0, l = methods.length; i < l; i++) {
			context[methods[i]] = bind(context[methods[i]], context);
		}

		// Set up event handlers as required
		if (deviceIsAndroid) {
			layer.addEventListener('mouseover', this.onMouse, true);
			layer.addEventListener('mousedown', this.onMouse, true);
			layer.addEventListener('mouseup', this.onMouse, true);
		}

		layer.addEventListener('click', this.onClick, true);
		layer.addEventListener('touchstart', this.onTouchStart, false);
		layer.addEventListener('touchmove', this.onTouchMove, false);
		layer.addEventListener('touchend', this.onTouchEnd, false);
		layer.addEventListener('touchcancel', this.onTouchCancel, false);

		// Hack is required for browsers that don't support Event#stopImmediatePropagation (e.g. Android 2)
		// which is how FastClick normally stops click events bubbling to callbacks registered on the FastClick
		// layer when they are cancelled.
		if (!Event.prototype.stopImmediatePropagation) {
			layer.removeEventListener = function(type, callback, capture) {
				var rmv = Node.prototype.removeEventListener;
				if (type === 'click') {
					rmv.call(layer, type, callback.hijacked || callback, capture);
				} else {
					rmv.call(layer, type, callback, capture);
				}
			};

			layer.addEventListener = function(type, callback, capture) {
				var adv = Node.prototype.addEventListener;
				if (type === 'click') {
					adv.call(layer, type, callback.hijacked || (callback.hijacked = function(event) {
						if (!event.propagationStopped) {
							callback(event);
						}
					}), capture);
				} else {
					adv.call(layer, type, callback, capture);
				}
			};
		}

		// If a handler is already declared in the element's onclick attribute, it will be fired before
		// FastClick's onClick handler. Fix this by pulling out the user-defined handler function and
		// adding it as listener.
		if (typeof layer.onclick === 'function') {

			// Android browser on at least 3.2 requires a new reference to the function in layer.onclick
			// - the old one won't work if passed to addEventListener directly.
			oldOnClick = layer.onclick;
			layer.addEventListener('click', function(event) {
				oldOnClick(event);
			}, false);
			layer.onclick = null;
		}
	}

	/**
	* Windows Phone 8.1 fakes user agent string to look like Android and iPhone.
	*
	* @type boolean
	*/
	var deviceIsWindowsPhone = navigator.userAgent.indexOf("Windows Phone") >= 0;

	/**
	 * Android requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsAndroid = navigator.userAgent.indexOf('Android') > 0 && !deviceIsWindowsPhone;


	/**
	 * iOS requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsIOS = /iP(ad|hone|od)/.test(navigator.userAgent) && !deviceIsWindowsPhone;


	/**
	 * iOS 4 requires an exception for select elements.
	 *
	 * @type boolean
	 */
	var deviceIsIOS4 = deviceIsIOS && (/OS 4_\d(_\d)?/).test(navigator.userAgent);


	/**
	 * iOS 6.0-7.* requires the target element to be manually derived
	 *
	 * @type boolean
	 */
	var deviceIsIOSWithBadTarget = deviceIsIOS && (/OS [6-7]_\d/).test(navigator.userAgent);

	/**
	 * BlackBerry requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsBlackBerry10 = navigator.userAgent.indexOf('BB10') > 0;

	/**
	 * Determine whether a given element requires a native click.
	 *
	 * @param {EventTarget|Element} target Target DOM element
	 * @returns {boolean} Returns true if the element needs a native click
	 */
	FastClick.prototype.needsClick = function(target) {
		switch (target.nodeName.toLowerCase()) {

		// Don't send a synthetic click to disabled inputs (issue #62)
		case 'button':
		case 'select':
		case 'textarea':
			if (target.disabled) {
				return true;
			}

			break;
		case 'input':

			// File inputs need real clicks on iOS 6 due to a browser bug (issue #68)
			if ((deviceIsIOS && target.type === 'file') || target.disabled) {
				return true;
			}

			break;
		case 'label':
		case 'iframe': // iOS8 homescreen apps can prevent events bubbling into frames
		case 'video':
			return true;
		}

		return (/\bneedsclick\b/).test(target.className);
	};


	/**
	 * Determine whether a given element requires a call to focus to simulate click into element.
	 *
	 * @param {EventTarget|Element} target Target DOM element
	 * @returns {boolean} Returns true if the element requires a call to focus to simulate native click.
	 */
	FastClick.prototype.needsFocus = function(target) {
		switch (target.nodeName.toLowerCase()) {
		case 'textarea':
			return true;
		case 'select':
			return !deviceIsAndroid;
		case 'input':
			switch (target.type) {
			case 'button':
			case 'checkbox':
			case 'file':
			case 'image':
			case 'radio':
			case 'submit':
				return false;
			}

			// No point in attempting to focus disabled inputs
			return !target.disabled && !target.readOnly;
		default:
			return (/\bneedsfocus\b/).test(target.className);
		}
	};


	/**
	 * Send a click event to the specified element.
	 *
	 * @param {EventTarget|Element} targetElement
	 * @param {Event} event
	 */
	FastClick.prototype.sendClick = function(targetElement, event) {
		var clickEvent, touch;

		// On some Android devices activeElement needs to be blurred otherwise the synthetic click will have no effect (#24)
		if (document.activeElement && document.activeElement !== targetElement) {
			document.activeElement.blur();
		}

		touch = event.changedTouches[0];

		// Synthesise a click event, with an extra attribute so it can be tracked
		clickEvent = document.createEvent('MouseEvents');
		clickEvent.initMouseEvent(this.determineEventType(targetElement), true, true, window, 1, touch.screenX, touch.screenY, touch.clientX, touch.clientY, false, false, false, false, 0, null);
		clickEvent.forwardedTouchEvent = true;
		targetElement.dispatchEvent(clickEvent);
	};

	FastClick.prototype.determineEventType = function(targetElement) {

		//Issue #159: Android Chrome Select Box does not open with a synthetic click event
		if (deviceIsAndroid && targetElement.tagName.toLowerCase() === 'select') {
			return 'mousedown';
		}

		return 'click';
	};


	/**
	 * @param {EventTarget|Element} targetElement
	 */
	FastClick.prototype.focus = function(targetElement) {
		var length;

		// Issue #160: on iOS 7, some input elements (e.g. date datetime month) throw a vague TypeError on setSelectionRange. These elements don't have an integer value for the selectionStart and selectionEnd properties, but unfortunately that can't be used for detection because accessing the properties also throws a TypeError. Just check the type instead. Filed as Apple bug #15122724.
		if (deviceIsIOS && targetElement.setSelectionRange && targetElement.type.indexOf('date') !== 0 && targetElement.type !== 'time' && targetElement.type !== 'month') {
			length = targetElement.value.length;
			targetElement.setSelectionRange(length, length);
		} else {
			targetElement.focus();
		}
	};


	/**
	 * Check whether the given target element is a child of a scrollable layer and if so, set a flag on it.
	 *
	 * @param {EventTarget|Element} targetElement
	 */
	FastClick.prototype.updateScrollParent = function(targetElement) {
		var scrollParent, parentElement;

		scrollParent = targetElement.fastClickScrollParent;

		// Attempt to discover whether the target element is contained within a scrollable layer. Re-check if the
		// target element was moved to another parent.
		if (!scrollParent || !scrollParent.contains(targetElement)) {
			parentElement = targetElement;
			do {
				if (parentElement.scrollHeight > parentElement.offsetHeight) {
					scrollParent = parentElement;
					targetElement.fastClickScrollParent = parentElement;
					break;
				}

				parentElement = parentElement.parentElement;
			} while (parentElement);
		}

		// Always update the scroll top tracker if possible.
		if (scrollParent) {
			scrollParent.fastClickLastScrollTop = scrollParent.scrollTop;
		}
	};


	/**
	 * @param {EventTarget} targetElement
	 * @returns {Element|EventTarget}
	 */
	FastClick.prototype.getTargetElementFromEventTarget = function(eventTarget) {

		// On some older browsers (notably Safari on iOS 4.1 - see issue #56) the event target may be a text node.
		if (eventTarget.nodeType === Node.TEXT_NODE) {
			return eventTarget.parentNode;
		}

		return eventTarget;
	};


	/**
	 * On touch start, record the position and scroll offset.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchStart = function(event) {
		var targetElement, touch, selection;

		// Ignore multiple touches, otherwise pinch-to-zoom is prevented if both fingers are on the FastClick element (issue #111).
		if (event.targetTouches.length > 1) {
			return true;
		}

		targetElement = this.getTargetElementFromEventTarget(event.target);
		touch = event.targetTouches[0];

		if (deviceIsIOS) {

			// Only trusted events will deselect text on iOS (issue #49)
			selection = window.getSelection();
			if (selection.rangeCount && !selection.isCollapsed) {
				return true;
			}

			if (!deviceIsIOS4) {

				// Weird things happen on iOS when an alert or confirm dialog is opened from a click event callback (issue #23):
				// when the user next taps anywhere else on the page, new touchstart and touchend events are dispatched
				// with the same identifier as the touch event that previously triggered the click that triggered the alert.
				// Sadly, there is an issue on iOS 4 that causes some normal touch events to have the same identifier as an
				// immediately preceeding touch event (issue #52), so this fix is unavailable on that platform.
				// Issue 120: touch.identifier is 0 when Chrome dev tools 'Emulate touch events' is set with an iOS device UA string,
				// which causes all touch events to be ignored. As this block only applies to iOS, and iOS identifiers are always long,
				// random integers, it's safe to to continue if the identifier is 0 here.
				if (touch.identifier && touch.identifier === this.lastTouchIdentifier) {
					event.preventDefault();
					return false;
				}

				this.lastTouchIdentifier = touch.identifier;

				// If the target element is a child of a scrollable layer (using -webkit-overflow-scrolling: touch) and:
				// 1) the user does a fling scroll on the scrollable layer
				// 2) the user stops the fling scroll with another tap
				// then the event.target of the last 'touchend' event will be the element that was under the user's finger
				// when the fling scroll was started, causing FastClick to send a click event to that layer - unless a check
				// is made to ensure that a parent layer was not scrolled before sending a synthetic click (issue #42).
				this.updateScrollParent(targetElement);
			}
		}

		this.trackingClick = true;
		this.trackingClickStart = event.timeStamp;
		this.targetElement = targetElement;

		this.touchStartX = touch.pageX;
		this.touchStartY = touch.pageY;

		// Prevent phantom clicks on fast double-tap (issue #36)
		if ((event.timeStamp - this.lastClickTime) < this.tapDelay) {
			event.preventDefault();
		}

		return true;
	};


	/**
	 * Based on a touchmove event object, check whether the touch has moved past a boundary since it started.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.touchHasMoved = function(event) {
		var touch = event.changedTouches[0], boundary = this.touchBoundary;

		if (Math.abs(touch.pageX - this.touchStartX) > boundary || Math.abs(touch.pageY - this.touchStartY) > boundary) {
			return true;
		}

		return false;
	};


	/**
	 * Update the last position.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchMove = function(event) {
		if (!this.trackingClick) {
			return true;
		}

		// If the touch has moved, cancel the click tracking
		if (this.targetElement !== this.getTargetElementFromEventTarget(event.target) || this.touchHasMoved(event)) {
			this.trackingClick = false;
			this.targetElement = null;
		}

		return true;
	};


	/**
	 * Attempt to find the labelled control for the given label element.
	 *
	 * @param {EventTarget|HTMLLabelElement} labelElement
	 * @returns {Element|null}
	 */
	FastClick.prototype.findControl = function(labelElement) {

		// Fast path for newer browsers supporting the HTML5 control attribute
		if (labelElement.control !== undefined) {
			return labelElement.control;
		}

		// All browsers under test that support touch events also support the HTML5 htmlFor attribute
		if (labelElement.htmlFor) {
			return document.getElementById(labelElement.htmlFor);
		}

		// If no for attribute exists, attempt to retrieve the first labellable descendant element
		// the list of which is defined here: http://www.w3.org/TR/html5/forms.html#category-label
		return labelElement.querySelector('button, input:not([type=hidden]), keygen, meter, output, progress, select, textarea');
	};


	/**
	 * On touch end, determine whether to send a click event at once.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchEnd = function(event) {
		var forElement, trackingClickStart, targetTagName, scrollParent, touch, targetElement = this.targetElement;

		if (!this.trackingClick) {
			return true;
		}

		// Prevent phantom clicks on fast double-tap (issue #36)
		if ((event.timeStamp - this.lastClickTime) < this.tapDelay) {
			this.cancelNextClick = true;
			return true;
		}

		if ((event.timeStamp - this.trackingClickStart) > this.tapTimeout) {
			return true;
		}

		// Reset to prevent wrong click cancel on input (issue #156).
		this.cancelNextClick = false;

		this.lastClickTime = event.timeStamp;

		trackingClickStart = this.trackingClickStart;
		this.trackingClick = false;
		this.trackingClickStart = 0;

		// On some iOS devices, the targetElement supplied with the event is invalid if the layer
		// is performing a transition or scroll, and has to be re-detected manually. Note that
		// for this to function correctly, it must be called *after* the event target is checked!
		// See issue #57; also filed as rdar://13048589 .
		if (deviceIsIOSWithBadTarget) {
			touch = event.changedTouches[0];

			// In certain cases arguments of elementFromPoint can be negative, so prevent setting targetElement to null
			targetElement = document.elementFromPoint(touch.pageX - window.pageXOffset, touch.pageY - window.pageYOffset) || targetElement;
			targetElement.fastClickScrollParent = this.targetElement.fastClickScrollParent;
		}

		targetTagName = targetElement.tagName.toLowerCase();
		if (targetTagName === 'label') {
			forElement = this.findControl(targetElement);
			if (forElement) {
				this.focus(targetElement);
				if (deviceIsAndroid) {
					return false;
				}

				targetElement = forElement;
			}
		} else if (this.needsFocus(targetElement)) {

			// Case 1: If the touch started a while ago (best guess is 100ms based on tests for issue #36) then focus will be triggered anyway. Return early and unset the target element reference so that the subsequent click will be allowed through.
			// Case 2: Without this exception for input elements tapped when the document is contained in an iframe, then any inputted text won't be visible even though the value attribute is updated as the user types (issue #37).
			if ((event.timeStamp - trackingClickStart) > 100 || (deviceIsIOS && window.top !== window && targetTagName === 'input')) {
				this.targetElement = null;
				return false;
			}

			this.focus(targetElement);
			this.sendClick(targetElement, event);

			// Select elements need the event to go through on iOS 4, otherwise the selector menu won't open.
			// Also this breaks opening selects when VoiceOver is active on iOS6, iOS7 (and possibly others)
			if (!deviceIsIOS || targetTagName !== 'select') {
				this.targetElement = null;
				event.preventDefault();
			}

			return false;
		}

		if (deviceIsIOS && !deviceIsIOS4) {

			// Don't send a synthetic click event if the target element is contained within a parent layer that was scrolled
			// and this tap is being used to stop the scrolling (usually initiated by a fling - issue #42).
			scrollParent = targetElement.fastClickScrollParent;
			if (scrollParent && scrollParent.fastClickLastScrollTop !== scrollParent.scrollTop) {
				return true;
			}
		}

		// Prevent the actual click from going though - unless the target node is marked as requiring
		// real clicks or if it is in the whitelist in which case only non-programmatic clicks are permitted.
		if (!this.needsClick(targetElement)) {
			event.preventDefault();
			this.sendClick(targetElement, event);
		}

		return false;
	};


	/**
	 * On touch cancel, stop tracking the click.
	 *
	 * @returns {void}
	 */
	FastClick.prototype.onTouchCancel = function() {
		this.trackingClick = false;
		this.targetElement = null;
	};


	/**
	 * Determine mouse events which should be permitted.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onMouse = function(event) {

		// If a target element was never set (because a touch event was never fired) allow the event
		if (!this.targetElement) {
			return true;
		}

		if (event.forwardedTouchEvent) {
			return true;
		}

		// Programmatically generated events targeting a specific element should be permitted
		if (!event.cancelable) {
			return true;
		}

		// Derive and check the target element to see whether the mouse event needs to be permitted;
		// unless explicitly enabled, prevent non-touch click events from triggering actions,
		// to prevent ghost/doubleclicks.
		if (!this.needsClick(this.targetElement) || this.cancelNextClick) {

			// Prevent any user-added listeners declared on FastClick element from being fired.
			if (event.stopImmediatePropagation) {
				event.stopImmediatePropagation();
			} else {

				// Part of the hack for browsers that don't support Event#stopImmediatePropagation (e.g. Android 2)
				event.propagationStopped = true;
			}

			// Cancel the event
			event.stopPropagation();
			event.preventDefault();

			return false;
		}

		// If the mouse event is permitted, return true for the action to go through.
		return true;
	};


	/**
	 * On actual clicks, determine whether this is a touch-generated click, a click action occurring
	 * naturally after a delay after a touch (which needs to be cancelled to avoid duplication), or
	 * an actual click which should be permitted.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onClick = function(event) {
		var permitted;

		// It's possible for another FastClick-like library delivered with third-party code to fire a click event before FastClick does (issue #44). In that case, set the click-tracking flag back to false and return early. This will cause onTouchEnd to return early.
		if (this.trackingClick) {
			this.targetElement = null;
			this.trackingClick = false;
			return true;
		}

		// Very odd behaviour on iOS (issue #18): if a submit element is present inside a form and the user hits enter in the iOS simulator or clicks the Go button on the pop-up OS keyboard the a kind of 'fake' click event will be triggered with the submit-type input element as the target.
		if (event.target.type === 'submit' && event.detail === 0) {
			return true;
		}

		permitted = this.onMouse(event);

		// Only unset targetElement if the click is not permitted. This will ensure that the check for !targetElement in onMouse fails and the browser's click doesn't go through.
		if (!permitted) {
			this.targetElement = null;
		}

		// If clicks are permitted, return true for the action to go through.
		return permitted;
	};


	/**
	 * Remove all FastClick's event listeners.
	 *
	 * @returns {void}
	 */
	FastClick.prototype.destroy = function() {
		var layer = this.layer;

		if (deviceIsAndroid) {
			layer.removeEventListener('mouseover', this.onMouse, true);
			layer.removeEventListener('mousedown', this.onMouse, true);
			layer.removeEventListener('mouseup', this.onMouse, true);
		}

		layer.removeEventListener('click', this.onClick, true);
		layer.removeEventListener('touchstart', this.onTouchStart, false);
		layer.removeEventListener('touchmove', this.onTouchMove, false);
		layer.removeEventListener('touchend', this.onTouchEnd, false);
		layer.removeEventListener('touchcancel', this.onTouchCancel, false);
	};


	/**
	 * Check whether FastClick is needed.
	 *
	 * @param {Element} layer The layer to listen on
	 */
	FastClick.notNeeded = function(layer) {
		var metaViewport;
		var chromeVersion;
		var blackberryVersion;
		var firefoxVersion;

		// Devices that don't support touch don't need FastClick
		if (typeof window.ontouchstart === 'undefined') {
			return true;
		}

		// Chrome version - zero for other browsers
		chromeVersion = +(/Chrome\/([0-9]+)/.exec(navigator.userAgent) || [,0])[1];

		if (chromeVersion) {

			if (deviceIsAndroid) {
				metaViewport = document.querySelector('meta[name=viewport]');

				if (metaViewport) {
					// Chrome on Android with user-scalable="no" doesn't need FastClick (issue #89)
					if (metaViewport.content.indexOf('user-scalable=no') !== -1) {
						return true;
					}
					// Chrome 32 and above with width=device-width or less don't need FastClick
					if (chromeVersion > 31 && document.documentElement.scrollWidth <= window.outerWidth) {
						return true;
					}
				}

			// Chrome desktop doesn't need FastClick (issue #15)
			} else {
				return true;
			}
		}

		if (deviceIsBlackBerry10) {
			blackberryVersion = navigator.userAgent.match(/Version\/([0-9]*)\.([0-9]*)/);

			// BlackBerry 10.3+ does not require Fastclick library.
			// https://github.com/ftlabs/fastclick/issues/251
			if (blackberryVersion[1] >= 10 && blackberryVersion[2] >= 3) {
				metaViewport = document.querySelector('meta[name=viewport]');

				if (metaViewport) {
					// user-scalable=no eliminates click delay.
					if (metaViewport.content.indexOf('user-scalable=no') !== -1) {
						return true;
					}
					// width=device-width (or less than device-width) eliminates click delay.
					if (document.documentElement.scrollWidth <= window.outerWidth) {
						return true;
					}
				}
			}
		}

		// IE10 with -ms-touch-action: none or manipulation, which disables double-tap-to-zoom (issue #97)
		if (layer.style.msTouchAction === 'none' || layer.style.touchAction === 'manipulation') {
			return true;
		}

		// Firefox version - zero for other browsers
		firefoxVersion = +(/Firefox\/([0-9]+)/.exec(navigator.userAgent) || [,0])[1];

		if (firefoxVersion >= 27) {
			// Firefox 27+ does not have tap delay if the content is not zoomable - https://bugzilla.mozilla.org/show_bug.cgi?id=922896

			metaViewport = document.querySelector('meta[name=viewport]');
			if (metaViewport && (metaViewport.content.indexOf('user-scalable=no') !== -1 || document.documentElement.scrollWidth <= window.outerWidth)) {
				return true;
			}
		}

		// IE11: prefixed -ms-touch-action is no longer supported and it's recomended to use non-prefixed version
		// http://msdn.microsoft.com/en-us/library/windows/apps/Hh767313.aspx
		if (layer.style.touchAction === 'none' || layer.style.touchAction === 'manipulation') {
			return true;
		}

		return false;
	};


	/**
	 * Factory method for creating a FastClick object
	 *
	 * @param {Element} layer The layer to listen on
	 * @param {Object} [options={}] The options to override the defaults
	 */
	FastClick.attach = function(layer, options) {
		return new FastClick(layer, options);
	};


	if (typeof define === 'function' && typeof define.amd === 'object' && define.amd) {

		// AMD. Register as an anonymous module.
		define(function() {
			return FastClick;
		});
	} else if (typeof module !== 'undefined' && module.exports) {
		module.exports = FastClick.attach;
		module.exports.FastClick = FastClick;
	} else {
		window.FastClick = FastClick;
	}
}());

/**
 * Simple localStorage with Cookie Fallback
 * v.1.0.0
 *
 * USAGE:
 * ----------------------------------------
 * Set New / Modify:
 *   store('my_key', 'some_value');
 *
 * Retrieve:
 *   store('my_key');
 *
 * Delete / Remove:
 *   store('my_key', null);
 */
 
var store = function store(key, value) {
 
    var lsSupport = false;
    
    // Check for native support
    if (window['localStorage']) {
        lsSupport = true;
    }
    
    // If value is detected, set new or modify store
    if (typeof value !== "undefined" && value !== null) {
        // Convert object values to JSON
        if ( typeof value === 'object' ) {
            value = JSON.stringify(value);
        }
        // Set the store
        if (lsSupport) { // Native support
            window['localStorage'].setItem(key, value);
        } else { // Use Cookie
            createCookie(key, value, 30);
        }
    }
    
    // No value supplied, return value
    if (typeof value === "undefined") {
        // Get value
        if (lsSupport) { // Native support
            data = window['localStorage'].getItem(key);
        } else { // Use cookie 
            data = readCookie(key);
        }
        
        // Try to parse JSON...
        try {
           data = JSON.parse(data);
        }
        catch(e) {
           data = data;
        }
        
        return data;
        
    }
    
    // Null specified, remove store
    if (value === null) {
        if (lsSupport) { // Native support
            window['localStorage'].removeItem(key);
        } else { // Use cookie
            createCookie(key, '', -1);
        }
    }
    
    /**
     * Creates new cookie or removes cookie with negative expiration
     * @param  key       The key or identifier for the store
     * @param  value     Contents of the store
     * @param  exp       Expiration - creation defaults to 30 days
     */
    
    function createCookie(key, value, exp) {
        var date = new Date();
        date.setTime(date.getTime() + (exp * 24 * 60 * 60 * 1000));
        var expires = "; expires=" + date.toGMTString();
        document.cookie = key + "=" + value + expires + "; path=/";
    }
    
    /**
     * Returns contents of cookie
     * @param  key       The key or identifier for the store
     */
    
    function readCookie(key) {
        var nameEQ = key + "=";
        var ca = document.cookie.split(';');
        for (var i = 0, max = ca.length; i < max; i++) {
            var c = ca[i];
            while (c.charAt(0) === ' ') c = c.substring(1, c.length);
            if (c.indexOf(nameEQ) === 0) return c.substring(nameEQ.length, c.length);
        }
        return null;
    }
    
};
/*! highlight.js v9.12.0 | BSD3 License | git.io/hljslicense */
!function(e){var t="object"==typeof window&&window||"object"==typeof self&&self;"undefined"!=typeof exports?e(exports):t&&(t.hljs=e({}),"function"==typeof define&&define.amd&&define([],function(){return t.hljs}))}(function(e){function t(e){return e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;")}function r(e){return e.nodeName.toLowerCase()}function a(e,t){var r=e&&e.exec(t);return r&&0===r.index}function n(e){return E.test(e)}function i(e){var t,r,a,i,s=e.className+" ";if(s+=e.parentNode?e.parentNode.className:"",r=M.exec(s))return w(r[1])?r[1]:"no-highlight";for(s=s.split(/\s+/),t=0,a=s.length;a>t;t++)if(i=s[t],n(i)||w(i))return i}function s(e){var t,r={},a=Array.prototype.slice.call(arguments,1);for(t in e)r[t]=e[t];return a.forEach(function(e){for(t in e)r[t]=e[t]}),r}function c(e){var t=[];return function a(e,n){for(var i=e.firstChild;i;i=i.nextSibling)3===i.nodeType?n+=i.nodeValue.length:1===i.nodeType&&(t.push({event:"start",offset:n,node:i}),n=a(i,n),r(i).match(/br|hr|img|input/)||t.push({event:"stop",offset:n,node:i}));return n}(e,0),t}function o(e,a,n){function i(){return e.length&&a.length?e[0].offset!==a[0].offset?e[0].offset<a[0].offset?e:a:"start"===a[0].event?e:a:e.length?e:a}function s(e){function a(e){return" "+e.nodeName+'="'+t(e.value).replace('"',"&quot;")+'"'}u+="<"+r(e)+N.map.call(e.attributes,a).join("")+">"}function c(e){u+="</"+r(e)+">"}function o(e){("start"===e.event?s:c)(e.node)}for(var l=0,u="",d=[];e.length||a.length;){var b=i();if(u+=t(n.substring(l,b[0].offset)),l=b[0].offset,b===e){d.reverse().forEach(c);do o(b.splice(0,1)[0]),b=i();while(b===e&&b.length&&b[0].offset===l);d.reverse().forEach(s)}else"start"===b[0].event?d.push(b[0].node):d.pop(),o(b.splice(0,1)[0])}return u+t(n.substr(l))}function l(e){return e.v&&!e.cached_variants&&(e.cached_variants=e.v.map(function(t){return s(e,{v:null},t)})),e.cached_variants||e.eW&&[s(e)]||[e]}function u(e){function t(e){return e&&e.source||e}function r(r,a){return new RegExp(t(r),"m"+(e.cI?"i":"")+(a?"g":""))}function a(n,i){if(!n.compiled){if(n.compiled=!0,n.k=n.k||n.bK,n.k){var s={},c=function(t,r){e.cI&&(r=r.toLowerCase()),r.split(" ").forEach(function(e){var r=e.split("|");s[r[0]]=[t,r[1]?Number(r[1]):1]})};"string"==typeof n.k?c("keyword",n.k):k(n.k).forEach(function(e){c(e,n.k[e])}),n.k=s}n.lR=r(n.l||/\w+/,!0),i&&(n.bK&&(n.b="\\b("+n.bK.split(" ").join("|")+")\\b"),n.b||(n.b=/\B|\b/),n.bR=r(n.b),n.e||n.eW||(n.e=/\B|\b/),n.e&&(n.eR=r(n.e)),n.tE=t(n.e)||"",n.eW&&i.tE&&(n.tE+=(n.e?"|":"")+i.tE)),n.i&&(n.iR=r(n.i)),null==n.r&&(n.r=1),n.c||(n.c=[]),n.c=Array.prototype.concat.apply([],n.c.map(function(e){return l("self"===e?n:e)})),n.c.forEach(function(e){a(e,n)}),n.starts&&a(n.starts,i);var o=n.c.map(function(e){return e.bK?"\\.?("+e.b+")\\.?":e.b}).concat([n.tE,n.i]).map(t).filter(Boolean);n.t=o.length?r(o.join("|"),!0):{exec:function(){return null}}}}a(e)}function d(e,r,n,i){function s(e,t){var r,n;for(r=0,n=t.c.length;n>r;r++)if(a(t.c[r].bR,e))return t.c[r]}function c(e,t){if(a(e.eR,t)){for(;e.endsParent&&e.parent;)e=e.parent;return e}return e.eW?c(e.parent,t):void 0}function o(e,t){return!n&&a(t.iR,e)}function l(e,t){var r=v.cI?t[0].toLowerCase():t[0];return e.k.hasOwnProperty(r)&&e.k[r]}function p(e,t,r,a){var n=a?"":L.classPrefix,i='<span class="'+n,s=r?"":R;return i+=e+'">',i+t+s}function m(){var e,r,a,n;if(!N.k)return t(E);for(n="",r=0,N.lR.lastIndex=0,a=N.lR.exec(E);a;)n+=t(E.substring(r,a.index)),e=l(N,a),e?(M+=e[1],n+=p(e[0],t(a[0]))):n+=t(a[0]),r=N.lR.lastIndex,a=N.lR.exec(E);return n+t(E.substr(r))}function f(){var e="string"==typeof N.sL;if(e&&!x[N.sL])return t(E);var r=e?d(N.sL,E,!0,k[N.sL]):b(E,N.sL.length?N.sL:void 0);return N.r>0&&(M+=r.r),e&&(k[N.sL]=r.top),p(r.language,r.value,!1,!0)}function g(){C+=null!=N.sL?f():m(),E=""}function _(e){C+=e.cN?p(e.cN,"",!0):"",N=Object.create(e,{parent:{value:N}})}function h(e,t){if(E+=e,null==t)return g(),0;var r=s(t,N);if(r)return r.skip?E+=t:(r.eB&&(E+=t),g(),r.rB||r.eB||(E=t)),_(r,t),r.rB?0:t.length;var a=c(N,t);if(a){var n=N;n.skip?E+=t:(n.rE||n.eE||(E+=t),g(),n.eE&&(E=t));do N.cN&&(C+=R),N.skip||(M+=N.r),N=N.parent;while(N!==a.parent);return a.starts&&_(a.starts,""),n.rE?0:t.length}if(o(t,N))throw new Error('Illegal lexeme "'+t+'" for mode "'+(N.cN||"<unnamed>")+'"');return E+=t,t.length||1}var v=w(e);if(!v)throw new Error('Unknown language: "'+e+'"');u(v);var y,N=i||v,k={},C="";for(y=N;y!==v;y=y.parent)y.cN&&(C=p(y.cN,"",!0)+C);var E="",M=0;try{for(var B,S,$=0;;){if(N.t.lastIndex=$,B=N.t.exec(r),!B)break;S=h(r.substring($,B.index),B[0]),$=B.index+S}for(h(r.substr($)),y=N;y.parent;y=y.parent)y.cN&&(C+=R);return{r:M,value:C,language:e,top:N}}catch(A){if(A.message&&-1!==A.message.indexOf("Illegal"))return{r:0,value:t(r)};throw A}}function b(e,r){r=r||L.languages||k(x);var a={r:0,value:t(e)},n=a;return r.filter(w).forEach(function(t){var r=d(t,e,!1);r.language=t,r.r>n.r&&(n=r),r.r>a.r&&(n=a,a=r)}),n.language&&(a.second_best=n),a}function p(e){return L.tabReplace||L.useBR?e.replace(B,function(e,t){return L.useBR&&"\n"===e?"<br>":L.tabReplace?t.replace(/\t/g,L.tabReplace):""}):e}function m(e,t,r){var a=t?C[t]:r,n=[e.trim()];return e.match(/\bhljs\b/)||n.push("hljs"),-1===e.indexOf(a)&&n.push(a),n.join(" ").trim()}function f(e){var t,r,a,s,l,u=i(e);n(u)||(L.useBR?(t=document.createElementNS("http://www.w3.org/1999/xhtml","div"),t.innerHTML=e.innerHTML.replace(/\n/g,"").replace(/<br[ \/]*>/g,"\n")):t=e,l=t.textContent,a=u?d(u,l,!0):b(l),r=c(t),r.length&&(s=document.createElementNS("http://www.w3.org/1999/xhtml","div"),s.innerHTML=a.value,a.value=o(r,c(s),l)),a.value=p(a.value),e.innerHTML=a.value,e.className=m(e.className,u,a.language),e.result={language:a.language,re:a.r},a.second_best&&(e.second_best={language:a.second_best.language,re:a.second_best.r}))}function g(e){L=s(L,e)}function _(){if(!_.called){_.called=!0;var e=document.querySelectorAll("pre code");N.forEach.call(e,f)}}function h(){addEventListener("DOMContentLoaded",_,!1),addEventListener("load",_,!1)}function v(t,r){var a=x[t]=r(e);a.aliases&&a.aliases.forEach(function(e){C[e]=t})}function y(){return k(x)}function w(e){return e=(e||"").toLowerCase(),x[e]||x[C[e]]}var N=[],k=Object.keys,x={},C={},E=/^(no-?highlight|plain|text)$/i,M=/\blang(?:uage)?-([\w-]+)\b/i,B=/((^(<[^>]+>|\t|)+|(?:\n)))/gm,R="</span>",L={classPrefix:"hljs-",tabReplace:null,useBR:!1,languages:void 0};return e.highlight=d,e.highlightAuto=b,e.fixMarkup=p,e.highlightBlock=f,e.configure=g,e.initHighlighting=_,e.initHighlightingOnLoad=h,e.registerLanguage=v,e.listLanguages=y,e.getLanguage=w,e.inherit=s,e.IR="[a-zA-Z]\\w*",e.UIR="[a-zA-Z_]\\w*",e.NR="\\b\\d+(\\.\\d+)?",e.CNR="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",e.BNR="\\b(0b[01]+)",e.RSR="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",e.BE={b:"\\\\[\\s\\S]",r:0},e.ASM={cN:"string",b:"'",e:"'",i:"\\n",c:[e.BE]},e.QSM={cN:"string",b:'"',e:'"',i:"\\n",c:[e.BE]},e.PWM={b:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},e.C=function(t,r,a){var n=e.inherit({cN:"comment",b:t,e:r,c:[]},a||{});return n.c.push(e.PWM),n.c.push({cN:"doctag",b:"(?:TODO|FIXME|NOTE|BUG|XXX):",r:0}),n},e.CLCM=e.C("//","$"),e.CBCM=e.C("/\\*","\\*/"),e.HCM=e.C("#","$"),e.NM={cN:"number",b:e.NR,r:0},e.CNM={cN:"number",b:e.CNR,r:0},e.BNM={cN:"number",b:e.BNR,r:0},e.CSSNM={cN:"number",b:e.NR+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",r:0},e.RM={cN:"regexp",b:/\//,e:/\/[gimuy]*/,i:/\n/,c:[e.BE,{b:/\[/,e:/\]/,r:0,c:[e.BE]}]},e.TM={cN:"title",b:e.IR,r:0},e.UTM={cN:"title",b:e.UIR,r:0},e.METHOD_GUARD={b:"\\.\\s*"+e.UIR,r:0},e.registerLanguage("apache",function(e){var t={cN:"number",b:"[\\$%]\\d+"};return{aliases:["apacheconf"],cI:!0,c:[e.HCM,{cN:"section",b:"</?",e:">"},{cN:"attribute",b:/\w+/,r:0,k:{nomarkup:"order deny allow setenv rewriterule rewriteengine rewritecond documentroot sethandler errordocument loadmodule options header listen serverroot servername"},starts:{e:/$/,r:0,k:{literal:"on off all"},c:[{cN:"meta",b:"\\s\\[",e:"\\]$"},{cN:"variable",b:"[\\$%]\\{",e:"\\}",c:["self",t]},t,e.QSM]}}],i:/\S/}}),e.registerLanguage("bash",function(e){var t={cN:"variable",v:[{b:/\$[\w\d#@][\w\d_]*/},{b:/\$\{(.*?)}/}]},r={cN:"string",b:/"/,e:/"/,c:[e.BE,t,{cN:"variable",b:/\$\(/,e:/\)/,c:[e.BE]}]},a={cN:"string",b:/'/,e:/'/};return{aliases:["sh","zsh"],l:/\b-?[a-z\._]+\b/,k:{keyword:"if then else elif fi for while in do done case esac function",literal:"true false",built_in:"break cd continue eval exec exit export getopts hash pwd readonly return shift test times trap umask unset alias bind builtin caller command declare echo enable help let local logout mapfile printf read readarray source type typeset ulimit unalias set shopt autoload bg bindkey bye cap chdir clone comparguments compcall compctl compdescribe compfiles compgroups compquote comptags comptry compvalues dirs disable disown echotc echoti emulate fc fg float functions getcap getln history integer jobs kill limit log noglob popd print pushd pushln rehash sched setcap setopt stat suspend ttyctl unfunction unhash unlimit unsetopt vared wait whence where which zcompile zformat zftp zle zmodload zparseopts zprof zpty zregexparse zsocket zstyle ztcp",_:"-ne -eq -lt -gt -f -d -e -s -l -a"},c:[{cN:"meta",b:/^#![^\n]+sh\s*$/,r:10},{cN:"function",b:/\w[\w\d_]*\s*\(\s*\)\s*\{/,rB:!0,c:[e.inherit(e.TM,{b:/\w[\w\d_]*/})],r:0},e.HCM,r,a,t]}}),e.registerLanguage("coffeescript",function(e){var t={keyword:"in if for while finally new do return else break catch instanceof throw try this switch continue typeof delete debugger super yield import export from as default await then unless until loop of by when and or is isnt not",literal:"true false null undefined yes no on off",built_in:"npm require console print module global window document"},r="[A-Za-z$_][0-9A-Za-z$_]*",a={cN:"subst",b:/#\{/,e:/}/,k:t},n=[e.BNM,e.inherit(e.CNM,{starts:{e:"(\\s*/)?",r:0}}),{cN:"string",v:[{b:/'''/,e:/'''/,c:[e.BE]},{b:/'/,e:/'/,c:[e.BE]},{b:/"""/,e:/"""/,c:[e.BE,a]},{b:/"/,e:/"/,c:[e.BE,a]}]},{cN:"regexp",v:[{b:"///",e:"///",c:[a,e.HCM]},{b:"//[gim]*",r:0},{b:/\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/}]},{b:"@"+r},{sL:"javascript",eB:!0,eE:!0,v:[{b:"```",e:"```"},{b:"`",e:"`"}]}];a.c=n;var i=e.inherit(e.TM,{b:r}),s="(\\(.*\\))?\\s*\\B[-=]>",c={cN:"params",b:"\\([^\\(]",rB:!0,c:[{b:/\(/,e:/\)/,k:t,c:["self"].concat(n)}]};return{aliases:["coffee","cson","iced"],k:t,i:/\/\*/,c:n.concat([e.C("###","###"),e.HCM,{cN:"function",b:"^\\s*"+r+"\\s*=\\s*"+s,e:"[-=]>",rB:!0,c:[i,c]},{b:/[:\(,=]\s*/,r:0,c:[{cN:"function",b:s,e:"[-=]>",rB:!0,c:[c]}]},{cN:"class",bK:"class",e:"$",i:/[:="\[\]]/,c:[{bK:"extends",eW:!0,i:/[:="\[\]]/,c:[i]},i]},{b:r+":",e:":",rB:!0,rE:!0,r:0}])}}),e.registerLanguage("cpp",function(e){var t={cN:"keyword",b:"\\b[a-z\\d_]*_t\\b"},r={cN:"string",v:[{b:'(u8?|U)?L?"',e:'"',i:"\\n",c:[e.BE]},{b:'(u8?|U)?R"',e:'"',c:[e.BE]},{b:"'\\\\?.",e:"'",i:"."}]},a={cN:"number",v:[{b:"\\b(0b[01']+)"},{b:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{b:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],r:0},n={cN:"meta",b:/#\s*[a-z]+\b/,e:/$/,k:{"meta-keyword":"if else elif endif define undef warning error line pragma ifdef ifndef include"},c:[{b:/\\\n/,r:0},e.inherit(r,{cN:"meta-string"}),{cN:"meta-string",b:/<[^\n>]*>/,e:/$/,i:"\\n"},e.CLCM,e.CBCM]},i=e.IR+"\\s*\\(",s={keyword:"int float while private char catch import module export virtual operator sizeof dynamic_cast|10 typedef const_cast|10 const for static_cast|10 union namespace unsigned long volatile static protected bool template mutable if public friend do goto auto void enum else break extern using asm case typeid short reinterpret_cast|10 default double register explicit signed typename try this switch continue inline delete alignof constexpr decltype noexcept static_assert thread_local restrict _Bool complex _Complex _Imaginary atomic_bool atomic_char atomic_schar atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong atomic_ullong new throw return and or not",built_in:"std string cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap array shared_ptr abort abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr",literal:"true false nullptr NULL"},c=[t,e.CLCM,e.CBCM,a,r];return{aliases:["c","cc","h","c++","h++","hpp"],k:s,i:"</",c:c.concat([n,{b:"\\b(deque|list|queue|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<",e:">",k:s,c:["self",t]},{b:e.IR+"::",k:s},{v:[{b:/=/,e:/;/},{b:/\(/,e:/\)/},{bK:"new throw return else",e:/;/}],k:s,c:c.concat([{b:/\(/,e:/\)/,k:s,c:c.concat(["self"]),r:0}]),r:0},{cN:"function",b:"("+e.IR+"[\\*&\\s]+)+"+i,rB:!0,e:/[{;=]/,eE:!0,k:s,i:/[^\w\s\*&]/,c:[{b:i,rB:!0,c:[e.TM],r:0},{cN:"params",b:/\(/,e:/\)/,k:s,r:0,c:[e.CLCM,e.CBCM,r,a,t]},e.CLCM,e.CBCM,n]},{cN:"class",bK:"class struct",e:/[{;:]/,c:[{b:/</,e:/>/,c:["self"]},e.TM]}]),exports:{preprocessor:n,strings:r,k:s}}}),e.registerLanguage("cs",function(e){var t={keyword:"abstract as base bool break byte case catch char checked const continue decimal default delegate do double enum event explicit extern finally fixed float for foreach goto if implicit in int interface internal is lock long nameof object operator out override params private protected public readonly ref sbyte sealed short sizeof stackalloc static string struct switch this try typeof uint ulong unchecked unsafe ushort using virtual void volatile while add alias ascending async await by descending dynamic equals from get global group into join let on orderby partial remove select set value var where yield",literal:"null false true"},r={cN:"string",b:'@"',e:'"',c:[{b:'""'}]},a=e.inherit(r,{i:/\n/}),n={cN:"subst",b:"{",e:"}",k:t},i=e.inherit(n,{i:/\n/}),s={cN:"string",b:/\$"/,e:'"',i:/\n/,c:[{b:"{{"},{b:"}}"},e.BE,i]},c={cN:"string",b:/\$@"/,e:'"',c:[{b:"{{"},{b:"}}"},{b:'""'},n]},o=e.inherit(c,{i:/\n/,c:[{b:"{{"},{b:"}}"},{b:'""'},i]});n.c=[c,s,r,e.ASM,e.QSM,e.CNM,e.CBCM],i.c=[o,s,a,e.ASM,e.QSM,e.CNM,e.inherit(e.CBCM,{i:/\n/})];var l={v:[c,s,r,e.ASM,e.QSM]},u=e.IR+"(<"+e.IR+"(\\s*,\\s*"+e.IR+")*>)?(\\[\\])?";return{aliases:["csharp"],k:t,i:/::/,c:[e.C("///","$",{rB:!0,c:[{cN:"doctag",v:[{b:"///",r:0},{b:"<!--|-->"},{b:"</?",e:">"}]}]}),e.CLCM,e.CBCM,{cN:"meta",b:"#",e:"$",k:{"meta-keyword":"if else elif endif define undef warning error line region endregion pragma checksum"}},l,e.CNM,{bK:"class interface",e:/[{;=]/,i:/[^\s:]/,c:[e.TM,e.CLCM,e.CBCM]},{bK:"namespace",e:/[{;=]/,i:/[^\s:]/,c:[e.inherit(e.TM,{b:"[a-zA-Z](\\.?\\w)*"}),e.CLCM,e.CBCM]},{cN:"meta",b:"^\\s*\\[",eB:!0,e:"\\]",eE:!0,c:[{cN:"meta-string",b:/"/,e:/"/}]},{bK:"new return throw await else",r:0},{cN:"function",b:"("+u+"\\s+)+"+e.IR+"\\s*\\(",rB:!0,e:/[{;=]/,eE:!0,k:t,c:[{b:e.IR+"\\s*\\(",rB:!0,c:[e.TM],r:0},{cN:"params",b:/\(/,e:/\)/,eB:!0,eE:!0,k:t,r:0,c:[l,e.CNM,e.CBCM]},e.CLCM,e.CBCM]}]}}),e.registerLanguage("css",function(e){var t="[a-zA-Z-][a-zA-Z0-9_-]*",r={b:/[A-Z\_\.\-]+\s*:/,rB:!0,e:";",eW:!0,c:[{cN:"attribute",b:/\S/,e:":",eE:!0,starts:{eW:!0,eE:!0,c:[{b:/[\w-]+\(/,rB:!0,c:[{cN:"built_in",b:/[\w-]+/},{b:/\(/,e:/\)/,c:[e.ASM,e.QSM]}]},e.CSSNM,e.QSM,e.ASM,e.CBCM,{cN:"number",b:"#[0-9A-Fa-f]+"},{cN:"meta",b:"!important"}]}}]};return{cI:!0,i:/[=\/|'\$]/,c:[e.CBCM,{cN:"selector-id",b:/#[A-Za-z0-9_-]+/},{cN:"selector-class",b:/\.[A-Za-z0-9_-]+/},{cN:"selector-attr",b:/\[/,e:/\]/,i:"$"},{cN:"selector-pseudo",b:/:(:)?[a-zA-Z0-9\_\-\+\(\)"'.]+/},{b:"@(font-face|page)",l:"[a-z-]+",k:"font-face page"},{b:"@",e:"[{;]",i:/:/,c:[{cN:"keyword",b:/\w+/},{b:/\s/,eW:!0,eE:!0,r:0,c:[e.ASM,e.QSM,e.CSSNM]}]},{cN:"selector-tag",b:t,r:0},{b:"{",e:"}",i:/\S/,c:[e.CBCM,r]}]}}),e.registerLanguage("diff",function(e){return{aliases:["patch"],c:[{cN:"meta",r:10,v:[{b:/^@@ +\-\d+,\d+ +\+\d+,\d+ +@@$/},{b:/^\*\*\* +\d+,\d+ +\*\*\*\*$/},{b:/^\-\-\- +\d+,\d+ +\-\-\-\-$/}]},{cN:"comment",v:[{b:/Index: /,e:/$/},{b:/={3,}/,e:/$/},{b:/^\-{3}/,e:/$/},{b:/^\*{3} /,e:/$/},{b:/^\+{3}/,e:/$/},{b:/\*{5}/,e:/\*{5}$/}]},{cN:"addition",b:"^\\+",e:"$"},{cN:"deletion",b:"^\\-",e:"$"},{cN:"addition",b:"^\\!",e:"$"}]}}),e.registerLanguage("http",function(e){var t="HTTP/[0-9\\.]+";return{aliases:["https"],i:"\\S",c:[{b:"^"+t,e:"$",c:[{cN:"number",b:"\\b\\d{3}\\b"}]},{b:"^[A-Z]+ (.*?) "+t+"$",rB:!0,e:"$",c:[{cN:"string",b:" ",e:" ",eB:!0,eE:!0},{b:t},{cN:"keyword",b:"[A-Z]+"}]},{cN:"attribute",b:"^\\w",e:": ",eE:!0,i:"\\n|\\s|=",starts:{e:"$",r:0}},{b:"\\n\\n",starts:{sL:[],eW:!0}}]}}),e.registerLanguage("ini",function(e){var t={cN:"string",c:[e.BE],v:[{b:"'''",e:"'''",r:10},{b:'"""',e:'"""',r:10},{b:'"',e:'"'},{b:"'",e:"'"}]};return{aliases:["toml"],cI:!0,i:/\S/,c:[e.C(";","$"),e.HCM,{cN:"section",b:/^\s*\[+/,e:/\]+/},{b:/^[a-z0-9\[\]_-]+\s*=\s*/,e:"$",rB:!0,c:[{cN:"attr",b:/[a-z0-9\[\]_-]+/},{b:/=/,eW:!0,r:0,c:[{cN:"literal",b:/\bon|off|true|false|yes|no\b/},{cN:"variable",v:[{b:/\$[\w\d"][\w\d_]*/},{b:/\$\{(.*?)}/}]},t,{cN:"number",b:/([\+\-]+)?[\d]+_[\d_]+/},e.NM]}]}]}}),e.registerLanguage("java",function(e){var t="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",r=t+"(<"+t+"(\\s*,\\s*"+t+")*>)?",a="false synchronized int abstract float private char boolean static null if const for true while long strictfp finally protected import native final void enum else break transient catch instanceof byte super volatile case assert short package default double public try this switch continue throws protected public private module requires exports do",n="\\b(0[bB]([01]+[01_]+[01]+|[01]+)|0[xX]([a-fA-F0-9]+[a-fA-F0-9_]+[a-fA-F0-9]+|[a-fA-F0-9]+)|(([\\d]+[\\d_]+[\\d]+|[\\d]+)(\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))?|\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))([eE][-+]?\\d+)?)[lLfF]?",i={cN:"number",b:n,r:0};return{aliases:["jsp"],k:a,i:/<\/|#/,c:[e.C("/\\*\\*","\\*/",{r:0,c:[{b:/\w+@/,r:0},{cN:"doctag",b:"@[A-Za-z]+"}]}),e.CLCM,e.CBCM,e.ASM,e.QSM,{cN:"class",bK:"class interface",e:/[{;=]/,eE:!0,k:"class interface",i:/[:"\[\]]/,c:[{bK:"extends implements"},e.UTM]},{bK:"new throw return else",r:0},{cN:"function",b:"("+r+"\\s+)+"+e.UIR+"\\s*\\(",rB:!0,e:/[{;=]/,eE:!0,k:a,c:[{b:e.UIR+"\\s*\\(",rB:!0,r:0,c:[e.UTM]},{cN:"params",b:/\(/,e:/\)/,k:a,r:0,c:[e.ASM,e.QSM,e.CNM,e.CBCM]},e.CLCM,e.CBCM]},i,{cN:"meta",b:"@[A-Za-z]+"}]}}),e.registerLanguage("javascript",function(e){var t="[A-Za-z$_][0-9A-Za-z$_]*",r={keyword:"in of if for while finally var new function do return void else break catch instanceof with throw case default try this switch continue typeof delete let yield const export super debugger as async await static import from as",literal:"true false null undefined NaN Infinity",built_in:"eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent encodeURI encodeURIComponent escape unescape Object Function Boolean Error EvalError InternalError RangeError ReferenceError StopIteration SyntaxError TypeError URIError Number Math Date String RegExp Array Float32Array Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require module console window document Symbol Set Map WeakSet WeakMap Proxy Reflect Promise"},a={cN:"number",v:[{b:"\\b(0[bB][01]+)"},{b:"\\b(0[oO][0-7]+)"},{b:e.CNR}],r:0},n={cN:"subst",b:"\\$\\{",e:"\\}",k:r,c:[]},i={cN:"string",b:"`",e:"`",c:[e.BE,n]};n.c=[e.ASM,e.QSM,i,a,e.RM];var s=n.c.concat([e.CBCM,e.CLCM]);return{aliases:["js","jsx"],k:r,c:[{cN:"meta",r:10,b:/^\s*['"]use (strict|asm)['"]/},{cN:"meta",b:/^#!/,e:/$/},e.ASM,e.QSM,i,e.CLCM,e.CBCM,a,{b:/[{,]\s*/,r:0,c:[{b:t+"\\s*:",rB:!0,r:0,c:[{cN:"attr",b:t,r:0}]}]},{b:"("+e.RSR+"|\\b(case|return|throw)\\b)\\s*",k:"return throw case",c:[e.CLCM,e.CBCM,e.RM,{cN:"function",b:"(\\(.*?\\)|"+t+")\\s*=>",rB:!0,e:"\\s*=>",c:[{cN:"params",v:[{b:t},{b:/\(\s*\)/},{b:/\(/,e:/\)/,eB:!0,eE:!0,k:r,c:s}]}]},{b:/</,e:/(\/\w+|\w+\/)>/,sL:"xml",c:[{b:/<\w+\s*\/>/,skip:!0},{b:/<\w+/,e:/(\/\w+|\w+\/)>/,skip:!0,c:[{b:/<\w+\s*\/>/,skip:!0},"self"]}]}],r:0},{cN:"function",bK:"function",e:/\{/,eE:!0,c:[e.inherit(e.TM,{b:t}),{cN:"params",b:/\(/,e:/\)/,eB:!0,eE:!0,c:s}],i:/\[|%/},{b:/\$[(.]/},e.METHOD_GUARD,{cN:"class",bK:"class",e:/[{;=]/,eE:!0,i:/[:"\[\]]/,c:[{bK:"extends"},e.UTM]},{bK:"constructor",e:/\{/,eE:!0}],i:/#(?!!)/}}),e.registerLanguage("json",function(e){var t={literal:"true false null"},r=[e.QSM,e.CNM],a={e:",",eW:!0,eE:!0,c:r,k:t},n={b:"{",e:"}",c:[{cN:"attr",b:/"/,e:/"/,c:[e.BE],i:"\\n"},e.inherit(a,{b:/:/})],i:"\\S"},i={b:"\\[",e:"\\]",c:[e.inherit(a)],i:"\\S"};return r.splice(r.length,0,n,i),{c:r,k:t,i:"\\S"}}),e.registerLanguage("makefile",function(e){var t={cN:"variable",v:[{b:"\\$\\("+e.UIR+"\\)",c:[e.BE]},{b:/\$[@%<?\^\+\*]/}]},r={cN:"string",b:/"/,e:/"/,c:[e.BE,t]},a={cN:"variable",b:/\$\([\w-]+\s/,e:/\)/,k:{built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"},c:[t]},n={b:"^"+e.UIR+"\\s*[:+?]?=",i:"\\n",rB:!0,c:[{b:"^"+e.UIR,e:"[:+?]?=",eE:!0}]},i={cN:"meta",b:/^\.PHONY:/,e:/$/,k:{"meta-keyword":".PHONY"},l:/[\.\w]+/},s={cN:"section",b:/^[^\s]+:/,e:/$/,c:[t]};return{aliases:["mk","mak"],k:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath",l:/[\w-]+/,c:[e.HCM,t,r,a,n,i,s]}}),e.registerLanguage("xml",function(e){var t="[A-Za-z0-9\\._:-]+",r={eW:!0,i:/</,r:0,c:[{cN:"attr",b:t,r:0},{b:/=\s*/,r:0,c:[{cN:"string",endsParent:!0,v:[{b:/"/,e:/"/},{b:/'/,e:/'/},{b:/[^\s"'=<>`]+/}]}]}]};return{aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist"],cI:!0,c:[{cN:"meta",b:"<!DOCTYPE",e:">",r:10,c:[{b:"\\[",e:"\\]"}]},e.C("<!--","-->",{r:10}),{b:"<\\!\\[CDATA\\[",e:"\\]\\]>",r:10},{b:/<\?(php)?/,e:/\?>/,sL:"php",c:[{b:"/\\*",e:"\\*/",skip:!0}]},{cN:"tag",b:"<style(?=\\s|>|$)",e:">",k:{name:"style"},c:[r],starts:{e:"</style>",rE:!0,sL:["css","xml"]}},{cN:"tag",b:"<script(?=\\s|>|$)",e:">",k:{name:"script"},c:[r],starts:{e:"</script>",rE:!0,sL:["actionscript","javascript","handlebars","xml"]}},{cN:"meta",v:[{b:/<\?xml/,e:/\?>/,r:10},{b:/<\?\w+/,e:/\?>/}]},{cN:"tag",b:"</?",e:"/?>",c:[{cN:"name",b:/[^\/><\s]+/,r:0},r]}]}}),e.registerLanguage("markdown",function(e){return{aliases:["md","mkdown","mkd"],c:[{cN:"section",v:[{b:"^#{1,6}",e:"$"},{b:"^.+?\\n[=-]{2,}$"}]},{b:"<",e:">",sL:"xml",r:0},{cN:"bullet",b:"^([*+-]|(\\d+\\.))\\s+"},{cN:"strong",b:"[*_]{2}.+?[*_]{2}"},{cN:"emphasis",v:[{b:"\\*.+?\\*"},{b:"_.+?_",r:0}]},{cN:"quote",b:"^>\\s+",e:"$"},{cN:"code",v:[{b:"^```w*s*$",e:"^```s*$"},{b:"`.+?`"},{b:"^( {4}|	)",e:"$",r:0}]},{b:"^[-\\*]{3,}",e:"$"},{b:"\\[.+?\\][\\(\\[].*?[\\)\\]]",rB:!0,c:[{cN:"string",b:"\\[",e:"\\]",eB:!0,rE:!0,r:0},{cN:"link",b:"\\]\\(",e:"\\)",eB:!0,eE:!0},{cN:"symbol",b:"\\]\\[",e:"\\]",eB:!0,eE:!0}],r:10},{b:/^\[[^\n]+\]:/,rB:!0,c:[{cN:"symbol",b:/\[/,e:/\]/,eB:!0,eE:!0},{cN:"link",b:/:\s*/,e:/$/,eB:!0}]}]}}),e.registerLanguage("nginx",function(e){var t={cN:"variable",v:[{b:/\$\d+/},{b:/\$\{/,e:/}/},{b:"[\\$\\@]"+e.UIR}]},r={eW:!0,l:"[a-z/_]+",k:{literal:"on off yes no true false none blocked debug info notice warn error crit select break last permanent redirect kqueue rtsig epoll poll /dev/poll"},r:0,i:"=>",c:[e.HCM,{cN:"string",c:[e.BE,t],v:[{b:/"/,e:/"/},{b:/'/,e:/'/}]},{b:"([a-z]+):/",e:"\\s",eW:!0,eE:!0,c:[t]},{cN:"regexp",c:[e.BE,t],v:[{b:"\\s\\^",e:"\\s|{|;",rE:!0},{b:"~\\*?\\s+",e:"\\s|{|;",rE:!0},{b:"\\*(\\.[a-z\\-]+)+"},{b:"([a-z\\-]+\\.)+\\*"}]},{cN:"number",b:"\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b"},{cN:"number",b:"\\b\\d+[kKmMgGdshdwy]*\\b",r:0},t]};return{aliases:["nginxconf"],c:[e.HCM,{b:e.UIR+"\\s+{",rB:!0,e:"{",c:[{cN:"section",b:e.UIR}],r:0},{b:e.UIR+"\\s",e:";|{",rB:!0,c:[{cN:"attribute",b:e.UIR,starts:r}],r:0}],i:"[^\\s\\}]"}}),e.registerLanguage("objectivec",function(e){var t={cN:"built_in",b:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"},r={keyword:"int float while char export sizeof typedef const struct for union unsigned long volatile static bool mutable if do return goto void enum else break extern asm case short default double register explicit signed typename this switch continue wchar_t inline readonly assign readwrite self @synchronized id typeof nonatomic super unichar IBOutlet IBAction strong weak copy in out inout bycopy byref oneway __strong __weak __block __autoreleasing @private @protected @public @try @property @end @throw @catch @finally @autoreleasepool @synthesize @dynamic @selector @optional @required @encode @package @import @defs @compatibility_alias __bridge __bridge_transfer __bridge_retained __bridge_retain __covariant __contravariant __kindof _Nonnull _Nullable _Null_unspecified __FUNCTION__ __PRETTY_FUNCTION__ __attribute__ getter setter retain unsafe_unretained nonnull nullable null_unspecified null_resettable class instancetype NS_DESIGNATED_INITIALIZER NS_UNAVAILABLE NS_REQUIRES_SUPER NS_RETURNS_INNER_POINTER NS_INLINE NS_AVAILABLE NS_DEPRECATED NS_ENUM NS_OPTIONS NS_SWIFT_UNAVAILABLE NS_ASSUME_NONNULL_BEGIN NS_ASSUME_NONNULL_END NS_REFINED_FOR_SWIFT NS_SWIFT_NAME NS_SWIFT_NOTHROW NS_DURING NS_HANDLER NS_ENDHANDLER NS_VALUERETURN NS_VOIDRETURN",literal:"false true FALSE TRUE nil YES NO NULL",built_in:"BOOL dispatch_once_t dispatch_queue_t dispatch_sync dispatch_async dispatch_once"},a=/[a-zA-Z@][a-zA-Z0-9_]*/,n="@interface @class @protocol @implementation";return{aliases:["mm","objc","obj-c"],k:r,l:a,i:"</",c:[t,e.CLCM,e.CBCM,e.CNM,e.QSM,{cN:"string",v:[{b:'@"',e:'"',i:"\\n",c:[e.BE]},{b:"'",e:"[^\\\\]'",i:"[^\\\\][^']"}]},{cN:"meta",b:"#",e:"$",c:[{cN:"meta-string",v:[{b:'"',e:'"'},{b:"<",e:">"}]}]},{cN:"class",b:"("+n.split(" ").join("|")+")\\b",e:"({|$)",eE:!0,k:n,l:a,c:[e.UTM]},{b:"\\."+e.UIR,r:0}]}}),e.registerLanguage("perl",function(e){var t="getpwent getservent quotemeta msgrcv scalar kill dbmclose undef lc ma syswrite tr send umask sysopen shmwrite vec qx utime local oct semctl localtime readpipe do return format read sprintf dbmopen pop getpgrp not getpwnam rewinddir qqfileno qw endprotoent wait sethostent bless s|0 opendir continue each sleep endgrent shutdown dump chomp connect getsockname die socketpair close flock exists index shmgetsub for endpwent redo lstat msgctl setpgrp abs exit select print ref gethostbyaddr unshift fcntl syscall goto getnetbyaddr join gmtime symlink semget splice x|0 getpeername recv log setsockopt cos last reverse gethostbyname getgrnam study formline endhostent times chop length gethostent getnetent pack getprotoent getservbyname rand mkdir pos chmod y|0 substr endnetent printf next open msgsnd readdir use unlink getsockopt getpriority rindex wantarray hex system getservbyport endservent int chr untie rmdir prototype tell listen fork shmread ucfirst setprotoent else sysseek link getgrgid shmctl waitpid unpack getnetbyname reset chdir grep split require caller lcfirst until warn while values shift telldir getpwuid my getprotobynumber delete and sort uc defined srand accept package seekdir getprotobyname semop our rename seek if q|0 chroot sysread setpwent no crypt getc chown sqrt write setnetent setpriority foreach tie sin msgget map stat getlogin unless elsif truncate exec keys glob tied closedirioctl socket readlink eval xor readline binmode setservent eof ord bind alarm pipe atan2 getgrent exp time push setgrent gt lt or ne m|0 break given say state when",r={cN:"subst",b:"[$@]\\{",e:"\\}",k:t},a={b:"->{",e:"}"},n={v:[{b:/\$\d/},{b:/[\$%@](\^\w\b|#\w+(::\w+)*|{\w+}|\w+(::\w*)*)/},{b:/[\$%@][^\s\w{]/,r:0}]},i=[e.BE,r,n],s=[n,e.HCM,e.C("^\\=\\w","\\=cut",{eW:!0}),a,{cN:"string",c:i,v:[{b:"q[qwxr]?\\s*\\(",e:"\\)",r:5},{b:"q[qwxr]?\\s*\\[",e:"\\]",r:5},{b:"q[qwxr]?\\s*\\{",e:"\\}",r:5},{b:"q[qwxr]?\\s*\\|",e:"\\|",r:5},{b:"q[qwxr]?\\s*\\<",e:"\\>",r:5},{b:"qw\\s+q",e:"q",r:5},{b:"'",e:"'",c:[e.BE]},{b:'"',e:'"'},{b:"`",e:"`",c:[e.BE]},{b:"{\\w+}",c:[],r:0},{b:"-?\\w+\\s*\\=\\>",c:[],r:0}]},{cN:"number",b:"(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",r:0},{b:"(\\/\\/|"+e.RSR+"|\\b(split|return|print|reverse|grep)\\b)\\s*",k:"split return print reverse grep",r:0,c:[e.HCM,{cN:"regexp",b:"(s|tr|y)/(\\\\.|[^/])*/(\\\\.|[^/])*/[a-z]*",r:10},{cN:"regexp",b:"(m|qr)?/",e:"/[a-z]*",c:[e.BE],r:0}]},{cN:"function",bK:"sub",e:"(\\s*\\(.*?\\))?[;{]",eE:!0,r:5,c:[e.TM]},{b:"-\\w\\b",r:0},{b:"^__DATA__$",e:"^__END__$",sL:"mojolicious",c:[{b:"^@@.*",e:"$",cN:"comment"}]}];return r.c=s,a.c=s,{aliases:["pl","pm"],l:/[\w\.]+/,k:t,c:s}}),e.registerLanguage("php",function(e){var t={b:"\\$+[a-zA-Z_-ÿ][a-zA-Z0-9_-ÿ]*"},r={cN:"meta",b:/<\?(php)?|\?>/},a={cN:"string",c:[e.BE,r],v:[{b:'b"',e:'"'},{b:"b'",e:"'"},e.inherit(e.ASM,{i:null}),e.inherit(e.QSM,{i:null})]},n={v:[e.BNM,e.CNM]};return{aliases:["php3","php4","php5","php6"],cI:!0,k:"and include_once list abstract global private echo interface as static endswitch array null if endwhile or const for endforeach self var while isset public protected exit foreach throw elseif include __FILE__ empty require_once do xor return parent clone use __CLASS__ __LINE__ else break print eval new catch __METHOD__ case exception default die require __FUNCTION__ enddeclare final try switch continue endfor endif declare unset true false trait goto instanceof insteadof __DIR__ __NAMESPACE__ yield finally",c:[e.HCM,e.C("//","$",{c:[r]}),e.C("/\\*","\\*/",{c:[{cN:"doctag",b:"@[A-Za-z]+"}]}),e.C("__halt_compiler.+?;",!1,{eW:!0,k:"__halt_compiler",l:e.UIR}),{cN:"string",b:/<<<['"]?\w+['"]?$/,e:/^\w+;?$/,c:[e.BE,{cN:"subst",v:[{b:/\$\w+/},{b:/\{\$/,e:/\}/}]}]},r,{cN:"keyword",b:/\$this\b/},t,{b:/(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/},{cN:"function",bK:"function",e:/[;{]/,eE:!0,i:"\\$|\\[|%",c:[e.UTM,{cN:"params",b:"\\(",e:"\\)",c:["self",t,e.CBCM,a,n]}]},{cN:"class",bK:"class interface",e:"{",eE:!0,i:/[:\(\$"]/,c:[{bK:"extends implements"},e.UTM]},{bK:"namespace",e:";",i:/[\.']/,c:[e.UTM]},{bK:"use",e:";",c:[e.UTM]},{b:"=>"},a,n]}}),e.registerLanguage("python",function(e){var t={keyword:"and elif is global as in if from raise for except finally print import pass return exec else break not with class assert yield try while continue del or def lambda async await nonlocal|10 None True False",built_in:"Ellipsis NotImplemented"},r={cN:"meta",b:/^(>>>|\.\.\.) /},a={cN:"subst",b:/\{/,e:/\}/,k:t,i:/#/},n={cN:"string",c:[e.BE],v:[{b:/(u|b)?r?'''/,e:/'''/,c:[r],r:10},{b:/(u|b)?r?"""/,e:/"""/,c:[r],r:10},{b:/(fr|rf|f)'''/,e:/'''/,c:[r,a]},{b:/(fr|rf|f)"""/,e:/"""/,c:[r,a]},{b:/(u|r|ur)'/,e:/'/,r:10},{b:/(u|r|ur)"/,e:/"/,r:10},{b:/(b|br)'/,e:/'/},{b:/(b|br)"/,e:/"/},{b:/(fr|rf|f)'/,e:/'/,c:[a]},{b:/(fr|rf|f)"/,e:/"/,c:[a]},e.ASM,e.QSM]},i={cN:"number",r:0,v:[{b:e.BNR+"[lLjJ]?"},{b:"\\b(0o[0-7]+)[lLjJ]?"},{b:e.CNR+"[lLjJ]?"}]},s={cN:"params",b:/\(/,e:/\)/,c:["self",r,i,n]};return a.c=[n,i,r],{aliases:["py","gyp"],k:t,i:/(<\/|->|\?)|=>/,c:[r,i,n,e.HCM,{v:[{cN:"function",bK:"def"},{cN:"class",bK:"class"}],e:/:/,i:/[${=;\n,]/,c:[e.UTM,s,{b:/->/,eW:!0,k:"None"}]},{cN:"meta",b:/^[\t ]*@/,e:/$/},{b:/\b(print|exec)\(/}]}}),e.registerLanguage("ruby",function(e){
var t="[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?",r={keyword:"and then defined module in return redo if BEGIN retry end for self when next until do begin unless END rescue else break undef not super class case require yield alias while ensure elsif or include attr_reader attr_writer attr_accessor",literal:"true false nil"},a={cN:"doctag",b:"@[A-Za-z]+"},n={b:"#<",e:">"},i=[e.C("#","$",{c:[a]}),e.C("^\\=begin","^\\=end",{c:[a],r:10}),e.C("^__END__","\\n$")],s={cN:"subst",b:"#\\{",e:"}",k:r},c={cN:"string",c:[e.BE,s],v:[{b:/'/,e:/'/},{b:/"/,e:/"/},{b:/`/,e:/`/},{b:"%[qQwWx]?\\(",e:"\\)"},{b:"%[qQwWx]?\\[",e:"\\]"},{b:"%[qQwWx]?{",e:"}"},{b:"%[qQwWx]?<",e:">"},{b:"%[qQwWx]?/",e:"/"},{b:"%[qQwWx]?%",e:"%"},{b:"%[qQwWx]?-",e:"-"},{b:"%[qQwWx]?\\|",e:"\\|"},{b:/\B\?(\\\d{1,3}|\\x[A-Fa-f0-9]{1,2}|\\u[A-Fa-f0-9]{4}|\\?\S)\b/},{b:/<<(-?)\w+$/,e:/^\s*\w+$/}]},o={cN:"params",b:"\\(",e:"\\)",endsParent:!0,k:r},l=[c,n,{cN:"class",bK:"class module",e:"$|;",i:/=/,c:[e.inherit(e.TM,{b:"[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?"}),{b:"<\\s*",c:[{b:"("+e.IR+"::)?"+e.IR}]}].concat(i)},{cN:"function",bK:"def",e:"$|;",c:[e.inherit(e.TM,{b:t}),o].concat(i)},{b:e.IR+"::"},{cN:"symbol",b:e.UIR+"(\\!|\\?)?:",r:0},{cN:"symbol",b:":(?!\\s)",c:[c,{b:t}],r:0},{cN:"number",b:"(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",r:0},{b:"(\\$\\W)|((\\$|\\@\\@?)(\\w+))"},{cN:"params",b:/\|/,e:/\|/,k:r},{b:"("+e.RSR+"|unless)\\s*",k:"unless",c:[n,{cN:"regexp",c:[e.BE,s],i:/\n/,v:[{b:"/",e:"/[a-z]*"},{b:"%r{",e:"}[a-z]*"},{b:"%r\\(",e:"\\)[a-z]*"},{b:"%r!",e:"![a-z]*"},{b:"%r\\[",e:"\\][a-z]*"}]}].concat(i),r:0}].concat(i);s.c=l,o.c=l;var u="[>?]>",d="[\\w#]+\\(\\w+\\):\\d+:\\d+>",b="(\\w+-)?\\d+\\.\\d+\\.\\d(p\\d+)?[^>]+>",p=[{b:/^\s*=>/,starts:{e:"$",c:l}},{cN:"meta",b:"^("+u+"|"+d+"|"+b+")",starts:{e:"$",c:l}}];return{aliases:["rb","gemspec","podspec","thor","irb"],k:r,i:/\/\*/,c:i.concat(p).concat(l)}}),e.registerLanguage("shell",function(e){return{aliases:["console"],c:[{cN:"meta",b:"^\\s{0,3}[\\w\\d\\[\\]()@-]*[>%$#]",starts:{e:"$",sL:"bash"}}]}}),e.registerLanguage("sql",function(e){var t=e.C("--","$");return{cI:!0,i:/[<>{}*#]/,c:[{bK:"begin end start commit rollback savepoint lock alter create drop rename call delete do handler insert load replace select truncate update set show pragma grant merge describe use explain help declare prepare execute deallocate release unlock purge reset change stop analyze cache flush optimize repair kill install uninstall checksum restore check backup revoke comment",e:/;/,eW:!0,l:/[\w\.]+/,k:{keyword:"abort abs absolute acc acce accep accept access accessed accessible account acos action activate add addtime admin administer advanced advise aes_decrypt aes_encrypt after agent aggregate ali alia alias allocate allow alter always analyze ancillary and any anydata anydataset anyschema anytype apply archive archived archivelog are as asc ascii asin assembly assertion associate asynchronous at atan atn2 attr attri attrib attribu attribut attribute attributes audit authenticated authentication authid authors auto autoallocate autodblink autoextend automatic availability avg backup badfile basicfile before begin beginning benchmark between bfile bfile_base big bigfile bin binary_double binary_float binlog bit_and bit_count bit_length bit_or bit_xor bitmap blob_base block blocksize body both bound buffer_cache buffer_pool build bulk by byte byteordermark bytes cache caching call calling cancel capacity cascade cascaded case cast catalog category ceil ceiling chain change changed char_base char_length character_length characters characterset charindex charset charsetform charsetid check checksum checksum_agg child choose chr chunk class cleanup clear client clob clob_base clone close cluster_id cluster_probability cluster_set clustering coalesce coercibility col collate collation collect colu colum column column_value columns columns_updated comment commit compact compatibility compiled complete composite_limit compound compress compute concat concat_ws concurrent confirm conn connec connect connect_by_iscycle connect_by_isleaf connect_by_root connect_time connection consider consistent constant constraint constraints constructor container content contents context contributors controlfile conv convert convert_tz corr corr_k corr_s corresponding corruption cos cost count count_big counted covar_pop covar_samp cpu_per_call cpu_per_session crc32 create creation critical cross cube cume_dist curdate current current_date current_time current_timestamp current_user cursor curtime customdatum cycle data database databases datafile datafiles datalength date_add date_cache date_format date_sub dateadd datediff datefromparts datename datepart datetime2fromparts day day_to_second dayname dayofmonth dayofweek dayofyear days db_role_change dbtimezone ddl deallocate declare decode decompose decrement decrypt deduplicate def defa defau defaul default defaults deferred defi defin define degrees delayed delegate delete delete_all delimited demand dense_rank depth dequeue des_decrypt des_encrypt des_key_file desc descr descri describ describe descriptor deterministic diagnostics difference dimension direct_load directory disable disable_all disallow disassociate discardfile disconnect diskgroup distinct distinctrow distribute distributed div do document domain dotnet double downgrade drop dumpfile duplicate duration each edition editionable editions element ellipsis else elsif elt empty enable enable_all enclosed encode encoding encrypt end end-exec endian enforced engine engines enqueue enterprise entityescaping eomonth error errors escaped evalname evaluate event eventdata events except exception exceptions exchange exclude excluding execu execut execute exempt exists exit exp expire explain export export_set extended extent external external_1 external_2 externally extract failed failed_login_attempts failover failure far fast feature_set feature_value fetch field fields file file_name_convert filesystem_like_logging final finish first first_value fixed flash_cache flashback floor flush following follows for forall force form forma format found found_rows freelist freelists freepools fresh from from_base64 from_days ftp full function general generated get get_format get_lock getdate getutcdate global global_name globally go goto grant grants greatest group group_concat group_id grouping grouping_id groups gtid_subtract guarantee guard handler hash hashkeys having hea head headi headin heading heap help hex hierarchy high high_priority hosts hour http id ident_current ident_incr ident_seed identified identity idle_time if ifnull ignore iif ilike ilm immediate import in include including increment index indexes indexing indextype indicator indices inet6_aton inet6_ntoa inet_aton inet_ntoa infile initial initialized initially initrans inmemory inner innodb input insert install instance instantiable instr interface interleaved intersect into invalidate invisible is is_free_lock is_ipv4 is_ipv4_compat is_not is_not_null is_used_lock isdate isnull isolation iterate java join json json_exists keep keep_duplicates key keys kill language large last last_day last_insert_id last_value lax lcase lead leading least leaves left len lenght length less level levels library like like2 like4 likec limit lines link list listagg little ln load load_file lob lobs local localtime localtimestamp locate locator lock locked log log10 log2 logfile logfiles logging logical logical_reads_per_call logoff logon logs long loop low low_priority lower lpad lrtrim ltrim main make_set makedate maketime managed management manual map mapping mask master master_pos_wait match matched materialized max maxextents maximize maxinstances maxlen maxlogfiles maxloghistory maxlogmembers maxsize maxtrans md5 measures median medium member memcompress memory merge microsecond mid migration min minextents minimum mining minus minute minvalue missing mod mode model modification modify module monitoring month months mount move movement multiset mutex name name_const names nan national native natural nav nchar nclob nested never new newline next nextval no no_write_to_binlog noarchivelog noaudit nobadfile nocheck nocompress nocopy nocycle nodelay nodiscardfile noentityescaping noguarantee nokeep nologfile nomapping nomaxvalue nominimize nominvalue nomonitoring none noneditionable nonschema noorder nopr nopro noprom nopromp noprompt norely noresetlogs noreverse normal norowdependencies noschemacheck noswitch not nothing notice notrim novalidate now nowait nth_value nullif nulls num numb numbe nvarchar nvarchar2 object ocicoll ocidate ocidatetime ociduration ociinterval ociloblocator ocinumber ociref ocirefcursor ocirowid ocistring ocitype oct octet_length of off offline offset oid oidindex old on online only opaque open operations operator optimal optimize option optionally or oracle oracle_date oradata ord ordaudio orddicom orddoc order ordimage ordinality ordvideo organization orlany orlvary out outer outfile outline output over overflow overriding package pad parallel parallel_enable parameters parent parse partial partition partitions pascal passing password password_grace_time password_lock_time password_reuse_max password_reuse_time password_verify_function patch path patindex pctincrease pctthreshold pctused pctversion percent percent_rank percentile_cont percentile_disc performance period period_add period_diff permanent physical pi pipe pipelined pivot pluggable plugin policy position post_transaction pow power pragma prebuilt precedes preceding precision prediction prediction_cost prediction_details prediction_probability prediction_set prepare present preserve prior priority private private_sga privileges procedural procedure procedure_analyze processlist profiles project prompt protection public publishingservername purge quarter query quick quiesce quota quotename radians raise rand range rank raw read reads readsize rebuild record records recover recovery recursive recycle redo reduced ref reference referenced references referencing refresh regexp_like register regr_avgx regr_avgy regr_count regr_intercept regr_r2 regr_slope regr_sxx regr_sxy reject rekey relational relative relaylog release release_lock relies_on relocate rely rem remainder rename repair repeat replace replicate replication required reset resetlogs resize resource respect restore restricted result result_cache resumable resume retention return returning returns reuse reverse revoke right rlike role roles rollback rolling rollup round row row_count rowdependencies rowid rownum rows rtrim rules safe salt sample save savepoint sb1 sb2 sb4 scan schema schemacheck scn scope scroll sdo_georaster sdo_topo_geometry search sec_to_time second section securefile security seed segment select self sequence sequential serializable server servererror session session_user sessions_per_user set sets settings sha sha1 sha2 share shared shared_pool short show shrink shutdown si_averagecolor si_colorhistogram si_featurelist si_positionalcolor si_stillimage si_texture siblings sid sign sin size size_t sizes skip slave sleep smalldatetimefromparts smallfile snapshot some soname sort soundex source space sparse spfile split sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows sql_small_result sql_variant_property sqlcode sqldata sqlerror sqlname sqlstate sqrt square standalone standby start starting startup statement static statistics stats_binomial_test stats_crosstab stats_ks_test stats_mode stats_mw_test stats_one_way_anova stats_t_test_ stats_t_test_indep stats_t_test_one stats_t_test_paired stats_wsr_test status std stddev stddev_pop stddev_samp stdev stop storage store stored str str_to_date straight_join strcmp strict string struct stuff style subdate subpartition subpartitions substitutable substr substring subtime subtring_index subtype success sum suspend switch switchoffset switchover sync synchronous synonym sys sys_xmlagg sysasm sysaux sysdate sysdatetimeoffset sysdba sysoper system system_user sysutcdatetime table tables tablespace tan tdo template temporary terminated tertiary_weights test than then thread through tier ties time time_format time_zone timediff timefromparts timeout timestamp timestampadd timestampdiff timezone_abbr timezone_minute timezone_region to to_base64 to_date to_days to_seconds todatetimeoffset trace tracking transaction transactional translate translation treat trigger trigger_nestlevel triggers trim truncate try_cast try_convert try_parse type ub1 ub2 ub4 ucase unarchived unbounded uncompress under undo unhex unicode uniform uninstall union unique unix_timestamp unknown unlimited unlock unpivot unrecoverable unsafe unsigned until untrusted unusable unused update updated upgrade upped upper upsert url urowid usable usage use use_stored_outlines user user_data user_resources users using utc_date utc_timestamp uuid uuid_short validate validate_password_strength validation valist value values var var_samp varcharc vari varia variab variabl variable variables variance varp varraw varrawc varray verify version versions view virtual visible void wait wallet warning warnings week weekday weekofyear wellformed when whene whenev wheneve whenever where while whitespace with within without work wrapped xdb xml xmlagg xmlattributes xmlcast xmlcolattval xmlelement xmlexists xmlforest xmlindex xmlnamespaces xmlpi xmlquery xmlroot xmlschema xmlserialize xmltable xmltype xor year year_to_month years yearweek",literal:"true false null",built_in:"array bigint binary bit blob boolean char character date dec decimal float int int8 integer interval number numeric real record serial serial8 smallint text varchar varying void"},c:[{cN:"string",b:"'",e:"'",c:[e.BE,{b:"''"}]},{cN:"string",b:'"',e:'"',c:[e.BE,{b:'""'}]},{cN:"string",b:"`",e:"`",c:[e.BE]},e.CNM,e.CBCM,t]},e.CBCM,t]}}),e});
/*!
 * Fuse.js v3.1.0 - Lightweight fuzzy-search (http://fusejs.io)
 *
 * Copyright (c) 2012-2017 Kirollos Risk (http://kiro.me)
 * All Rights Reserved. Apache Software License 2.0
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 */
(function webpackUniversalModuleDefinition(root, factory) {
    if(typeof exports === 'object' && typeof module === 'object')
        module.exports = factory();
    else if(typeof define === 'function' && define.amd)
        define("Fuse", [], factory);
    else if(typeof exports === 'object')
        exports["Fuse"] = factory();
    else
        root["Fuse"] = factory();
})(this, function() {
    return /******/ (function(modules) { // webpackBootstrap
        /******/ 	// The module cache
        /******/ 	var installedModules = {};
        /******/
        /******/ 	// The require function
        /******/ 	function __webpack_require__(moduleId) {
            /******/
            /******/ 		// Check if module is in cache
            /******/ 		if(installedModules[moduleId]) {
                /******/ 			return installedModules[moduleId].exports;
                /******/ 		}
            /******/ 		// Create a new module (and put it into the cache)
            /******/ 		var module = installedModules[moduleId] = {
                /******/ 			i: moduleId,
                /******/ 			l: false,
                /******/ 			exports: {}
                /******/ 		};
            /******/
            /******/ 		// Execute the module function
            /******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
            /******/
            /******/ 		// Flag the module as loaded
            /******/ 		module.l = true;
            /******/
            /******/ 		// Return the exports of the module
            /******/ 		return module.exports;
            /******/ 	}
        /******/
        /******/
        /******/ 	// expose the modules object (__webpack_modules__)
        /******/ 	__webpack_require__.m = modules;
        /******/
        /******/ 	// expose the module cache
        /******/ 	__webpack_require__.c = installedModules;
        /******/
        /******/ 	// identity function for calling harmony imports with the correct context
        /******/ 	__webpack_require__.i = function(value) { return value; };
        /******/
        /******/ 	// define getter function for harmony exports
        /******/ 	__webpack_require__.d = function(exports, name, getter) {
            /******/ 		if(!__webpack_require__.o(exports, name)) {
                /******/ 			Object.defineProperty(exports, name, {
                    /******/ 				configurable: false,
                    /******/ 				enumerable: true,
                    /******/ 				get: getter
                    /******/ 			});
                /******/ 		}
            /******/ 	};
        /******/
        /******/ 	// getDefaultExport function for compatibility with non-harmony modules
        /******/ 	__webpack_require__.n = function(module) {
            /******/ 		var getter = module && module.__esModule ?
                /******/ 			function getDefault() { return module['default']; } :
                /******/ 			function getModuleExports() { return module; };
            /******/ 		__webpack_require__.d(getter, 'a', getter);
            /******/ 		return getter;
            /******/ 	};
        /******/
        /******/ 	// Object.prototype.hasOwnProperty.call
        /******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
        /******/
        /******/ 	// __webpack_public_path__
        /******/ 	__webpack_require__.p = "";
        /******/
        /******/ 	// Load entry module and return exports
        /******/ 	return __webpack_require__(__webpack_require__.s = 8);
        /******/ })
    /************************************************************************/
    /******/ ([
        /* 0 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (obj) {
                return Object.prototype.toString.call(obj) === '[object Array]';
            };

            /***/ }),
        /* 1 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

            function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

            var bitapRegexSearch = __webpack_require__(5);
            var bitapSearch = __webpack_require__(7);
            var patternAlphabet = __webpack_require__(4);

            var Bitap = function () {
                function Bitap(pattern, _ref) {
                    var _ref$location = _ref.location,
                        location = _ref$location === undefined ? 0 : _ref$location,
                        _ref$distance = _ref.distance,
                        distance = _ref$distance === undefined ? 100 : _ref$distance,
                        _ref$threshold = _ref.threshold,
                        threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                        _ref$maxPatternLength = _ref.maxPatternLength,
                        maxPatternLength = _ref$maxPatternLength === undefined ? 32 : _ref$maxPatternLength,
                        _ref$isCaseSensitive = _ref.isCaseSensitive,
                        isCaseSensitive = _ref$isCaseSensitive === undefined ? false : _ref$isCaseSensitive,
                        _ref$tokenSeparator = _ref.tokenSeparator,
                        tokenSeparator = _ref$tokenSeparator === undefined ? / +/g : _ref$tokenSeparator,
                        _ref$findAllMatches = _ref.findAllMatches,
                        findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                        _ref$minMatchCharLeng = _ref.minMatchCharLength,
                        minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng;

                    _classCallCheck(this, Bitap);

                    this.options = {
                        location: location,
                        distance: distance,
                        threshold: threshold,
                        maxPatternLength: maxPatternLength,
                        isCaseSensitive: isCaseSensitive,
                        tokenSeparator: tokenSeparator,
                        findAllMatches: findAllMatches,
                        minMatchCharLength: minMatchCharLength
                    };

                    this.pattern = this.options.isCaseSensitive ? pattern : pattern.toLowerCase();

                    if (this.pattern.length <= maxPatternLength) {
                        this.patternAlphabet = patternAlphabet(this.pattern);
                    }
                }

                _createClass(Bitap, [{
                    key: 'search',
                    value: function search(text) {
                        if (!this.options.isCaseSensitive) {
                            text = text.toLowerCase();
                        }

                        // Exact match
                        if (this.pattern === text) {
                            return {
                                isMatch: true,
                                score: 0,
                                matchedIndices: [[0, text.length - 1]]
                            };
                        }

                        // When pattern length is greater than the machine word length, just do a a regex comparison
                        var _options = this.options,
                            maxPatternLength = _options.maxPatternLength,
                            tokenSeparator = _options.tokenSeparator;

                        if (this.pattern.length > maxPatternLength) {
                            return bitapRegexSearch(text, this.pattern, tokenSeparator);
                        }

                        // Otherwise, use Bitap algorithm
                        var _options2 = this.options,
                            location = _options2.location,
                            distance = _options2.distance,
                            threshold = _options2.threshold,
                            findAllMatches = _options2.findAllMatches,
                            minMatchCharLength = _options2.minMatchCharLength;

                        return bitapSearch(text, this.pattern, this.patternAlphabet, {
                            location: location,
                            distance: distance,
                            threshold: threshold,
                            findAllMatches: findAllMatches,
                            minMatchCharLength: minMatchCharLength
                        });
                    }
                }]);

                return Bitap;
            }();

// let x = new Bitap("od mn war", {})
// let result = x.search("Old Man's War")
// console.log(result)

            module.exports = Bitap;

            /***/ }),
        /* 2 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var isArray = __webpack_require__(0);

            var deepValue = function deepValue(obj, path, list) {
                if (!path) {
                    // If there's no path left, we've gotten to the object we care about.
                    list.push(obj);
                } else {
                    var dotIndex = path.indexOf('.');
                    var firstSegment = path;
                    var remaining = null;

                    if (dotIndex !== -1) {
                        firstSegment = path.slice(0, dotIndex);
                        remaining = path.slice(dotIndex + 1);
                    }

                    var value = obj[firstSegment];

                    if (value !== null && value !== undefined) {
                        if (!remaining && (typeof value === 'string' || typeof value === 'number')) {
                            list.push(value.toString());
                        } else if (isArray(value)) {
                            // Search each item in the array.
                            for (var i = 0, len = value.length; i < len; i += 1) {
                                deepValue(value[i], remaining, list);
                            }
                        } else if (remaining) {
                            // An object. Recurse further.
                            deepValue(value, remaining, list);
                        }
                    }
                }

                return list;
            };

            module.exports = function (obj, path) {
                return deepValue(obj, path, []);
            };

            /***/ }),
        /* 3 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function () {
                var matchmask = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
                var minMatchCharLength = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;

                var matchedIndices = [];
                var start = -1;
                var end = -1;
                var i = 0;

                for (var len = matchmask.length; i < len; i += 1) {
                    var match = matchmask[i];
                    if (match && start === -1) {
                        start = i;
                    } else if (!match && start !== -1) {
                        end = i - 1;
                        if (end - start + 1 >= minMatchCharLength) {
                            matchedIndices.push([start, end]);
                        }
                        start = -1;
                    }
                }

                // (i-1 - start) + 1 => i - start
                if (matchmask[i - 1] && i - start >= minMatchCharLength) {
                    matchedIndices.push([start, i - 1]);
                }

                return matchedIndices;
            };

            /***/ }),
        /* 4 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (pattern) {
                var mask = {};
                var len = pattern.length;

                for (var i = 0; i < len; i += 1) {
                    mask[pattern.charAt(i)] = 0;
                }

                for (var _i = 0; _i < len; _i += 1) {
                    mask[pattern.charAt(_i)] |= 1 << len - _i - 1;
                }

                return mask;
            };

            /***/ }),
        /* 5 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var SPECIAL_CHARS_REGEX = /[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g;

            module.exports = function (text, pattern) {
                var tokenSeparator = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : / +/g;

                var regex = new RegExp(pattern.replace(SPECIAL_CHARS_REGEX, '\\$&').replace(tokenSeparator, '|'));
                var matches = text.match(regex);
                var isMatch = !!matches;
                var matchedIndices = [];

                if (isMatch) {
                    for (var i = 0, matchesLen = matches.length; i < matchesLen; i += 1) {
                        var match = matches[i];
                        matchedIndices.push([text.indexOf(match), match.length - 1]);
                    }
                }

                return {
                    // TODO: revisit this score
                    score: isMatch ? 0.5 : 1,
                    isMatch: isMatch,
                    matchedIndices: matchedIndices
                };
            };

            /***/ }),
        /* 6 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (pattern, _ref) {
                var _ref$errors = _ref.errors,
                    errors = _ref$errors === undefined ? 0 : _ref$errors,
                    _ref$currentLocation = _ref.currentLocation,
                    currentLocation = _ref$currentLocation === undefined ? 0 : _ref$currentLocation,
                    _ref$expectedLocation = _ref.expectedLocation,
                    expectedLocation = _ref$expectedLocation === undefined ? 0 : _ref$expectedLocation,
                    _ref$distance = _ref.distance,
                    distance = _ref$distance === undefined ? 100 : _ref$distance;

                var accuracy = errors / pattern.length;
                var proximity = Math.abs(expectedLocation - currentLocation);

                if (!distance) {
                    // Dodge divide by zero error.
                    return proximity ? 1.0 : accuracy;
                }

                return accuracy + proximity / distance;
            };

            /***/ }),
        /* 7 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var bitapScore = __webpack_require__(6);
            var matchedIndices = __webpack_require__(3);

            module.exports = function (text, pattern, patternAlphabet, _ref) {
                var _ref$location = _ref.location,
                    location = _ref$location === undefined ? 0 : _ref$location,
                    _ref$distance = _ref.distance,
                    distance = _ref$distance === undefined ? 100 : _ref$distance,
                    _ref$threshold = _ref.threshold,
                    threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                    _ref$findAllMatches = _ref.findAllMatches,
                    findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                    _ref$minMatchCharLeng = _ref.minMatchCharLength,
                    minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng;

                var expectedLocation = location;
                // Set starting location at beginning text and initialize the alphabet.
                var textLen = text.length;
                // Highest score beyond which we give up.
                var currentThreshold = threshold;
                // Is there a nearby exact match? (speedup)
                var bestLocation = text.indexOf(pattern, expectedLocation);

                var patternLen = pattern.length;

                // a mask of the matches
                var matchMask = [];
                for (var i = 0; i < textLen; i += 1) {
                    matchMask[i] = 0;
                }

                if (bestLocation !== -1) {
                    var score = bitapScore(pattern, {
                        errors: 0,
                        currentLocation: bestLocation,
                        expectedLocation: expectedLocation,
                        distance: distance
                    });
                    currentThreshold = Math.min(score, currentThreshold);

                    // What about in the other direction? (speed up)
                    bestLocation = text.lastIndexOf(pattern, expectedLocation + patternLen);

                    if (bestLocation !== -1) {
                        var _score = bitapScore(pattern, {
                            errors: 0,
                            currentLocation: bestLocation,
                            expectedLocation: expectedLocation,
                            distance: distance
                        });
                        currentThreshold = Math.min(_score, currentThreshold);
                    }
                }

                // Reset the best location
                bestLocation = -1;

                var lastBitArr = [];
                var finalScore = 1;
                var binMax = patternLen + textLen;

                var mask = 1 << patternLen - 1;

                for (var _i = 0; _i < patternLen; _i += 1) {
                    // Scan for the best match; each iteration allows for one more error.
                    // Run a binary search to determine how far from the match location we can stray
                    // at this error level.
                    var binMin = 0;
                    var binMid = binMax;

                    while (binMin < binMid) {
                        var _score3 = bitapScore(pattern, {
                            errors: _i,
                            currentLocation: expectedLocation + binMid,
                            expectedLocation: expectedLocation,
                            distance: distance
                        });

                        if (_score3 <= currentThreshold) {
                            binMin = binMid;
                        } else {
                            binMax = binMid;
                        }

                        binMid = Math.floor((binMax - binMin) / 2 + binMin);
                    }

                    // Use the result from this iteration as the maximum for the next.
                    binMax = binMid;

                    var start = Math.max(1, expectedLocation - binMid + 1);
                    var finish = findAllMatches ? textLen : Math.min(expectedLocation + binMid, textLen) + patternLen;

                    // Initialize the bit array
                    var bitArr = Array(finish + 2);

                    bitArr[finish + 1] = (1 << _i) - 1;

                    for (var j = finish; j >= start; j -= 1) {
                        var currentLocation = j - 1;
                        var charMatch = patternAlphabet[text.charAt(currentLocation)];

                        if (charMatch) {
                            matchMask[currentLocation] = 1;
                        }

                        // First pass: exact match
                        bitArr[j] = (bitArr[j + 1] << 1 | 1) & charMatch;

                        // Subsequent passes: fuzzy match
                        if (_i !== 0) {
                            bitArr[j] |= (lastBitArr[j + 1] | lastBitArr[j]) << 1 | 1 | lastBitArr[j + 1];
                        }

                        if (bitArr[j] & mask) {
                            finalScore = bitapScore(pattern, {
                                errors: _i,
                                currentLocation: currentLocation,
                                expectedLocation: expectedLocation,
                                distance: distance
                            });

                            // This match will almost certainly be better than any existing match.
                            // But check anyway.
                            if (finalScore <= currentThreshold) {
                                // Indeed it is
                                currentThreshold = finalScore;
                                bestLocation = currentLocation;

                                // Already passed `loc`, downhill from here on in.
                                if (bestLocation <= expectedLocation) {
                                    break;
                                }

                                // When passing `bestLocation`, don't exceed our current distance from `expectedLocation`.
                                start = Math.max(1, 2 * expectedLocation - bestLocation);
                            }
                        }
                    }

                    // No hope for a (better) match at greater error levels.
                    var _score2 = bitapScore(pattern, {
                        errors: _i + 1,
                        currentLocation: expectedLocation,
                        expectedLocation: expectedLocation,
                        distance: distance
                    });

                    if (_score2 > currentThreshold) {
                        break;
                    }

                    lastBitArr = bitArr;
                }

                // Count exact matches (those with a score of 0) to be "almost" exact
                return {
                    isMatch: bestLocation >= 0,
                    score: finalScore === 0 ? 0.001 : finalScore,
                    matchedIndices: matchedIndices(matchMask, minMatchCharLength)
                };
            };

            /***/ }),
        /* 8 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

            function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

            var Bitap = __webpack_require__(1);
            var deepValue = __webpack_require__(2);
            var isArray = __webpack_require__(0);

            var Fuse = function () {
                function Fuse(list, _ref) {
                    var _ref$location = _ref.location,
                        location = _ref$location === undefined ? 0 : _ref$location,
                        _ref$distance = _ref.distance,
                        distance = _ref$distance === undefined ? 100 : _ref$distance,
                        _ref$threshold = _ref.threshold,
                        threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                        _ref$maxPatternLength = _ref.maxPatternLength,
                        maxPatternLength = _ref$maxPatternLength === undefined ? 32 : _ref$maxPatternLength,
                        _ref$caseSensitive = _ref.caseSensitive,
                        caseSensitive = _ref$caseSensitive === undefined ? false : _ref$caseSensitive,
                        _ref$tokenSeparator = _ref.tokenSeparator,
                        tokenSeparator = _ref$tokenSeparator === undefined ? / +/g : _ref$tokenSeparator,
                        _ref$findAllMatches = _ref.findAllMatches,
                        findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                        _ref$minMatchCharLeng = _ref.minMatchCharLength,
                        minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng,
                        _ref$id = _ref.id,
                        id = _ref$id === undefined ? null : _ref$id,
                        _ref$keys = _ref.keys,
                        keys = _ref$keys === undefined ? [] : _ref$keys,
                        _ref$shouldSort = _ref.shouldSort,
                        shouldSort = _ref$shouldSort === undefined ? true : _ref$shouldSort,
                        _ref$getFn = _ref.getFn,
                        getFn = _ref$getFn === undefined ? deepValue : _ref$getFn,
                        _ref$sortFn = _ref.sortFn,
                        sortFn = _ref$sortFn === undefined ? function (a, b) {
                            return a.score - b.score;
                        } : _ref$sortFn,
                        _ref$tokenize = _ref.tokenize,
                        tokenize = _ref$tokenize === undefined ? false : _ref$tokenize,
                        _ref$matchAllTokens = _ref.matchAllTokens,
                        matchAllTokens = _ref$matchAllTokens === undefined ? false : _ref$matchAllTokens,
                        _ref$includeMatches = _ref.includeMatches,
                        includeMatches = _ref$includeMatches === undefined ? false : _ref$includeMatches,
                        _ref$includeScore = _ref.includeScore,
                        includeScore = _ref$includeScore === undefined ? false : _ref$includeScore,
                        _ref$verbose = _ref.verbose,
                        verbose = _ref$verbose === undefined ? false : _ref$verbose;

                    _classCallCheck(this, Fuse);

                    this.options = {
                        location: location,
                        distance: distance,
                        threshold: threshold,
                        maxPatternLength: maxPatternLength,
                        isCaseSensitive: caseSensitive,
                        tokenSeparator: tokenSeparator,
                        findAllMatches: findAllMatches,
                        minMatchCharLength: minMatchCharLength,
                        id: id,
                        keys: keys,
                        includeMatches: includeMatches,
                        includeScore: includeScore,
                        shouldSort: shouldSort,
                        getFn: getFn,
                        sortFn: sortFn,
                        verbose: verbose,
                        tokenize: tokenize,
                        matchAllTokens: matchAllTokens
                    };

                    this.setCollection(list);
                }

                _createClass(Fuse, [{
                    key: 'setCollection',
                    value: function setCollection(list) {
                        this.list = list;
                        return list;
                    }
                }, {
                    key: 'search',
                    value: function search(pattern) {
                        this._log('---------\nSearch pattern: "' + pattern + '"');

                        var _prepareSearchers2 = this._prepareSearchers(pattern),
                            tokenSearchers = _prepareSearchers2.tokenSearchers,
                            fullSearcher = _prepareSearchers2.fullSearcher;

                        var _search2 = this._search(tokenSearchers, fullSearcher),
                            weights = _search2.weights,
                            results = _search2.results;

                        this._computeScore(weights, results);

                        if (this.options.shouldSort) {
                            this._sort(results);
                        }

                        return this._format(results);
                    }
                }, {
                    key: '_prepareSearchers',
                    value: function _prepareSearchers() {
                        var pattern = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

                        var tokenSearchers = [];

                        if (this.options.tokenize) {
                            // Tokenize on the separator
                            var tokens = pattern.split(this.options.tokenSeparator);
                            for (var i = 0, len = tokens.length; i < len; i += 1) {
                                tokenSearchers.push(new Bitap(tokens[i], this.options));
                            }
                        }

                        var fullSearcher = new Bitap(pattern, this.options);

                        return { tokenSearchers: tokenSearchers, fullSearcher: fullSearcher };
                    }
                }, {
                    key: '_search',
                    value: function _search() {
                        var tokenSearchers = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
                        var fullSearcher = arguments[1];

                        var list = this.list;
                        var resultMap = {};
                        var results = [];

                        // Check the first item in the list, if it's a string, then we assume
                        // that every item in the list is also a string, and thus it's a flattened array.
                        if (typeof list[0] === 'string') {
                            // Iterate over every item
                            for (var i = 0, len = list.length; i < len; i += 1) {
                                this._analyze({
                                    key: '',
                                    value: list[i],
                                    record: i,
                                    index: i
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }

                            return { weights: null, results: results };
                        }

                        // Otherwise, the first item is an Object (hopefully), and thus the searching
                        // is done on the values of the keys of each item.
                        var weights = {};
                        for (var _i = 0, _len = list.length; _i < _len; _i += 1) {
                            var item = list[_i];
                            // Iterate over every key
                            for (var j = 0, keysLen = this.options.keys.length; j < keysLen; j += 1) {
                                var key = this.options.keys[j];
                                if (typeof key !== 'string') {
                                    weights[key.name] = {
                                        weight: 1 - key.weight || 1
                                    };
                                    if (key.weight <= 0 || key.weight > 1) {
                                        throw new Error('Key weight has to be > 0 and <= 1');
                                    }
                                    key = key.name;
                                } else {
                                    weights[key] = {
                                        weight: 1
                                    };
                                }

                                this._analyze({
                                    key: key,
                                    value: this.options.getFn(item, key),
                                    record: item,
                                    index: _i
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }
                        }

                        return { weights: weights, results: results };
                    }
                }, {
                    key: '_analyze',
                    value: function _analyze(_ref2, _ref3) {
                        var key = _ref2.key,
                            _ref2$arrayIndex = _ref2.arrayIndex,
                            arrayIndex = _ref2$arrayIndex === undefined ? -1 : _ref2$arrayIndex,
                            value = _ref2.value,
                            record = _ref2.record,
                            index = _ref2.index;
                        var _ref3$tokenSearchers = _ref3.tokenSearchers,
                            tokenSearchers = _ref3$tokenSearchers === undefined ? [] : _ref3$tokenSearchers,
                            _ref3$fullSearcher = _ref3.fullSearcher,
                            fullSearcher = _ref3$fullSearcher === undefined ? [] : _ref3$fullSearcher,
                            _ref3$resultMap = _ref3.resultMap,
                            resultMap = _ref3$resultMap === undefined ? {} : _ref3$resultMap,
                            _ref3$results = _ref3.results,
                            results = _ref3$results === undefined ? [] : _ref3$results;

                        // Check if the texvaluet can be searched
                        if (value === undefined || value === null) {
                            return;
                        }

                        var exists = false;
                        var averageScore = -1;
                        var numTextMatches = 0;

                        if (typeof value === 'string') {
                            this._log('\nKey: ' + (key === '' ? '-' : key));

                            var mainSearchResult = fullSearcher.search(value);
                            this._log('Full text: "' + value + '", score: ' + mainSearchResult.score);

                            if (this.options.tokenize) {
                                var words = value.split(this.options.tokenSeparator);
                                var scores = [];

                                for (var i = 0; i < tokenSearchers.length; i += 1) {
                                    var tokenSearcher = tokenSearchers[i];

                                    this._log('\nPattern: "' + tokenSearcher.pattern + '"');

                                    // let tokenScores = []
                                    var hasMatchInText = false;

                                    for (var j = 0; j < words.length; j += 1) {
                                        var word = words[j];
                                        var tokenSearchResult = tokenSearcher.search(word);
                                        var obj = {};
                                        if (tokenSearchResult.isMatch) {
                                            obj[word] = tokenSearchResult.score;
                                            exists = true;
                                            hasMatchInText = true;
                                            scores.push(tokenSearchResult.score);
                                        } else {
                                            obj[word] = 1;
                                            if (!this.options.matchAllTokens) {
                                                scores.push(1);
                                            }
                                        }
                                        this._log('Token: "' + word + '", score: ' + obj[word]);
                                        // tokenScores.push(obj)
                                    }

                                    if (hasMatchInText) {
                                        numTextMatches += 1;
                                    }
                                }

                                averageScore = scores[0];
                                var scoresLen = scores.length;
                                for (var _i2 = 1; _i2 < scoresLen; _i2 += 1) {
                                    averageScore += scores[_i2];
                                }
                                averageScore = averageScore / scoresLen;

                                this._log('Token score average:', averageScore);
                            }

                            var finalScore = mainSearchResult.score;
                            if (averageScore > -1) {
                                finalScore = (finalScore + averageScore) / 2;
                            }

                            this._log('Score average:', finalScore);

                            var checkTextMatches = this.options.tokenize && this.options.matchAllTokens ? numTextMatches >= tokenSearchers.length : true;

                            this._log('\nCheck Matches: ' + checkTextMatches);

                            // If a match is found, add the item to <rawResults>, including its score
                            if ((exists || mainSearchResult.isMatch) && checkTextMatches) {
                                // Check if the item already exists in our results
                                var existingResult = resultMap[index];
                                if (existingResult) {
                                    // Use the lowest score
                                    // existingResult.score, bitapResult.score
                                    existingResult.output.push({
                                        key: key,
                                        arrayIndex: arrayIndex,
                                        value: value,
                                        score: finalScore,
                                        matchedIndices: mainSearchResult.matchedIndices
                                    });
                                } else {
                                    // Add it to the raw result list
                                    resultMap[index] = {
                                        item: record,
                                        output: [{
                                            key: key,
                                            arrayIndex: arrayIndex,
                                            value: value,
                                            score: finalScore,
                                            matchedIndices: mainSearchResult.matchedIndices
                                        }]
                                    };

                                    results.push(resultMap[index]);
                                }
                            }
                        } else if (isArray(value)) {
                            for (var _i3 = 0, len = value.length; _i3 < len; _i3 += 1) {
                                this._analyze({
                                    key: key,
                                    arrayIndex: _i3,
                                    value: value[_i3],
                                    record: record,
                                    index: index
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }
                        }
                    }
                }, {
                    key: '_computeScore',
                    value: function _computeScore(weights, results) {
                        this._log('\n\nComputing score:\n');

                        for (var i = 0, len = results.length; i < len; i += 1) {
                            var output = results[i].output;
                            var scoreLen = output.length;

                            var totalScore = 0;
                            var bestScore = 1;

                            for (var j = 0; j < scoreLen; j += 1) {
                                var score = output[j].score;
                                var weight = weights ? weights[output[j].key].weight : 1;
                                var nScore = score * weight;

                                if (weight !== 1) {
                                    bestScore = Math.min(bestScore, nScore);
                                } else {
                                    output[j].nScore = nScore;
                                    totalScore += nScore;
                                }
                            }

                            results[i].score = bestScore === 1 ? totalScore / scoreLen : bestScore;

                            this._log(results[i]);
                        }
                    }
                }, {
                    key: '_sort',
                    value: function _sort(results) {
                        this._log('\n\nSorting....');
                        results.sort(this.options.sortFn);
                    }
                }, {
                    key: '_format',
                    value: function _format(results) {
                        var finalOutput = [];

                        this._log('\n\nOutput:\n\n', JSON.stringify(results));

                        var transformers = [];

                        if (this.options.includeMatches) {
                            transformers.push(function (result, data) {
                                var output = result.output;
                                data.matches = [];

                                for (var i = 0, len = output.length; i < len; i += 1) {
                                    var item = output[i];

                                    if (item.matchedIndices.length === 0) {
                                        continue;
                                    }

                                    var obj = {
                                        indices: item.matchedIndices,
                                        value: item.value
                                    };
                                    if (item.key) {
                                        obj.key = item.key;
                                    }
                                    if (item.hasOwnProperty('arrayIndex') && item.arrayIndex > -1) {
                                        obj.arrayIndex = item.arrayIndex;
                                    }
                                    data.matches.push(obj);
                                }
                            });
                        }

                        if (this.options.includeScore) {
                            transformers.push(function (result, data) {
                                data.score = result.score;
                            });
                        }

                        for (var i = 0, len = results.length; i < len; i += 1) {
                            var result = results[i];

                            if (this.options.id) {
                                result.item = this.options.getFn(result.item, this.options.id)[0];
                            }

                            if (!transformers.length) {
                                finalOutput.push(result.item);
                                continue;
                            }

                            var data = {
                                item: result.item
                            };

                            for (var j = 0, _len2 = transformers.length; j < _len2; j += 1) {
                                transformers[j](result, data);
                            }

                            finalOutput.push(data);
                        }

                        return finalOutput;
                    }
                }, {
                    key: '_log',
                    value: function _log() {
                        if (this.options.verbose) {
                            var _console;

                            (_console = console).log.apply(_console, arguments);
                        }
                    }
                }]);

                return Fuse;
            }();

            module.exports = Fuse;

            /***/ })
        /******/ ]);
});
//# sourceMappingURL=fuse.js.map
var AllInOneMenuTemplate = '<%var chunks = ["<div class=\'cont all-in-one-toc\'><h1 class=\'heading1\'>" + localization.TableOfContents + "</h1>"],    markup;function htmlTreeBuilder(items) {    if (items.length) {        chunks.push("<ul class=\'contents contents_all-in-one\'>");    }    items.forEach(function (item) {        if (!item.hidden) {            chunks.push("<li class=\'contents__item\'>");            chunks.push("<a href=\'");            chunks.push(item.url.match(/([\\w_]+\\.htm[l]?)/i)[1]);            chunks.push("\'>");            chunks.push(item.text);            chunks.push("</a>");            if (item.children) {                htmlTreeBuilder(item.children);            }            chunks.push("</li>");        }    });    if (items.length) {        chunks.push("</ul>");    }}htmlTreeBuilder(menu);chunks.push("</div>");markup = chunks.join("");%><%= markup %>';
var AsideTemplate = '<div class="aside ">    <div class="aside__inner">        <div class="aside__search search hidden-xs hidden-sm">            <div class="search__wrapper">                <input  class="search__field js_search_text" id="serch-text"                        placeholder="<%= localization.SearchLabel %>" type="text" />                <button class="search__btn js_search" id="search-button"></button>                <button class="search__clear is-hidden js_search_clear"></button>            </div>        </div>        <div class="selector-mobile js_selector_mobile_versions"></div>        <div class="selector-mobile js_selector_mobile_langs"></div>        <div class="aside__menu js_tabs_viewport">            <div class="js-menu-content">                <div class="js_menu"></div>            </div><!--            <div id="tab-names" class="b-tab__content js-tab-content">                <div class="b-index js_index_literals"></div>            </div>-->            <div class="js-search-content js_not_default">                <div class="search-results js_search_result_wrapper"></div>            </div>        </div>    </div></div>';
var BottomLinksTemplate = '<div class="bottom-links">    <!--<div class="feedback">        <div class="feedback__heading">Feedback</div>        <div class="feedback__text">            Was this article helpful?        </div>        <div>            <button class="button" type="button">Yes</button>            <button class="button" type="button">No</button>        </div>    </div>-->    <% if ((localization.ArticleIdText && localization.ArticleIdText.trim() && serviceInfo.id) ||            (localization.LastReviewText && localization.LastReviewText.trim() && serviceInfo.reviewDate)) { %>        <div class="bottom-links__service-info">            <% if (serviceInfo.id) { %>                <%= localization.ArticleIdText %> <%= serviceInfo.id %>,            <% } %>            <% if (serviceInfo.reviewDate) { %>                <%= localization.LastReviewText %> <%= serviceInfo.reviewDate %>            <% } %>        </div>    <% } %>    <div class="bottom-links__link">        <%= homeBtnHtml %>    </div></div>';
var ContainerTemplate = '<div class="main js_container">    <header class="js_header_placeholder"></header>    <div class="content js_main">        <div class="container">            <div class="row">                <div class="col-md-4 col-xs-20 menu-box js_aside_placeholder"></div>                <div class="col-md-1 hidden-xs hidden-sm js_prev_btn_placeholder"></div>                <div class="col-md-14 col-xs-20 js_content"></div>                <div class="col-md-1 hidden-xs hidden-sm js_next_btn_placeholder"></div>                <div class="col-md-16 col-xs-20 align-flex-end">                    <footer class="js_footer_placeholder"></footer>                </div>            </div>        </div>    </div>    <aside class="mobile-search-results is-hidden g-scrollable js_scrollable js_mobile_search_result js_mobile_aside"></aside></div><!--<div class="b-modal js_overlay">    <div class="b-modal__window js_modal">        <header class="b-modal__header js_modal_header"></header>        <div class="b-modal__content js_modal_content"></div>        <button href="#" class="b-modal__close-button js_modal_close"></button>    </div></div>--><div class="tooltip js_tooltip" data-id="">    <div class="tooltip__content js_tooltip_content"></div></div>';
var CustomStylesTemplate = '<style>    html {        color: <%= customization.ContentColorMain %>;    }    a {        color: <%= customization.LinkColor %>    }    a:hover {        color: <%= customization.LinkColorHover %>    }    a:visited {        color: <%= customization.LinkColorVisited %>    }    .page-title {        color: <%= customization.TitleColor %>;    }    /*.tablename,    .picturename,    .examplebodytext,    .examplebodytextblue2015,    .bottom-links__service-info,    .search-results__total,    .footer {        color: <%= customization.ContentColorSecondary %>;    }*/    .attentionbody,    .attentionbodytextindent,    .attentioncontinue1,    .attentioncontinue2,    .attentioncontinue3 {        color: <%= customization.AttentionBlockColor %>;    }    .warningbody,    .warningbodytextindent,    .warningcontinue1,    .warningcontinue2,    .warningcontinue3 {        color: <%= customization.WarningBlockColor %>;        border-color: <%= customization.WarningBlockBorder %>;        background: <%= customization.WarningBlockBackground %>;    }    .example-wrapper {        background: <%= customization.ExampleBlockBackground %> !important;    }    .exampleheading,    .examplebodytext,    .exampleheadingblue2015,    .examplebodytextblue2015 {        color: <%= customization.ExampleBlockColor %>;    }    mark {        background: <%= customization.SearchHighlightBackground %>;        color: <%= customization.SearchHighlightColor %>;    }</style>';
var FooterTemplate = '<div class="footer footer_inner">    <!--<div class="container">-->        <div class="row">            <div class="col-xs-20">                <div class="footer__divider"></div>            </div>            <div class="col-md-10 col-xs-20">                <div class="footer__text">                    <%= localization.FooterCopyrightText %>                </div>            </div>            <div class="col-md-10 col-xs-20">                <div class="footer__links">                    <% var hasOldFormatLinks = false %>                    <% if ( localization.FooterPrivacyPolicyLink && localization.FooterPrivacyPolicyLink.trim() &&                            localization.FooterPrivacyPolicyText && localization.FooterPrivacyPolicyText.trim() &&                            (!customization.FooterPrivacyPolicyLink || !customization.FooterPrivacyPolicyLink.hidden)) { %>                        <% hasOldFormatLinks = true %>                        <span class="footer__links-item">                            <% if (customization.FooterPrivacyPolicyLink && customization.FooterPrivacyPolicyLink.disabled) { %>                                <span class="footer__link">                                    <%= localization.FooterPrivacyPolicyText %>                                </span>                            <% } else { %>                                <a class="footer__link" target="blank" href="<%= localization.FooterPrivacyPolicyLink %>">                                    <%= localization.FooterPrivacyPolicyText %>                                </a>                            <% } %>                        </span>                    <% } %>                    <% if ( localization.FooterLegalLink && localization.FooterLegalLink.trim() &&                            localization.FooterLegalText && localization.FooterLegalText.trim() &&                            (!customization.FooterLegalLink || !customization.FooterLegalLink.hidden)) { %>                        <% hasOldFormatLinks = true %>                        <span class="footer__links-item">                            <% if (customization.FooterLegalLink && customization.FooterLegalLink.disabled) { %>                                <span class="footer__link">                                    <%= localization.FooterLegalText %>                                </span>                            <% } else { %>                                <a class="footer__link" target="blank" href="<%= localization.FooterLegalLink %>">                                    <%= localization.FooterLegalText %>                                </a>                            <% } %>                        </span>                    <% } %>                    <% if ( localization.FooterLinks && !hasOldFormatLinks ) { %>                        <% for (var i = 0, link; i < localization.FooterLinks.length; i++ ) { %>                            <% link = localization.FooterLinks[i] %>                            <span class="footer__links-item">                                <a class="footer__link" target="blank" href="<%= link.url %>">                                    <%= link.label %>                                </a>                            </span>                        <% } %>                    <% } %>                </div>            </div>        </div>    <!--</div>--></div>';
var HeaderTemplate = '<div class="header header_inner-help">    <div class="container">        <div class="row">            <div class="col-md-10 col-xs-20">                <button class="header__mobile-menu-btn js_burger" type="button"></button>                <div class="header__title hidden-xs hidden-sm">                    <% if ((!customization.HeaderLogoLink || !customization.HeaderLogoLink.hidden) && localization.HeaderTitle) { %>                        <% if ((customization.HeaderLogoLink && customization.HeaderLogoLink.disabled) || isOffline) { %>                            <span class="header__title-link">                        <% } else { %>                            <a href="<%= localization.HeaderLogoLink %>" class="header__title-link">                        <% } %>                            <% var index = localization.HeaderTitle.indexOf(" ") %>                            <%= localization.HeaderTitle.slice(0, index) %>                            <div class="header__title-big header__title-big_inner-help">                                <%= localization.HeaderTitle.slice(index, localization.HeaderTitle.length) %>                            </div>                        <%= (customization.HeaderLogoLink && customization.HeaderLogoLink.disabled) ? "</span>" : "</a>" %>                    <% } %>                </div>                <div class="header__title header__title_product"><%= titlePreffix %> <%= title %></div>                <div class="header__search">                    <button class="header__search-btn js_mobile_search_button" type="button"></button>                    <input type="search" class="header__search-input is-hidden js_mobile_search_input"                           placeholder="<%= localization.SearchPlaceholder %>" />                    <button class="header__clear-btn is-hidden js_mobile_search_clear" type="button"></button>                </div>            </div>            <div class="col-md-10 hidden-xs hidden-sm">                <div class="header__logo">                    <% if (!customization.FooterLogoLink || !customization.FooterLogoLink.hidden) { %>                        <% if (customization.FooterLogoLink && customization.FooterLogoLink.disabled) { %>                            <span class="logo"></span>                        <% } else { %>                            <a href="<%= localization.FooterLogoLink %>" class="logo"                               title="<%= localization.FooterLogoTitle %>"></a>                        <% } %>                    <% } %>                </div>            </div>        </div>    </div></div><div class="top-bar hidden-xs hidden-sm">    <div class="container">        <div class="row">            <div class="col-md-5">                <div class="top-bar__product-box">                    <div class="top-bar__product js_product_logo"></div>                    <h1 class="top-bar__title js_title">                        <% if (titlePreffix && titlePreffix.trim() ) { %>                            <span class="top-bar__title-small"><%= titlePreffix %></span>                        <% } %>                        <%= title %>                    </h1>                </div>            </div>            <div class="col-md-15">                <div class="top-bar__links-box">                    <div class="top-bar__links">                        <% if ( localization.PrintButtonText && localization.PrintButtonText.trim() ) { %>                            <% if (isAllInOne) { %>                                <a class="top-bar__link top-bar__link_print" href="javascript:print();">                                    <span class="top-bar__icon top-bar__icon_print"></span><%= localization.PrintButtonText %>                                </a>                            <% } else { %>                                <div class="dropdown js_dropdown">                                    <a class="top-bar__link top-bar__link_print js_dropdown_btn" href="#">                                        <span class="top-bar__icon top-bar__icon_print"></span><%= localization.PrintButtonText %>                                        <span class="top-bar__triangle"></span>                                    </a>                                    <ul class="dropdown__list js_dropdown_list">                                        <li class="dropdown__item">                                            <a class="dropdown__link" href="javascript:print();">                                                <%= localization.PrintPageText %>                                            </a>                                        </li>                                        <li class="dropdown__item">                                            <a class="dropdown__link js_print_section" href="">                                                <%= localization.PrintSectionText %>                                            </a>                                        </li>                                        <li class="dropdown__item">                                            <a class="dropdown__link js_print_all" href="all-in-one.htm" target="_blank">                                                <%= localization.PrintAllText %>                                            </a>                                        </li>                                    </ul>                                </div>                            <% } %>                        <% } %>                        <% if ( localization.SupportButtonText && localization.SupportButtonText.trim() &&                                localization.SupportButtonLink && localization.SupportButtonLink.trim() &&                                (!customization.SupportButtonLink || !customization.SupportButtonLink.hidden)) { %>                            <% if (customization.SupportButtonLink && customization.SupportButtonLink.disabled) { %>                                <span class="top-bar__link top-bar__link_support">                                    <span class="top-bar__icon top-bar__icon_support"></span><%= localization.SupportButtonText %>                                </span>                            <% } else { %>                                <a class="top-bar__link top-bar__link_support" href="<%= localization.SupportButtonLink %>" target="blank">                                    <span class="top-bar__icon top-bar__icon_support"></span><%= localization.SupportButtonText %>                                </a>                            <% } %>                        <% } %>                        <% if ( localization.SendLinkButtonText && localization.SendLinkButtonText.trim() &&                                (!customization.SendLinkButton || !customization.SendLinkButton.hidden)) { %>                            <% if (customization.SendLinkButton && customization.SendLinkButton.disabled) { %>                                <span class="top-bar__link top-bar__link_feedback">                                    <span class="top-bar__icon top-bar__icon_feedback"></span><%= localization.SendLinkButtonText %>                                </span>                            <% } else { %>                                <a class="top-bar__link top-bar__link_feedback js_feedback_link" href="">                                    <span class="top-bar__icon top-bar__icon_feedback"></span><%= localization.SendLinkButtonText %>                                </a>                            <% } %>                        <% } %>                    </div>                    <div class="top-bar__langs">                        <span class="top-bar__versions js_header_versions_list"></span>                        <span class="js_header_lang_list"></span>                    </div>                </div>            </div>        </div>    </div></div>';
var IndexLiteralsTemplate = '<ul class="b-index__list"><%    var result,        html = [];    for (var i= 0, item; i < index.length; i++ ) {        item = index[i];        if ( item.nested) {            html.push( "<li class=\'b-index__item js_menu_item b-index__item--nested\'>" );        } else {            html.push( "<li class=\'b-index__item js_menu_item\'>" );        }        if ( item["class"] === "indexlink" ) {            html.push( "<a class=\'b-index__link js_menu_link\' href=\'");            html.push( item.href );            html.push( "\'>" );            html.push( item.text );            html.push( "</a>" )        } else if ( item["class"] === "indexheading" ) {            html.push( "<span class=\'b-index__header\'>" );            html.push( item.text );            html.push( "</span>" )        } else {            html.push( "<span class=\'b-index__subheader\'>" );            html.push( item.text );            html.push( "</span>" )        }        html.push( "</li>" );    }    result = html.join("");%><%= result %></ul>';
var LangListTemplate = '<div class="dropdown dropdown_right js_dropdown">    <a class="dropdown__btn js_dropdown_btn">        <%= currentLang.name %>        <span class="dropdown__arrow"></span>    </a>    <ul class="dropdown__list js_dropdown_list">        <% _.each( langs, function( lang ) {%>            <% var dir = lang.dirname || lang.id %>            <% if (lang.id !== currentLang.id ) { %>                <li class="dropdown__item">                    <% if ( isMac ) { %>                        <a class="dropdown__link js_lang_item" data-lang-id="<%= dir %>" href="../../<%= dir %>/pgs">                            <%= lang.name %>                        </a>                    <% } else { %>                        <a class="dropdown__link js_lang_item" data-lang-id="<%= dir %>" href="../<%= dir %>">                            <%= lang.name %>                        </a>                    <% } %>                </li>            <% } %>        <% }) %>    </ul></div>';
var MenuTemplate = '<%var chunks = [],    isMac = isMacProject,    markup;function htmlTreeBuilder( items, opened ) {    if (items.length) {        chunks.push( "<ul class=\'contents js_contents_level\'" );        chunks.push( !opened ? " style=\'display:none\' ": "" );        chunks.push( ">" );    }    for (var i = 0, item; i < items.length; i++) {        item = items[i];        if ( !item.hidden ) {            if ( item.isActive ) {                chunks.push( "<li class=\'contents__item js_menu_item is-active\'>" );            } else {                chunks.push( "<li class=\'contents__item js_menu_item\'>" );            }            if ( item.children ) {                chunks.push( "<button class=\'contents__toggle js_contents_toggle" );                chunks.push( item.childIsActive || item.isActive ? " is-toggled" : "" );                chunks.push( "\' href=\'#\'></button>" );            }            chunks.push( "<a class=\'contents__item-link js_menu_link\' href=\'" );            chunks.push( (isMac ? "index.htm#" : "") + item.url );            chunks.push( "\'>" );            chunks.push( item.text );            chunks.push( "</a>" );            if ( item.children ) {                /*chunks.push( "<a class=\'contents__item-link-direct js_menu_link_direct\' href=\'" );                chunks.push( item.url );                chunks.push( "\'>" );                chunks.push( "</a>" );*/            }            if ( item.children ) {                htmlTreeBuilder( item.children, item.childIsActive || item.isActive );            }        }    }    if (items.length) {        chunks.push( "</ul>" );    }}htmlTreeBuilder( menu, true );markup = chunks.join("");%><%= markup %>';
var MobileSearchResultsTemplate = '<%if (!isInit){%>    <div class="mobile-search-results__total">        <% if ( resultsCount > 0) { %>            <%= localization.FoundTextBegin %> <%= resultsCount %> <%= localization.FoundTextEnd %>        <% } else { %>            <%= localization.NothingFoundText %>        <%}%>    </div>    <div class="mobile-search-results__content">        <%if ( found ){%>            <ul class="mobile-search-results__list">                <%_.each(results, function( page ){%>                    <li class="mobile-search-result">                        <% var link = isMacProject ? "index.htm#" + page.link : page.link %>                        <a class="mobile-search-result__title" href="<%= link %>"><%= page.title %></a>                        <%_.each( page.texts, function( text ){%>                            <p class="mobile-search-result__content"><%= text %></p>                        <%})%>                    </li>                <%})%>            </ul>        <%}%>    </div><%}%>';
var NextLinkTemplate = '<div class="nav-btn">    <% if (nextPage && nextPage.url) { %>        <% var link = isMacProject ? "index.htm#" + nextPage.url : nextPage.url %>        <a class="nav-btn__link-next js_next_link"           href="<%= link %>"           title="<%= nextPage.text %>"></a>    <% } else { %>        <span class="nav-btn__link-next-inactive"></span>    <% } %></div>';
var PageTitleTemplate = '<div class="page-title">    <div class="page-title__text">        <%= titleHtml %>    </div></div>';
var PrevLinkTemplate = '<div class="nav-btn">    <% if (prevPage && prevPage.url) { %>        <% var link = isMacProject ? "index.htm#" + prevPage.url : prevPage.url %>        <a class="nav-btn__link-prev js_prev_link"           href="<%= link %>"           title="<%= prevPage.text %>"></a>    <% } else { %>        <span class="nav-btn__link-prev-inactive"></span>    <% } %></div>';
var SearchResultsTemplate = '<%if (!isInit){%>    <div class="search-results__header">        <div class="search-results__total">            <%= localization.FoundTextBegin %> <%= resultsCount %> <%= localization.FoundTextEnd %>        </div>    </div>    <%if ( found ){%>        <div class="search-results__content">            <ul class="search-results__list">                <%_.each(results, function( page ){%>                    <li class="search-result">                        <% var link = isMacProject ? "index.htm#" + page.link : page.link %>                        <a class="search-result__title" href="<%= link %>"><%= page.title %></a>                        <%_.each( page.texts, function( text ){%>                            <p class="search-result__content"><%= text %></p>                        <%})%>                    </li>                <%})%>            </ul>        </div>    <%}%><%}%>';
var VersionsTemplate = '<div class="dropdown dropdown_right js_dropdown">    <a class="dropdown__btn js_dropdown_btn">        <%= currentVersion.label %>        <span class="dropdown__arrow"></span>    </a>    <ul class="dropdown__list js_dropdown_list">        <% _.each(versions, function(version)  {%>            <% if (version.url !== currentVersion.url) { %>                <li class="dropdown__item">                    <a class="dropdown__link js_version_item"                       data-version-url="<%= version.url %>" href="../../<%= version.url %>">                        <%= version.label %>                    </a>                </li>            <% } %>        <% }) %>    </ul></div>';
var LangsLocalization = {"en-US":"English","id-ID":"Bahasa Indonesia","cs-CZ":"Čeština &#x202A;(Česká republika)","da-DK":"Dansk &#x202A;(Danmark)","de-DE":"Deutsch","et-EE":"Eesti","es-ES":"Español &#x202A;(España, alfabetización internacional)","es-MX":"Español &#x202A;(México)","fr-FR":"Français","it-IT":"Italiano","lv-LV":"Latviešu","lt-LT":"Lietuvių","hu-HU":"Magyar &#x202A;(Magyarország)","nl-NL":"Nederlands &#x202A;(Nederland)","nb-NO":"Norsk, bokmål &#x202A;(Norge)","pl-PL":"Polski &#x202A;(Polska)","pt-BR":"Português &#x202A;(Brasil)","pt-PT":"Português &#x202A;(Portugal)","ro-RO":"Română &#x202A;(România)","sr-Latn":"Srpski","fi-FI":"Suomi &#x202A;(Suomi)","sv-SE":"Svenska &#x202A;(Sverige)","vi-VN":"Tiếng Việt &#x202A;(Việt Nam)","tr-TR":"Türkçe &#x202A;(Türkiye)","el-GR":"Ελληνικά &#x202A;(Ελλάδα)","bg-BG":"Български","kk-KZ":"Қазақ","ru-RU":"Русский","sr-Cyrl":"Српски","uk-UA":"Українська","ar-AE":"العربية (الإمارات العربية المتحدة&#x202B;)","fa-IR":"فارسى (ایران&#x202B;)","hi-IN":"हिंदी &#x202A;(भारत)","th-TH":"ไทย &#x202A;(ไทย)","ko-KR":"한국어 &#x202A;(대한민국)","ja-JP":"日本語&#x202A;(日本)","zh-Hans":"简体中文","zh-Hant":"繁體中文"};
var Page=new Array("Copyright"," "," "," "," ","Sehr geehrter Anwender, ","Vielen Dank, dass Sie sich für Kaspersky Lab als Ihren Anbieter für Sicherheitssoftware entschieden haben. Wir hoffen, dass dieses Dokument Sie bei der Verwendung unseres Produkts unterstützt.","Achtung! Dieses Dokument ist Eigentum von AO Kaspersky Lab (im Weiteren Kaspersky Lab): Alle Rechte an diesem Dokument sind durch die Urhebergesetze der Russischen Föderation und durch internationale Abkommen geschützt. Die illegale Vervielfältigung und Weitergabe dieses Dokuments kann gemäß geltendem Recht zivil-, verwaltungs- oder strafrechtlich haftbar gemacht werden. ","Jegliche Vervielfältigung oder Weitergabe aller Materialen einschließlich der Übersetzungen bedürfen der vorherigen schriftlichen Zustimmung von Kaspersky Lab.","Die Verwendung dieses Dokuments sowie der dazugehörigen Grafiken ist nur für informative, nicht kommerzielle und persönliche Zwecke gestattet.","Kaspersky Lab behält sich das Recht vor, dieses Dokument ohne zusätzliche Mitteilung zu ändern.","Kaspersky Lab übernimmt keine Haftung für die Inhalte, die Qualität, die Relevanz oder die Genauigkeit jeglicher Materialien in diesem Dokument, die dem Urheberrecht Dritter unterliegen, sowie keine Haftung für etwaige Schäden, die durch die Verwendung dieses Dokuments entstanden sind.","Revisionsdatum des Dokuments: 01.03.2018","© 2018 AO Kaspersky Lab. Alle Rechte vorbehalten.","https://www.kaspersky.dehttps://support.kaspersky.com/de"," Copyright ","55937.htm");
Page[1]=new Array("Über dieses Dokument","Das Benutzerhandbuch für Kaspersky Endpoint Security 10 Service Pack 1 für Linux (im Folgenden auch „Kaspersky Endpoint Security“ genannt) wendet sich an Fachleute, die für die Installation und Verwaltung von Kaspersky Endpoint Security sowie für den technischen Support von Unternehmen, die Kaspersky Endpoint Security nutzen, verantwortlich sind.","Sie können die Informationen in diesem Handbuch für die Ausführung folgender Aufgaben verwenden:","Vorbereitung der Installation, Installation und Aktivierung von Kaspersky Endpoint Security.Konfiguration und Nutzung von Kaspersky Endpoint Security.Dieses Handbuch bietet ferner Unterstützung beim Kennenlernen von Informationsquellen für das Programm sowie Möglichkeiten für den Erhalt von technischem Support.","In diesem AbschnittIn diesem HandbuchDokumentkonventionen"," &#xDC;ber dieses Dokument ","161208.htm");
Page[2]=new Array("In diesem Handbuch","Dieses Handbuch enthält folgende Abschnitte:","Informationsquellen zum Programm","Dieser Abschnitt enthält die Beschreibung der Informationsquellen zum Programm.","Kaspersky Endpoint Security","Dieser Abschnitt enthält eine Beschreibung der Möglichkeiten des Programms sowie Kurzinformationen über alle Komponenten. Sie erfahren, was im Lieferumfang enthalten ist und welche Dienste für registrierte Programmbenutzer zugänglich sind.","Installation des Programms","Dieser Abschnitt enthält Informationen über die Installation von Kaspersky Endpoint Security auf Ihrem Computer und die Durchführung der Erstkonfiguration.","Programm löschen","Dieser Abschnitt enthält Informationen über die Deinstallation des Programms von Ihrem Computer.","Lizenzierung des Programms","In diesem Abschnitt werden die wichtigsten Aspekte der Lizenzverwaltung des Programms behandelt.","Programm starten und anhalten","Dieser Abschnitt informiert über die Ausführung, den Neustart und das Beenden des Programms aus der Befehlszeile.","Allgemeine Einstellungen von Kaspersky Endpoint Security","Dieser Abschnitt bietet Informationen über die allgemeinen Programmeinstellungen.","Verwalten der Aufgaben in Kaspersky Endpoint Security mithilfe der Befehlszeile","Dieser Abschnitt enthält Informationen über die Aufgabentypen von Kaspersky Endpoint Security und Anweisungen zur Aufgabenverwaltung per Befehlszeile.","Aufgabe zum Echtzeitschutz (File_Monitoring ID:1)","Dieser Abschnitt enthält Informationen über die Aufgabe zum Echtzeitschutz, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Aufgabe zur Untersuchung auf Befehl (Scan_My_Computer ID:2)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Untersuchung auf Befehl, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Aufgabe zur benutzerdefinierten Untersuchung (Scan_File ID:3)","Dieser Abschnitt enthält Informationen über die Aufgabe zur benutzerdefinierten Untersuchung, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Aufgabe zur Untersuchung des Bootsektors (Boot_Scan ID:4)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Untersuchung der Bootsektoren, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgaben.","Aufgabe zur Untersuchung des Arbeitsspeichers (Memory_Scan ID_5)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Untersuchung des Arbeitsspeichers, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgaben.","Update-Aufgabe (Update-ID:6)","Dieser Abschnitt enthält Informationen über das Update der Antiviren-Datenbanken und der Programm-Module (im Folgenden auch \"Updates\") sowie Anweisungen zur Konfiguration der Update-Einstellungen.","Aufgabe zum Rollback eines Datenbanken-Updates (Rollback ID:7)","Dieser Abschnitt enthält Informationen über die Aufgabe zum Rollback eines Datenbanken-Updates, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Aufgabe zum Kopieren von Updates (Retranslate ID:8)","Dieser Abschnitt enthält Informationen über das Retranslate von Updates für Programme und Antiviren-Datenbanken, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Lizenz-Aufgabe (License ID:9)","Dieser Abschnitt enthält Informationen über die License-Aufgabe, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Aufgabe zur Speicherverwaltung (Backup ID:10)","Dieser Abschnitt enthält Anweisungen zur Konfiguration von Speichereinstellungen und Informationen darüber, welche Aktionen man mit den Objekten im Speicher ausführen kann.","Aufgabe zur Überwachung der Datei-Integrität (Integrity_Monitoring ID:11)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Überwachung der Datei-Integrität, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Aufgabe zur Firewall-Verwaltung (Firewall ID:12)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Firewall-Verwaltung, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Aufgabe zum Schutz vor Verschlüsselung (AntiCryptor ID:13)","Dieser Abschnitt enthält Informationen über die Aufgabe „Anti-Cryptor“, sowie Anweisungen zur Anpassung der Einstellungen dieser Aufgabe.","Teilnahme am Kaspersky Security Network","Dieser Abschnitt enthält Informationen über die Teilnahme am Kaspersky Security Network und erklärt, wie die Verwendung von Kaspersky Security Network aktiviert und deaktiviert werden kann.","Verwendung der grafischen Benutzeroberfläche von Kaspersky Endpoint Security","Dieser Abschnitt enthält Informationen über die grafische Benutzeroberfläche des Programms, sowie Anweisungen zu deren Aktivierung oder Deaktivierung.","Kontaktaufnahme mit dem Technischen Support","Dieser Abschnitt beschreibt, wie Sie technische Unterstützung erhalten, und nennt die Voraussetzungen, die dafür erfüllt sein müssen.","Anhänge","Dieser Abschnitt enthält Informationen über die Standardeinstellungen der Konfigurationsdateien und Rückgabecodes der Befehlszeile. Des Weiteren enthält dieser Abschnitt Anweisungen zur Konfiguration von Kaspersky Anti-Virus für Linux Mail Server.","AO Kaspersky Lab","Dieser Abschnitt enthält Informationen über Kaspersky Lab.","Informationen über den Code von Drittherstellern","Dieser Abschnitt enthält Informationen über den Code von Drittherstellern.","Markeninformationen","Dieser Abschnitt informiert über die Markenzeichen, die in diesem Dokument erwähnt werden.","Glossar","Dieser Abschnitt enthält eine Liste von Fachbegriffen aus dem Dokument sowie deren jeweilige Definitionen.","Sachregister","Dieser Abschnitt ermöglicht das schnelle Auffinden bestimmter Angaben in diesem Dokument."," In diesem Handbuch ","161209.htm");
Page[3]=new Array("Dokumentkonventionen","Dieses Dokument verwendet die folgenden Konventionen (siehe Tabelle unten).","Dokumentkonventionen"," ","Beispieltext","Beschreibung der Dokumentenkonvention","Beachten Sie, dass....","Warnungen sind rot und umrandet hervorgehoben. Warnungen zeigen Informationen über Aktionen an, die unerwünschte Folgen haben können.","Wir empfehlen Ihnen die Verwendung von....","Die Hinweise befinden sich in Boxen. Hinweise bieten zusätzliche Informationen und Referenzinformationen."," "," ","Beispiel:","…"," ","Beispiele sind auf einem hellblauen Hintergrund unter der Überschrift „Beispiel“ aufgeführt.","Update bedeutet...","Das Ereignis Datenbanken sind veraltet.","Die folgenden Elemente sind im Text kursiv gesetzt:","Neue BegriffeNamen der Programmstatus und -ereignisse","Drücken Sie auf die Eingabetaste.","Drücken Sie auf ALT+F4.","Die Namen der Tastaturtasten sind fett gedruckt und werden großgeschrieben.","Tastenbezeichnungen, die durch ein Pluszeichen (+) verbunden sind, stellen Tastenkombinationen dar. Solche Tasten müssen gleichzeitig gedrückt werden.","Klicken Sie auf die Schaltfläche Aktivieren.","Namen von Elementen der Programmoberfläche, wie Eingabefelder, Menüeinträge und Schaltflächen, sind fett gedruckt. ","Gehen Sie folgendermaßen vor, um einen Aufgabenzeitplan anzupassen:","Einleitende Sätze von Anweisungen sind kursiv gedruckt und werden durch das Pfeilsymbol begleitet.","Tippen Sie in der Befehlszeile help ein.","Daraufhin erscheint die folgende Meldung:","Geben Sie das Datum im Format dd:mm:yy an.","Die folgenden Arten von Textinhalten werden mit einer speziellen Schriftart abgesetzt:","Text in der BefehlszeileText der Meldungen, die das Programm auf dem Bildschirm anzeigtDateneingabe über die Tastatur","<Benutzername>","Variablen sind in spitzen Klammern eingeschlossen. Fügen Sie anstelle der Variablen den entsprechenden Wert ein, ohne die spitzen Klammern."," Dokumentkonventionen ","68566.htm");
Page[4]=new Array("Informationsquellen zum Programm","Seite von Kaspersky Endpoint Security auf der Website von Kaspersky Lab","Auf der Seite von Kaspersky Endpoint Security auf der Website von Kaspersky Lab finden Sie allgemeine Informationen über das Programm, seine Funktionen und Besonderheiten.","Seite von Kaspersky Endpoint Security in der Wissensdatenbank","Die Wissensdatenbank ist ein spezieller Bereich auf der Website des Technischen Supports von Kaspersky Lab.","Auf der Seite für Kaspersky Endpoint Security in der Wissensdatenbank finden Sie Artikel mit nützlichen Informationen, Tipps und Antworten auf häufige Fragen zum Kauf, zur Installation und zur Verwendung der Anwendung.","Die Artikel der Wissensdatenbank behandeln neben Fragen zu Kaspersky Endpoint Security auch andere Programme von Kaspersky Lab. Die Artikel in der Wissensdatenbank können auch Neuigkeiten des Technischen Supports enthalten.","Diskussion über die Programme von Kaspersky Lab im Forum","Wenn Ihre Frage keine dringende Antwort erfordert, können Sie sie mit den Mitarbeitern von Kaspersky Lab und mit anderen Anwendern in unserem Forum diskutieren.","Im Forum können Sie bereits veröffentlichte Themen nachlesen, Kommentare abgeben oder neue Themen erstellen.","Um die Online-Ressourcen nutzen zu können, ist eine Internetverbindung erforderlich.","Wenn Sie keine Lösung zu Ihrem Problem finden können, kontaktieren Sie den Technischen Support.","In diesem AbschnittQuellen für die selbständige Suche nach InformationenDiskussion über die Programme von Kaspersky Lab im Webforum"," Informationsquellen zum Programm ","80831.htm");
Page[5]=new Array("Quellen für die selbständige Suche nach Informationen","Sie können die folgenden Informationsquellen über Kaspersky Endpoint Security nutzen, um selbstständig zu recherchieren:","Seite von Kaspersky Endpoint Security auf der Website von Kaspersky LabSeite von Kaspersky Endpoint Security auf der Webseite des Technischen Supports (Wissensdatenbank)Hilfsdokumentation im Lieferumfang des Programms","Wenn Sie die Lösung für ein Problem nicht selbst finden können, empfehlen wir Ihnen, sich an den Technischen Support von Kaspersky Lab zu wenden.","Für den Zugriff auf Website-Ressourcen ist eine Internetverbindung erforderlich.","Seite von Kaspersky Endpoint Security auf der Website von Kaspersky Lab","Auf der Seite von Kaspersky Endpoint Security finden Sie allgemeine Informationen über das Programm, seine Funktionen und Besonderheiten.","Auf der Seite Kaspersky Endpoint Security finden Sie einen Link zum Online-Shop, wo Sie Ihre Lizenz für das Programm kaufen oder verlängern können.","Seite von Kaspersky Endpoint Security in der Wissensdatenbank","Die Wissensdatenbank ist ein spezieller Bereich auf der Website des Technischen Supports von Kaspersky Lab.","Auf der Seite von Kaspersky Endpoint Security in der Wissensdatenbank finden Sie nützliche Informationen, Tipps und Antworten auf häufig gestellte Fragen. Dabei werden Fragen wie Kauf, Installation und Verwendung des Programms behandelt.","Die Artikel der Wissensdatenbank behandeln neben Fragen zu Kaspersky Endpoint Security auch andere Programme von Kaspersky Lab. Artikel in der Wissensdatenbank können auch Neuigkeiten vom Technischen Support enthalten.","Hilfsdokumentation im Lieferumfang des Programms","Das Programm enthält eine vollständige Hilfe und eine Kontexthilfe.","Die vollständige Hilfe enthält Informationen zur Konfiguration und Verwendung von Kaspersky Endpoint Security.","Die Kontexthilfe bietet Informationen über die Fenster von Kaspersky Endpoint Security, beschreibt die Programmeinstellungen und enthält Links zu Aufgabenbeschreibungen, in denen diese Einstellungen verwendet werden.","Die Hilfe finden Sie im Lieferumfang oder auf der Website von Kaspersky Lab. Wenn die Online-Hilfe verfügbar ist, wird beim Aufruf der Online-Hilfe ein Browser-Fenster geöffnet. Für die Anzeige der Online-Hilfe ist eine Internetverbindung erforderlich.","Dokumentation","Das Benutzerhandbuch des Programms enthält Informationen zur Installation, Aktivierung und Konfiguration des Programms sowie zu seiner Verwendung. Das Dokument beschreibt auch die Programmschnittstelle und die Möglichkeiten, die typischen Benutzeraufgaben auszuführen."," Quellen f&#xFC;r die selbst&#xE4;ndige Suche nach Informationen ","166041.htm");
Page[6]=new Array("Diskussion über die Programme von Kaspersky Lab im Webforum","Wenn Ihre Frage keine dringende Antwort erfordert, können Sie sie mit den Mitarbeitern von Kaspersky Lab und mit anderen Anwendern in unserem Forum diskutieren.","Im Forum können Sie bereits veröffentlichte Themen nachlesen, Kommentare abgeben oder neue Themen erstellen."," Diskussion &#xFC;ber die Programme von Kaspersky Lab im Webforum ","35700.htm");
Page[7]=new Array("Kaspersky Endpoint Security 10 Service Pack 1 für Linux","Dieser Abschnitt enthält eine Beschreibung der Funktionen, Komponenten und des Lieferumfangs von Kaspersky Endpoint Security sowie eine Liste der Hardware- und Softwarevoraussetzungen für Kaspersky Endpoint Security.","In diesem AbschnittÜber Kaspersky Endpoint SecurityNeuerungenLieferumfangHardware- und Softwarevoraussetzungen"," Kaspersky Endpoint Security 10 Service Pack 1 f&#xFC;r Linux ","161213.htm");
Page[8]=new Array("Über Kaspersky Endpoint Security","Kaspersky Endpoint Security schützt Computer mit den Betriebssystemen von Linux® vor Schadsoftware. Bedrohungen können über Datenübertragungskanäle im Netzwerk oder über Wechseldatenträger in das Dateisystem gelangen.","Das Programm ermöglicht Folgendes:","Untersuchung aller Objekte, die sich auf lokalen Computerlaufwerken befinden, sowie aller eingebundenen und freigegebenen Ressourcen, auf die über SMB- und NFS-Protokolle zugegriffen wird.Untersuchung von Objekten des Dateisystems sowohl in Echtzeit mithilfe der Aufgabe zum Echtzeitschutz als auch auf Befehl mithilfe der Aufgaben zur Untersuchung auf Befehl.Untersuchungen der BootsektorenUntersuchungen des ProzessspeichersErkennung infizierter Objekte. Kaspersky Endpoint Security stuft ein Objekt als infiziert ein, wenn im Objekt der Code eines bekannten Virus gefunden wurde.Beseitigung der in den Dateien gefundenen Bedrohungen.Automatische Auswahl der Aktion, die zur Neutralisierung der Bedrohung ausgeführt wird.Speichern der Backup-Kopien der Dateien vor der Desinfektion oder dem Löschen und Wiederherstellen der Dateien aus den Backup-Kopien.Verwaltung von Aufgaben und Konfiguration der Einstellungen.Verwaltung der Aufgabe zum Echtzeitschutz, der Aufgabe zur Untersuchung auf Befehl, der Aufgabe zur Untersuchung des Bootsektors, der Aufgabe zur Untersuchung des Prozessarbeitsspeichers, der Update-Aufgabe, der Aufgabe zum Rollback eines Datenbanken-Updates und der Aufgabe zum Kopieren von Updates.Hinzufügen von Schlüsseln und Aktivieren des Programms mithilfe von Aktivierungscodes.Benachrichtigen des Administrators über Ereignisse, die während der Ausführung von Kaspersky Endpoint Security aufgetreten sind.Aktualisieren der Datenbanken von Kaspersky Endpoint Security über die Kaspersky-Lab-Update-Server, über den Administrationsserver oder über eine vom Benutzer angegebene Quelle nach Zeitplan oder auf Befehl.Verwendung der Antiviren-Datenbanken zum Erkennen und Desinfizieren von infizierten Dateien. Während des Untersuchungsprozesses analysiert Kaspersky Endpoint Security jede Datei auf Bedrohungen: Der Dateicode wird mit einem Code abgeglichen, der an eine bestimmte Bedrohung erinnert.Überwachung der Integrität der angegebenen Dateien und Bericht über Änderungen. Die Überwachung der Datei-Integrität kann in einem konstanten Überwachungsmodus und im Modus „Untersuchung auf Befehl“ ausgeführt werden.Verwaltung der Firewall eines Betriebssystems und, falls erforderlich, Wiederherstellen eines geänderten Satzes der Firewall-Regeln.Schutz Ihrer Dateien in den lokalen Verzeichnissen mit Netzwerkzugang durch SMB / NFS-Protokolle vor bösartiger Remote-Verschlüsselung.Verwaltung von grundlegenden Programmfunktionen durch Benutzer ohne Root-Rechte mithilfe der grafischen Benutzeroberfläche.Update des Programms mithilfe von Updatepaketen.Verwalten von Kaspersky Endpoint Security auf folgende Arten:über die Befehlszeile mithilfe von Befehlen zur ProgrammverwaltungVerwendung der grafischen Benutzeroberfläche.über Kaspersky Security Center"," &#xDC;ber Kaspersky Endpoint Security ","161214.htm");
Page[9]=new Array("Neuerungen","Kaspersky Endpoint Security 10 Service Pack 1 für Linux bietet die folgenden Funktionen und Verbesserungen:","Überwachung der Datei-IntegritätÜberwachung der Integrität der angegebenen Dateien und Bericht über Änderungen. Die Überwachung der Datei-Integrität kann in einem Echtzeit-Überwachungsmodus und im Modus „Untersuchung auf Befehl“ ausgeführt werden.","Firewall-VerwaltungVerwaltung der Firewall eines Betriebssystems und, falls erforderlich, Wiederherstellen eines geänderten Satzes der Firewall-Regeln.","Anti-CryptorSchutz Ihrer Dateien in den lokalen Verzeichnissen mit Netzwerkzugang durch SMB / NFS-Protokolle vor bösartiger Remote-Verschlüsselung.","Grafische BenutzeroberflächeVerwaltung von grundlegenden Programmfunktionen durch Benutzer ohne Root-Rechte mithilfe der lokalisierten grafischen Benutzeroberfläche (GUI).","Programm-UpdatesSie können das Programm mithilfe von Updatepaketen aktualisieren.","Das Tool kesl-control befindet sich jetzt im Systemverzeichnis /usr/bin."," Neuerungen ","162018.htm");
Page[10]=new Array("Lieferumfang","Der Lieferumfang umfasst das Installationspaket von Kaspersky Endpoint Security mit den folgenden Dateien:","kesl-10.1.0-<Versionsnummer>.i386.rpm, kesl_10.1.0-<Versionsnummer>_i386.debEnthält die wichtigsten Dateien von Kaspersky Endpoint Security. Pakete können auf 32-Bit-Betriebssystemen auf der Grundlage der Typs der Paketverwaltung installiert werden.","kesl-10.1.0-<Versionsnummer>.x86_64.rpm, kesl_10.1.0-<Versionsnummer>_amd64.debEnthält die wichtigsten Dateien von Kaspersky Endpoint Security. Pakete können auf 64-Bit-Betriebssystemen auf der Grundlage der Typs der Paketverwaltung installiert werden.","kesl.zipEnthält die Dateien kesl.kud und akinstall.sh, die während der Remote-Installation von Kaspersky Endpoint Security mithilfe von Kaspersky Security Center verwendet werden.","klnagent-<build number>.i386.rpm, klnagent_<build number>_i386.deb, klnagent64-<build number>.x86_64.rpm, klnagent64_<build number>_amd64.debEnthalten den Administrationsagenten (Tool zur Verbindung von Kaspersky Endpoint Security mit Kaspersky Security Center.","klnagent-rpm.tar.gz, klnagent-deb.tar.gzEnthält die Dateien klnagent.kpd und akinstall.sh, die während der Remote-Installation des Administrationsagenten mithilfe von Kaspersky Security Center verwendet werden.","Datei ksn_license.utf-8-unix, mit deren Hilfe Sie sich mit den Teilnahmebedingungen für das Kaspersky Security Network vertraut machen können.Datei license.utf-8-unix mit Erläuterungen zum Endbenutzer-Lizenzvertrag. Der Endbenutzer-Lizenzvertrag enthält die Bedingungen für die Nutzung des Programms."," Lieferumfang ","161216.htm");
Page[11]=new Array("Hardware- und Softwarevoraussetzungen","Um die Funktionsfähigkeit von Kaspersky Endpoint Security zu gewährleisten, sind folgende Voraussetzungen zu erfüllen:","Allgemeine Mindestanforderungen:","Prozessor Core™ 2 Duo 1,86 GHz oder höher1 GB Arbeitsspeichers für 32-Bit-Betriebssysteme2 GB Arbeitsspeichers für 64-Bit-BetriebssystemeSwap-Speicher nicht unter 1 GB1 GB freier Speicherplatz auf der FestplatteSoftwarevoraussetzungen:","Unterstützten 32-Bit-Betriebssysteme:Red Hat® Enterprise Linux® 6.9CentOS-6.9Ubuntu Server 14.04.5 LTSUbuntu Server 16.04.5 LTSUbuntu Server 17.10.1 LTSDebian GNU/Linux 7, alle Editionen (grafische Benutzeroberfläche wird nicht unterstützt)Debian GNU/Linux 8.10Debian GNU/Linux 9.3Unterstützten 64-Bit-Betriebssysteme:Red Hat Enterprise Linux 6.9Red Hat Enterprise Linux 7.4CentOS-6.9CentOS-7.4Ubuntu Server 14.04.5 LTSUbuntu Server 16.04.5 LTSUbuntu Server 17.10.1 LTSDebian GNU/Linux 7, alle Editionen (grafische Benutzeroberfläche wird nicht unterstützt)Debian GNU/Linux 8.10Debian GNU/Linux 9.3openSUSE 42.3SUSE Linux Enterprise Server 12.3Novell OES2015, alle Editionen (grafische Benutzeroberfläche wird nicht unterstützt)Oracle Linux 7.4Interpreter Perl Version 5.10 oder höherInstalliertes Hilfstool whichInstallierte Pakte zur Programmkompilierung (gcc, binutils, glibc, glibc-devel, make, ld),Quellcode für den Kernel des Betriebssystems – zum Kompilieren der Module von Kaspersky Endpoint Security auf Betriebssystemen ohne Unterstützung der fanotity-Technologie.Kaspersky Endpoint Security 10 für Linux ist mit Kaspersky Security Center 10 SP1 und Kaspersky Security Center 10 SP2 kompatibel.Für die Ausführung des Verwaltungs-Plug-in für Kaspersky Endpoint Security muss Microsoft® Visual C ++ 2015 Redistributable Update 3 RC installiert sein.Vor der Installation des Administrationsagenten müssen die folgenden Module installiert werden:Das Modul libc6-i386 muss auf 64-Bit-Versionen von Debian und Ubuntu installiert werden.Das Modul glibc.i686 muss auf Red Hat Enterprise Linux 7 und höher, CentOS 6 und höher, Oracle Linux 7 und höher installiert werden.Das Modul glibc-32bit muss auf openSUSE 42.2, CentOS 6 oder später, Novel installiert sein."," Hardware- und Softwarevoraussetzungen ","161217.htm");
Page[12]=new Array("Installation des Programms","Dieser Abschnitt enthält Anweisungen darüber, wie das Installationspaket (in Weiteren „Paket“) von Kaspersky Endpoint Security und dem Administrationsagenten installiert wird.","In diesem AbschnittÜber die Installation von Kaspersky Endpoint SecurityPaket von Kaspersky Endpoint Security installierenErstkonfiguration der Einstellungen von Kaspersky Endpoint SecurityAutomatischer Modus zur Erstkonfiguration von Kaspersky Endpoint SecurityKaspersky Endpoint Security über Kaspersky Security Center installierenAdministrationsagent installierenUpgrade einer alten ProgrammversionKonfiguration der Berechtigungen im SELinux-SystemKonfiguration der Berechtigungen im AppArmor-System"," Installation des Programms ","161219.htm");
Page[13]=new Array("Über die Installation von Kaspersky Endpoint Security","Kaspersky Endpoint Security wird in Installationspaketen der Formate DEB und RPM vertrieben.","Für die Arbeit mit Kaspersky Endpoint Security müssen Sie folgende Operationen ausführen:","Paket von Kaspersky Endpoint Security installieren.Skript für das Update der Einstellungen ausführen.Paket des Administrationsagenten und des Verwaltungs-Plug-ins für Kaspersky Security installieren, wenn Sie planen, Kaspersky Endpoint Security mithilfe von Kaspersky Security Center zu verwalten.Für den Zugriff auf die Programmdateien und Verzeichnisse während der Installation und das Herunterladen und Übernehmen von Programm-Update sind Root-Rechte erforderlich."," &#xDC;ber die Installation von Kaspersky Endpoint Security ","161220.htm");
Page[14]=new Array("Paket von Kaspersky Endpoint Security installieren","Kaspersky Endpoint Security wird in Installationspaketen der Formate DEB und RPM vertrieben.","Um Kaspersky Endpoint Security aus dem Paket im RPM-Format auf einem 32-Bit-Betriebssystem zu installieren, führen Sie den folgenden Befehl aus:","# rpm -i kesl-10.1.0-<Versionsnummer>.i386.rpm","Um Kaspersky Endpoint Security aus dem Paket im RPM-Format auf einem 64-Bit-Betriebssystem zu installieren, führen Sie den folgenden Befehl aus:","# rpm -i kesl-10.1.0-<Versionsnummer>.x86_64.rpm","Um Kaspersky Endpoint Security aus dem Paket im DEB-Format auf einem 32-Bit-Betriebssystem zu installieren, führen Sie den folgenden Befehl aus:","# dpkg -i kesl-10.1.0-<Versionsnummer>_i386.deb","Um Kaspersky Endpoint Security aus dem Paket im DEB-Format auf einem 64-Bit-Betriebssystem zu installieren, führen Sie den folgenden Befehl aus:","# dpkg -i kesl_10.1.0-<Versionsnummer>_amd64.deb"," Paket von Kaspersky Endpoint Security installieren ","161221.htm");
Page[15]=new Array("Erstkonfiguration der Einstellungen von Kaspersky Endpoint Security","Nach der Installation von Kaspersky Endpoint Security muss das Skript zur Konfiguration nach der Installation von Kaspersky Endpoint Security gestartet werden. Das Skript zur Konfiguration nach der Installation von Kaspersky Endpoint Security ist im Paket von Kaspersky Endpoint Security enthalten.","Wenn Sie die Prozedur der Erstkonfiguration von Kaspersky Endpoint Security nicht ausführen, funktioniert der Antiviren-Schutz des Computers nicht.","Um das Skript zum Update der Einstellungen von Kaspersky Endpoint Security zu starten, führen Sie den folgenden Befehl aus:","# /opt/kaspersky/kesl/bin/kesl-setup.pl","Das Skript zur Anpassung nach der Installation fordert die Einstellungswerte von Kaspersky Endpoint Security schrittweise an.","Das Skript zur Konfiguration nach der Installation muss nach Abschluss der Installation des Pakets von Kaspersky Endpoint Security mit den root-Rechten ausgeführt werden.","Sie können ein Upgrade von Kaspersky Endpoint Security 10 für Linux auf Kaspersky Endpoint Security 10 Service Pack 1 für Linux durchführen. ","Für Kaspersky Anti-Virus 8.0 für Linux File Server kann kein Upgrade auf Kaspersky Endpoint Security 10 Service Pack 1 für Linux durchgeführt werden. Sie müssen die frühere Programmversion deinstallieren, bevor Sie Kaspersky Endpoint Security 10 Service Pack 1 für Linux installieren."," Erstkonfiguration der Einstellungen von Kaspersky Endpoint Security ","161222.htm");
Page[16]=new Array("Schritt 1. Zeichensatz auswählen","In diesem Schritt müssen Sie die Bezeichnung des Gebietsschemas festlegen, das bei der Ausführung von Kaspersky Endpoint Security verwendet werden soll.","Sie können das Gebietsschema im durch RFC 3066 bestimmten Format festlegen.","Um die vollständige Liste der Bezeichnungen der Gebietsschemas zu erhalten, führen Sie den folgenden Befehl aus:","# locale -a","Standardmäßig bietet das Programm an, das Gebietsschema zu verwenden, das für root installiert ist."," Schritt 1. Zeichensatz ausw&#xE4;hlen ","161223.htm");
Page[17]=new Array("Schritt 2. Endbenutzer-Lizenzvertrag akzeptieren","In diesem Schritt müssen Sie die Bedingungen des Endbenutzer-Lizenzvertrags akzeptierten oder ablehnen.","Sie können den Text mithilfe des Tools less anzeigen. Um durch den Text zu navigieren, verwenden Sie die Pfeiltasten oder die Tasten B (um einen Schirm zurück zu blättern) und F (um einen Schirm nach vor zu blättern). Um Hilfe zu erhalten, verwenden Sie die Taste H. Verwenden Sie die Taste Q, um die Lektüre abzuschließen.","Geben Sie nach Beendigung des Anzeigemodus einen der folgenden Werte ein:","yes (oder y), wenn Sie mit den Bedingungen des Endbenutzer-Lizenzvertrags einverstanden sind.no (oder n), wenn Sie mit den Bedingungen des Endbenutzer-Lizenzvertrags nicht einverstanden sind.Wenn Sie mit den Bedingungen des Endbenutzer-Lizenzvertrags nicht einverstanden sind, bricht das Programm den Konfigurationsprozess von Kaspersky Endpoint Security ab."," Schritt 2. Endbenutzer-Lizenzvertrag akzeptieren ","161224.htm");
Page[18]=new Array("Schritt 3. Annahme der Datenschutzrichtlinie","In diesem Schritt müssen Sie die Bedingungen der Datenschutzrichtlinie akzeptieren oder ablehnen.","Sie können den Text mithilfe des Tools less anzeigen. Um durch den Text zu navigieren, verwenden Sie die Pfeiltasten oder die Tasten B (um einen Schirm zurück zu blättern) und F (um einen Schirm nach vor zu blättern). Um Hilfe zu erhalten, verwenden Sie die Taste H. Verwenden Sie die Taste Q, um die Lektüre abzuschließen.","Geben Sie nach Beendigung des Anzeigemodus einen der folgenden Werte ein:","yes (oder y), wenn Sie die Datenschutzrichtlinie akzeptieren.no (oder n), wenn Sie die Datenschutzrichtlinie nicht akzeptieren.Wenn Sie mit der Datenschutzrichtlinie nicht einverstanden sind, bricht das Programm den Konfigurationsprozess von Kaspersky Endpoint Security ab."," Schritt 3. Annahme der Datenschutzrichtlinie ","166206.htm");
Page[19]=new Array("4. Schritt. Text der Erklärung zu Kaspersky Security Network anzeigen","In diesem Schritt müssen Sie die Bedingungen der Erklärung zu Kaspersky Security Network entweder akzeptierten oder ablehnen. Die Datei mit dem Text der Erklärung zu Kaspersky Security Network befindet sich im Verzeichnis opt/kaspersky/kesl/doc/ksn_license.<lang>.","Geben Sie einen der folgenden Werte ein:","yes (oder y), wenn Sie mit den Bedingungen der Erklärung zu Kaspersky Security Network einverstanden sind. Der erweiterte Modus von Kaspersky Security Network wird aktiviert. no (oder n), wenn Sie mit den Bedingungen der Erklärung zu Kaspersky Security Network nicht einverstanden sind.Wenn Sie nicht an Kaspersky Security Network teilnehmen, wird der Installationsprozess für Kaspersky Endpoint Security nicht unterbrochen. Sie können den Modus von Kaspersky Security Network jederzeit aktivieren, deaktivieren oder ändern."," 4. Schritt. Text der Erkl&#xE4;rung zu Kaspersky Security Network anzeigen ","161225.htm");
Page[20]=new Array("5. Schritt. Typ des Abfangmoduls für Dateioperationen festlegen","In diesem Schritt wird der Typ des Abfangmodul für Dateioperationen festgelegt. Für Betriebssysteme, von denen die fanotify-Technologie nicht unterstützt wird, muss die Kompilation des Kernel-Moduls ausgeführt werden. Das Kernel-Modul ist für die Ausführung der Aufgabe zum Echtzeitschutz erforderlich.","Für die Kompilation des Kernel-Moduls muss die Datei System.map-<Kernel-Version> im Verzeichnis/boot vorhanden sein.","Wenn das Skript den Quellcode für den Kernel des Betriebssystemmoduls im Standardverzeichnis findet, verwendet das Programm den Pfad zu diesem Verzeichnis. Andernfalls müssen Sie den Pfad zum Quellcode des Modulkernels angeben.","Wenn die notwendigen Pakete im Laufe der Kompilation des Modulkernels nicht gefunden werden, versucht Kaspersky Endpoint Security, sie selbstständig herunterzuladen. Wenn das Herunterladen der Pakete fehlschlägt, wird eine Fehlermeldung ausgegeben.","Sie können die Kompilation des Kernel-Moduls später, nach Abschluss der Erstkonfiguration von Kaspersky Endpoint Security ausführen."," 5. Schritt. Typ des Abfangmoduls f&#xFC;r Dateioperationen festlegen ","161226.htm");
Page[21]=new Array("6. Schritt. Antiviren-Datenbanken von Kaspersky Endpoint Security herunterladen","In diesem Schritt können Sie die Antiviren-Datenbanken von Kaspersky Endpoint Security auf den Computer herunterladen. Die Antiviren-Datenbanken enthalten Beschreibungen der Signaturen von Bedrohungen und der Methoden zu ihrer Bekämpfung. Kaspersky Endpoint Security verwendet diese Einträge bei der Suche und der Desinfektion von Bedrohungen. Die Virenanalysten von Kaspersky Lab fügen regelmäßig Einträge über neue Bedrohungen hinzu.","Um die Antiviren-Datenbanken Kaspersky Endpoint Security auf den Computer herunterzuladen, müssen Sie die Antwort yes eingeben.","Geben Sie no ein, wenn Sie auf das sofortige Herunterladen der Antiviren-Datenbanken verzichten möchten.","Standardmäßig wird die Antwort yes vorgeschlagen.","Das Programm gewährleistet den Antiviren-Schutz des Computers nur nach dem Download der Antiviren-Datenbanken von Kaspersky Endpoint Security.","Sie können die Update-Aufgabe starten, ohne das Skript für die Erstkonfiguration zu verwenden."," 6. Schritt. Antiviren-Datenbanken von Kaspersky Endpoint Security herunterladen ","161228.htm");
Page[22]=new Array("Schritt 7. Proxyserver-Einstellungen","In diesem Schritt müssen Sie die Einstellungen des Proxyservers angeben, den Sie für den Internetzugang verwenden. Zum Herunterladen der Antiviren-Datenbanken für Kaspersky Endpoint Security von den Update-Servern ist eine Internetverbindung erforderlich.","Führen Sie eine folgenden Aktionen aus, um die Einstellungen des Proxyservers anzupassen:","Wenn Sie für die Internetverbindung einen Proxyserver verwenden, geben Sie die Adresse des Proxy-Servers in einem der folgenden Formate an:IP_Adresse_des_Proxyservers:Port, falls bei der Verbindung mit dem Proxyserver keine Authentifizierung erforderlich ist.Benutzername:Kennwort@IP_Adresse_des_Proxyservers:Port, falls bei der Verbindung mit dem Proxyserver eine Authentifizierung erforderlich ist.Wenn Sie für die Internetverbindung keinen Proxyserver verwenden, geben Sie die Antwort no ein.","Standardmäßig bietet das Programm die Antwort no an.","Sie können die Einstellungen für den Proxyserver auch konfigurieren, ohne das Skript für die Erstkonfiguration zu verwenden."," Schritt 7. Proxyserver-Einstellungen ","161227.htm");
Page[23]=new Array("8. Schritt. Automatisches Update der Antiviren-Datenbanken aktivieren","In diesem Schritt können Sie das automatische Update der Antiviren-Datenbanken aktivieren.","Geben Sie yes ein, um das automatische Update der Antiviren-Datenbanken zu aktivieren. Standardmäßig überprüft Kaspersky Endpoint Security alle 60 Minuten nach verfügbaren Antiviren-Datenbanken. Wenn Updates zur Verfügung stehen, lädt Kaspersky Endpoint Security die aktualisierten Antiviren-Datenbanken herunter.","Geben Sie die Antwort no ein, wenn Sie nicht möchten, dass Kaspersky Endpoint Security die Antiviren-Datenbanken automatisch aktualisiert.","Die können die automatischen Updates der Antiviren-Datenbanken ohne Verwendung des Erstkonfigurationsskripts aktivieren, indem Sie den Zeitplan der Update-Aufgabe verwalten."," 8. Schritt. Automatisches Update der Antiviren-Datenbanken aktivieren ","161229.htm");
Page[24]=new Array("9. Schritt. Programm aktivieren","In diesem Schritt müssen Sie das Programm mithilfe eines Aktivierungscodes oder einer Schlüsseldatei aktivieren.","Um das Programm mithilfe eines Aktivierungscodes zu aktivieren, müssen Sie den Aktivierungscode eingeben.","Um das Programm mithilfe einer Schlüsseldatei zu aktivieren, müssen Sie den vollständigen Pfad zur Schlüsseldatei oder den Pfad zum Verzeichnis angeben, das die Schlüsseldatei enthält.","Wenn kein Aktivierungscode bzw. keine Schlüsseldatei angegeben sind, wird das Programm mithilfe eines Testschlüssels für einen Monat aktiviert.","Sie können die Schlüsseldatei auch installieren, ohne das Skript für die Erstkonfiguration zu verwenden."," 9. Schritt. Programm aktivieren ","161230.htm");
Page[25]=new Array("Schritt 10. Grafische Benutzeroberfläche konfigurieren","In diesem Schritt können Sie die Nutzung der grafischen Benutzeroberfläche (GUI) aktivieren.","Sie können den Text mithilfe des Tools less einsehen. Verwenden Sie für die Navigation im Text die Pfeiltasten oder die Tasten B (um eine Seite auf dem Bildschirm zurückzugehen) bzw. F (um eine Seite auf dem Bildschirm vorwärts zu gehen). Um Hilfe zu erhalten, drücken Sie auf die Taste H. Um die Anzeige zu beenden, verwenden Sie die Taste Q.","yes (oder y), wenn Sie die Nutzung der grafischen Benutzeroberfläche aktivieren möchten. Kaspersky Endpoint Security überprüft alle erforderlichen Bibliotheken und versucht erforderlichenfalls, die fehlenden zu installieren.no (oder n), wenn Sie die Nutzung der grafischen Benutzeroberfläche nicht aktivieren möchten.Sie können die Nutzung der grafischen Benutzeroberfläche jederzeit aktivieren oder deaktivieren."," Schritt 10. Grafische Benutzeroberfl&#xE4;che konfigurieren ","161231.htm");
Page[26]=new Array("Automatischer Modus zur Erstkonfiguration von Kaspersky Endpoint Security","Sie können die Erstkonfiguration von Kaspersky Endpoint Security im automatischen Modus ausführen. Das Programm legt die Einstellungen anhand der in der Konfigurationsdatei für die Erstkonfiguration angegebenen Werte fest.","Um die Erstkonfiguration von Kaspersky Endpoint Security im automatischen Modus zu starten, führen Sie den folgenden Befehl aus:","kesl-setup.pl --autoinstall=<vollständiger Pfad der Erstkonfigurationsdatei>"," Automatischer Modus zur Erstkonfiguration von Kaspersky Endpoint Security ","161232.htm");
Page[27]=new Array("Einstellungen der Konfigurationsdatei für die Erstkonfiguration von Kaspersky Endpoint Security","Die Konfigurationsdatei für die Erstkonfiguration von Kaspersky Endpoint Security enthält die in der nachfolgenden Tabelle angeführten Einstellungen.","Einstellungen der Konfigurationsdatei für die Erstkonfiguration von Kaspersky Endpoint Security","Einstellung","Beschreibung","Mögliche Werte:","EULA_AGREED","Erforderliche Einstellung","Einverständnis mit den Bedingungen des Endbenutzer-Lizenzvertrags","yes – Sie müssen die Bedingungen des Endbenutzer-Lizenzvertrags akzeptieren, damit Sie mit dem Programminstallationsprozess fortfahren können.","no – Endbenutzer-Lizenzvertrag nicht akzeptieren. Die Installation des Programms wird unterbrochen.","PRIVACY_POLICY_AGREED","Erforderliche Einstellung","Akzeptieren der Datenschutzrichtlinie","yes – Sie müssen die Datenschutzrichtlinie akzeptieren, um mit der Programminstallation fortfahren zu können.","No – Datenschutzrichtlinie nicht akzeptieren. Die Installation des Programms wird unterbrochen.","USE_KSN","Einverständnis mit der Erklärung zu Kaspersky Security Network","yes – Erklärung zu Kaspersky Security Network akzeptieren","no – Erklärung zu Kaspersky Security Network nicht akzeptieren","SERVICE_LOCALE","Optionale Einstellung","Gebietsschema, das während der Ausführung von Kaspersky Endpoint Security verwendet wird.","Das Gebietsschema wird im Format mittels RFC 3066 angegeben.","Wenn keine SERVICE_LOCALE-Einstellung angegeben ist, wird das Standard-Gebietsschema festgelegt.","INSTALL_LICENSE","Aktivierungscode oder Schlüsseldatei","—","UPDATER_SOURCE","Updatequelle","SCServer ­ Administrationsserver von Kaspersky Security Center als Update-Quelle verwendenKLServers – die Kaspersky-Lab-Updateserver als Updatequelle verwendenAdresse der Updatequelle","PROXY_SERVER","Adresse des Proxyservers, der für die Internetverbindung verwendet wird","Adresse des Proxyserversno – keinen Proxyserver verwenden","UPDATE_EXECUTE","Aufgabe zum Datenbanken-Update während der Einrichtung starten","yes – Update-Aufgabe startenno – Update-Aufgabe nicht starten","KERNEL_SRCS_INSTALL","Automatischer Start der Kompilierung des Kernelmoduls","yes – Kernelmodul kompilierenno – Kernel-Modul nicht kompilieren","USE_GUI","Nutzung der grafischen Benutzeroberfläche aktivieren","yes –Nutzung der grafischen Benutzeroberfläche aktivierenno –Nutzung der grafischen Benutzeroberfläche deaktivieren","IMPORT_SETTINGS","Programmeinstellungen aus einer Konfigurationsdatei verwenden ","yes – Programmeinstellungen aus einer Konfigurationsdatei verwendenno – Keine Programmeinstellungen aus einer Konfigurationsdatei verwenden","Wenn Sie die Einstellungen in der Konfigurationsdatei für die Erstkonfiguration von Kaspersky Endpoint Security ändern möchten, geben Sie die Werte für die Einstellungen im Format Namen der Einstellung=Einstellungswert ein (das Programm verarbeitet keine Leerzeichen zwischen dem Namen der Einstellung und ihrem Wert)."," Einstellungen der Konfigurationsdatei f&#xFC;r die Erstkonfiguration von Kaspersky Endpoint Security ","161233.htm");
Page[28]=new Array("Kaspersky Endpoint Security über Kaspersky Security Center installieren","Sie können Kaspersky Endpoint Security mithilfe von Kaspersky Security Center auf den Computer installieren.","Details über diesen Installationstyp des Programms finden Sie in der Dokumentation für Kaspersky Security Center"," Kaspersky Endpoint Security &#xFC;ber Kaspersky Security Center installieren ","161234.htm");
Page[29]=new Array("Administrationsagent installieren","Falls Sie Kaspersky Endpoint Security über Kaspersky Security Center verwalten wollen, müssen Sie den Administrationsagenten installieren.","Um den Administrationsagenten zu installieren, müssen Sie über root-Benutzerrechte verfügen.","Um den Administrationsagenten aus einem RPM-Paket auf einem 32-Bit-Betriebssystem zu installieren, führen Sie den folgenden Befehl aus:","# rpm -i klnagent-<Versionsnummer>.i386.rpm","Um den Administrationsagenten aus einem RPM-Paket auf einem 64-Bit-Betriebssystem zu installieren, führen Sie den folgenden Befehl aus:","# rpm -i klnagent64-<Versionsnummer>.x86_64.rpm","Um den Administrationsagenten aus einem DEB-Paket auf einem 32-Bit-Betriebssystem zu installieren, führen Sie den folgenden Befehl aus:","# dpkg -i klnagent_<Versionsnummer>_i386.deb","Um den Administrationsagenten aus einem DEB-Paket auf einem 64-Bit-Betriebssystem zu installieren, führen Sie den folgenden Befehl aus:","# dpkg -i klnagent64_<Versionsnummer>_amd64.deb","Starten Sie nach der Installation des Paktes das Skript zum Update der Einstellungen von Kaspersky Endpoint Security, indem Sie den folgenden Befehl ausführen:","für ein 32-Bit-Betriebssystem:/opt/kaspersky/klnagent/lib/bin/setup/postinstall.pl","für ein 64-Bit-Betriebssystem:/opt/kaspersky/klnagent64/lib/bin/setup/postinstall.pl"," Administrationsagent installieren ","161235.htm");
Page[30]=new Array("Erstkonfiguration der Einstellungen des Administrationsagenten","Wenn Sie Kaspersky Endpoint Security mithilfe von Kaspersky Security Center verwalten wollen, müssen Sie die Einstellungen des Administrationsagenten konfigurieren.","Gehen Sie folgendermaßen vor, um die Einstellungen des Administrationsagenten anzupassen:","Führen Sie den folgenden Befehl aus:für ein 32-Bit-Betriebssystem:# /opt/kaspersky/klnagent/lib/bin/setup/postinstall.pl","für ein 64-Bit-Betriebssystem:# /opt/kaspersky/klnagent64/lib/bin/setup/postinstall.pl","Geben Sie den DNS-Namen oder die IP-Adresse des Administrationsserver an.Geben Sie die Portnummer des Administrationsservers an.standardmäßig wird Port 14000 verwendet.","Wenn Sie eine SSL-Verbindung verwenden möchten, geben Sie die Nummer des SSL-Ports des Administrationsservers an.standardmäßig wird Port 13000 verwendet.","Führen Sie eine der folgenden Aktionen aus:Geben Sie yes ein, wenn Sie die SSL-Verbindung verwenden wollen.Geben Sie no ein, wenn Sie die SSL-Verbindung nicht verwenden wollen.Standardmäßig ist die SSL-Verbindung aktiviert.","Geben Sie erforderlichenfalls den Modus des Verbindungs-Gateways an:0 – Kein Verbindungs-Gateway verwenden.1 – Diesen Administrationsagenten als Verbindungs-Gateway verwenden.2 – Über das Verbindungs-Gateway zum Administrationsserver verbinden.Nähere Informationen zur Konfiguration des Administrationsagenten finden Sie in der Dokumentation für Kaspersky Security Center."," Erstkonfiguration der Einstellungen des Administrationsagenten ","161236.htm");
Page[31]=new Array("Upgrade einer alten Programmversion","Sie können ein Upgrade von Kaspersky Endpoint Security 10 für Linux auf Kaspersky Endpoint Security 10 Service Pack 1 für Linux durchführen. ","Sie können das Upgrade einer alten Programmversion wie folgt durchführen:","Lokal—Aus der BefehlszeileFerngesteuert—Mithilfe der Kaspersky Security Center Software Suite (siehe Dokumentation für Kaspersky Security Center)Wenn Sie ein Upgrade von einer früheren Version des Programms auf Kaspersky Endpoint Security 10 Service Pack 1 für Linux durchführen, müssen Sie die vorherige Version des Programms nicht entfernen. Es wird empfohlen, vor dem Upgrade einer früheren Programmversion alle aktiven Programme zu beenden."," Upgrade einer alten Programmversion ","161237.htm");
Page[32]=new Array("Upgrade des Programms aus der Befehlszeile","Sie können ein Upgrade von Kaspersky Endpoint Security 10 für Linux auf Kaspersky Endpoint Security 10 Service Pack 1 für Linux lokal durchführen, indem Sie den nachfolgenden Vorgang ausführen.","Nach Abschluss des Upgrade-Vorgangs kann ein Neustart des Betriebssystems oder des Programms erforderlich sein.","Um ein Upgrade des Programms durchzuführen, gehen Sie wie folgt vor:","Führen Sie die Installation des gewünschten Pakets für Kaspersky Endpoint Security 10 Service Pack 1 für Linux durch.Kaspersky Endpoint Security 10 für Linux wird gestoppt und die Programmeinstellungen und das Ereignisprotokoll werden exportiert.","Führen Sie das Skript zur Konfiguration nach der Installation aus.Das Skript zur Anpassung nach der Installation fordert die Einstellungswerte von Kaspersky Endpoint Security schrittweise an.","Der Endbenutzer-Lizenzvertrag (EULA) und die Datenschutzrichtlinie müssen akzeptiert werden.","Die Programmeinstellungen und das Ereignisprotokoll werden in die upgegradete Programmversion übertragen; neue Einstellungen werden auf die Standardwerte gesetzt. Nach Übertragung der Programmeinstellungen wird das Programm beendet.","Starten Sie das Betriebssystem oder das Programm erforderlichenfalls neu.Wenn während des Programm-Upgrades ein Fehler auftritt, kann das Programm nicht automatisch auf die vorherige Version wiederhergestellt werden. Eine Fehlermeldung wird angezeigt.","Wenn die Übertragung der Programmeinstellungen aus irgendeinem Grund fehlschlägt, wird das Programm auf die Standardwerte gesetzt."," Upgrade des Programms aus der Befehlszeile ","165607.htm");
Page[33]=new Array("Upgrade des Programms mithilfe von Kaspersky Security Center","Sie können ein Remote-Upgrade von Kaspersky Endpoint Security 10 für Linux auf Kaspersky Endpoint Security 10 Service Pack 1 für Linux mithilfe von Kaspersky Security Center durchführen, indem Sie den nachfolgenden Vorgang durchführen.","Um ein Upgrade für ein Programm durchzuführen, das von der Richtlinie für Kaspersky Security Center verwaltet wird, gehen Sie wie folgt vor:","Upgrade des AdministrationsagentenWenn kein Upgrade des Administrationsagenten durchgeführt wird, kann das Programm nicht über Kaspersky Security Center verwaltet werden.","Während des Upgrades des Administrationsagenten funktioniert das Programm ordnungsgemäß.","Führen Sie eine Remote-Installation von Kaspersky Endpoint Security 10 Service Pack 1 für Linux aus.Details über diesen Upgrade-Typ des Programms finden Sie im Administratorhandbuch für Kaspersky Security Center."," Upgrade des Programms mithilfe von Kaspersky Security Center ","165608.htm");
Page[34]=new Array("Konfiguration der Berechtigungen im SELinux-System","Um das Modul SELinux mit den für die Ausführung von Kaspersky Endpoint Security erforderlichen Regeln zu erstellen, gehen Sie wie folgt vor:","Setzen Sie SELinux in den Erlaubnismodus:Wenn SELinux aktiviert wurde, führen Sie den folgenden Befehl aus:# setenforce Permissive","Falls SELinux deaktiviert wurde, geben Sie in der Konfigurationsdatei /etc/selinux/config den Einstellungswert SELINUX=permissive an und starten Sie das Betriebssystem neu.Führen Sie den folgenden Aufgaben aus:Aufgabe zum Echtzeitschutz:kesl-control --start-t 1","Aufgabe zur Untersuchung des Prozessarbeitsspeichers:kesl-control --start-t 4 -W","Aufgabe zur Untersuchung des Bootsektors:kesl-control --start-t 5 -W","Erstellen Sie auf Basis von Sperreinträgen ein Regelmodul:grep kesl /var/log/audit/audit.log | audit2allow -M kesl","Vergewissern Sie sich, dass die erstellte Liste nur Regeln enthält, die zur Kaspersky Endpoint Security gehören.","Laden Sie das neue Regelmodul:# semodule -i kesl.pp","Schalten Sie SELinux in den Enforcing-Modus um:# setenforce Enforcing","Wenn neue Audit-Meldungen erscheinen, die sich auf Kaspersky Endpoint Security beziehen, muss die Datei des Regelmoduls aktualisiert werden.","Weitere Informationen finden Sie in der Dokumentation des jeweiligen Betriebssystems."," Konfiguration der Berechtigungen im SELinux-System ","161238.htm");
Page[35]=new Array("Konfiguration der Berechtigungen im AppArmor-System","Um die für die Ausführung von Kaspersky Endpoint Security benötigten AppArmor-Profile zu aktualisieren, gehen Sie wie folgt vor:","Vergewissern Sie sich, dass das AppArmor-Modul geladen ist und verwenden Sie dazu eine der folgenden Methoden:systemctl status apparmor/etc/init.d/apparmor statusErstellen Sie ein Profil für Kaspersky Endpoint Security:Führen Sie in der ersten Konsole die folgenden Befehle aus:cd /etc/apparmor.d","aa-genprof /opt/kaspersky/kesl/libexec/kesl","Führen Sie in der zweiten Konsole die folgenden Aufgaben aus:Aufgabe zum Echtzeitschutz:kesl-control --start-t 1","Aufgabe zur Untersuchung des Prozessarbeitsspeichers:kesl-control --start-t 4 -W","Aufgabe zur Untersuchung des Bootsektors:kesl-control --start-t 5 -W","Update-Aufgabe:kesl-control --start-t 6 -W","Drücken Sie in der ersten Konsole auf S. Nach Abschluss der Ereignisuntersuchung drücken Sie auf F.Schalten Sie das erstellte Profil für Kaspersky Endpoint Security in den Nachrichtenanzeigemodus:aa-complain opt.kaspersky.kesl.libexec.kesl","Nachdem das Programm einige Tage gelaufen ist, aktualisieren Sie das Profil, indem Sie den folgenden Befehl ausführen:# aa-logprof","Geben Sie die Berechtigungen Allow oder Glob für alle Dateien an, die Kaspersky Endpoint Security während dieser Zeitspanne verwendet hat.","Schalten Sie das Profil für Kaspersky Endpoint Security in den Blockiermodus:aa-enforce opt.kaspersky.kesl.libexec.kesl","Wenn neue Audit-Meldungen erscheinen, die sich auf Kaspersky Endpoint Security beziehen, muss die Datei des Regelmoduls aktualisiert werden.","Weitere Informationen finden Sie in der Dokumentation des jeweiligen Betriebssystems."," Konfiguration der Berechtigungen im AppArmor-System ","161239.htm");
Page[36]=new Array("Programm löschen","Dieser Abschnitt enthält Anweisungen, wie Kaspersky Endpoint Security lokal oder über Kaspersky Security Center gelöscht wird.","In diesem AbschnittKaspersky Endpoint Security lokal löschenKaspersky Endpoint Security über Kaspersky Security Center löschen"," Programm l&#xF6;schen ","161240.htm");
Page[37]=new Array("Kaspersky Endpoint Security lokal löschen","Während das Programms entfernt wird, werden alle Aufgaben von Kaspersky Endpoint Security angehalten.","Um Kaspersky Endpoint Security zu deinstallieren, wenn das Programm aus einem RPM-Paket installiert wurde, führen Sie den folgenden Befehl aus:","# rpm -e kesl","Um Kaspersky Endpoint Security zu deinstallieren, wenn das Programm aus einem DEB-Paket installiert wurde, führen Sie den folgenden Befehl aus:","# dpkg -r kesl","Um den Administrationsagenten zu löschen, wenn er aus einem RPN-Paket installiert wurde, führen Sie den folgenden Befehl aus:","# rpm -e klnagent","Um den Administrationsagenten zu löschen, wenn er aus einem DEB-Paket installiert wurde, führen Sie den folgenden Befehl aus:","# dpkg -r klnagent","Das Programm führt den Löschvorgang automatisch aus. Nach dem Abschluss gibt das Programm eine Nachricht über die Ergebnissen des Löschens aus.","Nach dem Entfernen von Kaspersky Endpoint Security bleibt die Lizenzdatenbank bestehen und kann bei der erneuten Installation des Programms verwendet werden."," Kaspersky Endpoint Security lokal l&#xF6;schen ","161241.htm");
Page[38]=new Array("Kaspersky Endpoint Security über Kaspersky Security Center löschen","Sie können Kaspersky Endpoint Security über Kaspersky Security Center löschen. Dazu müssen Sie die Aufgabe zum Löschen von Kaspersky Endpoint Security erstellen und starten.","Ausführliche Informationen zum Erstellen und Starten der Aufgabe zum Löschen von Kaspersky Endpoint Security finden Sie in der Dokumentation für Kaspersky Security Center."," Kaspersky Endpoint Security &#xFC;ber Kaspersky Security Center l&#xF6;schen ","161242.htm");
Page[39]=new Array("Lizenzierung des Programms","In diesem Abschnitt werden die wichtigsten Aspekte der Lizenzverwaltung des Programms behandelt.","In diesem AbschnittÜber den Endbenutzer-LizenzvertragÜber die LizenzÜber das LizenzzertifikatÜber den AktivierungscodeÜber SchlüsselÜber die SchlüsseldateiÜber das AbonnementÜber die Zurverfügungstellung von Daten"," Lizenzierung des Programms ","161243.htm");
Page[40]=new Array("Über den Endbenutzer-Lizenzvertrag","Der Endbenutzer-Lizenzvertrag ist ein rechtsgültiger Vertrag zwischen Ihnen und AO Kaspersky Lab. Er legt die Nutzungsbedingungen für das Programm fest.","Lesen Sie den Lizenzvertrag sorgfältig durch, bevor Sie beginnen, mit dem Programm zu arbeiten.","Die Lizenzbedingungen können Sie wie folgt einsehen:","Während der Installation von Kaspersky Endpoint Security.In der Datei license.<language ID>. Das Dokument gehört zum Lieferumfang des Programms.Wenn Sie bei der Programminstallation den Lizenzbedingungen zustimmen, gilt Ihr Einverständnis mit den Lizenzbedingungen als erteilt. Falls Sie dem Lizenzvertrag nicht zustimmen, müssen Sie die Programminstallation abbrechen oder das Programm nicht mehr verwenden."," &#xDC;ber den Endbenutzer-Lizenzvertrag ","161244.htm");
Page[41]=new Array("Über die Lizenz","Eine Lizenz begründet ein zeitlich begrenztes Nutzungsrecht für ein Programm, das Ihnen auf Basis eines Endbenutzer-Lizenzvertrags überlassen wird.","Eine aktive Lizenz berechtigt zur Nutzung folgender Dienstleistungen:","Nutzung des Programms gemäß den Bestimmungen des Lizenzvertrages;Erhalt von technischem SupportDer Umfang der verfügbaren Leistungen und die Nutzungsdauer für das Programm sind vom Typ der Lizenz abhängig, mit der das Programm aktiviert wurde.","Es sind folgende Lizenztypen vorgesehen:","Test – Kostenlose Lizenz zum Kennenlernen des Programms.Eine Probelizenz hat in der Regel nur eine sehr kurze Gültigkeitsdauer. Nach Ablauf der Gültigkeitsdauer der Testlizenz stellt Kaspersky Endpoint Security alle Funktionen ein. Um das Programm weiter nutzen zu können, müssen Sie eine kommerzielle Lizenz erwerben.","Die Aktivierung des Programms mithilfe einer Probelizenz kann nur einmal erfolgen.","Kommerziell – Kostenpflichtige Lizenz, die beim Erwerb des Programms zur Verfügung gestellt wird.Nach Ablauf der kommerziellen Lizenz funktioniert das Programm weiterhin, wobei aber der Funktionsumfang eingeschränkt wird (dann ist, beispielsweise, das Datenbanken-Update von Kaspersky Endpoint Security nicht mehr verfügbar). Zur weiteren Nutzung von Kaspersky Endpoint Security mit allen Funktionen ist eine Verlängerung der kommerziellen Lizenz erforderlich.","Es wird empfohlen, die Gültigkeitsdauer einer Lizenz spätestens zum Ablaufdatum der aktiven Lizenz zu verlängern, um einen optimalen Schutz zu gewährleisten."," &#xDC;ber die Lizenz ","161245.htm");
Page[42]=new Array("Über das Lizenzzertifikat","Ein Lizenzzertifikat ist ein Dokument, das Sie zusammen mit der Schlüsseldatei oder dem Aktivierungscode erhalten.","Das Lizenzzertifikat enthält folgende Informationen über die bereitgestellte Lizenz:","BestellnummerInformationen zum Benutzer, der die Lizenz erhältInformationen zum Programm, welches über die bereitgestellte Lizenz aktiviert werden kannBeschränkung der Anzahl der Einheiten der Lizenzverwaltung (beispielsweise, Geräte, auf denen das Programm mit der bereitgestellten Lizenz genutzt werden darf)Beginn der Gültigkeitsdauer der LizenzAblaufdatum der Lizenzgültigkeit oder Gültigkeitsdauer der LizenzLizenztyp"," &#xDC;ber das Lizenzzertifikat ","161246.htm");
Page[43]=new Array("Über den Aktivierungscode","Der Aktivierungscode ist eine eindeutige Zeichenfolge aus zwanzig Buchstaben und Ziffern. Den Aktivierungscode geben Sie ein, um einen Schlüssel zur Aktivierung von Kaspersky Endpoint Security hinzuzufügen. Der Aktivierungscode wird an die E-Mail-Adresse geschickt, die Sie angegeben haben, nachdem Sie Kaspersky Endpoint Security gekauft oder eine Testversion von Kaspersky Endpoint Security angefordert haben.","Um das Programm mithilfe des Aktivierungscodes zu aktivieren, ist ein Zugriff auf das Internet für die Verbindung mit den Kaspersky Lab-Aktivierungsservern erforderlich.","Wenn der Aktivierungscode nach der Aktivierung des Programms verloren geht, können Sie den Aktivierungscode wiederherstellen. Der Aktivierungscode kann beispielsweise für die Registrierung in Kaspersky CompanyAccount erforderlich sein. Um den Aktivierungscode wiederherzustellen, müssen Sie sich an den Technischen Support von Kaspersky Lab wenden."," &#xDC;ber den Aktivierungscode ","161247.htm");
Page[44]=new Array("Über Schlüssel","Ein Schlüssel ist eine Abfolge von Bits, mit deren Hilfe Sie das Programm aktivieren und anschließend gemäß den Bedingungen des Endbenutzer-Lizenzvertrags verwenden können. Ein Schlüssel wird von Kaspersky Lab erzeugt.","Sie können auf eine der folgenden Arten einen Schlüssel zum Programm hinzufügen: eine Schlüsseldatei übernehmen oder einen Aktivierungscode eingeben. Nachdem Sie den Schlüssel im Programm hinzugefügt haben, wird er auf der Programmoberfläche als eindeutige Folge aus Buchstaben und Ziffern angezeigt.","Kaspersky Lab kann einen Schlüssel aufgrund von Verletzungen des Endbenutzer-Lizenzvertrags auf die schwarze Liste setzen. Wenn ein Schlüssel auf die schwarze Liste gesetzt wurde, müssen Sie einen anderen Schlüssel hinzufügen, wenn Sie das Programm weiter verwenden möchten.","Es gibt zwei Arten von Schlüsseln: aktive und Reserveschlüssel.","Ein aktiver Schlüssel ist der Schlüssel, der momentan für Programmausführung verwendet wird. Ein aktiver Schlüssel kann sowohl ein Schlüssel für eine Testlizenz als auch für eine kommerzielle Lizenz sein. Im Programm kann es immer nur einen aktiven Schlüssel geben.","Ein Reserveschlüssel ist ein Schlüssel, der das Recht auf Nutzung des Programms bestätigt, jedoch im Augenblick nicht aktiviert ist. Ein Reserveschlüssel wird automatisch zu einem aktiven Schlüssel, sobald die mit dem aktuellen Schlüssel verbundene Lizenz abläuft. Ein Reserveschlüssel kann nur hinzugefügt werden, wenn bereits ein aktiver Schlüssel vorhanden ist.","Der Schlüssel einer Testlizenz kann nur als aktiver Schlüssel hinzugefügt werden. Der Schlüssel einer Testlizenz kann nicht als Reserveschlüssel hinzugefügt werden."," &#xDC;ber Schl&#xFC;ssel ","161248.htm");
Page[45]=new Array("Über die Schlüsseldatei","Bei der Schlüsseldatei handelt es sich um eine Datei mit der Erweiterung key, die Ihnen von Kaspersky Lab zur Verfügung gestellt wird. Schlüsseldateien dienen zum Aktivieren des Programms durch Hinzufügen eines Schlüssels.","Die Schlüsseldatei wird an die E-Mail-Adresse geschickt, die Sie angegeben haben, als Sie Kaspersky Endpoint Security gekauft oder eine Testversion von Kaspersky Endpoint Security angefordert haben.","Um das Programm mithilfe der Schlüsseldatei zu aktivieren, ist keine Verbindung mit den Kaspersky Lab-Aktivierungsservern erforderlich.","Wenn die Schlüsseldatei versehentlich verlegt wurde, können Sie sie wiederherstellen. Eine Schlüsseldatei kann beispielsweise für die Registrierung in Kaspersky CompanyAccount erforderlich sein.","Für die Wiederherstellung der Schlüsseldatei führen Sie eine der folgenden Aktionen aus:","Technischen Support kontaktieren (http://support.kaspersky.com/de).Schlüsseldatei mithilfe Ihres verfügbaren Aktivierungscodes über die Website von Kaspersky Lab () abrufen."," &#xDC;ber die Schl&#xFC;sseldatei ","161249.htm");
Page[46]=new Array("Über das Abonnement","Ein Abonnement für Kaspersky Endpoint Security ist ein Kaufauftrag für das Programm mit bestimmten Parametern (Ablaufdatum des Abonnements, Anzahl der geschützten Geräte). Sie können ein Abonnement für Kaspersky Endpoint Security über Ihren Dienstanbieter (wie beispielsweise Ihren Internetprovider) bestellen. Ein Abonnement kann manuell oder automatisch verlängert werden, oder Sie können Ihr Abonnement kündigen. Sie können Ihr Abonnement auf der Website des Dienstanbieters verwalten.","Ein Abonnement kann beschränkt (beispielsweise auf ein Jahr) oder unbefristet (ohne Ablaufdatum) sein. Damit Kaspersky Endpoint Security nach Ablauf des beschränkten Abonnements weiter funktioniert, müssen Sie Ihr Abonnement verlängern. Ein unbefristetes Abonnement wird automatisch verlängert, wenn die Gebühren des Händlers rechtzeitig bezahlt wurden.","Nach Ablauf eines befristeten Abonnements wird möglicherweise eine Nachfrist zur Abonnement-Verlängerung gewährt, während der die Funktionalität des Programms erhalten bleibt. Ob es eine Nachfrist gibt und wie lang diese ist, wird vom Dienstanbieter bestimmt.","Um Kaspersky Endpoint Security im Abonnement zu nutzen, muss der Aktivierungscode übernommen werden, den Sie von Ihrem Dienstanbieter erhalten. Nach Übernahme des Aktivierungscodes wird der aktive Schlüssel installiert. Der aktive Schlüssel bestimmt die Lizenz für die Nutzung des Programms im Abonnement. Ein Reserveschlüssel kann nur mithilfe eines Aktivierungscodes installiert werden. Eine Installation mithilfe einer Schlüsseldatei oder im Abonnement ist nicht möglich.","Die im Abonnement verfügbare Programmfunktionalität kann der Programmfunktionalität für die folgenden Arten einer kommerziellen Lizenz entsprechen: Standard, Kaspersky Business Space Security, Kaspersky Enterprise Space Security. Lizenzen dieser Art dienen dem Schutz von Dateiservern, Workstations und mobilen Geräten und unterstützen die Nutzung von Steuerungskomponenten auf Workstations und mobilen Geräten.","Die Optionen für die Abonnementsverwaltung können je nach Dienstanbieter unterschiedlich sein. Der Dienstanbieter stellt möglicherweise keine Nachfrist für die Verlängerung des Abonnements zur Verfügung, innerhalb der die Funktionen des Programms erhalten bleiben.","Die für ein Abonnement erhaltenen Aktivierungscodes können nicht zum Aktivieren vorheriger Versionen von Kaspersky Endpoint Security verwendet werden."," &#xDC;ber das Abonnement ","161250.htm");
Page[47]=new Array("Über die Zurverfügungstellung von Daten","Indem Sie den Endbenutzer-Lizenzvertrag annehmen, stimmen Sie zu, automatisch Informationen zu Ihrer Nutzung des Produkts, zu dem Typ, der Version und der Lokalisierung des installierten Programms, zu der eindeutigen ID des Installationsprogramms und dem Installationstyp, sowie Daten zu aktiven Schlüsseln und Reserveschlüsseln zu übermitteln (einschließlich Lizenztyp, Gültigkeitszeitraum, Datum der Programmaktivierung, Ablaufdatum der Lizenz, Nummer der Lizenz, aktueller Lizenzstatus, Version des Protokolls für die Interaktion mit dem Aktivierungsserver).","Durch die Annahme der Bedingungen der Erklärung zu Kaspersky Security Network, stimmen Sie ferner zu, die folgenden Informationen im automatischen Modus zu übermitteln:","ID und Version der Erklärung zu Kaspersky Security Network, die Sie angenommen oder abgelehnt habenInformationen über die Annahme oder Ablehnung der Erklärung zu Kaspersky Security NetworkDatum und Uhrzeit, zu der Sie die Erklärung zu Kaspersky Security Network angenommen oder abgelehnt habenInformationen über die Auswahl „Kaspersky Security Network ohne Statistiken“Informationen über die Auswahl „Kaspersky Security Network mit Statistiken“Eindeutige IDs des Computers und Benutzers, vollständige Programmversion und ProgrammtypFalls das Programm mit einem Aktivierungscode aktiviert wurde, stimmen Sie zu, automatisch die Version des verwendeten Programms (einschließlich Informationen zu installierten Programm-Updates, Installations-ID und Lizenzinformationen), die Version des Betriebssystems und die IDs der Programmkomponenten, die während der Informationsabfrage aktiv waren, zur Verfügung zu stellen, um statistische Daten zur Distribution und zur Verwendung der Produkte des Lizenzinhabers abzurufen.","Kaspersky Lab schützt alle auf diese Weise empfangenen Daten gemäß gesetzlichen Vorschriften und den geltenden Regeln von Kaspersky Lab.","Kaspersky Lab nutzt die erhaltenen Informationen in anonymer Form und ausschließlich als allgemeine Statistik. Die aggregierte Statistik wird automatisch aus den erhaltenen Quellinformationen erstellt und enthält keine persönlichen oder vertraulichen Daten. Die gesammelten Quellinformationen werden regelmäßig gelöscht (ein Mal jährlich). Die Daten der aggregierten Statistik werden unbegrenzt gespeichert.","Ausführliche Angaben darüber, wie Informationen über die Programmverwendung empfangen, verarbeitet, gespeichert und gelöscht werden, nachdem Sie den Endbenutzer-Lizenzvertrag akzeptiert und der KSN-Erklärung zugestimmt haben, finden Sie im Text des Endbenutzer-Lizenzvertrags und auf der Website von Kaspersky Lab. Die Dateien license.<Sprach-ID> und ksn_license.<Sprach-ID> enthalten den Endbenutzer-Lizenzvertrag und die Erklärung zu Kaspersky Security Network und sind Bestandteil des Installationspakets des Programms."," &#xDC;ber die Zurverf&#xFC;gungstellung von Daten ","161251.htm");
Page[48]=new Array("Starten und Stoppen des Programms","Standardmäßig wird Kaspersky Endpoint Security automatisch gestartet, wenn das Betriebssystem hochfährt (an der Standardausführungsebene für jedes Betriebssystem). Kaspersky Endpoint Security startet alle Dienstaufgaben sowie benutzerdefinierte Aufgaben, deren Zeitplaneinstellungen auf PS festgelegt sind.","Wenn Sie Kaspersky Endpoint Security anhalten, werden alle momentan laufenden Aufgaben unterbrochen. Nach dem Neustart von Kaspersky Endpoint Security werden die unterbrochenen benutzerdefinierten Aufgaben nicht automatisch fortgesetzt. Nur jene Benutzeraufgaben, deren Zeitplaneinstellungen auf PS festgelegt sind, werden neu gestartet.","Führen Sie folgenden Befehl aus, um Kaspersky Endpoint Security zu starten:","/etc/init.d/kesl-supervisor start","Führen Sie folgenden Befehl aus, um Kaspersky Endpoint Security anzuhalten:","/etc/init.d/kesl-supervisor stop","Führen Sie folgenden Befehl aus, um Kaspersky Endpoint Security neu zu starten:","/etc/init.d/kesl-supervisor restart","Führen Sie folgenden Befehl aus, den Status von Kaspersky Endpoint Security anzuzeigen:","/etc/init.d/kesl-supervisor status","Führen Sie folgenden Befehl aus, um Kaspersky Endpoint Security im systemd-System zu starten:","systemctl start kesl-supervisor","Führen Sie folgenden Befehl aus, um Kaspersky Endpoint Security im systemd-System anzuhalten:","systemctl stop kesl-supervisor","Führen Sie folgenden Befehl aus, um Kaspersky Endpoint Security im systemd-System neu zu starten:","systemctl restart kesl-supervisor","Führen Sie folgenden Befehl aus, um den Status von Kaspersky Endpoint Security im systemd-System anzuzeigen:","systemctl status kesl-supervisor","Überwachung des Programmzustands","Der Programmzustand wird mithilfe des Dienstes Watchdog überwacht. Der Dienst Watchdog wird beim Programmstart automatisch gestartet.","Sollte das Programm abstürzen, wird eine Dump-Datei erzeugt, und das Programm wird automatisch neu gestartet. Das Verzeichnis /var/opt/kaspersky/kesl directory, mit Ausnahme der Dump-Dateien, wird gesichert."," Starten und Stoppen des Programms ","161252.htm");
Page[49]=new Array("Allgemeine Einstellungen von Kaspersky Endpoint Security","In diesem Abschnitt werden die allgemeinen Programmeinstellungen für Kaspersky Endpoint Security beschrieben.","Starten Sie das Programm neu, nachdem Sie die allgemeinen Einstellungen von Kaspersky Endpoint Security geändert haben.","Die allgemeinen Einstellungen der Konfigurationsdatei haben folgende Werte:","SambaConfigPath","Verzeichnis, in dem die Samba-Konfigurationsdatei gespeichert ist. Die Samba-Konfigurationsdatei ist erforderlich, um zu gewährleisten, dass die Werte AllShared bzw. Shared:SMB für die Option Path übernommen werden.","Standardmäßig ist das Standardverzeichnis der Samba-Konfigurationsdatei auf dem Computer angegeben.","Standardwert: /etc/samba/smb.conf","NfsExportPath","Verzeichnis, in dem die NFS-Konfigurationsdatei gespeichert ist. Die NFS-Konfigurationsdatei ist erforderlich, um zu gewährleisten, dass die Werte AllShared bzw. Shared:NFS für die Option Path übernommen werden.","Geben Sie diese Einstellung an, wenn der Speicherort der NFS-Konfigurationsdatei vom Standardverzeichnis abweicht.","Standardwert: /etc/exports","TraceFolder","Verzeichnis, in dem Kaspersky Endpoint Security Log-Dateien für das Protokoll speichert.","Wenn Sie ein anderes Verzeichnis angeben, stellen Sie sicher, dass das Benutzerkonto, mit dessen Rechten Kaspersky Endpoint Security ausgeführt wird, eine Lese- und Schreibberechtigung für dieses Verzeichnis besitzt.","Standardwert: /var/log/kaspersky/kesl","TraceLevel","Genauigkeitsstufe des Protokolls zur Ablaufverfolgung.","Mögliche Werte:","Detailed – das detaillierteste Protokoll zur Ablaufverfolgung.","NotDetailed – das Protokoll zur Ablaufverfolgung enthält Fehlerbenachrichtigungen.","None – erstellt kein Protokoll zur Ablaufverfolgung","Standardwert: None.","BlockFilesGreaterMaxFileNamePath","Sperrt den Zugriff auf Dateien, deren vollständige Pfadlänge den in Bytes angegebenen Wert der Einstellung übersteigt.","Wenn der vollständige Pfad der Datei, die untersucht werden soll, den Wert dieser Einstellung übersteigt, wird die Datei von der Aufgabe zur Untersuchung auf Befehl während der Untersuchung übersprungen.","Mögliche Werte: 4096 – 33554432.","Standardwert: 16384.","DetectOtherObjects","Aktiviert bzw. deaktiviert das Erkennen von legaler Software, die von Angreifern zur Beeinträchtigung des Computers bzw. der Benutzerdaten verwendet werden kann.","Mögliche Werte:","Yes – Erkennen von legaler Software, die von Angreifern zur Beeinträchtigung des Computers bzw. der Benutzerdaten verwendet werden kann, aktivieren.","No — Erkennen von legaler Software, die von Angreifern zur Beeinträchtigung des Computers bzw. der Benutzerdaten verwendet werden kann, deaktivieren.","Standardwert: No","UseKSN","Aktiviert bzw. deaktiviert die Teilnahme an Kaspersky Security Network.","Mögliche Werte:","No — Teilnahme an Kaspersky Security Network deaktivieren.","Basic – Teilnahme an Kaspersky Security Network ohne den Versand von Statistiken aktivieren","Extended – Teilnahme an Kaspersky Security Network mit dem Versand von Statistiken aktivieren","Standardwert: No","UseProxy","Aktiviert bzw. deaktiviert die Nutzung eines Proxyservers für Kaspersky Security Network, die Aktivierung des Programms und der Updates.","Mögliche Werte:","Yes – Nutzung eines Proxyservers aktivieren.","No — Nutzung eines Proxyservers deaktivieren.","Standardwert: No","ProxyServer","Proxyserver-Einstellungen im Format [user[:password]@]host[:port].","MaxEventsNumber","Maximale Anzahl von Ereignissen , die von Kaspersky Endpoint Security gespeichert werden. Wenn die angegebene Anzahl von Ereignissen übertroffen wird, löscht Kaspersky Endpoint Security die ältesten Ereignisse.","Standardwert: 500000.","LimitNumberOfScanFileTasks","Maximale Anzahl der Aufgaben vom Typ Scan_File, die ein nicht privilegierter Benutzer gleichzeitig auf dem Computer starten kann. Durch diese Einstellung wird die Anzahl der Aufgaben, die ein Benutzer mit Root-Berechtigungen starten kann, nicht beschränkt. Wenn der Wert 0 angegeben ist, kann ein nicht privilegierter Benutzer keine Aufgaben vom Typ Scan_File starten.","Mögliche Werte: 0 – 4294967295.","Standardwert: 0.","Wenn die Einstellung USE_GUI während der Programminstallation auf yes gesetzt wurde, ist der Standardwert für LimitNumberOfScanFileTasks 5.","UseSysLog","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über Ereignisse im syslog. In bestimmten Fällen kann das Programm kein Ereignis generieren und speichern. Informationen werden dann im syslog gespeichert.","Yes – Protokollieren von Informationen über Ereignisse im syslog aktivieren.","No — Protokollieren von Informationen über Ereignisse im syslog deaktivieren.","Standardwert: No","UIReportsForRootOnly","Aktiviert bzw. deaktiviert die Anzeige von Berichten für Benutzer aus der grafischen Benutzeroberfläche.","Yes – Nur Root-Benutzer die Anzeige von Berichten in der GUI erlauben.","No — Nicht privilegierten Benutzern die Anzeige von Berichten in der GUI erlauben. Nicht privilegierte Benutzer können ferner bis zu 5 benutzerdefinierte Untersuchungsaufgaben erstellen und starten.","Standardwert: No.","EventsStoragePath","Datenbankdatei, in der Kaspersky Endpoint Security Informationen über Ereignisse speichert.","Standardwert: /var/opt/kaspersky/kesl/events.db","In diesem AbschnittBefehle zur Verwaltung von Kaspersky Endpoint Security und von einzelnen AufgabenHilfe zu Befehlen für Kaspersky Endpoint Security anzeigenAusgabe von Ereignissen aktivierenInformationen über das Programm anzeigenBefehle für Kaspersky Endpoint SecurityExportieren und Importieren von Programmeinstellungen"," Allgemeine Einstellungen von Kaspersky Endpoint Security ","161254.htm");
Page[50]=new Array("Befehle zur Verwaltung von Kaspersky Endpoint Security und von einzelnen Aufgaben","Dieser Abschnitt enthält Informationen zu den Befehlen für die Verwaltung der Einstellungen und Aufgaben von Kaspersky Endpoint Security."," Befehle zur Verwaltung von Kaspersky Endpoint Security und von einzelnen Aufgaben ","161255.htm");
Page[51]=new Array("Allgemeine Programmeinstellungen für Kaspersky Endpoint Security abrufen","Mit dem Befehl --get-app-settings werden die allgemeinen Einstellungen von Kaspersky Endpoint Security angezeigt. Mithilfe dieses Befehls können Sie auch die allgemeinen Einstellungen von Kaspersky Endpoint Security abrufen, die mit Hilfe von Schlüsseln zugewiesen wurden.","Sie können diesen Befehl verwenden, um die allgemeinen Einstellungen für die auf dem Computer installierte Version von Kaspersky Endpoint Security zu bearbeiten:","Speichern Sie die allgemeinen Einstellungen für Kaspersky Endpoint Security mithilfe der Option --get-app-settings in einer Konfigurationsdatei.Öffnen Sie die erstellte Konfigurationsdatei, ändern Sie die gewünschten Parameter, und speichern Sie die Änderungen.Importieren Sie die Einstellungen mithilfe der Option --set-app-settings aus der Konfigurationsdatei in Kaspersky Endpoint Security. Kaspersky Endpoint Security übernimmt die neuen Einstellungswerte, nachdem Sie Kaspersky Endpoint Security angehalten und neu gestartet haben.Sie können die erstellte Konfigurationsdatei auch verwenden, um die Einstellungen in eine auf einem anderen Computer installierte Version von Kaspersky Endpoint Security zu importieren.","Befehlssyntax","kesl-control [-T] --get-app-settings --file <Name der Konfigurationsdatei>","kesl-control [-T] --get-app-settings","Argumente und Schlüssel","--file <Name der Konfigurationsdatei>","Name der Konfigurationsdatei, in der die Programmeinstellungen für Kaspersky Endpoint Security gespeichert werden. Wenn Sie den Dateinamen eingeben, ohne einen Dateipfad vorzugeben, wird die Datei im aktuellen Verzeichnis erstellt. Ist unter dem gewünschten Pfad bereits eine Datei mit gleichem Namen vorhanden, wird diese überschreiben. Falls das von Ihnen vorgegebene Verzeichnis auf dem Speicher nicht existiert, wird die Konfigurationsdatei nicht erstellt.","Beispiel:","Allgemeine Einstellungen für Kaspersky Endpoint Security in eine Datei namens kesl_сonfig.ini exportieren. Erstellte Datei im aktuellen Verzeichnis speichern:","kesl-control --get-app-settings --file kesl_config.ini"," Allgemeine Programmeinstellungen f&#xFC;r Kaspersky Endpoint Security abrufen ","161256.htm");
Page[52]=new Array("Allgemeine Programmeinstellungen für Kaspersky Endpoint Security ändern","Der Befehls --set-app-settings legt die allgemeinen Einstellungen für Kaspersky Endpoint Security mithilfe der Befehlsschlüssel fest oder importiert die allgemeinen Einstellungen für Kaspersky Endpoint Security aus der angegebenen Konfigurationsdatei.","Sie können diesen Befehl verwenden, um die allgemeinen Einstellungen für Kaspersky Endpoint Security zu bearbeiten:","Speichern Sie die allgemeinen Einstellungen für Kaspersky Endpoint Security mithilfe der Option --get-app-settings in einer Konfigurationsdatei.Öffnen Sie die erstellte Konfigurationsdatei, ändern Sie die gewünschten Parameter, und speichern Sie die Änderungen.Importieren Sie die Einstellungen mithilfe der Option --set-app-settings aus der Konfigurationsdatei in Kaspersky Endpoint Security. Kaspersky Endpoint Security übernimmt die neuen Einstellungswerte, nachdem Sie Kaspersky Endpoint Security mithilfe der Optionen --stop-app und --start-app oder mithilfe der Option --restart-app angehalten und neu gestartet haben.Befehlssyntax","kesl-control [-T] --set-app-settings --file <Name der Konfigurationsdatei>","kesl-control [-T] --set-app-settings <Name der Einstellung>=<Einstellungswert> <Name der Einstellung>=<Einstellungswert>","Argumente und Schlüssel","--file <Name der Konfigurationsdatei>","Name der Konfigurationsdatei, deren Einstellungen in Kaspersky Endpoint Security importiert werden, inklusive vollständigem Dateipfad.","Beispiel:","Allgemeine Programmeinstellungen aus der Konfigurationsdatei namens /home/test/kav_сonfig.ini in Kaspersky Endpoint Security importieren:","kesl-control --set-app-settings --file /home/test/kav_сonfig.ini","Niedrige Genauigkeitsstufe für das Protokoll für die Ablaufverfolgung festlegen:","kesl-control --set-app-settings TraceLevel=NotDetailed"," Allgemeine Programmeinstellungen f&#xFC;r Kaspersky Endpoint Security &#xE4;ndern ","161257.htm");
Page[53]=new Array("Hilfe zu Befehlen für Kaspersky Endpoint Security anzeigen","Der Befehl kesl-control mit dem Schlüssel --help <Auswahl von Befehlen für Kaspersky Endpoint Security> zeigt die Hilfe zu den Befehlen von Kaspersky Endpoint Security an.","Befehlssyntax","kesl-control --help [<Auswahl von Befehlen für Kaspersky Endpoint Security>]","<Auswahl von Befehlen für Kaspersky Endpoint Security>","Mögliche Werte:","[-T] – Befehle zur Verwaltung der Aufgaben und allgemeinen Einstellungen von Kaspersky Endpoint Security.","[-L] – Befehle zur Schlüsselverwaltung.","[-B] – Befehle zur Speicherverwaltung.","[-E] – Befehle zur Verwaltung von Ereignissen in Kaspersky Endpoint Security.","[-F]—Befehle für die Aufgabe zur Firewall-Verwaltung.","[-H]—Befehle für die Anti-Cryptor-Aufgabe.","[-S]—Statistik-Befehle.","-W—Überwachung von Ereignissen."," Hilfe zu Befehlen f&#xFC;r Kaspersky Endpoint Security anzeigen ","161258.htm");
Page[54]=new Array("Ausgabe von Ereignissen aktivieren","Der Befehl -W aktiviert die Anzeige von Ereignissen in Kaspersky Endpoint Security. Sie können diesen Befehl entweder separat verwenden, um alle Ereignisse in Kaspersky Endpoint Security anzuzeigen, oder gemeinsam mit dem Befehl --start-task, um nur Ereignisse anzuzeigen, die mit der ausgeführten Aufgabe verknüpft sind. Sie können --query mit dem Kennzeichen -W verwenden, um nur bestimmte Ereignisse anzuzeigen.","Der Befehl gibt den Namen des Ereignisses und zusätzliche Informationen über das Ereignis zurück.","Befehlssyntax","kesl-control -W","Beispiel:","Anzeige von Ereignissen in Kaspersky Endpoint Security aktivieren:","kesl-control -W"," Ausgabe von Ereignissen aktivieren ","161259.htm");
Page[55]=new Array("Informationen über das Programm anzeigen","Der Befehl --app-info zeigt Informationen über Kaspersky Endpoint Security an.","Befehlssyntax","kesl-control [-S] --app-info","Ergebnis der Befehlsausführung","Name","Programmname.","Version","Aktuelle Programmversion","Schlüsselstatus","Status des Schlüssels.","Abonnementstatus","Status des Abonnements. Dieses Feld wird angezeigt, wenn das Programm im Abonnement ausgeführt wird.","Gültigkeitsdauer der Lizenz","Gültigkeitsdauer der Lizenz.","Speicherstatus","Status des Speichers. Zeigt Informationen über zeitliche oder Größenbeschränkungen an.","Verwendung des Speicherplatzes","Größe des Speichers.","Letztes Ausführungsdatum der Aufgabe Scan_My_Computer","Zeitpunkt der letzten Ausführung der Aufgabe Scan_My_Computer.","Aktuelles Veröffentlichungsdatum von Datenbanken","Zeitpunkt der letzten Veröffentlichung der Datenbanken.","Antiviren-Datenbanken geladen","Zeigt an, ob Antiviren-Datenbanken heruntergeladen wurden oder nicht.","Datensätze der Antiviren-Datenbanken","Anzahl der Datensätze in Antiviren-Datenbanken.","KSN-Status","Teilnahme an Kaspersky Security Network","Dateiüberwachung","Status der Komponente Dateiüberwachung.","Überwachung der Integrität","Status der Komponente Überwachung der Datei-Integrität.","Firewall-Verwaltung","Status der Komponente Firewall-Verwaltung.","Anti-Cryptor","Status der Komponente Schutz vor Verschlüsselung.","Status des Programm-Updates","Zeigt die Verfügbarkeit der Programm-Updates an."," Informationen &#xFC;ber das Programm anzeigen ","161260.htm");
Page[56]=new Array("Befehle für Kaspersky Endpoint Security","Sie können die Werte der Einstellungen für Kaspersky Endpoint Security ändern.","Es gelten die folgenden Regeln für die Nutzung der Befehle für Kaspersky Endpoint Security:","Beachten Sie die Groß- und Kleinschreibung.Trennen Sie Befehlsschlüssel durch ein Leerzeichen.Wenn Sie die volle Bezeichnung für Befehle oder Schlüssel verwenden, geben Sie den Wert nach einem Gleichheitszeichen (=) ein.","Beispiel:","Geben Sie den URL-Parameterwert für die benutzerdefinierte Update-Quelle der Update-Aufgabe (ID=6) aus der Befehlszeile an:","kesl-control --set-settings 6","SourceType=Custom CustomSources.item_0000.URL=http://site.domain/path CustomSources.item_0000.Enabled=Yes","Anzeigen der Hilfe zu Befehlen für Kaspersky Endpoint Security","--help","Zeigt die Hilfe zu Befehlen in Kaspersky Endpoint Security an.","Anzeigen der Ereignisse für Kaspersky Endpoint Security","-W","Aktiviert die Anzeige von Ereignissen in Kaspersky Endpoint Security.","Befehle zur Verwaltung von Einstellungen und Aufgaben in Kaspersky Endpoint Security","-T","Ein Präfix, der anzeigt, dass es sich um einen Befehl zur Verwaltung der Einstellungen in Kaspersky Endpoint Security bzw. zur Verwaltung von Aufgaben handelt (optional).","[-S] --app-info","Zeigt allgemeine Informationen zu Kaspersky Endpoint Security an.","[-Т] --get-app-settings --file <Dateiname und Verzeichnis>","Gibt die allgemeinen Programmeinstellungen für Kaspersky Endpoint Security zurück.","[-Т] --set-app-settings --file <Dateiname und Verzeichnis>","Legt die allgemeinen Einstellungen für Kaspersky Endpoint Security fest.","[-T] --get-task-list","Gibt die Liste der vorhandenen Aufgaben für Kaspersky Endpoint Security zurück.","[-T] --get-task-state <Aufgaben-ID>|<Aufgabenname>","Zeigt den Status der angegebenen Aufgabe an.","[-T] --create-task <Aufgabennname> --type <Aufgabentyp> --file <Dateiname und Verzeichnis>","Erstellt eine Aufgabe des festgelegten Typs. Importiert die Einstellungen aus der ausgewählten Konfigurationsdatei in die Aufgabe.","[-T] --delete-task <Aufgaben-ID>|<Aufgabenname>","Löscht die Aufgabe.","[-T] --start-task <Aufgaben-ID>|<Aufgabenname> [-W] [--progress] [--file <Dateiname und Verzeichnis>]","Startet die Aufgabe.","[-T] --stop-task <Aufgaben-ID>|<Aufgabenname>","Hält die Aufgabe an.","[-T] --suspend-task <Aufgaben-ID>|<Aufgabenname>","Unterbricht die Aufgabe.","[-T] --resume-task <Aufgaben-ID>|<Aufgabenname>","Setzt die Aufgabe fort.","[-T] --get-settings <Aufgaben-ID>|<Aufgabenname> --file <Dateiname und Verzeichnis>","Gibt die Aufgabeneinstellungen zurück.","[-T] --set-settings <Aufgaben-ID>|<Aufgabenname> [<Einstellungen>] [--file <Dateiname und Verzeichnis>] [--add-path <path>] [--del-path <Pdad>] [--add-exclusion <Ausnahme>] [--del-exclusion <Ausnahme>]","Legt die Aufgabeneinstellungen fest.","[-T] --scan-file <Pfad> [--action <Aktion>]","Erstellt und startet eine temporäre Scan_File-Aufgabe.","[-T] --import-settings --file <Datei>","Importiert die Programmeinstellung in die Konfigurationsdatei.","[-T] --update-application","Aktualisiert das Programm.","[-S] --omsinfo --file <path>","Erstellt eine Datei im JSON-Format für die Integration mit der Microsoft Operations Management Suite.","Befehle zur Schlüsselverwaltung","-L","Präfix, das anzeigt, dass der Befehl zur Gruppe der Befehle zur Schlüsselverwaltung gehört.","[-L] --install-active-key <Aktivierungscode>|<Schlüsseldatei>","Fügt den aktiven Schlüssel hinzu.","[-L] --install-additional-key <Aktivierungscode>|<Schlüsseldatei>","Fügt den Reserveschlüssel hinzu.","[-L] --revoke-active-key","Löscht den aktiven Schlüssel.","[-L] --revoke-additional-key","Löscht den Reserveschlüssel.","[-L] --query","Zeigt Informationen über den Schlüssel an.","Befehle für die Firewall-Verwaltungsaufgabe","[-F] --add-rule [--name <Zeichenfolge>] [--action <Aktion>] [--protocol <Protokoll>] [--direction <Verzeichnis>] [--remote <Remote>] [--local <lokal>] [--at <Index>]","Fügt eine neue Regel hinzu.","[-F] --del-rule [--name <Zeichenfolge>] [--index <Index>]","Löscht eine Regel.","[-F] --move-rule [--name <Zeichenfolge>] [--index <Index>] [--at <Index>]","Ändert die Priorität der Regel.","[-F] --add-zone [--zone <Zone>] [--address <Adresse>]","Fügt eine IP-Adresse zur Zone hinzu.","[-F] --del-zone [--zone <Zone>] [--address <Adress>] [--index <Index>]","Löscht eine IP-Adresse aus der Zone.","-F --query","Zeigt Informationen an.","Befehle für die Aufgabe zum Schutz vor Verschlüsselung","[-H] --get-blocked-hosts","Zeigt eine Liste mit blockierten Computern an.","[-H] --allow-hosts","Entsperrt nicht vertrauenswürdige Geräte.","Befehle zur Speicherverwaltung","-B","Präfix, das anzeigt, dass der Befehl zur Gruppe der Befehle zur Speicherverwaltung gehört.","[-B] --mass-remove --query","Löscht den Speicher, vollständig oder selektiv.","[-B] --query --limit --offset","Zeigt Informationen über Objekte im Speicher an:","--limit","Maximale Anzahl von Objekten, für die Informationen angezeigt werden.","--offset","Anzahl der Einträge ab Anfang der Auswahl, die nicht angezeigt werden sollen.","[B] --restore <ID des Objektes> --file <Dateiname und Verzeichnis>","Stellt ein Objekt aus dem Speicher wieder her.","Befehle zur Verwaltung des Ereignisprotokolls","-E","Präfix, das anzeigt, dass der Befehl zur Gruppe der Befehle zur Verwaltung des Ereignisprotokolls gehört.","[-E] --query --limit --offset --file <Dateiname und Verzeichnis> --db <db-Datei>","Maximale Anzahl von Ereignissen, für die Informationen angezeigt werden.","--query","Gibt Informationen über die gefilterten Ereignisse aus dem Ereignisprotokoll oder aus der angegebenen Protokollrotationsdatei zurück.","--offset","Anzahl der Einträge ab Anfang der Auswahl, die nicht angezeigt werden sollen.","--db","Name der Datenbankdatei.","Befehle zur Verwaltung des Aufgabenzeitplans","[-T] --set-schedule <Aufgaben-ID>|<Aufgabenname> --file <Dateiname und Verzeichnis>","Legt die Einstellungen des Aufgabenzeitplans fest bzw. importiert sie aus der Konfigurationsdatei in die Aufgabe.","[-T] --get-schedule <Aufgaben-ID>|<Aufgabenname> --file <Dateiname und Verzeichnis>","Gibt die Einstellungen des Aufgabenzeitplans zurück.","RuleType=Once|Monthly|Weekly|Daily|Hourly|Minutely|Manual|PS|BR","Zeitplan für den Aufgabenstart.","PS  — Aufgabe nach dem Start von Kaspersky Endpoint Security starten.","BR  — Aufgabe nach einem Antiviren-Datenbanken-Update starten.","StartTime=[year/month/month_day] [hh]:[mm]:[ss]; [<Kalendertag>|<Wochentag>]; [<Dauer>]","Uhrzeit des Aufgabenstarts","RandomInterval=<min.>","Intervall des Aufgabenstarts, wenn mehrere Aufgaben gleichzeitig ausgeführt werden (in Minuten).","ExecuteTimeLimit=<min.>","Ausführungszeit der Aufgabe beschränken (in Minuten).","RunMissedStartRules","Aktiviert bzw. deaktiviert den Start einer übersprungenen Aufgabe nach dem Start von Kaspersky Endpoint Security."," Befehle f&#xFC;r Kaspersky Endpoint Security ","161262.htm");
Page[57]=new Array("Exportieren und Importieren von Programmeinstellungen","In Kaspersky Endpoint Security können Sie zur Fehlerbehebung, Überprüfung der Einstellungen oder zur einfacheren Programmkonfiguration auf anderen Computern alle Programmeinstellungen exportieren und importieren.","Beim Exportieren von Einstellungen werden alle Programm- und Aufgabeneinstellungen in einer Konfigurationsdatei gespeichert. Diese Konfigurationsdatei wird zum Importieren der Einstellungen und Konfigurieren des Programms verwendet.","Zum Importieren und Exportieren von Einstellungen muss Kaspersky Endpoint Security gestartet werden. Nach dem Importieren von Einstellungen muss das Programm neu gestartet werden. ","Wenn das Programm über Kaspersky Security Center verwaltet wird, ist der Import von Einstellungen nicht verfügbar. ","Beim Importieren oder Exportieren von Einstellungen aus älteren Programmversionen, werden neue Einstellungen auf Standardwerte gesetzt. Wenn Konfigurationsdateien für neue und ältere Programmversionen übereinstimmen, ist der Rückgabecode 1.","Das Importieren von Einstellungen in eine ältere Programmversion ist nicht möglich.","Beim Importieren von Programmeinstellungen wird die Einstellung UseKSN auf No gesetzt. Für den Beginn der Teilnahme am Kaspersky Security Network müssen Sie dieEinstellung UseKSN=Basic oder UseKSN=Extended festlegen.","Nach dem Import von Programmeinstellungen, können interne Aufgaben-IDs geändert werden. Es wird empfohlen, zu deren Verwaltung die Aufgabennamen zu verwenden.","Um Programmeinstellungen in eine Konfigurationsdatei zu exportieren, führen Sie den folgenden Befehl aus:","kesl-control --export-settings --file [vollständiger Pfad der Konfigurationsdatei] ","Um das Programm mithilfe der Einstellungen aus einer Konfigurationsdatei zu konfigurieren (Einstellungen zu importieren), führen Sie den folgenden Befehl aus:","kesl-control --import-settings --file vollständiger Pfad der Konfigurationsdatei"," Exportieren und Importieren von Programmeinstellungen ","162401.htm");
Page[58]=new Array("Verwalten der Aufgaben in Kaspersky Endpoint Security mithilfe der Befehlszeile","Dieser Abschnitt enthält Informationen über die Aufgabentypen von Kaspersky Endpoint Security und Anweisungen zur Aufgabenverwaltung.","In diesem AbschnittÜber die Aufgaben von Kaspersky Endpoint SecurityAufgabenliste für Kaspersky Endpoint Security anzeigenAufgabe erstellenAufgabeneinstellungen mithilfe einer Konfigurationsdatei bearbeitenAufgabeneinstellungen mithilfe der Befehlszeile bearbeitenAufgabe starten und beendenUntersuchungsbereiche aus der Befehlszeile verwaltenAusschlussbereiche aus der Befehlszeile verwaltenAufgabenstatus anzeigenAufgabe anhalten und fortsetzenAufgabenzeitplan anpassenParameter für Aufgabenzeitplan anzeigenParameter für Aufgabenzeitplan ändernAufgabe löschen"," Verwalten der Aufgaben in Kaspersky Endpoint Security mithilfe der Befehlszeile ","161263.htm");
Page[59]=new Array("Über die Aufgaben von Kaspersky Endpoint Security","Sie können die Ausführung von Kaspersky Endpoint Security mithilfe von Aufgaben sowohl lokal auf Computern (mithilfe der Befehlszeile oder der Konfigurationsdateien), als auch zentral über Kaspersky Security Center verwalten.","Für die Arbeit mit Kaspersky Endpoint Security gibt es zwei Typen von Aufgaben:","Vordefinierte Aufgabe — Aufgabe, die während der Installation des Programms erstellt wird. Sie können vordefinierte Aufgaben nicht erstellen oder löschen, aber Sie können die Einstellungen dieser Aufgaben ändern.Benutzerdefinierte Aufgabe — Aufgabe, die Sie selbstständig erstellen oder löschen können.Sie können die folgenden Aufgaben verwalten:","File_Monitoring ist eine Aufgabe zum Echtzeitschutz (ID=1, Typ: OAS)Scan_My_Computer ist eine Aufgabe zur Untersuchung auf Befehl (ID=2, Typ: ODS)Scan_File ist eine Aufgabe zur benutzerdefinierten Untersuchung (ID=3, Typ: ODS) Standardmäßig stimmen die Einstellungen dieser Aufgabe mit den Einstellungen der Aufgabe Scan_My_Computer überein;Boot_Scan ist eine Aufgabe zur Untersuchung des Bootsektors (ID=4, Typ: BootScan)Memory_Scan ist eine Aufgabe zur Untersuchung des Arbeitsspeichers (ID=5, Typ: MemoryScan)Update ist eine Update-Aufgabe (ID=6, Typ: Update)Rollback ist eine Aufgabe zum Rollback eines Datenbanken-Updates (ID=7, Typ: Rollback) Dies Aufgabe hat keine Einstellungen. Sie können diese Aufgabe nur starten und stoppenRetranslate ist eine Aufgabe zur Update Software-Distribution (ID=8, Typ: Retranslate)License ist eine Aufgabe zur Realisierung des Lizenzservers (ID=9, Typ: License)Backup ist eine Aufgabe zur Speicherverwaltung (ID=10, Typ: Backup).Integrity_Monitoring ist eine Aufgabe zur Überwachung der Datei-Integrität (ID=11, Typ: OAFIM).Firewall ist eine Aufgabe zur Verwaltung der System-Firewall (ID=12, Typ: Firewall).Anti-Cryptor ist eine Aufgabe zum Schutz vor Verschlüsselung (ID=13, Typ: AntiCryptor).ID — Aufgabennummer, die Kaspersky Endpoint Security beim Erstellen der Aufgabe automatisch vergibt.","Sie können mit Aufgaben folgende Aktionen ausführen:","Aufgaben starten und stoppen.Aufgaben erstellen und löschen (nur für benutzerdefinierte Aufgabe)Aufgabeneinstellungen bearbeiten"," &#xDC;ber die Aufgaben von Kaspersky Endpoint Security ","161264.htm");
Page[60]=new Array("Aufgabenliste für Kaspersky Endpoint Security anzeigen","Um eine Liste der Aufgaben von Kaspersky Endpoint Security anzuzeigen, führen Sie folgenden Befehl aus:","kesl-control [-T] --get-task-list","Eine Liste der Aufgaben von Kaspersky Endpoint Security wird angezeigt.","Für jede Aufgabe werden folgende Informationen angezeigt:","Name. Aufgabenname.ID. Aufgaben-ID.Type. Aufgabentyp.State. Status der aktuellen Aufgabe.Wenn ein Benutzer keine Erlaubnis zum Anzeigen und Bearbeiten von Aufgabeneinstellungen hat, werden Informationen über die Aufgaben Scan_File, Backup, License, File_Monitoring, Integrity_Monitor und Anti_Cryptor angezeigt. Informationen über andere Aufgaben stehen nicht zur Verfügung.","Wenn Ihre Lizenz die Funktionen Anti-Cryptor und Überwachung der Datei-Integrität nicht abdeckt, werden Informationen zu den entsprechenden Aufgaben nicht angezeigt.","Weitere Informationen finden Sie im Abschnitt Über die Aufgaben von Kaspersky Endpoint Security."," Aufgabenliste f&#xFC;r Kaspersky Endpoint Security anzeigen ","161267.htm");
Page[61]=new Array("Aufgabe erstellen","Sie können Aufgaben mit Standardeinstellungen oder mit Einstellungen erstellen, die in einer Konfigurationsdatei angegeben sind.","Aufgaben vom Typ OAS, Firewall, OAFIM, License, Backup und AntiCryptor können nicht erstellt werden.","Um eine Aufgabe mit Standardeinstellungen zu erstellen, führen Sie den folgenden Befehl aus:","kesl-control [-T] --create-task <Aufgabenname> --type <Aufgabentyp>","Wobei:","<Aufgabenname> ein Name ist, den Sie für eine neue Aufgabe vergeben<Aufgabentyp> ein vordefinierter Aufgabentyp istEine Aufgabe des angegebenen Typs wird mit Standardeinstellungen erstellt.","Um eine Aufgabe mit Einstellungen zu erstellen, die in einer Konfigurationsdatei angegeben sind, führen Sie den folgenden Befehl aus:","kesl-control [-T] --create-task <Aufgabenname> --type <Aufgabentype> --file <vollständiger Pfad der Konfigurationsdatei>","Wobei:","<Aufgabenname> ein Name ist, den Sie für eine neue Aufgabe vergeben<Aufgabentyp> ein vordefinierter Aufgabentyp ist<vollständiger Pfad der Konfigurationsdatei> ist der vollständige Pfad zur KonfigurationsdateiEine Aufgabe des angegebenen Typs wird mit den Einstellungen erstellt, die in einer Konfigurationsdatei angegeben sind."," Aufgabe erstellen ","161268.htm");
Page[62]=new Array("Aufgabeneinstellungen mithilfe einer Konfigurationsdatei bearbeiten","Um die Einstellungen einer Aufgabe durch Änderung der Konfigurationsdatei zu bearbeiten, gehen Sie wie folgt vor:","Speichern Sie die Einstellungen einer Aufgabe in der Konfigurationsdatei:kesl-control --get-settings <Name der Aufgabe>|<Aufgaben-ID> --file <vollständiger Dateipfad>","Öffnen Sie die erstellte Konfigurationsdatei zum Bearbeiten.Bearbeiten Sie die gewünschten Einstellungen in der Konfigurationsdatei.Speichern Sie die Änderungen in der Konfigurationsdatei.Importieren Sie die Einstellungen aus der Konfigurationsdatei in die Aufgabe:kesl-control --set-settings <Name der Aufgabe>|<Aufgaben-ID> --file <vollständiger Dateipfad>","Als Ergebnis wird die Aufgabe mit aktualisierten Einstellungen ausgeführt."," Aufgabeneinstellungen mithilfe einer Konfigurationsdatei bearbeiten ","162022.htm");
Page[63]=new Array("Aufgabeneinstellungen mithilfe der Befehlszeile bearbeiten","Um die Einstellungen einer Aufgabe mithilfe der Befehlszeile zu bearbeiten, gehen Sie wie folgt vor:","Geben Sie den gewünschten Einstellungswert an:kesl-control --set-settings <Name oder ID der Aufgabe> setting=value [setting=value]","Kaspersky Endpoint Security ändert die angegebene Einstellung.","Stellen Sie sicher, dass der Einstellungswert in einer Aufgabenkonfigurationsdatei geändert wird:kesl-control --get-settings <Name oder ID der Aufgabe>","Wenn Sie einen neuen Untersuchungsbereich oder Ausschlussbereich hinzufügen, ohne alle Einstellungen anzugeben, wird ein Bereich mit Standardeinstellungen zu einer Konfigurationsdatei hinzugefügt.","Beispiel:","Führen Sie den folgenden Befehl aus, um einen neuen Untersuchungsbereich anzugeben:","--set-settings 100 ScanScope.item_0001.UseScanArea=Yes ScanScope.item_0001.Path=/home","Ein neuer Abschnitt zur Beschreibung eines Untersuchungsbereichs wird für die Aufgabe mit ID=100 zur Konfigurationsdatei hinzugefügt:","[ScanScope.item_0001]","AreaDesc=","UseScanArea=Yes","Path=/home","AreaMask.item_0000=*"," Aufgabeneinstellungen mithilfe der Befehlszeile bearbeiten ","162393.htm");
Page[64]=new Array("Aufgabe starten und beenden","Backup- und License-Aufgaben können nicht gestartet oder gestoppt werden.","Um die Aufgabe zu starten, führen Sie folgenden Befehl aus:","kesl-control --start-task <Aufgaben-ID>|<Aufgabenname>","Um die Aufgabe zu stoppen, führen Sie folgenden Befehl aus:","kesl-control --stop-task <Aufgaben-ID> [--use-name]"," Aufgabe starten und beenden ","161269.htm");
Page[65]=new Array("Untersuchungsbereiche aus der Befehlszeile verwalten","Sie können einen Untersuchungsbereich mit angegebenem Path für OAS-, ODS-, OAFIM-, ODFIM-Aufgaben und Aufgabe zum Schutz vor Verschlüsselung aus der Befehlszeile hinzufügen oder löschen.","Um einen neuen Untersuchungsbereich hinzuzufügen, führen Sie den folgenden Befehl aus:","kesl-control --set-settings <ID oder Name der Aufgabe> --add-path <Pfad>","Ein neuer [ScanScope.item_#]-Abschnitt wird zur Konfigurationsdatei einer Aufgabe hinzugefügt. Kaspersky Endpoint Security untersucht Objekte, die sich im in der Einstellung Pfad angegebenen Verzeichnis befinden. ","Wenn ein [ScanScope.item_#]-Abschnitt für den angegebenen Pfad  bereits existiert, wird der Abschnitt in der Konfigurationsdatei nicht dupliziert. Wenn die Einstellungen für UseScanArea auf No eingestellt wurden, ändert sich der Wert nach der Ausführung dieses Befehls auf Yes und Objekte, die sich in diesem Verzeichnis befinden, werden untersucht.","Um einen Untersuchungsbereich zu löschen, führen Sie den folgenden Befehl aus:","kesl-control --set-settings <ID oder Name der Aufgabe> --del-path <Pfad>","Ein [ScanScope.item_#]-Abschnitt, der den angegebenen Pfad enthält, wird aus der Konfigurationsdatei einer Aufgabe gelöscht. Kaspersky Endpoint Security untersucht keine Objekte, die sich im in der Einstellung Path angegebenen Verzeichnis befinden. "," Untersuchungsbereiche aus der Befehlszeile verwalten ","162407.htm");
Page[66]=new Array("Ausschlussbereiche aus der Befehlszeile verwalten","Sie können einen Ausschlussbereich mit angegebenem Path für OAS-, ODS-, OAFIM-, ODFIM-Aufgaben und Aufgabe zum Schutz vor Verschlüsselung aus der Befehlszeile hinzufügen oder löschen.","Um einen neuen Ausschlussbereich hinzuzufügen, führen Sie den folgenden Befehl aus:","kesl-control --set-settings <ID oder Name der Aufgabe> --add-exclusion <Pfad>","Ein neuer [ExcludedFromScanScope.item_#]-Abschnitt wird zur Konfigurationsdatei einer Aufgabe hinzugefügt. Kaspersky Endpoint Security schließt Objekte aus, die sich im in der Einstellung Path angegebenen Verzeichnis befinden. ","Wenn ein [ExcludedFromScanScope.item_#]-Abschnitt für den angegebenen Path  bereits existiert, wird der Abschnitt in der Konfigurationsdatei nicht dupliziert. Wenn die Einstellungen für UseScanArea auf No eingestellt wurden, ändert sich der Wert nach der Ausführung dieses Befehls auf Yes und Objekte, die sich in diesem Verzeichnis befinden, werden von der Untersuchung ausgeschlossen.","Um einen Ausschlussbereich zu löschen, führen Sie den folgenden Befehl aus:","kesl-control --set-settings <ID oder Name der Aufgabe> --del-exclusion <Pfad>","Ein [ExcludedFromScanScope.item_#]-Abschnitt, der den angegebenen Pfad enthält, wird aus der Konfigurationsdatei einer Aufgabe gelöscht. Kaspersky Endpoint Security schließt Objekte, die sich im in der Einstellung Path angegebenen Verzeichnis befinden, nicht aus. "," Ausschlussbereiche aus der Befehlszeile verwalten ","162408.htm");
Page[67]=new Array("Aufgabenstatus anzeigen","Sie können den Status einer Aufgabe anzeigen.","Führen Sie folgenden Befehl aus, um einen Aufgabenstatus anzuzeigen:","kesl-control --get-task-state <Aufgaben-ID>|<Aufgabenname>","Wobei:","<Aufgaben-ID> eine Aufgaben-ID ist, die Kaspersky Endpoint Security der Aufgabe bei der Erstellung zuweist<Aufgabenname> ein Name ist, den Sie für eine neue Aufgabe vergebenAufgaben von Kaspersky Endpoint Security können einen der folgende Status aufweisen:","Started – Aufgabe wird ausgeführtStarting – Aufgabe wird gestartet.Stopped – Aufgabe wird beendet.Stopping – Aufgabe wird gestopptSuspended – Aufgabe wird unterbrochen.Suspending – Aufgabe wird unterbrochenResumed – Aufgabe wird fortgesetzt.Resuming – Aufgabe wird fortgesetzt"," Aufgabenstatus anzeigen ","161277.htm");
Page[68]=new Array("Aufgabe anhalten und fortsetzen","Sie können die Ausführung von Aufgaben der folgenden Typen anhalten und fortsetzen: ODS, BootScan, MemoryScan, Rollback, Retranslate und Update.","Um eine Aufgabe anzuhalten, führen Sie folgenden Befehl aus:","kesl-control --suspend-task <Aufgaben-ID>|<Aufgabenname>","Die Aufgabenausführung wird angehalten, nachdem der Befehl ausgeführt wurde.","Um eine Aufgabe fortzusetzen, führen Sie folgenden Befehl aus:","kesl-control --resume-task <Aufgaben-ID>|<Aufgabenname>","Die Aufgabenausführung wird wieder aufgenommen, nachdem der Befehl ausgeführt wurde."," Aufgabe anhalten und fortsetzen ","161271.htm");
Page[69]=new Array("Aufgabenzeitplan anpassen","Gehen Sie folgendermaßen vor, um einen Aufgabenzeitplan anzupassen:","Speichern Sie die Einstellungen des Aufgabenzeitplans in einer Konfigurationsdatei, indem Sie folgenden Befehl ausführen:kesl-control --get-schedule <Aufgaben-ID>|<Aufgabenname>","Öffnen Sie die Konfigurationsdatei zum Bearbeiten.Geben Sie die Einstellungen des Zeitplans an.Speichern Sie die Änderungen in der Konfigurationsdatei.Importieren Sie die Zeitplaneinstellungen mithilfe des folgenden Befehls in die Aufgabe:kesl-control --set-schedule <Aufgaben-ID>|<Aufgabenname> --file <vollständiger Dateipfad>"," Aufgabenzeitplan anpassen ","161272.htm");
Page[70]=new Array("Parameter für Aufgabenzeitplan anzeigen","Der Befehl --get-schedule gibt Einstellungen für den Aufgabenzeitplan zurück. Mithilfe dieses Befehls können Sie auch die Einstellungen des Aufgabenzeitplans abrufen, die mit Hilfe von Befehlsschlüsseln festgelegt wurden.","Sie können diesen Befehl verwenden um den Aufgabenzeitplan zu ändern:","Speichern Sie die Zeitplaneinstellungen mithilfe des Befehls --get-schedule in der Konfigurationsdatei .Öffnen Sie die erstellte Konfigurationsdatei, ändern Sie die gewünschten Parameter, und speichern Sie die Änderungen.Importieren Sie die Einstellungen aus der Konfigurationsdatei mithilfe des Befehls --set-schedule in Kaspersky Endpoint Security. Die neuen Werte für die Zeitplaneinstellungen werden von Kaspersky Endpoint Security sofort übernommen.Befehlssyntax","kesl-control [-T] --get-schedule <Aufgaben-ID> [--file <Name der Konfigurationsdatei>] [--use-name]","kesl-control [-T] --get-schedule <Aufgaben-ID> <Name der Einstellung> [--use-name]","Argumente und Schlüssel","<Aufgaben-ID>","Aufgaben-ID in Kaspersky Endpoint Security.","<Aufgabenname>","Aufgabenname.","--file <Name der Konfigurationsdatei>","Name der Konfigurationsdatei, in der die Zeitplaneinstellungen gespeichert werden. Wenn Sie den Dateinamen eingeben, ohne einen Dateipfad vorzugeben, wird die Datei im aktuellen Verzeichnis erstellt. Ist unter dem gewünschten Pfad bereits eine Datei mit gleichem Namen vorhanden, wird diese überschreiben. Falls das von Ihnen vorgegebene Verzeichnis auf dem Speicher nicht existiert, wird die Konfigurationsdatei nicht erstellt.","Beispiel:","Einstellungen für Kaspersky Endpoint Security in die Datei update_schedule.ini speichern. Erstellte Datei im aktuellen Verzeichnis speichern:","kesl-control --get-schedule 6 --file update_schedule.ini","Zeitplan für Update-Aufgabe zurückgeben:","kesl-control --get-schedule 6"," Parameter f&#xFC;r Aufgabenzeitplan anzeigen ","161274.htm");
Page[71]=new Array("Parameter für Aufgabenzeitplan ändern","Der Befehl --set-schedule legt die Einstellungen des Aufgabenzeitplans fest oder importiert die Einstellungen des Aufgabenzeitplans aus der angegebenen Konfigurationsdatei.","Sie können diesen Befehl verwenden, um die Einstellungen für Kaspersky Endpoint Security zu ändern:","Speichern Sie die Zeitplaneinstellungen mithilfe des Befehls --get-schedule in der Konfigurationsdatei.Öffnen Sie die erstellte Konfigurationsdatei, ändern Sie die gewünschten Parameter, und speichern Sie die Änderungen.Importieren Sie die Einstellungen aus der Konfigurationsdatei mithilfe des Befehls -T --set-schedule in Kaspersky Endpoint Security. Die neuen Werte für die Zeitplaneinstellungen werden von Kaspersky Endpoint Security sofort übernommen.Befehlssyntax","kesl-control --set-schedule <Aufgaben-ID> --file <Name der Konfigurationsdatei> [--use-name]","kesl-control --set-schedule <Aufgaben-ID> <Name der Einstellung>=<Einstellungswert> <Name der Einstellung>=<Einstellungswert> [--use-name]","Argumente und Schlüssel","<Aufgaben-ID>","Aufgaben-ID in Kaspersky Endpoint Security.","<Aufgabenname>","Aufgabenname.","--file <Name der Konfigurationsdatei>","Name der Konfigurationsdatei, deren Zeitplaneinstellungen in die Aufgabe importiert werden, inklusive vollständigem Dateipfad.","Beispiel:","Zeitplaneinstellungen aus der Konfigurationsdatei /home/test/on_demand_schedule.ini in die Aufgabe mit ID=2 importieren:","kesl-control --set-schedule 2 --file /home/test/on_demand_schedule.ini"," Parameter f&#xFC;r Aufgabenzeitplan &#xE4;ndern ","161275.htm");
Page[72]=new Array("Aufgabe löschen","Sie können Aufgaben löschen, die Sie erstellt haben (benutzerdefinierte Aufgaben).","Um eine Aufgabe zu löschen, führen Sie folgenden Befehl aus:","kesl-control --delete-task <Aufgaben-ID> | <Aufgabenname>"," Aufgabe l&#xF6;schen ","161270.htm");
Page[73]=new Array("Aufgabe zum Echtzeitschutz (File_Monitoring ID:1)","Dieser Abschnitt enthält Informationen über die Aufgabe zum Echtzeitschutz.","In diesem AbschnittÜber den EchtzeitschutzÜber die infizierten DateienBesonderheiten der Untersuchung von symbolischen Links und festen LinksEinstellungen der Aufgabe zum EchtzeitschutzGlobalen Ausnahmebereich festlegen"," Aufgabe zum Echtzeitschutz (File_Monitoring ID:1) ","161279.htm");
Page[74]=new Array("Über den Echtzeitschutz","Echtzeitschutz verhindert eine Infektion des Dateisystem des Computers. Die Aufgabe zum Echtzeitschutz wird bei der Installation von Kaspersky Endpoint Security auf dem Computer mit den Standardeinstellungen erstellt. Standardmäßig wird die Aufgabe zum Echtzeitschutz automatisch beim Start von Kaspersky Endpoint Security gestartet. Diese Aufgabe befindet sich permanent im Arbeitsspeicher des Computers und untersucht alle Dateien, die geöffnet, gespeichert und ausgeführt werden. Sie können die Aufgabe stoppen und starten.","Sie können keine benutzerdefinierten Aufgaben zum Echtzeitschutz erstellen. Sie können die Einstellungen der vordefinierten Aufgabe zum Echtzeitschutz ändern.","Die Einstellungen für den Echtzeitschutz sind in der Konfigurationsdatei enthalten, die von der Aufgabe zum Echtzeitschutz verwendet werden. "," &#xDC;ber den Echtzeitschutz ","161280.htm");
Page[75]=new Array("Über die infizierten Dateien","Bei der Untersuchung von Dateien verwendet Kaspersky Endpoint Security die Antiviren-Datenbanken. Diese Datenbanken enthalten Dateien mit Fragmenten von bösartigem Code sowie Algorithmen für die Desinfizierung der Objekte, in denen diese Bedrohungen enthalten sind. Antiviren-Datenbanken ermöglichen das Erkennen von bekannten Bedrohungen in den untersuchten Dateien.","Wenn eine Datei einen Code enthält, der mit dem Code einer bekannten Bedrohung vollständig übereinstimmt, weist Kaspersky Endpoint Security der Datei den Status Infiziert zu."," &#xDC;ber die infizierten Dateien ","161281.htm");
Page[76]=new Array("Besonderheiten der Untersuchung von symbolischen Links und festen Links","Kaspersky Endpoint Security ermöglicht die Untersuchung symbolischer und fester Links zu Dateien.","Untersuchung von symbolischen Links","Kaspersky Endpoint Security prüft symbolische Links nur dann, wenn die Datei, auf die der symbolische Link verweist, zum Schutzbereich der Aufgabe zum Echtzeitschutz bzw. zum Untersuchungsbereich der Aufgaben zur Untersuchung auf Befehl gehört.","Wenn die vom symbolischen Link referenzierte Datei nicht in den Schutzbereich oder Untersuchungsbereich der Aufgabe fällt, führt das Programm keine Untersuchung dieser Datei durch. Sollte die Datei jedoch bösartigen Code enthalten, ist die Sicherheit des Computers gefährdet.","Untersuchung von festen Links","Wenn Kaspersky Endpoint Security eine Datei verarbeitet, die mehrere feste Links enthält, wählt das Programm die Aktion je nach der festgelegten Aktion mit den Objekten aus:","Wenn die Aktion Empfohlene Aktion ausführen ausgewählt wurde, wählt Kaspersky Endpoint Security die Aktion mit dem Objekt automatisch auf Basis von Informationen zum Risikowert der in der Datei gefundenen Bedrohung und zur Möglichkeiten seiner Desinfektion aus und wendet sie an.Wenn die Aktion Entfernen ausgewählt wurde, löscht Kaspersky Endpoint Security den zu verarbeitenden festen Link.  Die übrigen festen Links zu dieser Datei werden nicht verarbeitet.Wenn die Aktion Desinfizieren ausgewählt wurde, desinfiziert Kaspersky Endpoint Security die Quelldatei. Wenn keine Desinfektion möglich ist, löscht das Programm den festen Link und erstellt stattdessen eine Kopie der Quelldatei mit dem Namen des entfernten festen Links.Wenn Sie die Datei mit dem festen Link aus dem Speicher wiederherstellen, erstellt Kaspersky Endpoint Security eine Kopie der Quelldatei mit dem Namen des festen Links, der in den Speicher verschoben wurde. Verknüpfungen mit den anderen harten Links zur Quelldatei werden nicht wiederhergestellt."," Besonderheiten der Untersuchung von symbolischen Links und festen Links ","161283.htm");
Page[77]=new Array("Einstellungen der Aufgabe zum Echtzeitschutz","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zum Echtzeitschutz festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","ScanArchived","Aktiviert bzw. deaktiviert die Untersuchung von Archiven (einschließlich selbstentpackender sfx-Archive). Kaspersky Endpoint Security erkennt Bedrohungen in Archiven, aber desinfiziert sie nicht. Die folgenden Archivtypen werden unterstützt: .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Mögliche Werte:","Yes – Archive untersuchen.","No – Archive nicht untersuchen.","Standardwert: No.","ScanSfxArchived","Aktiviert bzw. deaktiviert nur die Untersuchung von selbstentpackenden Archiven (Archive, zu deren Bestandteilen ein ausführbares Dekompressionsmodul gehört).","Mögliche Werte:","Yes – Selbstentpackende Archive untersuchen.","No – Selbstentpackende Archive nicht untersuchen.","Standardwert: No.","ScanMailBases","Aktiviert bzw. deaktiviert die Untersuchung von E-Mail-Datenbanken von Microsoft Outlook®, Outlook Express, The Bat! und anderer Mail-Clients.","Mögliche Werte:","Yes – Dateien von E-Mail-Datenbanken untersuchen.","No – Dateien von E-Mail-Datenbanken nicht untersuchen.","Standardwert: No","ScanPlainMail","Aktiviert bzw.deaktiviert die Untersuchung von E-Mail-Nachrichten im Textformat.","Mögliche Werte:","Yes – E-Mail-Nachrichten im Textformat untersuchen.","No – E-Mail-Nachrichten im Textformat nicht untersuchen.","Standardwert: No","SizeLimit","Legt die maximale Größe eines zu untersuchenden Objekts (in Megabyte) fest. Wenn die Größe des zu untersuchenden Objekts den angegebenen Wert übersteigt, überspringt Kaspersky Endpoint Security das Objekt.","Diese Einstellung wird zusammen mit der Einstellung UseSizeLimit verwendet.","Mögliche Werte:","0 – 999.999.","0 – Kaspersky Endpoint Security untersucht Objekte beliebiger Größe","Standardwert: 0.","TimeLimit","Legt die maximale Untersuchungsdauer (in Sekunden) für ein Objekt fest. Kaspersky Endpoint Security stellt die Untersuchung eines Objekts ein, wenn sie länger dauert als durch diese Einstellung festgelegt.","Diese Einstellung wird zusammen mit der Einstellung UseTimeLimit verwendet.","Mögliche Werte:","0 – 9999.","0 – die Untersuchungsdauer für Objekte ist nicht begrenzt.","Standardwert: 60.","FirstAction","Auswahl der ersten von Kaspersky Endpoint Security ausgeführten Aktion für infizierte Objekte","In der Aufgabe zum Echtzeitschutz sperrt Kaspersky Endpoint Security den Zugriff auf das Objekt für das Programm, das auf das Objekt zugegriffen hat, bevor die von Ihnen gewählte Aktion ausgeführt wird.","Mögliche Werte:","Cure (desinfizieren) – Kaspersky Endpoint Security versucht, ein Objekt zu desinfizieren und speichert eine Kopie davon im Speicher. Wenn die Desinfektion fehlschlägt (beispielsweise, weil der Typ des Objekts oder der Typ der Bedrohung im Objekt nicht desinfiziert werden kann), lässt Kaspersky Endpoint Security das Objekt unverändert. Wenn die erste Aktion auf Cure festgelegt ist, wird empfohlen, die zweite Aktion mithilfe der Einstellung SecondAction anzugeben.","Remove – Kaspersky Endpoint Security entfernt das infizierte Objekt, nachdem eine Backup-Kopie davon erstellt wurde.","Recommended (empfohlene Aktion ausführen) – Kaspersky Endpoint Security wählt automatisch eine Aktion für das Objekt und führt sie aus, wobei Informationen zu der im Objekt gefundenen Bedrohung berücksichtigt werden. Beispielsweise löscht Kaspersky Endpoint Security Trojaner sofort, da sie andere Dateien nicht infizieren und deshalb keine Desinfektion erfordern.","Block – Kaspersky Endpoint Security blockiert den Zugriff auf das infizierte Objekt. Informationen über das infizierte Objekt werden im Protokoll gespeichert.","Standardwert: Recommended.","SecondAction","Auswahl der zweiten von Kaspersky Endpoint Security ausgeführten Aktion für infizierte Objekte. Kaspersky Endpoint Security führt die zweite Aktion aus, wenn die Ausführung der ersten Aktion misslingt.","Die Werte der Einstellung SecondAction sind dieselben wie die Werte der Einstellung FirstAction.","Wenn als erste Aktion Block oder Remove ausgewählt ist, muss keine zweite Aktion angegeben werden. In allen anderen Fällen wird empfohlen, zwei Aktionen anzugeben. Wenn Sie keine zweite Aktion angegeben haben, übernimmt Kaspersky Endpoint Security Block als zweite Aktion.","Standardwert: Block.","UseExcludeMasks","Aktiviert bzw. deaktiviert mithilfe der Einstellung ExcludeMasks die Ausnahme von Objekten von der Untersuchung.","Mögliche Werte:","Yes – Unter ExcludeMasks definierte Objekte ausschließen.","No – Unter ExcludeMasks definierte Objekte nicht ausschließen.","Standardwert: No","ExcludeMasks","Schließt Objekte nach Name oder Maske von der Untersuchung aus. Mit dieser Einstellung können Sie eine einzelne Datei anhand des Namens oder mehrere Dateien anhand von Masken im Format der Befehlsschnittstelle aus dem angegebenen Untersuchungsbereich ausschließen.","Der Standardwert ist nicht angegeben.","Beispiel:","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Aktiviert bzw. deaktiviert die Ausnahme von Objekten mit Bedrohungen, die durch die Einstellung ExcludeThreats festgelegt sind, von der Untersuchung.","Mögliche Werte:","Yes – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, von der Untersuchung ausschließen.","No – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, nicht von der Untersuchung ausschließen.","Standardwert: No","ExcludeThreats","Schließt Objekte nach dem Namen der in den Objekten gefundenen Bedrohungen von der Untersuchung aus. Bevor Sie die Werte dieser Einstellung festlegen, stellen Sie sicher, dass die Einstellung UseExcludeThreats aktiviert ist.","Um ein Objekt von der Untersuchung auszuschließen, geben Sie den vollständigen Namen der Bedrohung an, die im Objekt gefunden wurde, d. h. die Ergebniszeile von Kaspersky Endpoint Security, die angibt, dass ein Objekt infiziert ist.","Sie können beispielsweise ein Tool zum Sammeln von Informationen über Ihr Netzwerk verwenden. Damit es von Kaspersky Endpoint Security nicht blockiert wird, fügen Sie den vollständigen Namen der darin enthaltenen Bedrohung zur Liste der Bedrohungen hinzu, die von der Untersuchung ausgenommen sind.","Sie finden den vollständigen Namen der im Objekt gefundenen Bedrohung im Protokoll von Kaspersky Endpoint Security. Außerdem finden Sie den vollständigen Namen der Bedrohung auf der Website der Viren-Enzyklopädie (). Um den Namen einer Bedrohung zu finden, geben Sie im Feld „Suchen“ den Programmnamen ein.","Beim Wert der Einstellung muss die Groß- und Kleinschreibung beachtet werden.","Der Standardwert ist nicht angegeben.","Beispiel:","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über untersuchte Objekte, die Kaspersky Endpoint Security als nicht infiziert erkannt hat.","Sie können diese Einstellung aktivieren, um beispielsweise sicherzustellen, dass ein bestimmtes Objekt von Kaspersky Endpoint Security untersucht wurde.","Mögliche Werte:","Yes – Informationen zu nicht infizierten Objekten im Protokoll speichern.","No – Informationen zu nicht infizierten Objekten nicht im Protokoll speichern.","Standardwert: No","ReportPackedObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über untersuchte Objekte, die Bestandteil zusammengesetzter Objekte sind.","Sie können diese Einstellung aktivieren, um beispielsweise sicherzustellen, dass ein bestimmtes, zu einem Archiv gehörendes Objekt von Kaspersky Endpoint Security untersucht wurde.","Mögliche Werte:","Yes – Informationen über die Untersuchung von Objekten, die zu einem Archiv gehören, im Protokoll speichern.","No – Informationen über die Untersuchung von Objekten, die zu einem Archiv gehören, nicht im Protokoll speichern.","Standardwert: No","ReportUnprocessedObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen zu nicht untersuchten Objekten.","Mögliche Werte:","Yes – Informationen zu nicht untersuchten Objekten im Protokoll speichern.","No – Informationen zu nicht untersuchten Objekten nicht im Protokoll speichern.","Standardwert: No","UseAnalyzer","Aktiviert bzw. deaktiviert die heuristische Analyse.","Mithilfe der heuristischen Analyse kann das Programm neue Bedrohungen bereits erkennen, bevor sie den Virenanalysten bekannt sind. ","Mögliche Werte:","Yes – Heuristische Analyse aktivieren.","No – Heuristische Analyse deaktivieren.","Standardwert: Yes.","HeuristicLevel","Ebene der heuristischen Analyse","Sie können die Ebene der heuristischen Analyse festlegen. Die Ebene der heuristischen Analyse regelt das Verhältnis zwischen der Gründlichkeit der Suche nach Bedrohungen, der Belastung der Betriebssystemressourcen und der Untersuchungsdauer. Je höher die festgelegte Ebene der heuristischen Analyse, desto mehr Ressourcen verbraucht die Untersuchung und desto länger dauert sie.","Mögliche Werte:","Light – am wenigsten gründliche Untersuchung mit minimaler Belastung des Systems.","Medium – mittlere Ebene der heuristischen Analyse mit ausgeglichener Belastung des Betriebssystems","Deep – gründlichste Untersuchung mit maximaler Belastung des Betriebssystems","Recommended – empfohlener Wert.","Standardwert: Recommended.","UseIChecker","Aktiviert bzw deaktiviert die Verwendung der iChecker-Technologie.","Mögliche Werte:","Yes – Nutzung der iChecker-Technologie aktivieren.","No – Nutzung der iChecker-Technologie deaktivieren.","Standardwert: Yes.","ScanByAccessType","Mithilfe dieser Einstellung können Sie den Modus des Echtzeitschutzes festlegen. Die Einstellung ScanByAccessType wird nur in den Aufgaben zum Echtzeitschutz verwendet.","Mögliche Werte:","SmartCheck – die Datei wird beim Öffnen und erneut beim Schließen untersucht, falls sie geändert wurde. Wenn ein Prozess während seiner Ausführung in einem bestimmten Zeitraum mehrmals auf die Datei zugreift und diese verändert, wird diese Datei erst beim letzten Versuch des Prozesses, die Datei zu schließen, untersucht.","OpenAndModify – die Datei wird beim Öffnen und erneut beim Schließen untersucht, falls sie geändert wurde.","Open – die Datei wird beim Öffnen zum Lesen sowie beim Ausführen oder Ändern untersucht.","Standardwert: SmartCheck.","Der Abschnitt [ScanScope.item_#] enthält folgende Einstellungen:","AreaDesc","Beschreibung des Untersuchungsbereichs, der erweiterte Informationen über den Untersuchungsbereich enthält. Die maximale Länge einer Zeichenfolge, die mit dieser Einstellung angegeben werden kann, beträgt 4096 Zeichen.","Standardwert: All objects.","Beispiel:","AreaDesc=\"Mail-Datenbanken untersuchen\"","UseScanArea","Diese Einstellung aktiviert bzw. deaktiviert die Untersuchung des angegebenen Bereichs Um die Aufgabe auszuführen, müssen Sie zumindest einen zu untersuchenden Bereich angeben.","Mögliche Werte:","Yes – Angegebenen Bereich untersuchen.","No – Angegebenen Bereich nicht untersuchen.","Standardwert: Yes.","AreaMask","Mithilfe dieser Einstellung können Sie den Untersuchungsbereich einschränken.","Kaspersky Endpoint Security untersucht im Untersuchungsbereich nur die Dateien, die mithilfe von Masken im Format der Befehlsschnittstelle angegeben sind.","Wenn die Einstellung nicht festgelegt ist, untersucht Kaspersky Endpoint Security alle Objekte im Untersuchungsbereich. Sie können für diese Einstellung mehrere Werte angeben.","Standardwert: * (alle Objekte untersuchen)","Beispiel:","AreaMask=*doc","Pfad","Mithilfe dieser Einstellung können Sie den Pfad der zu untersuchenden Objekte angeben.","Der Wert der Einstellung Path besteht aus zwei Elementen: <Typ des Dateisystems>:<Zugriffsprotokoll>. Er kann ferner den Pfad des Verzeichnisses im lokalen Dateisystem enthalten.","Mögliche Werte:","<Pfad zum lokalen Verzeichnis> – Objekte im angegebenen Verzeichnis untersuchen.","Shared:NFS – Ressourcen des Computerdateisystems untersuchen, auf die über das NFS-Protokoll zugegriffen wird.","Shared:SMB – Ressourcen des Computerdateisystems untersuchen, auf die über das SMB-Protokoll zugegriffen wird.","AllRemoteMounted – alle Remote-Verzeichnisse untersuchen, die auf dem Computer über SMB- oder NFS-Protokolle montiert sind.","AllShared – Ressourcen des Computerdateisystems untersuchen, auf die über das SMB- und NFS-Protokoll zugegriffen wird.","Der Abschnitt [ExcludedFromScanScope.item_#] enthält folgende Einstellungen:","AreaDesc","Beschreibung des von der Untersuchung ausgeschlossenen Bereichs. Enthält erweiterte Informationen über den Ausschlussbereich.","Der Standardwert ist nicht angegeben.","Beispiel:","AreaDesc=\"Ausschluss von geteilten SAMBA\"","UseScanArea","Diese Einstellung aktiviert bzw. deaktiviert die Untersuchung des angegebenen Bereichs.","Mögliche Werte:","Yes – angegebenen Bereich ausschließen.","No – angegebenen Bereich nicht ausschließen.","Standardwert: Yes.","Pfad","Mithilfe dieser Einstellung können Sie den Pfad der Objekte angeben, die von der Untersuchung ausgeschlossen werden sollen.","Der Wert der Einstellung Path besteht aus zwei Elementen: <Typ des Dateisystems>:<Zugriffsprotokoll>. Er kann ferner den Pfad des Verzeichnisses im lokalen Dateisystem enthalten.","Mögliche Werte:","<Pfad zum lokalen Verzeichnis> – Objekte im angegebenen Verzeichnis aus der Untersuchung ausschließen.","Shared:NFS – Ressourcen des Computerdateisystems, auf die über das NFS-Protokoll zugegriffen wird, von der Untersuchung ausschließen.","Shared:SMB – Ressourcen des Computerdateisystems, auf die über das Samba-Protokoll zugegriffen wird, von der Untersuchung ausschließen.","AllRemoteMounted – Alle Remote-Verzeichnisse, die auf dem Computer über SMB- oder NFS-Protokolle montiert sind, von der Untersuchung ausschließen.","AllShared – Ressourcen des Computerdateisystems, auf die über das SMB- und NFS-Protokoll zugegriffen wird, ausschließen."," Einstellungen der Aufgabe zum Echtzeitschutz ","161284.htm");
Page[78]=new Array("Globalen Ausnahmebereich festlegen","Sie können einen globalen Ausschlussbereich für die Aufgabe zum Echtzeitschutz angeben. Dateien im globalen Ausschlussbereich werden aus den Echtzeitschutzbereichen ausgenommen.","Um einen globalen Ausschlussbereich erstellen, gehen Sie wie folgt vor:","Speichern Sie die Einstellungen der Aufgabe zum Echtzeitschutz mit folgendem Befehl in der Datei:kesl-control --get-settings <Name der Aufgabe oder Aufgaben-ID> --file <vollständiger Pfad der Konfigurationsdatei>","Fügen Sie [ExcludedFromScanScope.item_#]-Abschnitte zur erstellten Datei hinzu. Jeder [ExcludedFromScanScope.item_#]-Abschnitt beinhaltet folgende Einstellungen:AreaMask – gibt Masken für Dateinamen für Dateien an, die aus dem Schutzbereich ausgeschlossen werden sollen.AreaDesc – legt einen eindeutigen Namen für den Ausschlussbereich fest.Path – gibt den Pfad der Dateien an, die aus dem Schutzbereich ausgeschlossen werden sollen. Importieren Sie die Einstellungen aus der Konfigurationsdatei in die Aufgabe zum Echtzeitschutz mithilfe des folgenden Befehls:kesl-control --set-settings <Name der Aufgabe oder Aufgaben-ID> --file <vollständiger Pfad der Konfigurationsdatei>"," Globalen Ausnahmebereich festlegen ","162099.htm");
Page[79]=new Array("Aufgabe zur Untersuchung auf Befehl (Scan_My_Computer ID:2)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Untersuchung auf Befehl.","In diesem AbschnittÜber die Untersuchung auf BefehlEinstellungen der Aufgabe zur Untersuchung auf Befehl"," Aufgabe zur Untersuchung auf Befehl (Scan_My_Computer ID:2) ","161286.htm");
Page[80]=new Array("Über die Untersuchung auf Befehl","Die Untersuchung auf Befehl ist eine einmalige vollständige oder benutzerdefinierte Untersuchung der Dateien auf dem Computer, die von Kaspersky Endpoint Security ausgeführt wird. Kaspersky Endpoint Security kann gleichzeitig mehrere Aufgaben zur Untersuchung auf Befehl ausführen.","Standardmäßig erstellt Kaspersky Endpoint Security eine vordefinierte Aufgaben zur Untersuchung auf Befehl, nämlich die vollständige Untersuchung. Das Programm untersucht alle Objekte, die sich auf den lokalen Computerlaufwerken befinden, sowie alle montierten und freigegebene Objekte, auf welche der Zugriff gemäß den Protokollen Samba und NFS mit den empfohlenen Sicherheitseinstellungen erfolgt.","Benutzer können benutzerdefinierte Aufgaben zur Untersuchung auf Befehl erstellen.","Kaspersky Endpoint Security erstellt ferner eine vordefinierte Aufgabe zur benutzerdefinierten Untersuchung.","Wenn das Programm während der Ausführung einer Untersuchung auf Befehl über den Watchdog oder manuell von einem Benutzer neu gestartet wurde, wird die Aufgabe unterbrochen. Das Programm protokolliert das Ereignis OnDemandTaskInterrupted."," &#xDC;ber die Untersuchung auf Befehl ","161287.htm");
Page[81]=new Array("Einstellungen der Aufgabe zur Untersuchung auf Befehl","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zur Untersuchung auf Befehl festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","ScanArchived ","Aktiviert bzw. deaktiviert die Untersuchung von Archiven (einschließlich selbstentpackender sfx-Archive). Kaspersky Endpoint Security erkennt Bedrohungen in Archiven, aber desinfiziert sie nicht. Die folgenden Archivtypen werden unterstützt: .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Mögliche Werte:","Yes – Archive untersuchen.","No – Archive nicht untersuchen.","Standardwert: Yes.","ScanSfxArchived","Aktiviert bzw. deaktiviert nur die Untersuchung von selbstentpackenden Archiven (Archive, zu deren Bestandteilen ein ausführbares Dekompressionsmodul gehört).","Mögliche Werte:","Yes – Selbstentpackende Archive untersuchen.","No – Selbstentpackende Archive nicht untersuchen.","Standardwert: Yes.","ScanMailBases","Aktiviert bzw. deaktiviert die Untersuchung von E-Mail-Datenbanken von Microsoft Outlook®, Outlook Express, The Bat! und anderer Mail-Clients.","Mögliche Werte:","Yes – Dateien von E-Mail-Datenbanken untersuchen.","No – Dateien von E-Mail-Datenbanken nicht untersuchen.","Standardwert: No","ScanPlainMail","Aktiviert bzw.deaktiviert die Untersuchung von E-Mail-Nachrichten im Textformat.","Mögliche Werte:","Yes – E-Mail-Nachrichten im Textformat untersuchen.","No – E-Mail-Nachrichten im Textformat nicht untersuchen.","Standardwert: No","UseSizeLimit","Aktiviert bzw. deaktiviert die Verwendung der Einstellung SizeLimit (maximale Größe des zu untersuchenden Objekts).","Mögliche Werte:","Yes – Einstellung SizeLimit übernehmen.","No – Einstellung SizeLimit nicht übernehmen.","Standardwert: No","SizeLimit","Legt die maximale Größe eines zu untersuchenden Objekts (in Megabyte) fest. Wenn die Größe des zu untersuchenden Objekts den angegebenen Wert übersteigt, überspringt Kaspersky Endpoint Security das Objekt.","Diese Einstellung wird zusammen mit der Einstellung UseSizeLimit verwendet.","Mögliche Werte:","0 – 999.999.","0 – Kaspersky Endpoint Security untersucht Objekte beliebiger Größe","Standardwert: 0.","UseTimeLimit","Aktiviert bzw. deaktiviert die Verwendung der Einstellung TimeLimit (maximale Dauer der Untersuchung eines Objekts).","Mögliche Werte:","Yes – Einstellung TimeLimit übernehmen.","No – Einstellung TimeLimit nicht übernehmen.","Standardwert: No.","TimeLimit","Legt die maximale Untersuchungsdauer (in Sekunden) für ein Objekt fest. Kaspersky Endpoint Security stellt die Untersuchung eines Objekts ein, wenn sie länger dauert als durch diese Einstellung festgelegt.","Diese Einstellung wird zusammen mit der Einstellung UseTimeLimit verwendet.","Mögliche Werte:","0 – 9999.","0 – die Untersuchungsdauer für Objekte ist nicht begrenzt.","Standardwert: 0.","FirstAction","Auswahl der ersten von Kaspersky Endpoint Security ausgeführten Aktion für infizierte Objekte","Mögliche Werte:","Cure (desinfizieren) – Kaspersky Endpoint Security versucht, ein Objekt zu desinfizieren und speichert eine Kopie davon im Speicher. Wenn die Desinfektion fehlschlägt (beispielsweise, weil der Typ des Objekts oder der Typ der Bedrohung im Objekt nicht desinfiziert werden kann), lässt Kaspersky Endpoint Security das Objekt unverändert. Wenn die erste Aktion auf Cure festgelegt ist, wird empfohlen, die zweite Aktion mithilfe der Einstellung SecondAction anzugeben.","Remove – Kaspersky Endpoint Security entfernt das infizierte Objekt, nachdem eine Backup-Kopie davon erstellt wurde.","Recommended (empfohlene Aktion ausführen) – Kaspersky Endpoint Security wählt automatisch eine Aktion für das Objekt und führt sie aus, wobei Informationen zu der im Objekt gefundenen Bedrohung berücksichtigt werden. Beispielsweise löscht Kaspersky Endpoint Security Trojaner sofort, da sie andere Dateien nicht infizieren und deshalb keine Desinfektion erfordern.","Skip – Kaspersky Endpoint Security versucht nicht, ein infiziertes Objekt zu desinfizieren oder zu löschen. Informationen über das infizierte Objekt werden im Protokoll gespeichert.","Standardwert: Recommended.","SecondAction","Auswahl der zweiten von Kaspersky Endpoint Security ausgeführten Aktion für infizierte Objekte. Kaspersky Endpoint Security führt die zweite Aktion aus, wenn die Ausführung der ersten Aktion misslingt.","Die Werte der Einstellung SecondAction sind dieselben wie die Werte der Einstellung FirstAction.","Wenn als erste Aktion Skip oder Remove ausgewählt ist, muss keine zweite Aktion angegeben werden. In allen anderen Fällen wird empfohlen, zwei Aktionen anzugeben. Wenn Sie keine zweite Aktion angegeben haben, übernimmt Kaspersky Endpoint Security Überspringen als zweite Aktion.","Standardwert: Skip.","UseExcludeMasks","Aktiviert bzw. deaktiviert mithilfe der Einstellung ExcludeMasks die Ausnahme von Objekten von der Untersuchung.","Mögliche Werte:","Yes – Unter ExcludeMasks definierte Objekte ausschließen.","No – Unter ExcludeMasks definierte Objekte nicht ausschließen.","Standardwert: No","ExcludeMasks","Schließt Objekte nach Name oder Maske von der Untersuchung aus. Mit dieser Einstellung können Sie eine einzelne Datei anhand des Namens oder mehrere Dateien anhand von Masken im Format der Befehlsschnittstelle aus dem angegebenen Untersuchungsbereich ausschließen.","Der Standardwert ist nicht angegeben.","Beispiel:","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Aktiviert bzw. deaktiviert die Ausnahme von Objekten mit Bedrohungen, die durch die Einstellung ExcludeThreats festgelegt sind, von der Untersuchung.","Mögliche Werte:","Yes – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, von der Untersuchung ausschließen.","No – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, nicht von der Untersuchung ausschließen.","Standardwert: No","ExcludeThreats","Schließt Objekte nach dem Namen der in den Objekten gefundenen Bedrohungen von der Untersuchung aus. Bevor Sie die Werte dieser Einstellung festlegen, stellen Sie sicher, dass die Einstellung UseExcludeThreats aktiviert ist.","Um ein Objekt von der Untersuchung auszuschließen, geben Sie den vollständigen Namen der Bedrohung an, die im Objekt gefunden wurde, d. h. die Ergebniszeile von Kaspersky Endpoint Security, die angibt, dass ein Objekt infiziert ist.","Sie können beispielsweise ein Tool zum Sammeln von Informationen über Ihr Netzwerk verwenden. Damit es von Kaspersky Endpoint Security nicht blockiert wird, fügen Sie den vollständigen Namen der darin enthaltenen Bedrohung zur Liste der Bedrohungen hinzu, die von der Untersuchung ausgenommen sind.","Sie finden den vollständigen Namen der im Objekt gefundenen Bedrohung im Protokoll von Kaspersky Endpoint Security. Außerdem finden Sie den vollständigen Namen der Bedrohung auf der Website der Viren-Enzyklopädie (). Um den Namen einer Bedrohung zu finden, geben Sie im Feld „Suchen“ den Programmnamen ein.","Beim Wert der Einstellung muss die Groß- und Kleinschreibung beachtet werden.","Der Standardwert ist nicht angegeben.","Beispiel:","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über untersuchte Objekte, die Kaspersky Endpoint Security als nicht infiziert erkannt hat.","Sie können diese Einstellung aktivieren, um beispielsweise sicherzustellen, dass ein bestimmtes Objekt von Kaspersky Endpoint Security untersucht wurde.","Mögliche Werte:","Yes – Informationen zu nicht infizierten Objekten im Protokoll speichern.","No – Informationen zu nicht infizierten Objekten nicht im Protokoll speichern.","Standardwert: No","ReportPackedObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über untersuchte Objekte, die Bestandteil zusammengesetzter Objekte sind.","Sie können diese Einstellung aktivieren, um beispielsweise sicherzustellen, dass ein bestimmtes, zu einem Archiv gehörendes Objekt von Kaspersky Endpoint Security untersucht wurde.","Mögliche Werte:","Yes – Informationen über die Untersuchung von Objekten, die zu einem Archiv gehören, im Protokoll speichern.","No – Informationen über die Untersuchung von Objekten, die zu einem Archiv gehören, nicht im Protokoll speichern.","Standardwert: No","ReportUnprocessedObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen zu nicht untersuchten Objekten.","Mögliche Werte:","Yes – Informationen zu nicht untersuchten Objekten im Protokoll speichern.","No – Informationen zu nicht untersuchten Objekten nicht im Protokoll speichern.","Standardwert: No","UseAnalyzer","Aktiviert bzw. deaktiviert die heuristische Analyse.","Mithilfe der heuristischen Analyse kann das Programm neue Bedrohungen bereits erkennen, bevor sie den Virenanalysten bekannt sind.","Mögliche Werte:","Yes – Heuristische Analyse aktivieren.","No – Heuristische Analyse deaktivieren.","Standardwert: Yes.","HeuristicLevel","Ebene der heuristischen Analyse","Sie können die Ebene der heuristischen Analyse festlegen. Die Ebene der heuristischen Analyse regelt das Verhältnis zwischen der Gründlichkeit der Suche nach Bedrohungen, der Belastung der Betriebssystemressourcen und der Untersuchungsdauer. Je höher die festgelegte Ebene der heuristischen Analyse, desto mehr Ressourcen verbraucht die Untersuchung und desto länger dauert sie.","Mögliche Werte:","Light – am wenigsten gründliche Untersuchung mit minimaler Belastung des Systems.","Medium – mittlere Ebene der heuristischen Analyse mit ausgeglichener Belastung des Betriebssystems","Deep – gründlichste Untersuchung mit maximaler Belastung des Betriebssystems","Recommended – empfohlener Wert.","Standardwert: Recommended.","UseIChecker","Aktiviert bzw deaktiviert die Verwendung der iChecker-Technologie.","Mögliche Werte:","Yes – Nutzung der iChecker-Technologie aktivieren.","No – Nutzung der iChecker-Technologie deaktivieren.","Standardwert: Yes.","ScanByAccessType","Mithilfe dieser Einstellung können Sie den Modus des Echtzeitschutzes festlegen. Die Einstellung ScanByAccessType wird nur in den Aufgaben zum Echtzeitschutz verwendet.","Mögliche Werte:","SmartCheck – die Datei wird beim Öffnen und erneut beim Schließen untersucht, falls sie geändert wurde. Wenn ein Prozess während seiner Ausführung in einem bestimmten Zeitraum mehrmals auf die Datei zugreift und diese verändert, wird diese Datei erst beim letzten Versuch des Prozesses, die Datei zu schließen, untersucht.","OpenAndModify – die Datei wird beim Öffnen und erneut beim Schließen untersucht, falls sie geändert wurde.","Open – die Datei wird beim Öffnen zum Lesen sowie beim Ausführen oder Ändern untersucht.","Standardwert: SmartCheck.","Der Abschnitt [ScanScope.item_#] enthält folgende Einstellungen:","AreaDesc","Beschreibung des Untersuchungsbereichs, der erweiterte Informationen über den Untersuchungsbereich enthält. Die maximale Länge einer Zeichenfolge, die mit dieser Einstellung angegeben werden kann, beträgt 4096 Zeichen.","Standardwert: All objects.","Beispiel:","AreaDesc=\"Mail-Datenbanken untersuchen\"","UseScanArea","Diese Einstellung aktiviert bzw. deaktiviert die Untersuchung des angegebenen Bereichs Um die Aufgabe auszuführen, müssen Sie zumindest einen zu untersuchenden Bereich angeben.","Mögliche Werte:","Yes – Angegebenen Bereich untersuchen.","No – Angegebenen Bereich nicht untersuchen.","Standardwert: Yes.","AreaMask","Mithilfe dieser Einstellung können Sie den Untersuchungsbereich einschränken.","Kaspersky Endpoint Security untersucht im Untersuchungsbereich nur die Dateien, die mithilfe von Masken im Format der Befehlsschnittstelle angegeben sind.","Wenn die Einstellung nicht festgelegt ist, untersucht Kaspersky Endpoint Security alle Objekte im Untersuchungsbereich. Sie können für diese Einstellung mehrere Werte angeben.","Standardwert: * (alle Objekte untersuchen).","Beispiel:","AreaMask=*doc","Pfad","Mithilfe dieser Einstellung können Sie den Pfad der zu untersuchenden Objekte angeben.","Der Wert der Einstellung Path besteht aus zwei Elementen: <Typ des Dateisystems>:<Zugriffsprotokoll>. Er kann ferner den Pfad des Verzeichnisses im lokalen Dateisystem enthalten.","Mögliche Werte:","<Pfad zum lokalen Verzeichnis> – Objekte im angegebenen Verzeichnis untersuchen.","Shared:NFS – Ressourcen des Computerdateisystems untersuchen, auf die über das NFS-Protokoll zugegriffen wird.","Shared:SMB – Ressourcen des Computerdateisystems untersuchen, auf die über das SMB-Protokoll zugegriffen wird.","AllRemoteMounted – alle Remote-Verzeichnisse untersuchen, die auf dem Computer über SMB- oder NFS-Protokolle montiert sind.","AllShared – Ressourcen des Computerdateisystems untersuchen, auf die über das SMB- und NFS-Protokoll zugegriffen wird.","Der Abschnitt [ExcludedFromScanScope.item_#] enthält folgende Einstellungen:","AreaDesc","Beschreibung des von der Untersuchung ausgeschlossenen Bereichs. Enthält erweiterte Informationen über den Ausschlussbereich.","Der Standardwert ist nicht angegeben.","Beispiel:","AreaDesc=\"Ausschluss von geteilten SAMBA\"","UseScanArea","Diese Einstellung aktiviert bzw. deaktiviert die Untersuchung des angegebenen Bereichs.","Mögliche Werte:","Yes – angegebenen Bereich ausschließen.","No – angegebenen Bereich nicht ausschließen.","Standardwert: Yes.","Pfad","Mithilfe dieser Einstellung können Sie den Pfad der Objekte angeben, die von der Untersuchung ausgeschlossen werden sollen.","Der Wert der Einstellung Path besteht aus zwei Elementen: <Typ des Dateisystems>:<Zugriffsprotokoll>. Er kann ferner den Pfad des Verzeichnisses im lokalen Dateisystem enthalten.","Mögliche Werte:","<Pfad zum lokalen Verzeichnis> – Objekte im angegebenen Verzeichnis aus der Untersuchung ausschließen.","Shared:NFS – Ressourcen des Computerdateisystems, auf die über das NFS-Protokoll zugegriffen wird, von der Untersuchung ausschließen.","Shared:SMB – Ressourcen des Computerdateisystems, auf die über das Samba-Protokoll zugegriffen wird, von der Untersuchung ausschließen.","AllRemoteMounted – Alle Remote-Verzeichnisse, die auf dem Computer über SMB- oder NFS-Protokolle montiert sind, von der Untersuchung ausschließen.","AllShared – Ressourcen des Computerdateisystems, auf die über das SMB- und NFS-Protokoll zugegriffen wird, ausschließen."," Einstellungen der Aufgabe zur Untersuchung auf Befehl ","161288.htm");
Page[82]=new Array("Aufgabe zur benutzerdefinierten Untersuchung (Scan_File ID:3)","Dieser Abschnitt enthält Informationen über die Aufgabe zur benutzerdefinierten Untersuchung.","In diesem AbschnittÜber die Aufgabe zur benutzerdefinierten UntersuchungEinstellungen der Aufgabe zur benutzerdefinierten Untersuchung"," Aufgabe zur benutzerdefinierten Untersuchung (Scan_File ID:3) ","161290.htm");
Page[83]=new Array("Über die Aufgabe zur benutzerdefinierten Untersuchung","Eine benutzerdefinierte Untersuchung verwendet die Einstellungen, die mithilfe des Befehls --scan-file übernommen werden.","Sie können eine Datei oder ein Verzeichnis mithilfe des folgenden Befehls untersuchen:","--scan-file <Pfad>","Das Programm erstellt eine temporäre Aufgabe zur Untersuchung auf Befehl (ODS) mit den Einstellungen aus der Scan_File-Aufgabe. Nach Abschluss der Untersuchung wird die temporäre Aufgabe automatisch gelöscht.","Sie können die Untersuchungseinstellungen für die temporäre Scan_File-Aufgabe aus der Befehlszeile ändern."," &#xDC;ber die Aufgabe zur benutzerdefinierten Untersuchung ","161291.htm");
Page[84]=new Array("Einstellungen der Aufgabe zur benutzerdefinierten Untersuchung","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zur benutzerdefinierten Untersuchung festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","ScanArchived","Aktiviert bzw. deaktiviert die Untersuchung von Archiven (einschließlich selbstentpackender sfx-Archive). Kaspersky Endpoint Security erkennt Bedrohungen in Archiven, desinfiziert sie jedoch nicht. Die folgenden Archivtypen werden unterstützt: .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Mögliche Werte:","Yes – Archive untersuchen.","No – Archive nicht untersuchen.","Standardwert: Yes.","ScanSfxArchived","Aktiviert bzw. deaktiviert nur die Untersuchung von selbstentpackenden Archiven (Archive, zu deren Bestandteilen ein ausführbares Dekompressionsmodul gehört).","Mögliche Werte:","Yes – Selbstentpackende Archive untersuchen.","No – Selbstentpackende Archive nicht untersuchen.","Standardwert: Yes.","ScanMailBases","Aktiviert bzw. deaktiviert die Untersuchung von E-Mail-Datenbanken von Microsoft Outlook®, Outlook Express, The Bat! und anderer Mail-Clients.","Mögliche Werte:","Yes – Dateien von E-Mail-Datenbanken untersuchen.","No – Dateien von E-Mail-Datenbanken nicht untersuchen.","Standardwert: No","ScanPlainMail","Aktiviert bzw.deaktiviert die Untersuchung von E-Mail-Nachrichten im Textformat.","Mögliche Werte:","Yes – E-Mail-Nachrichten im Textformat untersuchen.","No – E-Mail-Nachrichten im Textformat nicht untersuchen.","Standardwert: No","UseSizeLimit","Aktiviert bzw. deaktiviert die Verwendung der Einstellung SizeLimit (maximale Größe des zu untersuchenden Objekts).","Mögliche Werte:","Yes – Einstellung SizeLimit übernehmen.","No – Einstellung SizeLimit nicht übernehmen.","Standardwert: No","SizeLimit","Legt die maximale Größe eines zu untersuchenden Objekts (in Megabyte) fest. Wenn die Größe des zu untersuchenden Objekts den angegebenen Wert übersteigt, überspringt Kaspersky Endpoint Security das Objekt.","Diese Einstellung wird zusammen mit der Einstellung UseSizeLimit verwendet.","Mögliche Werte:","0 – 999.999.","0 – Kaspersky Endpoint Security untersucht Objekte beliebiger Größe","Standardwert: 0.","UseTimeLimit","Aktiviert bzw. deaktiviert die Verwendung der Einstellung TimeLimit (maximale Dauer der Untersuchung eines Objekts).","Mögliche Werte:","Yes – Einstellung TimeLimit übernehmen.","No – Einstellung TimeLimit nicht übernehmen.","Standardwert: No.","TimeLimit","Legt die maximale Untersuchungsdauer (in Sekunden) für ein Objekt fest. Kaspersky Endpoint Security stellt die Untersuchung eines Objekts ein, wenn sie länger dauert als durch diese Einstellung festgelegt.","Diese Einstellung wird zusammen mit der Einstellung UseTimeLimit verwendet.","Mögliche Werte:","0-9999.","0 – die Untersuchungsdauer für Objekte ist nicht begrenzt.","Standardwert: 0.","FirstAction","Auswahl der ersten von Kaspersky Endpoint Security ausgeführten Aktion für infizierte Objekte","Mögliche Werte:","Cure (desinfizieren) – Kaspersky Endpoint Security versucht, ein Objekt zu desinfizieren und speichert eine Kopie davon im Speicher. Wenn die Desinfektion fehlschlägt (beispielsweise, weil der Typ des Objekts oder der Typ der Bedrohung im Objekt nicht desinfiziert werden kann), lässt Kaspersky Endpoint Security das Objekt unverändert. Wenn die erste Aktion auf Cure festgelegt ist, wird empfohlen, die zweite Aktion mithilfe der Einstellung SecondAction anzugeben.","Remove – Kaspersky Endpoint Security entfernt das infizierte Objekt, nachdem eine Backup-Kopie davon erstellt wurde.","Recommended (empfohlene Aktion ausführen) – Kaspersky Endpoint Security wählt automatisch eine Aktion für das Objekt und führt sie aus, wobei Informationen zu der im Objekt gefundenen Bedrohung berücksichtigt werden. Beispielsweise löscht Kaspersky Endpoint Security Trojaner sofort, da sie andere Dateien nicht infizieren und deshalb keine Desinfektion erfordern.","Skip – Kaspersky Endpoint Security versucht nicht, ein infiziertes Objekt zu desinfizieren oder zu löschen. Informationen über das infizierte Objekt werden im Protokoll gespeichert.","Standardwert: Recommended.","SecondAction","Auswahl der zweiten von Kaspersky Endpoint Security ausgeführten Aktion für infizierte Objekte. Kaspersky Endpoint Security führt die zweite Aktion aus, wenn die Ausführung der ersten Aktion misslingt.","Die Werte der Einstellung SecondAction sind dieselben wie die Werte der Einstellung FirstAction.","Wenn als erste Aktion Skip oder Remove ausgewählt ist, muss keine zweite Aktion angegeben werden. In allen anderen Fällen wird empfohlen, zwei Aktionen anzugeben. Wenn Sie keine zweite Aktion angegeben haben, übernimmt Kaspersky Endpoint Security Überspringen als zweite Aktion.","Standardwert: Skip.","UseExcludeMasks","Aktiviert bzw. deaktiviert mithilfe der Einstellung ExcludeMasks die Ausnahme von Objekten von der Untersuchung.","Mögliche Werte:","Yes – Unter ExcludeMasks definierte Objekte ausschließen.","No – Unter ExcludeMasks definierte Objekte nicht ausschließen.","Standardwert: No","ExcludeMasks","Schließt Objekte nach Name oder Maske von der Untersuchung aus. Mit dieser Einstellung können Sie eine einzelne Datei anhand des Namens oder mehrere Dateien anhand von Masken im Format der Befehlsschnittstelle aus dem angegebenen Untersuchungsbereich ausschließen.","Der Standardwert ist nicht angegeben.","Beispiel:","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Aktiviert bzw. deaktiviert die Ausnahme von Objekten mit Bedrohungen, die durch die Einstellung ExcludeThreats festgelegt sind, von der Untersuchung.","Mögliche Werte:","Yes – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, von der Untersuchung ausschließen.","No – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, nicht von der Untersuchung ausschließen.","Standardwert: No","ExcludeThreats","Schließt Objekte nach dem Namen der in den Objekten gefundenen Bedrohungen von der Untersuchung aus. Bevor Sie die Werte dieser Einstellung festlegen, stellen Sie sicher, dass die Einstellung UseExcludeThreats aktiviert ist.","Um ein Objekt von der Untersuchung auszuschließen, geben Sie den vollständigen Namen der Bedrohung an, die im Objekt gefunden wurde, d. h. die Ergebniszeile von Kaspersky Endpoint Security, die angibt, dass ein Objekt infiziert ist.","Sie können beispielsweise ein Tool zum Sammeln von Informationen über Ihr Netzwerk verwenden. Damit es von Kaspersky Endpoint Security nicht blockiert wird, fügen Sie den vollständigen Namen der darin enthaltenen Bedrohung zur Liste der Bedrohungen hinzu, die von der Untersuchung ausgenommen sind.","Sie finden den vollständigen Namen der im Objekt gefundenen Bedrohung im Protokoll von Kaspersky Endpoint Security. Außerdem finden Sie den vollständigen Namen der Bedrohung auf der Website der Viren-Enzyklopädie (). Um den Namen einer Bedrohung zu finden, geben Sie im Feld „Suchen“ den Programmnamen ein.","Beim Wert der Einstellung muss die Groß- und Kleinschreibung beachtet werden.","Der Standardwert ist nicht angegeben.","Beispiel:","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über untersuchte Objekte, die Kaspersky Endpoint Security als nicht infiziert erkannt hat.","Sie können diese Einstellung aktivieren, um beispielsweise sicherzustellen, dass ein bestimmtes Objekt von Kaspersky Endpoint Security untersucht wurde.","Mögliche Werte:","Yes – Informationen zu nicht infizierten Objekten im Protokoll speichern.","No – Informationen zu nicht infizierten Objekten nicht im Protokoll speichern.","Standardwert: No","ReportPackedObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über untersuchte Objekte, die Bestandteil zusammengesetzter Objekte sind.","Sie können diese Einstellung aktivieren, um beispielsweise sicherzustellen, dass ein bestimmtes, zu einem Archiv gehörendes Objekt von Kaspersky Endpoint Security untersucht wurde.","Mögliche Werte:","Yes – Informationen über die Untersuchung von Objekten, die zu einem Archiv gehören, im Protokoll speichern.","No – Informationen über die Untersuchung von Objekten, die zu einem Archiv gehören, nicht im Protokoll speichern.","Standardwert: No","ReportUnprocessedObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen zu nicht untersuchten Objekten.","Mögliche Werte:","Yes – Informationen zu nicht untersuchten Objekten im Protokoll speichern.","No – Informationen zu nicht untersuchten Objekten nicht im Protokoll speichern.","Standardwert: No","UseAnalyzer","Aktiviert bzw. deaktiviert die heuristische Analyse. Mithilfe der heuristischen Analyse kann das Programm neue Bedrohungen bereits erkennen, bevor sie den Virenanalysten bekannt sind. ","Mögliche Werte:","Yes – Heuristische Analyse aktivieren.","No – Heuristische Analyse deaktivieren.","Standardwert: Yes.","HeuristicLevel","Ebene der heuristischen Analyse","Sie können die Ebene der heuristischen Analyse festlegen. Die Ebene der heuristischen Analyse regelt das Verhältnis zwischen der Gründlichkeit der Suche nach Bedrohungen, der Belastung der Betriebssystemressourcen und der Untersuchungsdauer. Je höher die festgelegte Ebene der heuristischen Analyse, desto mehr Ressourcen verbraucht die Untersuchung und desto länger dauert sie.","Mögliche Werte:","Light – am wenigsten gründliche Untersuchung mit minimaler Belastung des Systems.","Medium – mittlere Ebene der heuristischen Analyse mit ausgeglichener Belastung des Betriebssystems","Deep – gründlichste Untersuchung mit maximaler Belastung des Betriebssystems","Recommended – empfohlener Wert.","Standardwert: Recommended.","UseIChecker","Aktiviert bzw deaktiviert die Verwendung der iChecker-Technologie.","Mögliche Werte:","Yes – Nutzung der iChecker-Technologie aktivieren.","No – Nutzung der iChecker-Technologie deaktivieren.","Standardwert: Yes.","ScanByAccessType","Mithilfe dieser Einstellung können Sie den Modus des Echtzeitschutzes festlegen. Die Einstellung ScanByAccessType wird nur in den Aufgaben zum Echtzeitschutz verwendet.","Mögliche Werte:","SmartCheck – die Datei wird beim Öffnen und erneut beim Schließen untersucht, falls sie geändert wurde. Wenn ein Prozess während seiner Ausführung in einem bestimmten Zeitraum mehrmals auf die Datei zugreift und diese verändert, wird diese Datei erst beim letzten Versuch des Prozesses, die Datei zu schließen, untersucht.","OpenAndModify – die Datei wird beim Öffnen und erneut beim Schließen untersucht, falls sie geändert wurde.","Open – die Datei wird beim Öffnen zum Lesen sowie beim Ausführen oder Ändern untersucht.","Standardwert: SmartCheck.","Der Abschnitt [ScanScope.item_#] enthält folgende Einstellungen:","AreaDesc","Beschreibung des Untersuchungsbereichs, der erweiterte Informationen über den Untersuchungsbereich enthält. Die maximale Länge einer Zeichenfolge, die mit dieser Einstellung angegeben werden kann, beträgt 4096 Zeichen.","Standardwert: All objects.","Beispiel:","AreaDesc=\"Mail-Datenbanken untersuchen\"","UseScanArea","Diese Einstellung aktiviert bzw. deaktiviert die Untersuchung des angegebenen Bereichs Um die Aufgabe auszuführen, müssen Sie zumindest einen zu untersuchenden Bereich angeben.","Mögliche Werte:","Yes – Angegebenen Bereich untersuchen.","No – Angegebenen Bereich nicht untersuchen.","Standardwert: Yes.","AreaMask","Mithilfe dieser Einstellung können Sie den Untersuchungsbereich einschränken.","Kaspersky Endpoint Security untersucht im Untersuchungsbereich nur die Dateien, die mithilfe von Masken im Format der Befehlsschnittstelle angegeben sind.","Wenn die Einstellung nicht festgelegt ist, untersucht Kaspersky Endpoint Security alle Objekte im Untersuchungsbereich. Sie können für diese Einstellung mehrere Werte angeben.","Standardwert: * (alle Objekte untersuchen)","Beispiel:","AreaMask=*doc","Pfad","Mithilfe dieser Einstellung können Sie den Pfad der zu untersuchenden Objekte angeben.","Der Wert der Einstellung Path besteht aus zwei Elementen: <Typ des Dateisystems>:<Zugriffsprotokoll>. Er kann ferner den Pfad des Verzeichnisses im lokalen Dateisystem enthalten.","Mögliche Werte:","<Pfad zum lokalen Verzeichnis> – Objekte im angegebenen Verzeichnis untersuchen.","Shared:NFS – Ressourcen des Computerdateisystems untersuchen, auf die über das NFS-Protokoll zugegriffen wird.","Shared:SMB – Ressourcen des Computerdateisystems untersuchen, auf die über das SMB-Protokoll zugegriffen wird.","AllRemoteMounted – alle Remote-Verzeichnisse untersuchen, die auf dem Computer über SMB- oder NFS-Protokolle montiert sind.","AllShared – Ressourcen des Computerdateisystems untersuchen, auf die über das SMB- und NFS-Protokoll zugegriffen wird.","Der Abschnitt [ExcludedFromScanScope.item_#] enthält folgende Einstellungen:","AreaDesc","Beschreibung des von der Untersuchung ausgeschlossenen Bereichs. Enthält erweiterte Informationen über den Ausschlussbereich.","Der Standardwert ist nicht angegeben.","Beispiel:","AreaDesc=\"Ausschluss von geteilten SAMBA\"","UseScanArea","Diese Einstellung aktiviert bzw. deaktiviert die Untersuchung des angegebenen Bereichs.","Mögliche Werte:","Yes – angegebenen Bereich ausschließen.","No – angegebenen Bereich nicht ausschließen.","Standardwert: Yes.","Pfad","Mithilfe dieser Einstellung können Sie den Pfad der Objekte angeben, die von der Untersuchung ausgeschlossen werden sollen.","Der Wert der Einstellung Path besteht aus zwei Elementen: <Typ des Dateisystems>:<Zugriffsprotokoll>. Er kann ferner den Pfad des Verzeichnisses im lokalen Dateisystem enthalten.","Mögliche Werte:","<Pfad zum lokalen Verzeichnis> – Objekte im angegebenen Verzeichnis aus der Untersuchung ausschließen.","Shared:NFS – Ressourcen des Computerdateisystems, auf die über das NFS-Protokoll zugegriffen wird, von der Untersuchung ausschließen.","Shared:SMB – Ressourcen des Computerdateisystems, auf die über das Samba-Protokoll zugegriffen wird, von der Untersuchung ausschließen.","AllRemoteMounted – Alle Remote-Verzeichnisse, die auf dem Computer über SMB- oder NFS-Protokolle montiert sind, von der Untersuchung ausschließen.","AllShared – Ressourcen des Computerdateisystems, auf die über das SMB- und NFS-Protokoll zugegriffen wird, ausschließen."," Einstellungen der Aufgabe zur benutzerdefinierten Untersuchung ","161292.htm");
Page[85]=new Array("Aufgabe zur Untersuchung des Bootsektors (Boot_Scan ID:4)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Untersuchung des Bootsektors.","In diesem AbschnittÜber die Aufgabe zur Untersuchung des BootsektorsEinstellungen der Aufgabe zur Untersuchung des Bootsektors"," Aufgabe zur Untersuchung des Bootsektors (Boot_Scan ID:4) ","161294.htm");
Page[86]=new Array("Über die Aufgabe zur Untersuchung des Bootsektors","Mithilfe der Aufgabe zur Untersuchung des Bootsektors können Sie Bootsektoren untersuchen, die keinen Untersuchungsbereich festgelegt haben."," &#xDC;ber die Aufgabe zur Untersuchung des Bootsektors ","161295.htm");
Page[87]=new Array("Einstellungen der Aufgabe zur Untersuchung des Bootsektors","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zur Untersuchung des Bootsektors festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","UseExcludeMasks ","Aktiviert bzw. deaktiviert mithilfe der Einstellung ExcludeMasks die Ausnahme von Objekten von der Untersuchung.","Mögliche Werte:","Yes – Unter ExcludeMasks definierte Objekte ausschließen.","No – Unter ExcludeMasks definierte Objekte nicht ausschließen.","Standardwert: No","ExcludeMasks","Schließt Objekte nach Name oder Maske von der Untersuchung aus. Mit dieser Einstellung können Sie eine einzelne Datei anhand des Namens oder mehrere Dateien anhand von Masken im Format der Befehlsschnittstelle aus dem angegebenen Untersuchungsbereich ausschließen.","Der Standardwert ist nicht angegeben.","UseExcludeThreats","Aktiviert bzw. deaktiviert die Ausnahme von Objekten mit Bedrohungen, die durch die Einstellung ExcludeThreats festgelegt sind, von der Untersuchung.","Mögliche Werte:","Yes – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, von der Untersuchung ausschließen.","No – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, nicht von der Untersuchung ausschließen.","Standardwert: No.","ExcludeThreats","Schließt Objekte nach dem Namen der in den Objekten gefundenen Bedrohungen von der Untersuchung aus. Bevor Sie die Werte dieser Einstellung festlegen, stellen Sie sicher, dass die Einstellung UseExcludeThreats aktiviert ist.","Um ein Objekt von der Untersuchung auszuschließen, geben Sie den vollständigen Namen der Bedrohung an, die im Objekt gefunden wurde, d. h. die Ergebniszeile von Kaspersky Endpoint Security, die angibt, dass ein Objekt infiziert ist.","Sie können beispielsweise ein Tool zum Sammeln von Informationen über Ihr Netzwerk verwenden. Damit es von Kaspersky Endpoint Security nicht blockiert wird, fügen Sie den vollständigen Namen der darin enthaltenen Bedrohung zur Liste der Bedrohungen hinzu, die von der Untersuchung ausgenommen sind.","Sie finden den vollständigen Namen der im Objekt gefundenen Bedrohung im Protokoll von Kaspersky Endpoint Security. Außerdem finden Sie den vollständigen Namen der Bedrohung auf der Website der Viren-Enzyklopädie (). Um den Namen einer Bedrohung zu finden, geben Sie im Feld „Suchen“ den Programmnamen ein.","Beim Wert der Einstellung muss die Groß- und Kleinschreibung beachtet werden.","Der Standardwert ist nicht angegeben.","ReportCleanObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über untersuchte Objekte, die Kaspersky Endpoint Security als nicht infiziert erkannt hat.","Sie können diese Einstellung aktivieren, um beispielsweise sicherzustellen, dass ein bestimmtes Objekt von Kaspersky Endpoint Security untersucht wurde.","Mögliche Werte:","Yes – Informationen zu nicht infizierten Objekten im Protokoll speichern.","No – Informationen zu nicht infizierten Objekten nicht im Protokoll speichern.","Standardwert: No","ReportUnprocessedObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über Dateien, die aus einem bestimmten Grund nicht verarbeitet wurden.","Mögliche Werte:","Yes – Informationen zu nicht verarbeiteten Objekten im Protokoll speichern. Es wird nicht empfohlen, diese Einstellung für einen längeren Zeitraum auf Yes festzulegen, da durch das Protokollieren einer großen Informationsmenge die Leistung des Programms beeinträchtigt werden könnte.","No – Informationen zu nicht verarbeiteten Objekten nicht im Protokoll speichern.","Standardwert: No","UseAnalyzer","Aktiviert bzw. deaktiviert die heuristische Analyse. Mithilfe der heuristischen Analyse kann das Programm neue Bedrohungen bereits erkennen, bevor sie den Virenanalysten bekannt sind.","Mögliche Werte:","Yes – Heuristische Analyse aktivieren.","No – Heuristische Analyse deaktivieren.","Standardwert: Yes.","HeuristicLevel","Ebene der heuristischen Analyse","Sie können die Ebene der heuristischen Analyse festlegen. Die Ebene der heuristischen Analyse regelt das Verhältnis zwischen der Gründlichkeit der Suche nach Bedrohungen, der Belastung der Betriebssystemressourcen und der Untersuchungsdauer. Je höher die festgelegte Ebene der heuristischen Analyse, desto mehr Ressourcen verbraucht die Untersuchung und desto länger dauert sie.","Mögliche Werte:","Light – am wenigsten gründliche Untersuchung mit minimaler Belastung des Systems.","Medium – mittlere Ebene der heuristischen Analyse mit ausgeglichener Belastung des Betriebssystems.","Deep – gründlichste Untersuchung mit maximaler Belastung des Betriebssystems","Recommended – empfohlener Wert.","Standardwert: Recommended.","Aktion","Auswahl der Aktion, die von Kaspersky Endpoint Security für infizierte Objekte ausgeführt werden soll.","Mögliche Werte:","Cure (desinfizieren) – Kaspersky Endpoint Security versucht, ein Objekt zu desinfizieren und speichert eine Kopie davon im Speicher. Wenn die Desinfektion fehlschlägt (beispielsweise, weil der Typ des Objekts oder der Typ der Bedrohung im Objekt nicht desinfiziert werden kann), lässt Kaspersky Endpoint Security das Objekt unverändert.","Skip – Kaspersky Endpoint Security versucht nicht, ein infiziertes Objekt zu desinfizieren oder zu löschen. Informationen über das infizierte Objekt werden im Protokoll gespeichert.","Standardwert: Cure."," Einstellungen der Aufgabe zur Untersuchung des Bootsektors ","161296.htm");
Page[88]=new Array("Aufgabe zur Untersuchung des Prozessarbeitsspeichers (Memory_Scan ID:5)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Untersuchung des Prozessarbeitsspeichers.","In diesem AbschnittÜber die Aufgabe zur Untersuchung des ProzessarbeitsspeichersEinstellungen der Aufgabe zur Untersuchung des Prozessarbeitsspeichers"," Aufgabe zur Untersuchung des Prozessarbeitsspeichers (Memory_Scan ID:5) ","161297.htm");
Page[89]=new Array("Über die Aufgabe zur Untersuchung des Prozessarbeitsspeichers","Mithilfe der Aufgabe zur Untersuchung des Prozessarbeitsspeichers können Sie den Prozessarbeitsspeicher untersuchen, der keinen Untersuchungsbereich festgelegt hat."," &#xDC;ber die Aufgabe zur Untersuchung des Prozessarbeitsspeichers ","161298.htm");
Page[90]=new Array("Einstellungen der Aufgabe zur Untersuchung des Prozessarbeitsspeichers","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zur Untersuchung des Prozessarbeitsspeichers festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","UseExcludeThreats","Aktiviert bzw. deaktiviert die Ausnahme von Objekten mit Bedrohungen, die durch die Einstellung ExcludeThreats festgelegt sind, von der Untersuchung.","Mögliche Werte:","Yes – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, von der Untersuchung ausschließen.","No – Objekte, die Bedrohungen enthalten, die in der Einstellung ExcludeThreats angegeben sind, nicht von der Untersuchung ausschließen.","Standardwert: No","ExcludeThreats","Schließt Objekte nach dem Namen der in den Objekten gefundenen Bedrohungen von der Untersuchung aus. Bevor Sie die Werte dieser Einstellung festlegen, stellen Sie sicher, dass die Einstellung UseExcludeThreats aktiviert ist.","Um ein Objekt von der Untersuchung auszuschließen, geben Sie den vollständigen Namen der Bedrohung an, die im Objekt gefunden wurde, d. h. die Ergebniszeile von Kaspersky Endpoint Security, die angibt, dass ein Objekt infiziert ist.","Sie können beispielsweise ein Tool zum Sammeln von Informationen über Ihr Netzwerk verwenden. Damit es von Kaspersky Endpoint Security nicht blockiert wird, fügen Sie den vollständigen Namen der darin enthaltenen Bedrohung zur Liste der Bedrohungen hinzu, die von der Untersuchung ausgenommen sind.","Sie finden den vollständigen Namen der im Objekt gefundenen Bedrohung im Protokoll von Kaspersky Endpoint Security. Außerdem finden Sie den vollständigen Namen der Bedrohung auf der Website der Viren-Enzyklopädie (). Um den Namen einer Bedrohung zu finden, geben Sie im Feld „Suchen“ den Programmnamen ein.","Beim Wert der Einstellung muss die Groß- und Kleinschreibung beachtet werden.","Der Standardwert ist nicht angegeben.","ReportCleanObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über untersuchte Objekte, die Kaspersky Endpoint Security als nicht infiziert erkannt hat.","Sie können diese Einstellung aktivieren, um beispielsweise sicherzustellen, dass ein bestimmtes Objekt von Kaspersky Endpoint Security untersucht wurde.","Mögliche Werte:","Yes – Informationen zu nicht infizierten Objekten im Protokoll speichern.","No – Informationen zu nicht infizierten Objekten nicht im Protokoll speichern.","Standardwert: No","ReportUnprocessedObjects","Aktiviert bzw. deaktiviert das Protokollieren von Informationen über Dateien, die aus einem bestimmten Grund nicht verarbeitet wurden.","Mögliche Werte:","Yes – Informationen zu nicht verarbeiteten Objekten im Protokoll speichern. Es wird nicht empfohlen, diese Einstellung für einen längeren Zeitraum auf Yes festzulegen, da durch das Protokollieren einer großen Informationsmenge die Leistung des Programms beeinträchtigt werden könnte.","No – Informationen zu nicht verarbeiteten Objekten nicht im Protokoll speichern.","Standardwert: No","Aktion","Auswahl der Aktion, die von Kaspersky Endpoint Security für infizierte Objekte ausgeführt werden soll.","Mögliche Werte:","Cure (desinfizieren) – Kaspersky Endpoint Security versucht, ein Objekt zu desinfizieren und speichert eine Kopie davon im Speicher. Wenn die Desinfektion fehlschlägt (beispielsweise, weil der Typ des Objekts oder der Typ der Bedrohung im Objekt nicht desinfiziert werden kann), lässt Kaspersky Endpoint Security das Objekt unverändert.","Skip – Kaspersky Endpoint Security versucht nicht, ein infiziertes Objekt zu desinfizieren oder zu löschen. Informationen über das infizierte Objekt werden im Protokoll gespeichert.","Standardwert: Cure."," Einstellungen der Aufgabe zur Untersuchung des Prozessarbeitsspeichers ","161299.htm");
Page[91]=new Array("Update-Aufgabe (Update-ID:6)","Dieser Abschnitt enthält Informationen über die Update-Aufgabe.","In diesem AbschnittUpdate der Datenbanken und Programm-ModuleÜber Update-QuellenEinstellungen der Update-AufgabeProgramm-Update manuell installieren"," Update-Aufgabe (Update-ID:6) ","161300.htm");
Page[92]=new Array("Update der Datenbanken und Programm-Module","Ein Update der Datenbanken und Programm-Module von Kaspersky Endpoint Security gewährleistet, dass der Schutz Ihres Computers auf dem neuesten Stand ist. Weltweit tauchen praktisch täglich neue Viren und andere Typen von Schadsoftware auf. Die Datenbanken von Kaspersky Endpoint Security enthalten Informationen über Bedrohungen und Möglichkeiten für deren Neutralisierung. Um Bedrohungen rasch erkennen zu können, müssen Sie die Datenbanken und Programm-Module regelmäßig aktualisieren.","Für regelmäßige Updates ist eine gültige Lizenz erforderlich. Wenn Sie über keine gültige Lizenz verfügen, können Sie nur ein Mal ein Update durchführen.","Die wichtigste Update-Quelle für Kaspersky Endpoint Security sind die Kaspersky-Lab-Update-Server.","Ihr Computer muss mit dem Internet verbunden sein, um das Updatepaket erfolgreich von den Kaspersky-Lab-Update-Servern herunterladen zu können. Standardmäßig werden die Internetverbindungseinstellungen automatisch bestimmt. Wenn Sie einen Proxyserver verwenden, müssen Sie die Verbindungseinstellungen anpassen.","Während der Durchführung eines Updates werden die folgenden Objekte heruntergeladen und auf Ihrem Computer installiert.","Datenbanken von .Kaspersky Endpoint Security Während der Installation lädt Kaspersky Endpoint Security die aktuelle Datenbanken von einem der Kaspersky-Lab-HTTP-Update-Server herunter. Wenn für das Update die vordefinierte Aufgabe mit den Standardeinstellungen (ID=6) verwendet wird, aktualisiert Kaspersky Endpoint Security die Datenbanken einmal alle 60 Minuten. Sie können die Einstellungen der vordefinierten Aufgabe zum Datenbanken-Update und Update der Programm-Module ändern und benutzerdefinierte Update-Aufgaben erstellen.Kaspersky Endpoint Security verwendet die zuvor installierte Datenbankenversion, wenn der Download der Datenbanken-Updates unterbrochen wird oder mit einem Fehler endet.","Standardmäßig protokolliert das Programm das Ereignis Die Datenbanken sind veraltet (AVBasesAreOutOfDate), wenn die letzten installierten Datenbanken-Updates vor mehr als einem Tag, aber weniger als sieben Tagen auf dem Kaspersky Lab-Server veröffentlicht wurden. Falls die Datenbanken sieben Tage lang nicht aktualisiert wurden, protokolliert Kaspersky Endpoint Security das Ereignis Datenbanken sind stark veraltet (AVBasesAreTotallyOutOfDate). Die Datenbank ist aktuell, wenn sie vor weniger als 24 Stunden herunterladen wurde.","Programm-Updates. Zusätzlich zu den Datenbanken von Kaspersky Endpoint Security können Sie auch das Programm selbst aktualisieren. Ein Programm-Update behebt Schwachstellen in Kaspersky Endpoint Security oder verbessert die vorhandenen Funktionen.Das Programm-Update kann unabhängig vom Status des Programms (gestartet, gestoppt, durch eine Richtlinie von Kaspersky Security Center verwaltet) und dem Update-Zeitplan installiert werden.","Während des laufenden Programm-Updates setzt Kaspersky Endpoint Security den Schutz Ihres Computers fort.","Kaspersky Endpoint Security migriert die Programmeinstellungen und sogar das Protokoll automatisch. Die Einstellungen der vorherigen Programmversion werden beim Start der aktualisierten Version exportiert.","Sollte Kaspersky Endpoint Security nach der Installation des Programm-Updates nicht ordnungsgemäß funktionieren, führt das Programm automatisch ein Rollback auf die vorherige Version durch. Eine Nachricht über das  Rollback eines Datenbanken-Updates wird angezeigt. Es wird empfohlen, Kontakt mit dem Technischen Support von Kaspersky Lab aufzunehmen.","Während des Updates werden das Programm und die Datenbanken auf Ihrem Computer mit der aktuellen Version in der Update-Quelle verglichen. Wenn Ihre aktuellen Datenbanken und Programm-Module von den jeweiligen neuesten Versionen abweichen, wird der fehlende Teil der Updates auf Ihrem Computer installiert.","Wenn die Datenbanken stark veraltet sind, kann das Updatepaket groß sein, was zu zusätzlichem Internet-Datenverkehr (bis zu mehreren MB) führen kann."," Update der Datenbanken und Programm-Module ","161301.htm");
Page[93]=new Array("Über Update-Quellen","Eine Update-Quelle ist eine Ressource, die Datenbanken-Updates und Updates der Programm-Module für Kaspersky Endpoint Security enthält. Als Update-Quelle können FTP- oder HTTP-Server (beispielsweise Kaspersky Security Center, Kaspersky-Lab-Update-Server), lokale oder Netzwerkverzeichnisse agieren, die von den Benutzern vorinstalliert wurden.","In der vordefinierten Update-Aufgabe sind als Update-Quelle standardmäßig die Kaspersky-Lab-Update-Server ausgewählt. Auf den Update-Servern werden Datenbanken-Updates und Updates der Programm-Module für viele Programme von Kaspersky Lab veröffentlicht. Die Updates werden über HTTP-Protokolle heruntergeladen.","Wenn Sie aus irgendeinem Grund nicht die Kaspersky-Lab-Update-Server als Update-Quelle verwenden können, können Sie die Updates aus einer benutzerdefinierten Update-Quelle, beispielsweise einem lokalen oder Netzwerkverzeichnis (SMB/NFS) bzw. einen FTP-Server, das vom Benutzer montiert wurde, oder einem von Ihnen angegeben FTP- oder HTTP-Server abrufen. Sie können eine benutzerdefinierte Update-Quelle in der Konfigurationsdatei der Update-Aufgabe angeben."," &#xDC;ber Update-Quellen ","161302.htm");
Page[94]=new Array("Einstellungen der Update-Aufgabe","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Update-Aufgabe festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","SourceType","Mit dieser Einstellung bestimmen Sie die Quelle, aus der Kaspersky Endpoint Security Updates abruft.","Mögliche Werte:","KLServers – Kaspersky Endpoint Security ruft Updates von einem der Kaspersky-Lab-Update-Server ab. Die Updates werden über das HTTP-Protokoll heruntergeladen.","SCServer – Kaspersky Endpoint Security lädt die Updates von einem im lokalen Netzwerk installierten Administrationsserver für Kaspersky Security Center auf den geschützten Computer herunter. Sie können diese Update-Quelle auswählen, wenn Sie Kaspersky Security Center zur zentralisierten Verwaltung des Antiviren-Schutzes in Ihrem Unternehmen verwenden.","Custom – Kaspersky Endpoint Security lädt Updates von der im Abschnitt [CommonSettings:CustomSources] angegebenen benutzerdefinierten Quelle herunter. Sie können Verzeichnisse auf FTP- oder HTTP-Servern und Verzeichnisse auf einem beliebigen montierten Gerät des geschützten Computers angeben, einschließlich der Verzeichnisse auf Remote-Computern, die über Samba- oder NFS-Protokolle montiert sind.","Standardwert: KLServers.","UseKLServersWhenUnavailable","Mit dieser Einstellung legen Sie fest, ob Kaspersky Endpoint Security auf Kaspersky-Lab-Update-Server zugreift, wenn keine der benutzerdefinierten Quellen verfügbar ist.","Mögliche Werte:","Yes – Kaspersky Endpoint Security greift auf Kaspersky-Lab-Update-Server zu, wenn keine benutzerdefinierten Updatequellen verfügbar sind.","No – Kaspersky Endpoint Security greift nicht auf Kaspersky-Lab-Update-Server zu, wenn keine benutzerdefinierten Updatequellen verfügbar sind.","Standardwert: Yes.","IgnoreProxySettingsForKLServers","Mit dieser Einstellung legen Sie fest, ob ein Proxyserver für die Verbindung mit den Kaspersky-Lab-Update-Servern verwendet wird.","Mögliche Werte:","Yes – Kaspersky Endpoint Security verwendet für die Verbindung mit den Kaspersky-Lab-Update-Servern keinen Proxyserver.","No – Kaspersky Endpoint Security verwendet für die Verbindung mit den Kaspersky-Lab-Update-Servern einen Proxyserver.","Standardwert: No","IgnoreProxySettingsForCustomSources","Mit dieser Einstellung legen Sie fest, ob ein Proxyserver für die Verbindung mit benutzerdefinierten Update-Quellen verwendet wird. Sie müssen diese Einstellung aktivieren, wenn die Verbindung zu einem der benutzerdefinierten FTP- oder HTTP-Update-Server den Zugriff auf einen Proxyserver erfordert.","Mögliche Werte:","Yes – Kaspersky Endpoint Security verwendet für die Verbindung mit benutzerdefinierten Update-Quellen keinen Proxyserver.","No – Kaspersky Endpoint Security verwendet für die Verbindung mit benutzerdefinierten Updatequellen einen Proxyserver.","Standardwert: No","ApplicationUpdateMode","Legt den Modus für Download und Installation von Programm-Updates fest.","Mögliche Werte:","Disable—Keine Programm-Updates herunterladen und installieren","DownloadOnly—Programm-Updates herunterladen aber nicht installieren","DownloadAndInstall—Programm-Updates automatisch herunterladen und installieren","Standardwert: DownloadOnly.","ConnectionTimeout","Mithilfe dieser Einstellung können Sie die Wartezeit (in Sekunden) auf eine Antwort von der Update-Quelle – FTP- oder HTTP-Server – bei der Verbindungsherstellung angeben. Wenn im angegebenen Zeitraum keine Antwort von der Update-Quelle eingeht, greift Kaspersky Endpoint Security auf eine andere angegebene Update-Quelle zu.","Sie können nur ganze Zahlen zwischen 0 und 120 angeben.","Standardwert: 10.","Der Abschnitt [CustomSources.item_#] enthält die folgenden Einstellungen:","URL","In diesem Abschnitt können Sie die Adresse der benutzerdefinierten Update-Quelle im lokalen Netzwerk oder im Internet festlegen.","Der Standardwert ist nicht angegeben.","Beispiel:","URL=http://example.com/bases/ – Adresse des HTTP-Servers, auf dem sich das Verzeichnis mit den Updates befindet.","URL=/home/bases/ – Verzeichnis auf dem geschützten Computer mit den Programm-Datenbanken.","Enabled","Mit dieser Einstellung können Sie die Verwendung der in der Einstellung URL angegebenen Update-Quelle aktivieren bzw. deaktivieren. Die Verwendung von zumindest einer Update-Quelle muss aktiviert werden, bevor die Aufgabe ausgeführt werden kann.","Mögliche Werte:","Yes – Kaspersky Endpoint Security verwendet die Update-Quelle.","No – Kaspersky Endpoint Security verwendet die Updatequelle nicht.","Der Standardwert ist nicht angegeben.","Beispiel:","Enabled=yes"," Einstellungen der Update-Aufgabe ","161303.htm");
Page[95]=new Array("Programm-Update manuell installieren","Sie können das Programm-Update manuell aus der Befehlszeile installieren. Auf Ihrem Computer muss Kaspersky Endpoint Security installiert sein, damit Sie das Programm-Update installieren können.","Um ein Update für Kaspersky Endpoint Security aus einem RPM-Paket zu installieren, führen Sie den folgenden Befehl aus:","# rpm –U <Name des RPM-Pakets>.rpm","Um ein Update für Kaspersky Endpoint Security aus einem DEB-Paket zu installieren, führen Sie den folgenden Befehl aus:","# dpkg -i <Name des DEB-Pakets>.deb","Der Update-Vorgang für das Programm wird gestartet.","Möglicherweise ist ein Neustart des Programms oder des Betriebssystems erforderlich. Eine entsprechende Meldung wird angezeigt. Nach dem Neustart des Programms bzw. Betriebssystems wird die aktualisierte Version von Kaspersky Endpoint Security gestartet.","Nach dem Programm-Updates müssen Sie möglicherweise den Endbenutzer-Lizenzvertrag und/oder die Erklärung zu Kaspersky Security Network akzeptieren. ","Um den Endbenutzer-Lizenzvertrag zu akzeptieren, gehen Sie wie folgt vor:","Lesen Sie den Text des Endbenutzer-Lizenzvertrags.Wenn Sie mit dem Text des Endbenutzer-Lizenzvertrags einverstanden sind, geben Sie die Umgebungsvariable an:# KESL_EULA_AGREED=Yes rpm -U <Name des RPM-Pakets>.rpm für ein RPM-Paket.# KESL_EULA_AGREED=Yes dpkg -i <Name des DEB-Pakets>.deb für ein DEB-Paket.Um die Erklärung zu Kaspersky Security Network zu akzeptieren, gehen Sie wie folgt vor:","Lesen Sie den Text der Erklärung zu Kaspersky Security Network.Wenn Sie mit dem Text der Erklärung zu Kaspersky Security Network einverstanden sind, geben Sie die Umgebungsvariable an:# KESL_USE_KSN=Yes rpm -U <Name des RPM-Pakets>.rpm für ein RPM-Paket.# KESL_ USE_KSN=Yes dpkg -i <Name des DEB-Pakets>.deb für ein DEB-Paket."," Programm-Update manuell installieren ","162013.htm");
Page[96]=new Array("Aufgabe zum Rollback eines Datenbanken-Updates (Rollback ID:7)","Dieser Abschnitt enthält Informationen über die Aufgabe zum Rollback eines Datenbanken-Updates.","Die Aufgabe zum Rollback eines Datenbanken-Updates wird ausgeführt, um ein Rollback des letzten erfolgreichen Datenbanken-Updates durchzuführen.","Diese Aufgabe hat keine Einstellungen.","Weitere Informationen zur Verwaltung der Aufgabe zum Rollback eines Datenbanken-Updates finden Sie im Abschnitt „Verwalten der Aufgaben in Kaspersky Endpoint Security mithilfe der Befehlszeile“."," Aufgabe zum Rollback eines Datenbanken-Updates (Rollback ID:7) ","161304.htm");
Page[97]=new Array("Aufgabe zum Kopieren von Updates (Retranslate ID:8)","Dieser Abschnitt enthält Informationen über die Aufgabe zum Kopieren von Updates.","In diesem AbschnittÜber die Aufgabe zum Kopieren von UpdatesEinstellungen der Aufgabe zum Kopieren von Updates"," Aufgabe zum Kopieren von Updates (Retranslate ID:8) ","161306.htm");
Page[98]=new Array("Über die Aufgabe zum Kopieren von Updates","Mithilfe der Aufgabe zum Kopieren von Updates können Sie Datenbanken und Programm-Updates in das ausgewählte Verzeichnis herunterladen. Die Updates werden nicht installiert.","Kopierte Update-Datenbanken können nur vom Programm mit derselben Versionsnummer verwendet werden."," &#xDC;ber die Aufgabe zum Kopieren von Updates ","161307.htm");
Page[99]=new Array("Einstellungen der Aufgabe zum Kopieren von Updates","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zum Kopieren von Updates festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","SourceType ","Mit dieser Einstellung bestimmen Sie die Quelle, aus der Kaspersky Endpoint Security Updates abruft.","Mögliche Werte:","KLServers – Kaspersky Endpoint Security ruft Updates von einem der Kaspersky-Lab-Update-Server ab. Die Updates werden über das HTTP-Protokoll heruntergeladen.","SCServer – Kaspersky Endpoint Security lädt die Updates von einem im lokalen Netzwerk installierten Administrationsserver für Kaspersky Security Center auf den geschützten Computer herunter. Sie können diese Update-Quelle auswählen, wenn Sie Kaspersky Security Center zur zentralisierten Verwaltung des Antiviren-Schutzes in Ihrem Unternehmen verwenden.","Custom – Kaspersky Endpoint Security lädt Updates von der im Abschnitt [CommonSettings:CustomSources] angegebenen benutzerdefinierten Quelle herunter. Sie können Verzeichnisse auf FTP- oder HTTP-Servern und Verzeichnisse auf einem beliebigen montierten Gerät des geschützten Computers angeben, einschließlich der Verzeichnisse auf Remote-Computern, die über Samba- oder NFS-Protokolle montiert sind.","Standardwert: KLServers.","UseKLServersWhenUnavailable","Mit dieser Einstellung legen Sie fest, ob Kaspersky Endpoint Security auf Kaspersky-Lab-Update-Server zugreift, wenn keine der benutzerdefinierten Quellen verfügbar ist.","Mögliche Werte:","Yes – Kaspersky Endpoint Security greift auf Kaspersky-Lab-Update-Server zu, wenn keine benutzerdefinierten Updatequellen verfügbar sind.","No – Kaspersky Endpoint Security greift nicht auf Kaspersky-Lab-Update-Server zu, wenn keine benutzerdefinierten Updatequellen verfügbar sind.","Standardwert: Yes.","IgnoreProxySettingsForKLServers","Mit dieser Einstellung legen Sie fest, ob ein Proxyserver für die Verbindung mit den Kaspersky-Lab-Update-Servern verwendet wird.","Mögliche Werte:","Yes – Kaspersky Endpoint Security verwendet für die Verbindung mit den Kaspersky-Lab-Update-Servern keinen Proxyserver.","No – Kaspersky Endpoint Security verwendet für die Verbindung mit den Kaspersky-Lab-Update-Servern einen Proxyserver.","Standardwert: No","IgnoreProxySettingsForCustomSources","Mit dieser Einstellung legen Sie fest, ob ein Proxyserver für die Verbindung mit benutzerdefinierten Update-Quellen verwendet wird. Sie müssen diese Einstellung aktivieren, wenn die Verbindung zu einem der benutzerdefinierten FTP- oder HTTP-Update-Server den Zugriff auf einen Proxyserver erfordert.","Mögliche Werte:","Yes – Kaspersky Endpoint Security verwendet für die Verbindung mit benutzerdefinierten Update-Quellen keinen Proxyserver.","No – Kaspersky Endpoint Security verwendet für die Verbindung mit benutzerdefinierten Updatequellen einen Proxyserver.","Standardwert: No","ConnectionTimeout","Mithilfe dieser Einstellung können Sie die Wartezeit (in Sekunden) auf eine Antwort von der Update-Quelle – FTP- oder HTTP-Server – bei der Verbindungsherstellung angeben. Wenn im angegebenen Zeitraum keine Antwort von der Update-Quelle eingeht, greift Kaspersky Endpoint Security auf eine andere angegebene Update-Quelle zu.","Sie können nur ganze Zahlen zwischen 0 und 120 angeben.","Standardwert: 10.","RetranslationFolder","Mithilfe dieser Einstellung können Sie das Verzeichnis angeben, in das die Updates kopiert werden. Wenn das angegebene Verzeichnis nicht existiert, wird es von Kaspersky Endpoint Security während der Ausführung der Aufgabe zum Kopieren von Updates erstellt.","Der Abschnitt [CustomSources.item_#] enthält die folgenden Einstellungen:","URL","In diesem Abschnitt können Sie die Adresse der benutzerdefinierten Update-Quelle im lokalen Netzwerk oder im Internet festlegen.","Der Standardwert ist nicht angegeben.","Beispiel:","URL=http://example.com/bases/ – Adresse des HTTP-Servers, auf dem sich das Verzeichnis mit den Updates befindet.","URL=/home/bases/ – Verzeichnis auf dem geschützten Computer mit den Programm-Datenbanken.","Enabled","Mit dieser Einstellung können Sie die Verwendung der in der Einstellung URL angegebenen Update-Quelle aktivieren bzw. deaktivieren. Die Verwendung von zumindest einer Update-Quelle muss aktiviert werden, bevor die Aufgabe ausgeführt werden kann.","Mögliche Werte:","Yes – Kaspersky Endpoint Security verwendet die Update-Quelle.","No – Kaspersky Endpoint Security verwendet die Updatequelle nicht.","Der Standardwert ist nicht angegeben.","AutoPatchDownload","Aktiviert bzw. deaktiviert das automatische Herunterladen von Programm-Updates.","Mögliche Werte: ","Yes—Programm-Updates automatisch herunterladen","No—Programm-Updates nicht automatisch herunterladen","Standardwert: Yes."," Einstellungen der Aufgabe zum Kopieren von Updates ","161308.htm");
Page[100]=new Array("Lizenz-Aufgabe (License ID:9)","Dieser Abschnitt enthält Informationen über die Lizenz-Aufgabe.","In diesem AbschnittÜber die Lizenz-AufgabeAktiven Schlüssel hinzufügenReserveschlüssel hinzufügenAktiven Schlüssel löschenReserveschlüssel löschenEingabe eines zusätzlichen Aktivierungscodes"," Lizenz-Aufgabe (License ID:9) ","161309.htm");
Page[101]=new Array("Über die Lizenz-Aufgabe","Mithilfe der Lizenz-Aufgabe können Sie Schlüssel und Aktivierungscodes in Kaspersky Endpoint Security verwalten."," &#xDC;ber die Lizenz-Aufgabe ","161310.htm");
Page[102]=new Array("Aktiven Schlüssel hinzufügen","Der Befehl --install-active-key fügt einen aktiven Schlüssel hinzu. Details zu Schlüsseln finden Sie im Abschnitt „Über Schlüssel“.","Befehlssyntax","kesl-control [-L] --install-active-key <Pfad der Schlüsseldatei>|<Aktivierungscode>","Argumente und Schlüssel","<Pfad der Schlüsseldatei>","Der Pfad der Schlüsseldatei. Wenn sich die Schlüsseldatei im aktuellen Verzeichnis befindet, ist die Angabe des Dateinamens ausreichend.","Beispiel:","Schlüssel aus der Datei /home/test/00000001.key als aktiven Schlüssel hinzufügen:","kesl-control --install-active-key /home/test/00000001.keу"," Aktiven Schl&#xFC;ssel hinzuf&#xFC;gen ","161311.htm");
Page[103]=new Array("Reserveschlüssel hinzufügen","Der Befehl --install-additional-key fügt einen Reserveschlüssel hinzu. Details zu Schlüsseln finden Sie im Abschnitt „Über Schlüssel“.","Falls kein aktiver Schlüssel installiert ist, wird der Reserveschlüssel als Primärschlüssel installiert.","Befehlssyntax","kesl-control [-L] --install-additional-key <Pfad der Schlüsseldatei>","Argumente und Schlüssel","<Pfad der Schlüsseldatei>","Der Pfad der Schlüsseldatei. Wenn sich die Schlüsseldatei im aktuellen Verzeichnis befindet, ist die Angabe des Dateinamens ausreichend.","Beispiel:","Reserveschlüssel aus der Datei /home/test/00000002.key installieren:","kesl-control --install-additional-key /home/test/00000002.key"," Reserveschl&#xFC;ssel hinzuf&#xFC;gen ","161312.htm");
Page[104]=new Array("Aktiven Schlüssel löschen","Der Befehl --revoke-active-key entfernt den aktiven Schlüssel.","Befehlssyntax","kesl-control [-L] --revoke-active-key"," Aktiven Schl&#xFC;ssel l&#xF6;schen ","161313.htm");
Page[105]=new Array("Reserveschlüssel löschen","Der Befehl --revoke-additional-key entfernt den Reserveschlüssel.","Befehlssyntax","kesl-control [-L] --revoke-additional-key"," Reserveschl&#xFC;ssel l&#xF6;schen ","161314.htm");
Page[106]=new Array("Eingabe eines zusätzlichen Aktivierungscodes","Der Befehl --install-additional-key gibt einen zusätzlichen Aktivierungscode an. Weitere Informationen über Aktivierungscodes finden Sie im Abschnitt „Über den Aktivierungscode“.","Befehlssyntax","kesl-control [-L] --install-additional-key <Aktivierungscode>"," Eingabe eines zus&#xE4;tzlichen Aktivierungscodes ","161315.htm");
Page[107]=new Array("Aufgabe zur Speicherverwaltung (Backup ID:10)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Speicherverwaltung.","In diesem AbschnittÜber den SpeicherEinstellungen der Aufgabe zur SpeicherverwaltungIDs der Objekte im Speicher anzeigenÜber die Wiederherstellung von Objekten aus dem SpeicherObjekte aus dem Speicher wiederherstellenObjekte aus dem Speicher entfernen"," Aufgabe zur Speicherverwaltung (Backup ID:10) ","161316.htm");
Page[108]=new Array("Über den Speicher","Beim Speicher handelt es sich um eine Liste der Backup-Kopien von Dateien, die gelöscht oder bei der Desinfektion verändert wurden. Eine Backup-Kopie ist die Kopie einer Datei, die bei der ersten Desinfektion oder beim Löschen dieser Datei angelegt wird. Die Backup-Kopien von Dateien werden in einem speziellen Format gespeichert und stellen keine Gefahr dar.","Es kann vorkommen, dass Dateien bei der Desinfektion nicht vollständig erhalten bleiben. Wenn aufgrund einer Desinfektion wichtige Informationen, die in einer Datei enthalten waren, vollständig oder teilweise verloren gegangen sind, kann der Benutzer versuchen, die Datei aus ihrer desinfizierten Backup-Kopie im ursprünglichen Verzeichnis der Datei wiederherzustellen."," &#xDC;ber den Speicher ","161317.htm");
Page[109]=new Array("Einstellungen der Aufgabe zur Speicherverwaltung","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zur Speicherverwaltung festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","DaysToLive","Speicherzeit der Objekte im Speicher (in Tagen)","Um die Beschränkung der Speicherzeit der Objekte im Speicher aufzuheben, geben Sie den Wert 0 an.","Standardwert: 90","BackupSizeLimit","Maximale Speichergröße","Wenn die maximale Größe des Speichers erreicht ist, löscht Kaspersky Endpoint Security die ältesten Objekte.","Mögliche Werte:","0 – 999.999 (in Megabyte).","Um die Begrenzung der Speichergröße aufzuheben, geben Sie den Wert 0 an.","Standardwert: 0.","BackupFolder","Pfad des Speicherverzeichnisses. Sie können ein benutzerdefiniertes Speicherverzeichnis angeben, das sich vom Standardverzeichnis unterscheidet.","Sie können für den Speicher ein beliebiges Verzeichnis auf beliebigen Geräten des Computers wählen. Es wird nicht empfohlen, Verzeichnisse zu wählen, die sich auf Remote-Computern befindet und etwa über Samba- oder NFS-Protokolle montiert sind.","Kaspersky Endpoint Security beginnt, die Objekte im angegebenen Verzeichnis zu speichern, sobald Sie die Einstellungen aus der Datei in die Speicher-Aufgabe importiert und Kaspersky Endpoint Security neu gestartet haben.","Falls das gewählte Verzeichnis nicht existiert oder nicht verfügbar ist, verwendet Kaspersky Endpoint Security das Standardverzeichnis für den Speicher.","Standardwert: /var/opt/kaspersky/kesl/objects-backup/"," Einstellungen der Aufgabe zur Speicherverwaltung ","161318.htm");
Page[110]=new Array("IDs der Objekte im Speicher anzeigen","Kaspersky Endpoint Security weist Objekten, die den Speicher verschoben werden, eine numerische ID zu. Die ID wird bei Aktionen mit dem Objekt verwendet, zum Beispiel beim Wiederherstellen oder Entfernen des Objekts aus dem Speicher.","Um die IDs der Objekte im Speicher anzuzeigen,","führen Sie den Befehl kesl-control -B --query aus.","Die Objekt-ID: wird in der Zeichenfolge ObjectId angezeigt."," IDs der Objekte im Speicher anzeigen ","161319.htm");
Page[111]=new Array("Über die Wiederherstellung von Objekten aus dem Speicher","Kaspersky Endpoint Security bewahrt die Objekte im Speicher in verschlüsselter Form auf, um den geschützten Server vor möglichen schädlichen Aktionen der Objekte zu schützen.","Sie können Objekte aus dem Speicher wiederherstellen. In folgenden Fällen kann eine Wiederherstellung der Objekte aus dem Speicher notwendig sein:","Bei der Desinfektion der infizierten Datei gelang es Kaspersky Endpoint Security nicht, die Dateiintegrität zu bewahren, und als Folge sind die Informationen in der Datei nun nicht verfügbar.Wenn Sie der Ansicht sind, dass das Objekt keine Gefahr für den Server darstellt und es verwenden möchten, können Sie das Objekt von der Untersuchung ausschließen, damit es vom Programm bei den folgenden Untersuchungen nicht erkannt wird. Dazu müssen Sie das Objekt nach seinem Namen oder nach dem Namen der während der Aufgabe zum Echtzeitschutz gefundenen Bedrohung sowie auch nach dem Objektnamen und dem Namen der während der Aufgaben zur Untersuchung auf Befehl gefundenen Bedrohung ausschließen.Die Wiederherstellung infizierter Objekte kann zu einer Infektion des Computers führen.","Bei der Wiederherstellung aus dem Speicher können Sie die Datei unter einem neuen Namen speichern."," &#xDC;ber die Wiederherstellung von Objekten aus dem Speicher ","161320.htm");
Page[112]=new Array("Objekte aus dem Speicher wiederherstellen","Um das Objekt aus dem Speicher wiederherzustellen, führen Sie eine der folgenden Aktionen aus:","Um das Objekt unter dem ursprünglichen Namen am ursprünglichen Speicherort wiederherzustellen, führen Sie den folgenden Befehl aus:kesl-control --restore <Objekt-ID>","wobei Objekt-ID die ID des Objektes im Speicher ist.","Um das Objekt unter einem neuen Namen in einem angegebenen Verzeichnis wiederherzustellen, führen Sie den folgenden Befehl aus:kesl-control --restore <Objekt-ID> --file <Dateiname und Verzeichnis>","Wenn das angegebene Verzeichnis nicht existiert, wird es von Kaspersky Endpoint Security erstellt."," Objekte aus dem Speicher wiederherstellen ","161321.htm");
Page[113]=new Array("Objekte aus dem Speicher entfernen","Um ein Objekt aus dem Speicher zu löschen, führen Sie den folgenden Befehl aus:","kesl-control -B --mass-remove --query \"ObjectId == 'object ID>'\"","Um mehrere Objekte aus dem Speicher zu löschen, führen Sie den folgenden Befehl aus:","kesl-control -B --mass-remove --query \"<Feld><Vergleichsoperator> '<Wert>' [and <Feld> <Vergleichsoperator>'<Wert>' ]* ]","Um alle Objekte aus dem Speicher zu löschen, führen Sie einen der folgenden Befehle aus:","kesl-control -B --mass-remove","oder","kesl-control -B --mass-remove --query"," Objekte aus dem Speicher entfernen ","161322.htm");
Page[114]=new Array("Aufgabe zur Überwachung der Datei-Integrität (Integrity_Monitoring ID:11)","Dieser Abschnitt enthält Informationen über die Aufgabe zur Überwachung der Datei-Integrität.","In diesem AbschnittÜber die Überwachung der Datei-IntegritätÜberwachung der Datei-Integrität bei Zugriff (OAFIM)Überwachung der Datei-Integrität auf Befehl (ODFIM)Einstellungen der Aufgabe zur Überwachung der Datei-Integrität bei ZugriffEinstellungen der Aufgabe zur Überwachung der Datei-Integrität auf Befehl"," Aufgabe zur &#xDC;berwachung der Datei-Integrit&#xE4;t (Integrity_Monitoring ID:11) ","161323.htm");
Page[115]=new Array("Über die Überwachung der Datei-Integrität","Die Aufgabe zur Überwachung der Datei-Integrität dient zur Überwachung von Aktionen, die mit Dateien und Verzeichnissen in den in den Aufgabeneinstellungen angegebenen Überwachungsbereichen durchgeführt werden. Mithilfe der Aufgabe können Sie Änderungen an Dateien finden, die eventuell auf eine Verletzung der Sicherheit auf dem geschützten Server hindeuten. Sie können ferner Dateiänderungen konfigurieren, die während Zeiträumen verfolgt werden sollen, in denen die Überwachung unterbrochen ist.","Um die Funktionalität zur Überwachung der Datei-Integrität nutzen zu können, müssen Sie eine erweiterte Lizenz erwerben, in der diese Funktionalität enthalten ist. Die Überwachung der Datei-Integrität ist standardmäßig deaktiviert.","Die Überwachung der Datei-Integrität kann im Echtzeitmodus durch Ausführen der Aufgabe zur Überwachung der Datei-Integrität bei Zugriff (OAFIM) durchgeführt werden. Ferner können Aufgaben zur Überwachung der Datei-Integrität auf Befehl (ODFIM) erstellt und ausgeführt werden.","Sowohl OAFIM- als auch ODFIM-Aufgaben senden Benachrichtigungen über Änderungen der Listen zur Objektzugriffskontrolle. Für die OAFIM-Aufgabe werden keine Details darüber protokolliert, welche Änderungen genau durchgeführt wurden. Für die ODFIM-Aufgabe werden Informationen über Attributänderungen und Datei/Verzeichnisverschiebungen protokolliert."," &#xDC;ber die &#xDC;berwachung der Datei-Integrit&#xE4;t ","161324.htm");
Page[116]=new Array("Überwachung der Datei-Integrität bei Zugriff (OAFIM)","Während der Ausführung der OAFIM-Aufgabe wird jede Objektänderung durch Echtzeitüberwachung von Dateioperationen im Echtzeitmodus bestimmt. Bei Objektänderungen sendet Kaspersky Endpoint Security ein Ereignis an den Administrationsserver von Kaspersky Security Center. Während der Aufgabenausführung wird keine Datei-Prüfsumme berechnet. Die OAFIM-Aufgabe führt keine Überwachung von Dateiänderungen (Attribute und Inhalt) mit festen Links durch, die sich nicht in einem Überwachungsbereich befinden.","Kaspersky Endpoint Security überwacht Dateioperationen für bestimmte Dateien bzw. Bereichen, die in den Aufgabeneinstellungen festgelegt sind.","Überwachungsbereiche","Überwachungsbereiche für Aufgaben zur Überwachung der Datei-Integrität müssen immer angegeben sein. Der Administrator kann den Untersuchungs- und Überwachungsbereich im Echtzeitmodus ändern. Wenn kein Überwachungsumfang angegeben ist, können die Aufgabeneinstellungen nicht in der Konfigurationsdatei gespeichert werden. Wenn ein Überwachungs- oder Ausnahmebereich hinzugefügt wird, prüft das Programm nicht, ob das angegebene Verzeichnis existiert.","Sie können mehrere Überwachungsbereiche angeben.","Ausnahmen vom Überwachungsbereich","Sie können für den Überwachungsbereich Ausnahmen erstellen. Ausnahmen werden für einzelne Bereiche angegeben und funktionieren nur für den angegebenen Überwachungsbereich. Sie können mehrere Ausschlussbereiche angeben.","Ausnahmen haben eine höhere Priorität als der Überwachungsbereich und werden von der Aufgabe nicht überwacht, selbst wenn ein angegebenes Verzeichnis oder eine Datei im Überwachungsbereich ist. Wenn die Einstellungen für eine der Regeln einen Überwachungsbereich angeben, der sich auf einer niedrigeren Stufe befindet als ein in den Ausnahmen angegebenes Verzeichnis, wird der Überwachungsbereich bei der Ausführung der Aufgabe nicht berücksichtigt.","Um Ausnahmen anzugeben, können Sie dieselben Masken für die Befehlszeilenschnittstelle verwenden, die auch für die Angabe von Überwachungsbereichen verwendet werden.","Überwachte Einstellungen","Die Änderungen der folgenden Einstellungen werden während der Ausführung der Aufgabe zur Überwachung der Datei-Integrität überwacht:","Inhalt (schreiben (), abschneiden () usw.)Metadaten (Eigentumsrechte (chmod / chown))Zeitstempel (utimensat)Erweiterte Attribute ((setxattr) und andere)Aufgrund von technischen Beschränkungen des Betriebssystems Linux kann die Komponente Überwachung der Datei-Integrität nicht erkennen, welcher Administrator oder Prozess eine Änderung an einer Datei vorgenommen hat."," &#xDC;berwachung der Datei-Integrit&#xE4;t bei Zugriff (OAFIM) ","161948.htm");
Page[117]=new Array("Überwachung der Datei-Integrität auf Befehl (ODFIM)","Während der Ausführung der ODFIM-Aufgabe wird durch Vergleich des aktuellen Status des überwachten Objekts mit dem Originalstatus, der zuvor als Baseline erstellt wurde, jede Änderung eines Objekts bestimmt.","Sie können mehrere ODFIM-Aufgaben erstellen.","Baseline","Die Baseline wird während der ersten Ausführung der ODFIM-Aufgabe auf dem Computer erstellt. Für jede ODFIM-Aufgabe wird eine eigene Baseline erstellt. Die Aufgabe wird nur ausgeführt, wenn die Baseline dem Überwachungsbereich entspricht. Wenn die Baseline nicht dem Überwachungsbereich entspricht, erstellt Kaspersky Endpoint Security ein Ereignis über die Verletzung der Datei-Integrität.","Sie können eine Baseline für eine Aufgabe mithilfe der entsprechenden Einstellung neu erstellen. Die Baseline wird nach Abschluss der ODFIM-Aufgabe neu erstellt.","Eine Baseline wird auch neu erstellt, wenn die Einstellungen einer Aufgabe geändert werden, beispielsweise, wenn ein neuer Überwachungsbereich hinzugefügt wird. Die Baseline wird während der nächsten Ausführung der Aufgabe neu erstellt.","Die ODFIM-Aufgabe erstellt einen Speicher für Baselines auf einem Computer, auf dem die Komponente Überwachung der Datei-Integrität installiert ist.","Sie können eine Baseline nur löschen, indem Sie die entsprechende ODFIM-Aufgabe löschen. "," &#xDC;berwachung der Datei-Integrit&#xE4;t auf Befehl (ODFIM) ","161949.htm");
Page[118]=new Array("Einstellungen der Aufgabe zur Überwachung der Datei-Integrität bei Zugriff","Dieser Abschnitt beschreibt Einstellungen, die Sie für die Aufgabe zur Überwachung der Datei-Integrität bei Zugriff festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden nachfolgend beschrieben.","UseExcludeMasks","Aktiviert bzw. deaktiviert die Ausnahme vom Überwachungsbereich von Objekten, die in der Einstellung ExcludeMasks angegeben sind.","Die Einstellung UseExcludeMasks funktioniert nur, wenn die Einstellung ExcludeMasks angegeben ist.","Mögliche Werte:","Yes – Objekte, die in der Einstellung ExcludeMasks angegeben sind, aus dem Überwachungsbereich ausschließen","No—Objekte, die in der Einstellung ExcludeMasks angegeben sind, nicht aus dem Überwachungsbereich ausschließen","Standardwert: No","ExcludeMasks","Legt eine Liste von Masken fest, mit denen Objekte definiert werden, die vom Überwachungsbereich ausgeschlossen werden sollen.","Bevor Sie diese Einstellung festlegen, überzeugen Sie sich, dass der Wert der Einstellung UseExcludeMasks auf Yes festgelegt ist.","Masken werden im Format der Befehlsschnittstelle angegeben. ","Wenn Sie mehrere Masken angeben möchten, muss jede Maske in einer neuen Zeile mit einem neuen Index angegeben werden (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Standardwert: nicht definiert.","Abschnitt [ScanScope.item_#]","[ScanScope.item_#]-Abschnitte legen die durch die Aufgabe zur Überwachung der Datei-Integrität zu überwachenden Bereiche fest. Für die Aufgabe muss zumindest ein Überwachungsbereich festgelegt sein.","Sie können in einer Konfigurationsdatei mehrere [ScanScope.item_#]-Abschnitte in beliebiger Reihenfolge definieren. Kaspersky Endpoint Security verarbeitet die Bereiche nach Elementindex in aufsteigender Reihenfolge.","Jeder [ScanScope.item_#]-Abschnitt enthält folgende Einstellungen:","AreaDesc","Legt den Namen des Überwachungsbereichs fest.","UseScanArea","Aktiviert bzw. deaktiviert die Überwachung des angegebenen Bereichs.","Mögliche Werte:","Yes – Einen angegebenen Bereich überwachen","No – Einen angegebenen Bereich nicht überwachen","Standardwert: Yes.","Pfad","Gibt den vollständigen Pfad des zu überwachenden Objekts oder Verzeichnisses an.","Standardwert: /opt/kaspersky/kesl/","AreaMask.item_#","Gibt eine Maske der Befehlszeilenschnittstelle an, in der die zu überwachenden Objekte definiert werden.","Sie können mehrere AreaMask.item_#-Elemente in beliebiger Reihenfolge angeben. Kaspersky Endpoint Security verarbeitet die Elemente nach ihrem Index in aufsteigender Reihenfolge.","Standardwert: * (alle Objekte werden verarbeitet)","Abschnitt [ExcludedFromScanScope.item_#]","In [ExcludedFromScanScope.item_#]-Abschnitten werden die Objekte angegeben, die von allen [ScanScope.item_#]-Abschnitten ausgenommen werden sollen.","Alle Objekte, die den Regeln eines beliebigen [ExcludedFromScanScope.item_#]-Abschnitts entsprechen, werden aus der Überwachung ausgeschlossen. Das Format eines [ExcludedFromScanScope.item_#]-Abschnitts ähnelt dem Format eines [ScanScope.item_#]-Abschnitts.","Sie können in einer Konfigurationsdatei mehrere [ExcludedFromScanScope.item_#]-Abschnitte in beliebiger Reihenfolge definieren. Kaspersky Endpoint Security verarbeitet die Bereiche nach Elementindex in aufsteigender Reihenfolge.","Jeder [ScanScope.item_#]-Abschnitt enthält folgende Einstellungen:","AreaDesc","Gibt den Namen des Bereichs an, der von der Überwachung ausgeschlossen werden soll.","UseScanArea","Legt fest, ob der angegeben Bereich aus der Überwachung ausgeschlossen wird.","Mögliche Werte:","Yes – Einen angegebenen Bereich aus der Überwachung ausschließen","No – Den angegebenen Bereich nicht aus der Überwachung ausschließen","Standardwert: Yes.","Pfad","Gibt den Pfad der Objekte oder Verzeichnisses an, die von der Überwachung ausgeschlossen werden sollen.","AreaMask.item_#","Gibt eine Maske der Befehlszeilenschnittstelle an, in der die Objekte definiert werden, die von der Überwachung ausgeschlossen werden sollen.","Sie können mehrere AreaMask.item_#-Elemente in beliebiger Reihenfolge angeben. Kaspersky Endpoint Security verarbeitet die Elemente nach ihrem Index in aufsteigender Reihenfolge.","Standardwert: * (alle Objekte werden überwacht)"," Einstellungen der Aufgabe zur &#xDC;berwachung der Datei-Integrit&#xE4;t bei Zugriff ","161325.htm");
Page[119]=new Array("Einstellungen der Aufgabe zur Überwachung der Datei-Integrität auf Befehl","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zur Überwachung der Datei-Integrität auf Befehl festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","RebuildBaseline","Aktiviert bzw. deaktiviert die Neuerstellung einer Baseline nach Abschluss einer ODFIM-Aufgabe.","Mögliche Werte:","Yes – Baseline nach Abschluss einer ODFIM-Aufgabe neu erstellen.","No – Baseline nach Abschluss einer ODFIM-Aufgabe nicht neu erstellen.","Standardwert: No","CheckFileHash","Aktiviert bzw. deaktiviert eine Hash-Prüfung(SHA-256).","Mögliche Werte:","Yes – Hash-Prüfung aktivieren","No – Hash-Prüfung deaktivieren","Standardwert: No","TrackDirectoryChanges","Aktiviert bzw. deaktiviert die Überwachung von Verzeichnissen.","Mögliche Werte:","Yes – Verzeichnisse überwachen","No – Verzeichnisse nicht überwachen","Standardwert: No","TrackLastAccessTime","Aktiviert oder deaktiviert die Überprüfung des letzten Zugriffs auf die Datei. (Bei den Betriebssystemen von Linux ist es die Einstellung noatime.)","Mögliche Werte:","Yes—Zeitpunkt des letzten Zugriffs auf die Datei prüfen","No—Zeitpunkt des letzten Zugriffs auf die Datei nicht prüfen","Standardwert: No","UseExcludeMasks","Aktiviert bzw. deaktiviert die Ausnahme vom Überwachungsbereich von Objekten, die in der Einstellung ExcludeMasks angegeben sind.","Diese Einstellung funktioniert nur, wenn die Einstellung ExcludeMasks angegeben ist.","Mögliche Werte:","Yes – Objekte, die in der Einstellung ExcludeMasks angegeben sind, aus dem Überwachungsbereich ausschließen","No – Objekte, die in der Einstellung ExcludeMasks angegeben sind, nicht aus dem Überwachungsbereich ausschließen","Standardwert: No","ExcludeMasks","Legt eine Liste von Masken fest, mit denen Objekte definiert werden, die vom Überwachungsbereich ausgeschlossen werden sollen.","Bevor Sie diese Einstellung festlegen, überzeugen Sie sich, dass der Wert der Einstellung UseExcludeMasks auf Yes festgelegt ist.","Masken werden im Format der Befehlsschnittstelle angegeben. ","Wenn Sie mehrere Masken angeben möchten, muss jede Maske in einer neuen Zeile mit einem neuen Index angegeben werden (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Standardwert: nicht definiert.","Abschnitt [ScanScope.item_#]","[ScanScope.item_#]-Abschnitte legen die durch die Aufgabe zur Überwachung der Datei-Integrität zu überwachenden Bereiche fest. Für die Aufgabe muss zumindest ein Überwachungsbereich festgelegt sein.","Sie können in einer Konfigurationsdatei mehrere [ScanScope.item_#]-Abschnitte in beliebiger Reihenfolge definieren. Kaspersky Endpoint Security verarbeitet die Bereiche nach Elementindex in aufsteigender Reihenfolge.","Jeder [ScanScope.item_#]-Abschnitt enthält folgende Einstellungen:","AreaDesc","Legt den Namen des Überwachungsbereichs fest.","UseScanArea","Aktiviert bzw. deaktiviert die Überwachung des angegebenen Bereichs.","Mögliche Werte:","Yes – Einen angegebenen Bereich überwachen","No – Einen angegebenen Bereich nicht überwachen","Standardwert: Yes.","Pfad","Gibt den vollständigen Pfad des zu überwachenden Objekts oder Verzeichnisses an.","Standardwert: /opt/kaspersky/kesl/","AreaMask.item_#","Gibt eine Maske der Befehlszeilenschnittstelle an, in der die zu überwachenden Objekte definiert werden.","Sie können mehrere AreaMask.item_#-Elemente in beliebiger Reihenfolge angeben. Kaspersky Endpoint Security verarbeitet die Elemente nach ihrem Index in aufsteigender Reihenfolge.","Standardwert: * (alle Objekte werden verarbeitet)","Abschnitt [ExcludedFromScanScope.item_#]","In [ExcludedFromScanScope.item_#]-Abschnitten werden die Objekte angegeben, die von allen [ScanScope.item_#]-Abschnitten ausgenommen werden sollen.","Alle Objekte, die den Regeln eines beliebigen [ExcludedFromScanScope.item_#]-Abschnitts entsprechen, werden aus der Überwachung ausgeschlossen. Das Format eines [ExcludedFromScanScope.item_#]-Abschnitts ähnelt dem Format eines [ScanScope.item_#]-Abschnitts.","Sie können in einer Konfigurationsdatei mehrere [ExcludedFromScanScope.item_#]-Abschnitte in beliebiger Reihenfolge definieren. Kaspersky Endpoint Security verarbeitet die Bereiche nach Elementindex in aufsteigender Reihenfolge.","Jeder [ScanScope.item_#]-Abschnitt enthält folgende Einstellungen:","AreaDesc","Gibt den Namen des Bereichs an, der von der Überwachung ausgeschlossen werden soll.","UseScanArea","Legt fest, ob der angegeben Bereich aus der Überwachung ausgeschlossen wird.","Mögliche Werte:","Yes—Einen angegebenen Bereich aus der Überwachung ausschließen","No—Den angegebenen Bereich nicht aus der Überwachung ausschließen","Standardwert: Yes.","Pfad","Gibt den Pfad der Objekte oder Verzeichnisses an, die von der Überwachung ausgeschlossen werden sollen.","AreaMask.item_#","Gibt eine Maske der Befehlszeilenschnittstelle an, in der die Objekte definiert werden, die von der Überwachung ausgeschlossen werden sollen.","Sie können mehrere AreaMask.item_#-Elemente in beliebiger Reihenfolge angeben. Kaspersky Endpoint Security verarbeitet die Elemente nach ihrem Index in aufsteigender Reihenfolge.","Standardwert: * (alle Objekte werden überwacht)"," Einstellungen der Aufgabe zur &#xDC;berwachung der Datei-Integrit&#xE4;t auf Befehl ","165474.htm");
Page[120]=new Array("Aufgabe zur Firewall-Verwaltung (Firewall ID:12)","Dieser Abschnitt enthält Informationen über die Firewall-Verwaltungsaufgabe.","In diesem AbschnittÜber die Firewall-VerwaltungÜber NetzwerkpaketregelnÜber dynamische RegelnÜber die vordefinierten NetzwerkzonennamenEinstellungen der Firewall-VerwaltungsaufgabeNetzwerkpaketregel hinzufügenNetzwerkpaketregel löschenAusführungspriorität von Netzwerkpaketregeln ändernNetzwerkadresse zum Zonenbereich hinzufügenNetzwerkadresse aus dem Zonenbereich löschen"," Aufgabe zur Firewall-Verwaltung (Firewall ID:12) ","161326.htm");
Page[121]=new Array("Über die Firewall-Verwaltung","Bei der Verwendung in LANs und im Internet ist ein Computer Viren, anderer Schadsoftware und einer Vielzahl von Angriffen ausgesetzt, die Schwachstellen in Betriebssystemen und Software ausnutzen.","Die Firewall des Betriebssystems schützt persönliche Daten, die auf dem Computer des Benutzers gespeichert sind. Die Firewall blockiert die meisten potenziellen Bedrohungen für das Betriebssystem, wenn der Computer mit dem Internet oder einem LAN verbunden ist. Die Firewall-Verwaltung erkennt alle Netzwerkverbindungen des Benutzercomputers und erstellt eine Liste von IP-Adressen sowie mit Angabe des Status der Standardnetzwerkverbindung.","Die Firewall-Verwaltung filtert die gesamte Netzwerkaktivität gemäß den Netzwerkpaketregeln. Durch die Konfiguration von Netzwerkpaketregeln können Sie die gewünschte Ebene des Computerschutzes von Blockieren des Internetzugangs für alle Programme bis zur Erlaubnis von unbegrenzten Zugang festlegen.","Während die Firewall-Verwaltungsaufgabe ausgeführt wird, verwaltet Kaspersky Endpoint Security die Einstellungen und Regeln der Firewall des Betriebssystems. Das Programm blockiert die Konfiguration der Einstellungen der Betriebssystem-Firewall alle Arten, beispielsweise, wenn ein Programm oder Tool eine Regel hinzufügt oder löscht. Kaspersky Endpoint Security überprüft die Firewall des Betriebssystems alle 60 Sekunden und stellt erforderlichenfalls ein Paket der Firewall-Regeln wieder her. Das Überprüfungsintervall kann nicht geändert werden.","Die Überprüfung der Firewall des Betriebssystems wird fortgesetzt, auch wenn die Firewall-Verwaltungsaufgabe gestoppt wird. Das ermöglicht dem Programm, die dynamischen Regeln wiederherzustellen.","Wenn die Firewall-Verwaltungsaufgabe gestoppt wird (wenn die Komponente gelöscht wird, das Programm gestoppt oder deinstalliert wird), ändert Kaspersky Endpoint Security die Regeln der Firewall des Betriebssystems nicht und überwacht die Änderungen in den Einstellungen nicht.","Alle ausgehenden Verbindungen werden standardmäßig erlaubt (Standardeinstellung der Aktion), sofern keine entsprechende Verbotsregeln für die Firewall-Verwaltung angegeben sind. Die Standardaktion wird mit niedrigster Priorität ausgeführt: wenn keine andere Netzwerkpaketregel ausgelöst wurde, oder wenn keine Netzwerkpaketregeln angegeben sind, wird die Verbindung erlaubt.","Bevor die Aufgabe Firewall-Verwaltung aktiviert wird, empfehlen wir Ihnen, andere Firewall-Verwaltungstools des Betriebssystems zu deaktivieren."," &#xDC;ber die Firewall-Verwaltung ","161327.htm");
Page[122]=new Array("Über Netzwerkpaketregeln","Netzwerkpaketregeln sind erlaubte oder blockierte Aktionen, die von der Firewall-Verwaltung ausgeführt werden, wenn eine versuchte Netzwerkverbindung erkannt wird.","Netzwerkpaketregeln legen unabhängig vom Programm Beschränkungen für Netzwerkpakete fest. Solche Regeln schränken den eingehenden und ausgehenden Netzwerkverkehr durch bestimmte Ports des gewählten Datenprotokolls ein. ","In der Firewall-Verwaltung sind bestimmte Netzwerkpaketregeln standardmäßig angegeben. Sie können Ihre eigenen Netzwerkpaketregeln erstellen und für jede Netzwerkpaketregel eine Ausführungspriorität festlegen."," &#xDC;ber Netzwerkpaketregeln ","161953.htm");
Page[123]=new Array("Über dynamische Regeln","Die Komponenten von Kaspersky Endpoint Security können dynamische Regeln, die für die korrekte Funktion erforderlich sind, zur Firewall hinzufügen und löschen. Beispielsweise fügt der Administrationsagent dynamische Regeln hinzu, der Verbindungen zu Kaspersky Security Center erlaubt, die sowohl vom Programm als auch von Kaspersky Security Center initiiert werden.","Die Firewall-Verwaltungsaufgabe überwacht dynamische Regeln nicht und blockiert den Zugriff auf Netzwerkressourcen für die Programmkomponenten nicht. Dynamische Regeln hängen nicht vom Status der Firewall-Verwaltungsaufgabe (gestartet/gestoppt) oder den Änderungen ihrer Einstellungen ab. Eine Ausführungspriorität für die dynamischen Regeln ist höher als eine Priorität einer Netzwerkpaketregel. Kaspersky Endpoint Security stellt eine Auswahl von dynamischen Regeln wieder her, wenn eine davon beispielsweise mithilfe des Tools iptables gelöscht wurde.","Sie können eine Auswahl von dynamischen Regeln (mithilfe des Befehls kesl-control –F –query) anzeigen, Sie können die Einstellungen der dynamischen Regeln jedoch nicht ändern. "," &#xDC;ber dynamische Regeln ","161954.htm");
Page[124]=new Array("Über die vordefinierten Netzwerkzonennamen","Die Firewall kontrolliert alle Netzwerkverbindungen auf dem Computer des Benutzers. Sie können eine Netzwerkadresse zu einer der folgenden vordefinierten Zonen hinzufügen:","ÖffentlichLocalVertrauenswürdig"," &#xDC;ber die vordefinierten Netzwerkzonennamen ","161955.htm");
Page[125]=new Array("Einstellungen der Firewall-Verwaltungsaufgabe","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Firewall-Verwaltungsaufgabe festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","DefaultIncomingAction","Standardaktion, die mit einer eingehenden Verbindung ausgeführt werden soll, wenn für diese Verbindungsart keine Netzwerkregeln übernommen werden können.","Mögliche Werte:","Allow –Eingehende Verbindung erlauben","Block –Eingehende Verbindung blockieren","Standardwert: Allow.","DefaultIncomingPacketAction","Standardaktion, die mit einem eingehenden Pakt ausgeführt werden soll, wenn für diese Verbindungsart keine Netzwerkpaketregeln übernommen werden können.","Mögliche Werte:","Allow – Eingehendes Paket erlauben","Block – Eingehendes Paket blockieren","Standardwert: Allow.","Abschnitt [PacketRules.item_xxxx]","Die [PacketRules.item_#]-Abschnitte legen Netzwerkpaketregeln für die Firewall-Verwaltungsaufgabe fest.","Sie können in einer Konfigurationsdatei mehrere [PacketRules.item_#]-Abschnitte in beliebiger Reihenfolge definieren. Kaspersky Endpoint Security verarbeitet die Bereiche nach Elementindex in aufsteigender Reihenfolge.","Jeder [PacketRules.item_#]-Abschnitt enthält folgende Einstellungen:","Name","Ein Name für die Netzwerkpaketregel.","Standardwert: Network rule #<n>, wobei n ein Index ist.","FirewallAction","Aktion, die mit in dieser Netzwerkpaketregel angegebenen Verbindungen ausgeführt wird.","Mögliche Werte:","Allow – Netzwerkverbindung erlauben","Block – Netzwerkverbindung blockieren","Standardwert: Allow.","Protokoll","Typ des Protokolls, für das die Netzwerkaktivität überwacht werden soll.","Mögliche Werte:","Any – Die Firewall-Verwaltung überwacht die gesamte Netzwerkaktivität","TCP","UDP","ICMP","ICMPv6","IGMP","GRE","Standardwert: Any.","RemotePorts","Portnummern der Remote-Computer, zwischen denen die Verbindungen überwacht werden sollen.","Diese Einstellung kann nur angegeben werden, wenn der Wert der Einstellung Protocol auf TCP oder UDP festgelegt wurde.","Für diese Einstellung können Ganzzahlen oder Intervalle angegeben werden.","Mögliche Werte:","Any – Alle Remote-Ports werden überwacht","0–65535","Standardwert: Any.","LocalPorts","Portnummern der lokalen Computer, zwischen denen die Verbindungen überwacht werden sollen.","Diese Einstellung kann nur angegeben werden, wenn der Wert der Einstellung Protocol auf TCP oder UDP festgelegt wurde.","Für diese Einstellung können Ganzzahlen oder Intervalle angegeben werden.","Mögliche Werte:","Any – Alle lokalen Ports werden überwacht","0–65535","Standardwert: Any.","ICMPType","ICMP-Pakettyp.","Diese Einstellung kann nur angegeben werden, wenn der Wert der Einstellung Protokoll auf ICMP oder ICMPv6 festgelegt wurde.","Mögliche Werte:","Alle – Alle ICMP-Pakettypen werden überwacht","Ganzzahl entsprechend der Spezifikation eines Datentransferprotokolls","Standardwert: Any.","ICMPCode","ICMP-Paketcode.","Diese Einstellung kann nur angegeben werden, wenn der Wert der Einstellung Protokoll auf ICMP oder ICMPv6 festgelegt wurde.","Mögliche Werte:","Alle – Alle ICMP-Paketcodes werden überwacht","Ganzzahl entsprechend der Spezifikation eines Datentransferprotokolls","Standardwert: Any.","Richtung","Richtung der überwachten Netzwerkaktivität.","Mögliche Werte:","IncomingOutgoing – Sowohl eingehende als auch ausgehende Verbindungen überwachen","Incoming – Eingehende Verbindungen überwachen","Outgoing – Ausgehende Verbindungen überwachen","IncomingPacket – Eingehende Pakete überwachen","OutgoingPacket – Ausgehende Pakete überwachen","IncomingOutgoingPacket – Sowohl eingehende als auch ausgehende Pakete überwachen","Standardwert: IncomingOutgoing","RemoteAddress","Netzwerkadressen der Remote-Computer, die Netzwerkpakete senden und/oder empfangen können.","Mögliche Werte:","Any – Netzwerkpakete überwachen, die von Remote-Computern mit beliebiger IP-Adresse gesendet und/oder empfangen wurden","Trusted – Alle vertrauenswürdigen Netzwerke","Local – Alle lokalen Netzwerke","Public – Alle öffentlichen Netzwerke","d.d.d.d – IPv4-Adresse, wobei d eine Dezimalzahl von 0–255 ist","d.d.d.d/p –Subnetz von IPv4-Adressen, wobei p eine Zahl von 0–32 ist","x:x:x:x:x:x:x:x – IPv6-Adresse, wobei x eine hexadezimale Zahl von 0–ffffff ist","x:x:x:x::0/p – Subnetz von IPv6-Adressen, wobei p eine Zahl von 0–64 ist","Standardwert: Any.","LocalAddress","Netzwerkadressen der Computer, auf denen Kaspersky Endpoint Security installiert ist und die Netzwerkpakete senden bzw. empfangen können.","Mögliche Werte:","Any – Netzwerkpakete überwachen, die von Remote-Computern mit beliebiger IP-Adresse gesendet und/oder empfangen wurden","d.d.d.d – IPv4-Adresse, wobei d eine Dezimalzahl von 0–255 ist","d.d.d.d/p –Subnetz von IPv4-Adressen, wobei p eine Zahl von 0–32 ist","x:x:x:x:x:x:x:x – IPv6-Adresse, wobei x eine hexadezimale Zahl von 0–ffffff ist","x:x:x:x::0/p – Subnetz von IPv6-Adressen, wobei p eine Zahl von 0–64 ist","Standardwert: Any.","LogAttempts","Geben Sie an, ob die Aktionen der Netzwerkregel im Bericht wiedergegeben werden sollen.","Mögliche Werte:","Yes – Aktionen protokollieren","No – Aktionen nicht protokollieren","Standardwert: No","Abschnitt [NetworkZonesPublic]","Im Abschnitt [NetworkZonesPublic] werden die Netzwerkadressen angegeben, die mit öffentlichen Netzwerken assoziiert sind.","Sie können mehrere IP-Adressen oder Subnetze von IP-Adressen angeben.","Address.item_xxxx","Mögliche Werte:","d.d.d.d – IPv4-Adresse, wobei d eine Dezimalzahl von 0–255 ist","d.d.d.d/p –Subnetz von IPv4-Adressen, wobei p eine Zahl von 0–32 ist","x:x:x:x:x:x:x:x – IPv6-Adresse, wobei x eine hexadezimale Zahl von 0–ffffff ist","x:x:x:x::0/p – Subnetz von IPv6-Adressen, wobei p eine Zahl von 0–64 ist","Standardwert: “” (keine Netzwerkadressen in dieser Zone)","Abschnitt [NetworkZonesLocal]","Im Abschnitt [NetworkZonesLocal] werden Netzwerkadressen angegeben, die mit lokalen Netzwerken assoziiert sind.","Sie können mehrere IP-Adressen oder Subnetze von IP-Adressen angeben.","Address.item_xxxx","Mögliche Werte:","d.d.d.d – IPv4-Adresse, wobei d eine Dezimalzahl von 0–255 ist","d.d.d.d/p –Subnetz von IPv4-Adressen, wobei p eine Zahl von 0–32 ist","x:x:x:x:x:x:x:x – IPv6-Adresse, wobei x eine hexadezimale Zahl von 0–ffffff ist","x:x:x:x::0/p – Subnetz von IPv6-Adressen, wobei p eine Zahl von 0–64 ist","Standardwert: “” (keine Netzwerkadressen in dieser Zone)","Abschnitt [NetworkZonesTrusted]","Im Abschnitt [NetworkZonesTrusted] werden Netzwerkadressen angegeben, die mit vertrauenswürdigen Netzwerken assoziiert sind.","Sie können mehrere IP-Adressen oder Subnetze von IP-Adressen angeben.","Address.item_xxxx","Mögliche Werte:","d.d.d.d – IPv4-Adresse, wobei d eine Dezimalzahl von 0–255 ist","d.d.d.d/p –Subnetz von IPv4-Adressen, wobei p eine Zahl von 0–32 ist","x:x:x:x:x:x:x:x – IPv6-Adresse, wobei x eine hexadezimale Zahl von 0–ffffff ist","x:x:x:x::0/p – Subnetz von IPv6-Adressen, wobei p eine Zahl von 0–64 ist","Standardwert: “” (keine Netzwerkadressen in dieser Zone)"," Einstellungen der Firewall-Verwaltungsaufgabe ","161328.htm");
Page[126]=new Array("Netzwerkpaketregel hinzufügen","Sie können eine Netzwerkpaketregel manuell hinzufügen.","Sie können gleichzeitig immer nur eine Netzwerkpaketregel hinzufügen.","Um eine Netzwerkpaketregel hinzuzufügen, führen Sie den folgenden Befehl aus:","kesl-control -F --add-rule --name <Name der Regel> --action <Aktion> --protocol <Protokoll> --direction <Richtung> --remote <Remote-Adresse> --local <lokale Adresse> --at <Index in einer Liste von Netzwerkpaketregeln>","Ein Abschnitt mit den Einstellungen der neuen Netzwerkpaketregel wird zur Konfigurationsdatei der Firewall-Verwaltungsaufgabe hinzugefügt. Wenn Sie eine bestimmte Einstellung nicht angeben, wird der Standardwert eingestellt.","Mithilfe der Option –at können Sie den Index der zu erstellenden Regel in der Liste der Netzwerkpaketregeln angeben. Wenn die Option –at nicht angegeben wird oder ihr Wert größer als die Anzahl der Nummern in der Liste ist, wird die neue Regel zum Ende der Liste hinzugefügt."," Netzwerkpaketregel hinzuf&#xFC;gen ","161956.htm");
Page[127]=new Array("Netzwerkpaketregel löschen","Sie können eine Netzwerkpaketregel manuell löschen.","Sie können gleichzeitig immer nur eine Netzwerkpaketregel löschen.","Um eine Netzwerkpaketregel zu löschen, führen Sie einen der folgenden Befehle aus:","kesl-control -F --del-rule --name <Name>Eine Netzwerkpaketregel wird nach ihrem Namen gelöscht. Wenn eine Liste von Netzwerkpaketregeln mehrere Regeln mit demselben Namen enthält, löscht Kaspersky Endpoint Security keine davon.","kesl-control -F –del-rule --index <Index>Eine Netzwerkpaketregel wird nach ihrem Index in der Liste der Netzwerkpaketregeln gelöscht.","Ein Abschnitt mit den Einstellungen der neuen Netzwerkpaketregel wird aus der Konfigurationsdatei der Firewall-Verwaltungsaufgabe gelöscht.","Wenn die Liste der Netzwerkpaketregeln keine Regel mit dem angegeben Namen oder Index enthält, tritt ein Fehler auf."," Netzwerkpaketregel l&#xF6;schen ","161958.htm");
Page[128]=new Array("Ausführungspriorität von Netzwerkpaketregeln ändern","Sie können die Ausführungspriorität für eine Netzwerkpaketregel manuell ändern.","Um eine Ausführungspriorität für eine Netzwerkpaketregel zu ändern, führen Sie den folgenden Befehl aus:","kesl-control -F --move-rule [--name <Name>|--index <Index>] --at <Index>","Die Priorität der Netzwerkpaketregel wird auf den angegebenen Index geändert."," Ausf&#xFC;hrungspriorit&#xE4;t von Netzwerkpaketregeln &#xE4;ndern ","161960.htm");
Page[129]=new Array("Netzwerkadresse zum Zonenbereich hinzufügen","Sie können Netzwerkadressen, die einem bestimmten Netzwerktyp zugeordnet sind, manuell zur Konfigurationsdatei der Aufgabe Firewall-Verwaltung hinzufügen.","Um eine Netzwerkadresse zur Zone hinzuzufügen, führen Sie den folgenden Befehl aus:","kesl-control -F --add-zone <Öffentlich|Lokal|Vertrauenswürdig> --address <Adresse>","Eine Netzwerkadresse wird zum angegeben Zonenbereich in der Konfigurationsdatei hinzugefügt."," Netzwerkadresse zum Zonenbereich hinzuf&#xFC;gen ","161959.htm");
Page[130]=new Array("Netzwerkadresse aus dem Zonenbereich löschen","Sie können Netzwerkadressen, die einem bestimmten Netzwerktyp zugeordnet sind, manuell aus der Konfigurationsdatei der Firewall-Manager-Aufgabe löschen.","Um eine Netzwerkadresse aus der Zone in einer Konfigurationsdatei zu löschen, führen Sie den folgenden Befehl aus:","kesl_control -F --del-zone <Zone> [--address <Adresse>| --index <Adressindex in der Zone>]","Die angegebene Netzwerkadresse wird aus dem angegeben Zonenbereich in einer Konfigurationsdatei gelöscht.","Wenn eine Zone mehrere Elemente mit derselben Netzwerkadresse enthält, wird der Befehl -del-zone nicht ausgeführt.","Wenn die angegebene Netzwerkadresse oder der Index nicht existiert, tritt ein Fehler auf."," Netzwerkadresse aus dem Zonenbereich l&#xF6;schen ","161961.htm");
Page[131]=new Array("Aufgabe zum Schutz vor Verschlüsselung (AntiCryptor ID:13)","Dieser Abschnitt enthält Informationen über die Aufgabe zum Schutz vor Verschlüsselung.","In diesem AbschnittÜber die Aufgabe zum Schutz vor VerschlüsselungÜber die Blockierung nicht vertrauenswürdiger GeräteEinstellungen der Aufgabe zum Schutz vor VerschlüsselungListe der blockierten Computer anzeigenBlockierte Computer erlauben"," Aufgabe zum Schutz vor Verschl&#xFC;sselung (AntiCryptor ID:13) ","161329.htm");
Page[132]=new Array("Über die Aufgabe zum Schutz vor Verschlüsselung","Die Aufgabe zum Schutz vor Verschlüsselung ermöglicht Ihnen, Ihre Dateien in den lokalen Verzeichnissen mit Netzwerkzugang durch SMB/NFS-Protokolle vor bösartiger Remote-Verschlüsselung zu schützen.","Während die Aufgabe zum Schutz vor Verschlüsselung ausgeführt wird, untersucht Kaspersky Endpoint Security die Aufrufe von Remote-Computern zum Zugriff auf Dateien, die sich auf freigegebenen Netzwerkverzeichnissen des geschützten Geräts befinden. Wenn das Programm die Aktionen eines Remote-Computers in freigegebenen Netzwerkordnern als Verschlüsselung einstuft, wird dieser Computer zu einer Liste der nicht vertrauenswürdigen Computer hinzugefügt und der Zugriff auf die freigegebenen Netzwerkverzeichnisse blockiert.","Kaspersky Endpoint Security stuft eine Aktivität nicht als Verschlüsselung ein, wenn die gefundene Verschlüsselungsaktivität in Verzeichnissen stattfindet, die nicht in den Bereich der Aufgabe zum Schutz vor Verschlüsselung fallen.","Standardmäßig blockiert Kaspersky Endpoint Security den Zugriff von nicht vertrauenswürdigen Computern auf freigegebene Netzwerkordner für 30 Minuten.","Die Aufgabe zum Schutz vor Verschlüsselung wird mit den Protokollen SMB1, SMB2, SMB3, NFS3, TCP/UDP und IP/IPv6 korrekt ausgeführt. Die Protokolle NFS2 und NFS4 werden nicht unterstützt. Es wird empfohlen, dass Sie Ihre Server-Einstellungen so konfigurieren, dass NFS2- und NFS4-Protokolle nicht zum Montieren von Ressourcen verwendet werden können.","Die Aufgabe Schutz vor Verschlüsselung blockiert den Zugriff auf die freigegebenen Netzwerkordner erst dann, wenn die Aktivität des betreffenden Computers als bösartig eingestuft wurde. Es wird daher zumindest eine Datei verschlüsselt, bevor das Programm eine bösartige Aktivität erkennt. "," &#xDC;ber die Aufgabe zum Schutz vor Verschl&#xFC;sselung ","161330.htm");
Page[133]=new Array("Über die Blockierung nicht vertrauenswürdiger Geräte","Wenn eine bösartige Verschlüsselungsaktivität gefunden wird, erstellt und aktiviert Kaspersky Endpoint Security eine Regel für die Firewall des Betriebssystems, durch die der Datenverkehr von einem betroffenen Computer blockiert wird. Ein betroffener Computer wird zur Liste der nicht vertrauenswürdigen Computer hinzugefügt. Kaspersky Endpoint Security blockiert für alle Remote-Computer auf der Liste der nicht vertrauenswürdigen Computer den Zugriff auf die freigegebenen Netzwerkressourcen. Informationen über blockierte Computer auf einem geschützten Server werden an das Kaspersky Security Center gesendet.","Firewall-Regeln, die vom Schutz vor Verschlüsselung erstellt wurden, können nicht mithilfe des Tools iptables gelöscht werden: Kaspersky Endpoint Security stellt das Regelpaket einmal pro Minute wieder her. Verwenden Sie die Option --allow-hosts, um die Blockierung eines Computers aufzuheben.","Standardmäßig entfernt Kaspersky Endpoint Security nicht vertrauenswürdige Computer innerhalb von 30 Minuten, nachdem sie zur Liste hinzugefügt wurden, aus der Liste. Der Zugriff von Computers auf die freigegebenen Netzwerkordner wird automatisch wiederhergestellt, nachdem sie aus der Liste der nicht vertrauenswürdigen Computer gelöscht wurden. Sie können die Liste der blockierten Computer verändern und die Zeitspanne festlegen, nach der blockierte Computer automatisch entsperrt werden."," &#xDC;ber die Blockierung nicht vertrauensw&#xFC;rdiger Ger&#xE4;te ","161331.htm");
Page[134]=new Array("Einstellungen der Aufgabe zum Schutz vor Verschlüsselung","Dieser Abschnitt bietet Informationen zu den Einstellungen, die Sie für die Aufgabe zum Schutz vor Verschlüsselung festlegen können.","Alle verfügbaren Werte und Standardwerte für jede Einstellung werden beschrieben.","UseHostBlocker","Aktiviert bzw. deaktiviert die Blockierung nicht vertrauenswürdiger Computer.","Wenn die Blockierung nicht vertrauenswürdiger Computer deaktiviert ist, untersucht Kaspersky Endpoint Security die Aktionen von Remote-Computern mit Netzwerk-Ressourcen trotzdem auf bösartige Verschlüsselung, wenn die Aufgabe zum Schutz vor Verschlüsselung ausgeführt wird. Sollte eine bösartige Aktivität erkannt werden, wird das Ereignis EncryptionDetected erstellt, ein angreifender Computer wird jedoch nicht blockiert. ","Mögliche Werte:","Yes – Blockierung nicht vertrauenswürdiger Computer aktivieren","No – Blockierung nicht vertrauenswürdiger Computer deaktivieren","Standardwert: Yes.","BlockTime","Gibt die Dauer der Blockierung eines nicht vertrauenswürdigen Computers an (in Minuten).","Wenn ein betroffener Computer blockiert wurde und Sie den Wert der Einstellung BlockTime ändern, ändert sich die Dauer der Blockierung für diesen Computer nicht. Diese Dauer ist kein dynamischer Wert und wird zum Zeitpunkt der Blockierung berechnet.","Mögliche Werte:","Ganzzahl von 1 bis 4294967295","Standardwert: 30","UseExcludeMasks","Aktiviert bzw. deaktiviert die Ausnahme vom Schutzbereich von Objekten, die in der Einstellung ExcludeMasks angegeben sind.","Diese Einstellung funktioniert nur, wenn die Einstellung ExcludeMasks angegeben ist.","Mögliche Werte:","Yes – Objekte, die in der Einstellung ExcludeMasks angegeben sind, aus dem Schutzbereich ausschließen","No – Objekte, die in der Einstellung ExcludeMasks angegeben sind, nicht aus dem Schutzbereich ausschließen","Standardwert: No","ExcludeMasks","Legt eine Liste von Masken fest, mit denen Objekte definiert werden, die vom Schutzbereich ausgeschlossen werden sollen.","Bevor Sie diese Einstellung festlegen, überzeugen Sie sich, dass der Wert der Einstellung UseExcludeMasks auf Yes festgelegt ist.","Masken werden im Format der Befehlsschnittstelle angegeben. ","Wenn Sie mehrere Masken angeben möchten, muss jede Maske in einer neuen Zeile mit einem neuen Index angegeben werden (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Standardwert: nicht definiert.","Abschnitt [ScanScope.item_#]","[ScanScope.item_#]-Abschnitte geben die Bereiche an, die von Kaspersky Endpoint Security geschützt werden sollen. Für die Aufgabe zum Schutz vor Verschlüsselung muss zumindest ein Schutzbereich festgelegt sein.","Es können nur freigegebene Verzeichnisse für die Aufgabe zum Schutz vor Verschlüsselung angegeben werden.","Sie können in einer Konfigurationsdatei mehrere [ScanScope.item_#]-Abschnitte in beliebiger Reihenfolge definieren. Kaspersky Endpoint Security verarbeitet die Bereiche nach Elementindex in aufsteigender Reihenfolge.","Jeder [ScanScope.item_#]-Abschnitt enthält folgende Einstellungen:","AreaDesc","Legt den Namen des Schutzbereichs fest.","Standardwert: AllSharedFolders","UseScanArea","Aktiviert bzw. deaktiviert den Schutz des angegebenen Bereichs.","Mögliche Werte:","Yes –Einen angegebenen Bereich schützen","No – Einen angegebenen Bereich nicht schützen","Standardwert: Yes.","Pfad","Gibt den Pfad der Objekte an, die geschützt werden sollen.","Mögliche Werte:","über SMB/NFS verfügbarer absoluter Pfad (beispielsweise Path=/tmp)","AllShared – Alle über SMB/NFS freigegebenen Ressourcen schützen","Shared:SMB <Pfad> – Alle über SMB freigegebenen Ressourcen schützen","Shared:SMB <Pfad> – Alle über SMB freigegebenen Ressourcen schützen","Standardwert: AllShared","AreaMask.item_#","Gibt eine Maske der Befehlszeilenschnittstelle an, in der die zu schützende Objekte definiert werden.","Sie können mehrere AreaMask.item_#-Elemente in beliebiger Reihenfolge angeben. Kaspersky Endpoint Security verarbeitet die Elemente nach ihrem Index in aufsteigender Reihenfolge.","Standardwert: * (alle Objekte werden verarbeitet)","Abschnitt [ExcludedFromScanScope.item_#]","In [ExcludedFromScanScope.item_#]-Abschnitten werden die Objekte angegeben, die von allen [ScanScope.item_#]-Abschnitten ausgenommen werden sollen.","Alle Objekte, die den Regeln eines beliebigen [ExcludedFromScanScope.item_#]-Abschnitts entsprechen, werden nicht untersucht. Das Format eines [ExcludedFromScanScope.item_#]-Abschnitts ähnelt dem Format eines [ScanScope.item_#]-Abschnitts.","Sie können in einer Konfigurationsdatei mehrere [ExcludedFromScanScope.item_#]-Abschnitte in beliebiger Reihenfolge definieren. Kaspersky Endpoint Security verarbeitet die Bereiche nach Elementindex in aufsteigender Reihenfolge.","Jeder [ScanScope.item_#]-Abschnitt enthält folgende Einstellungen:","AreaDesc","Gibt den Namen des Bereichs an, der von der Untersuchung ausgeschlossen werden soll.","Standardwert: All Objects","UseScanArea","Legt fest, ob der angegeben Bereich vom Schutz ausgeschlossen wird.","Mögliche Werte:","Yes – Einen angegebenen Bereich vom Schutz ausschließen","No – Den angegebenen Bereich nicht vom Schutz ausschließen","Standardwert: Yes.","Pfad","Gibt den Pfad der Objekte an, die vom Schutz ausgeschlossen werden sollen.","Sie können nur einen absoluten Pfad eines lokalen Verzeichnisses angeben (beispielsweise /root /tmp/123), das nicht vom Schutz vor Verschlüsselung geschützt werden soll.","Standardwert: nicht definiert.","AreaMask.item_#","Gibt eine Maske der Befehlszeilenschnittstelle an, in der die Objekte definiert werden, die vom Schutz ausgeschlossen werden sollen.","Sie können mehrere AreaMask.item_#-Elemente in beliebiger Reihenfolge angeben. Kaspersky Endpoint Security verarbeitet die Elemente nach ihrem Index in aufsteigender Reihenfolge.","Standardwert: * (alle Objekte werden verarbeitet)"," Einstellungen der Aufgabe zum Schutz vor Verschl&#xFC;sselung ","161332.htm");
Page[135]=new Array("Liste der blockierten Computer anzeigen","Sie können eine Liste nicht vertrauenswürdiger Computer anzeigen, die von der Aufgabe zum Schutz vor Verschlüsselung blockiert wurden.","Um eine Liste blockierter Computer anzuzeigen, führen Sie den folgenden Befehl aus:","kesl-control -H --get-blocked-hosts","Es werden Computer angezeigt, die von der Aufgabe zum Schutz vor Verschlüsselung blockiert wurden."," Liste der blockierten Computer anzeigen ","161333.htm");
Page[136]=new Array("Blockierte Computer erlauben","Sie können die Blockierung von Computern, die von der Aufgabe zum Schutz vor Verschlüsselung blockiert wurden, manuell aufheben und deren Netzwerkzugriff wiederherstellen.","Um die Blockierung von Computern aufzuheben, führen Sie den folgenden Befehl aus:","kesl-control [-H] --allow-hosts <Computer>,","wobei <Computer> eine Liste von gültigen IPv4/IPv6-Adressen (einschließlich Adressen in Kurzform) oder/und ein Subnetz sein kann. Sie können Computer auch als Liste angeben.","Die Blockierung der angegebenen Computer wird aufgehoben.","Beispiele:","IPv4-Adressen:","dez – 192.168.0.1","dez – 192.168.0.0/24","IPv6-Adressen:","hex – FEDC:BA98:7654:3210:FEDC:BA98:7654:3210","hex – FEDC:BA98:7654:3210:FEDC:BA98:7654:3210%1","hex – 2001:db8::ae21:ad12","hex – ::ffff:255.255.255.254","hex – ::"," Blockierte Computer erlauben ","161334.htm");
Page[137]=new Array("Teilnahme am Kaspersky Security Network","Dieser Abschnitt enthält Informationen über die Teilnahme am Kaspersky Security Network und erklärt, wie die Verwendung von Kaspersky Security Network aktiviert und deaktiviert werden kann.","In diesem AbschnittÜber die Teilnahme am Kaspersky Security NetworkVerwendung von Kaspersky Security Network aktivieren und deaktivierenVerbindung zum Kaspersky Security Network prüfenZusätzlicher Schutz durch Verwendung von Kaspersky Security Network"," Teilnahme am Kaspersky Security Network ","161355.htm");
Page[138]=new Array("Über die Teilnahme am Kaspersky Security Network","Um Benutzercomputer effektiver zu schützen, verwendet Kaspersky Endpoint Security die von Benutzern aus aller Welt empfangenen Daten. Zur Erhebung dieser Daten dient das Netzwerk Kaspersky Security Network.","Kaspersky Security Network (KSN) ist eine Infrastruktur von Cloud-Diensten, die den umfassenden Zugriff auf die Wissensdatenbank von Kaspersky Lab über die Reputation von Dateien, Web-Ressourcen und Software gewährleistet. Durch die Verwendung der Daten aus dem Kaspersky Security Network wird die Reaktion von Kaspersky Endpoint Security auf unbekannte Bedrohungen beschleunigt, die Leistungsfähigkeit einiger Komponenten erhöht und das Risiko von Fehlalarmen reduziert.","Abhängig vom Standort der Infrastruktur unterscheidet man Global KSN (die Infrastruktur befindet sich auf den Servern von Kaspersky Lab) und Private KSN (die Infrastruktur befindet sich auf Servern außerhalb von Kaspersky, beispielsweise im Netzwerk des Internet-Providers).","Nach Änderung der Lizenz für die Nutzung von Private KSN müssen dem Provider die Informationen über den neuen Schlüssel zur Verfügung gestellt werden. Andernfalls ist der Austausch von Informationen mit Private KSN aufgrund eines Authentifizierungsfehlers unmöglich.","Die Teilnahme der Benutzer am KSN ermöglicht Kaspersky Lab, Informationen über Typen und Quellen von Bedrohungen zu erhalten, Möglichkeiten zur Neutralisation der Bedrohungen zu entwickeln und die Anzahl von Fehlalarmen der Programmkomponenten zu verringern.","Es gibt zwei Möglichkeiten, an KSN teilzunehmen:","Kaspersky Security Network mit Statistiken—Sie können Informationen aus der Wissensdatenbank abrufen. Das Programm sendet automatisch statistische Informationen an KSN, die während der Ausführung ermittelt wurden. Ferner kann das Programm Dateien (oder Teile von Dateien), die von Angreifern zur Beschädigung des Computers oder der Daten verwendet werden können, zur erweiterten Untersuchung an Kaspersky Lab senden.Kaspersky Security Network ohne Statistiken—Sie können Informationen aus der Wissensdatenbank abrufen, jedoch keine anonymen Statistiken und Informationen über die Arten und Quellen neuer Bedrohungen senden.Es werden keinerlei persönliche Daten des Benutzers erfasst, verarbeitet und gespeichert. Detaillierte Informationen über den Versand, die Speicherung und Vernichtung von während der Ausführung von KSN erfassten statistischen Informationen finden Sie in der Erklärung zu Kaspersky Security Network und auf der Website von Kaspersky Lab (http://www.kaspersky.de/privacy). Die Datei mit dem Text der Erklärung zu Kaspersky Security Network ist im Lieferumfang des Programms enthalten.","Benutzercomputer, die unter Verwaltung des Administrationsservers von Kaspersky Security Center stehen, können mithilfe des Dienstes KSN Proxy mit dem KSN interagieren.","Der Dienst KSN Proxy bietet Ihnen folgende Möglichkeiten:","Benutzercomputer können Anfragen an KSN initiieren und Informationen an KSN übermitteln, selbst wenn sie über keinen direkten Zugriff auf das Internet verfügen.Die verarbeiteten Daten werden vom Dienst KSN Proxy im Cache zwischengespeichert, wodurch die Belastung für den ausgehenden Datenverkehr verringert und das Empfangen der abgefragten Informationen durch den Benutzercomputer beschleunigt wird.Weitere Informationen über den KSN Proxy-Dienst finden Sie in der Dokumentation für Kaspersky Security Center","Die Einstellungen für die Nutzung des Dienstes KSN Proxy können in den Eigenschaften der Richtlinie für Kaspersky Security Center angepasst werden.","Die Teilnahme an Kaspersky Security Network ist freiwillig. Das Programm bietet dem Benutzer während der Installation an, am KSN teilzunehmen. Benutzer können die Nutzung von KSN zu jeder Zeit beginnen oder beenden."," &#xDC;ber die Teilnahme am Kaspersky Security Network ","161356.htm");
Page[139]=new Array("Verwendung von Kaspersky Security Network aktivieren und deaktivieren","Um die Nutzung von Kaspersky Security Network zu aktivieren, führen Sie die folgenden Befehle aus:","Zur Aktivierung der Nutzung von Kaspersky Security Network mit Statistiken:kesl-control --set-app-settings UseKSN=Extended","Zur Aktivierung der Nutzung von Kaspersky Security Network ohne Statistiken:kesl-control --set-app-settings UseKSN=Basic","Um die Nutzung von Kaspersky Security Network zu deaktivieren, führen Sie den folgenden Befehl aus:","kesl-control --set-app-settings UseKSN=No","Um die Nutzung von Kaspersky Security Network mithilfe einer Konfigurationsdatei zu aktivieren oder zu deaktivieren, führen Sie den folgenden Befehl aus:","kesl-control [-T] --set-app-settings --file=<Name der Konfigurationsdatei>","Wenn Kaspersky Endpoint Security auf einem Computer installiert ist und unter einer Richtlinie arbeitet, die in Kaspersky Security Center zugewiesen wurde, kann der Wert der Einstellung UseKSN nur mithilfe von Kaspersky Security Center geändert werden.","Wenn Kaspersky Endpoint Security auf einem Computer installiert ist und von der Richtlinie abgemeldet wird, wird der Wert der Einstellung UseKSN=No festgelegt.","Die Datei mit dem Text der Erklärung zu Kaspersky Security Network befindet sich im Verzeichnis opt/kaspersky/kesl/doc/ksn_license.<Sprach-ID>."," Verwendung von Kaspersky Security Network aktivieren und deaktivieren ","161357.htm");
Page[140]=new Array("Verbindung zum Kaspersky Security Network prüfen","Um die Verbindung mit Kaspersky Security Network zu überprüfen, führen Sie den folgenden Befehl aus:","kesl-control --app-info","In der Zeichenfolge KSN-Status wird der Status der Verbindung zum Kaspersky Security Network angezeigt:","Wenn der Status Extended angezeigt wird, ist Kaspersky Endpoint Security mit dem Kaspersky Security Network verbunden, Informationen aus der Wissensdatenbank können abgerufen werden, anonyme Statistiken und Informationen über die Arten und Quellen neuer Bedrohungen werden gesendet.Wenn der Status Basic angezeigt wird, ist Kaspersky Endpoint Security mit dem Kaspersky Security Network verbunden, Informationen aus der Wissensdatenbank können abgerufen werden, aber anonyme Statistiken und Informationen über die Arten und Quellen neuer Bedrohungen werden nicht gesendet.Wenn der Status No angezeigt wird, ist Kaspersky Endpoint Security nicht mit Kaspersky Security Network verbunden.Mögliche Gründe, warum keine Verbindung mit Kaspersky Security Network besteht:","Der Computer ist nicht mit dem Internet verbunden.Sie nehmen nicht an Kaspersky Security Network teil.Das Programm wurde nicht aktiviert oder die Lizenz ist abgelaufen.Es wurden Probleme im Zusammenhang mit dem Schlüssel gefunden. Beispielsweise könnte der Schlüssel auf der schwarzen Liste stehen."," Verbindung zum Kaspersky Security Network pr&#xFC;fen ","161358.htm");
Page[141]=new Array("Zusätzlicher Schutz durch Verwendung von Kaspersky Security Network","Kaspersky Lab bietet ein zusätzliches Schutzniveau durch Verwendung von Kaspersky Security Network. Ziel dieser Schutzmethode ist der effektive Kampf gegen komplizierte, ständig auftauchende Bedrohungen, sowie Zero-Day-Bedrohungen. Die integrierten Cloud-Technologien und fachspezifische Kenntnisse der Virenanalysten von Kaspersky Lab machen Kaspersky Endpoint Security zur ersten Wahl bei umfangreichem Schutz gegen die kompliziertesten Bedrohungen im Netzwerk.","Weitere Informationen über den zusätzlichen Schutz von Kaspersky Endpoint Security finden Sie auf der Website von Kaspersky Lab."," Zus&#xE4;tzlicher Schutz durch Verwendung von Kaspersky Security Network ","161359.htm");
Page[142]=new Array("Verwendung der grafischen Benutzeroberfläche von Kaspersky Endpoint Security","In diesem Abschnitt wird beschrieben, wie Sie mithilfe der grafischen Benutzeroberfläche (GUI) mit Kaspersky Endpoint Security arbeiten.","In diesem AbschnittDie grafische Benutzeroberfläche lokal aktivieren und deaktivierenProgrammoberflächeAufgaben und Komponenten verwaltenBerichte erstellenObjekte im Speicher anzeigenProtokolldatei erstellen"," Verwendung der grafischen Benutzeroberfl&#xE4;che von Kaspersky Endpoint Security ","161978.htm");
Page[143]=new Array("Die grafische Benutzeroberfläche lokal aktivieren und deaktivieren","Sie können die grafische Benutzeroberfläche (GUI) von Kaspersky Endpoint Security über die Befehlszeile lokal aktivieren bzw. deaktivieren.","Zum Aktivieren bzw. Deaktivieren der GUI sind Root-Rechte erforderlich.","So aktivieren bzw. deaktivieren Sie die grafische Benutzeroberfläche:","Führen Sie das Konfigurationsskript des Programms aus:/opt/kaspersky/kesl/bin/kesl-setup.pl –G","Führen Sie in der Befehlszeile eine der folgenden Aktionen aus:Wenn Sie die grafische Benutzeroberfläche aktivieren möchten, drücken Sie die Taste Y.Wenn Sie die GUI aktivieren, können Benutzer ohne Root-Rechte Aufgaben zur Untersuchung auf Befehl ausführen.","Wenn ein Benutzer angemeldet ist, wird eine GUI für diesen Benutzer gestartet, wenn alle notwendigen Bibliotheken vorhanden sind. Das Programmsymbol wird im Infobereich der Taskleiste angezeigt und Verknüpfungen werden erstellt.","Wenn Sie die GUI deaktivieren möchten, drücken Sie die Taste N.Das Programm verhindert, dass Benutzer die GUI starten. Das Programmsymbol und die Verknüpfungen werden entfernt."," Die grafische Benutzeroberfl&#xE4;che lokal aktivieren und deaktivieren ","161980.htm");
Page[144]=new Array("Programmoberfläche","In diesem Abschnitt werden die wichtigsten Elemente der grafischen Benutzeroberfläche (GUI) beschrieben."," Programmoberfl&#xE4;che ","161988.htm");
Page[145]=new Array("Programmsymbol im Infobereich","Nach der Aktivierung der grafischen Benutzeroberfläche von Kaspersky Endpoint Security erscheint das Programmsymbol im Infobereich auf der rechten Seite der Taskleiste.","Das Symbol fungiert als Verknüpfung zu Kontextmenü und Hauptfenster des Programms.","Das Kontextmenü des Programms enthält die folgenden Punkte:","Kaspersky Endpoint Security 10 SP1 für Linux. Öffnet das Programmhauptfenster. Im Programmhauptfenster können Sie den Schutzstatus Ihres Computers und den Status der Aufgabe zur Untersuchung auf Befehl und der Update-Aufgabe einsehen. Außerdem können Sie zu den Fenstern Berichte, Speicher, Einstellungen und Support navigieren.Beenden. Beendet die GUI von Kaspersky Endpoint Security. Sie können das Kontextmenü des Programmsymbols öffnen, indem Sie mit der rechten Maustaste auf das Programmsymbol im Infobereich klicken."," Programmsymbol im Infobereich ","161990.htm");
Page[146]=new Array("Programmhauptfenster","Das Hauptfenster von Kaspersky Endpoint Security enthält Oberflächenelemente, die Zugriff auf die Funktionen des Programms bieten.","Das Programmhauptfenster ist in mehrere Bereiche unterteilt:","Der mittlere Bereich des Fensters zeigt den Schutzstatus des Computers. Durch Klicken in diesen Bereich des Hauptfensters gelangen Sie zum Fenster Schutzzentrum.Auf der Registerkarte Untersuchen werden der Status der Aufgabe zur Untersuchung auf Befehl und die Anzahl der erkannten Bedrohungen angezeigt. Durch Klicken auf diese Registerkarte gelangen Sie zum Fenster Untersuchen. In diesem Fenster können Sie die Aufgaben zur Untersuchung auf Befehl, Untersuchung des Startsektors und Untersuchung des Arbeitsspeichers starten bzw. beenden. Außerdem können Sie Berichte zu diesen Aufgaben anzeigen.Die Registerkarte Update zeigt den Status von Update-Aufgabe und Antiviren-Datenbanken. Durch Klicken auf diese Registerkarte gelangen Sie zum Fenster Update. In diesem Fenster können Sie Update-Aufgaben und Aufgaben zur Update-Verteilung starten bzw. beenden. Außerdem können Sie Berichte zu diesen Aufgaben anzeigen.Der untere Bereich des E-Mail-Programmfensters enthält die folgenden Elemente:Die Schaltfläche Berichte. Durch Klicken auf diese Schaltfläche gelangen Sie zum Fenster Berichte, in dem Sie die Aufgabenstatistik und verschiedene Berichte anzeigen können.Die Schaltfläche Speicher. Durch Klicken auf diese Schaltfläche gelangen Sie zum Fenster Speicher, das Informationen zu Objekten im Speicher enthält.Die Schaltfläche Einstellungen. Durch Klicken auf diese Schaltfläche gelangen Sie zum Fenster \"Einstellungen\", in dem Sie die Teilnahme am Kaspersky Security Network sowie die Aufgaben für Echtzeitschutz, Firewall-Verwaltung, Anti-Cryptor und Überwachung der Datei-Integrität aktivieren bzw. deaktivieren können.Die Schaltfläche Support. Durch Klicken auf diese Schaltfläche gelangen Sie zum Fenster Support, das Informationen zur aktuellen Version von Kaspersky Endpoint Security, Informationen zu Lizenzen, Schlüsselstatus, Status der Datenbanken und Betriebssystem sowie Links zu Informationsressourcen von Kaspersky Lab enthält.Führen Sie einen der folgenden Schritte durch, um das Hauptfenster von Kaspersky Endpoint Security zu öffnen:","Doppelklicken Sie auf das Programmsymbol im Infobereich der Taskleiste oder klicken Sie mit der rechten Maustaste darauf.Klicken Sie mit der rechten Maustaste auf das Programm und wählen Sie Kaspersky Endpoint Security 10 Server Pack 1 für Linux aus."," Programmhauptfenster ","161987.htm");
Page[147]=new Array("Aufgaben und Komponenten verwalten","Über die grafische Benutzeroberfläche (GUI) von Kaspersky Endpoint Security können Sie standardmäßig folgende Aufgaben starten und beenden:","Aufgabe zur vollständigen Untersuchung (Scan_My_Computer)Aufgaben zur Untersuchung auf Befehl (Scan_File, Boot_Scan, Memory_Scan)Update-Aufgaben (Update, Rollback, Retranslate)Über die GUI von Kaspersky Endpoint Security können Sie auch die folgenden Komponenten aktivieren und deaktivieren:","EchtzeitschutzFirewall-VerwaltungAnti-CryptorÜberwachung der Datei-IntegritätDarüber hinaus können Sie Ihre Teilnahme am Kaspersky Security Network verwalten."," Aufgaben und Komponenten verwalten ","165423.htm");
Page[148]=new Array("Untersuchungsaufgaben starten und beenden","Die vollständige Untersuchung, die Untersuchung auf Befehl, die Untersuchung des Bootsektors und die Untersuchung des Arbeitsspeichers können über das GUI von Kaspersky Endpoint Security gestartet bzw. beendet werden.","So starten bzw. beenden Sie eine Untersuchungsaufgabe:","Öffnen Sie das Programmhauptfenster.Klicken Sie im Programmhauptfenster auf Untersuchung, um das Fenster Untersuchung zu öffnen.Führen Sie eine der folgenden Aktionen aus:Wenn Sie eine Aufgabe starten möchten, klicken Sie unter der betreffenden Untersuchungsaufgabe Aufgabe auf Starten.Der Fortschritt der laufenden Aufgabe wird angezeigt.","Wenn Sie eine Aufgabe beenden möchten, klicken Sie unter der betreffenden Untersuchungsaufgabe auf Beenden.Die Untersuchungsaufgabe wird angehalten, und Informationen zu untersuchten Objekten und erkannten Bedrohungen werden angezeigt.","Bei Bedarf können Sie auf Bericht anzeigen klicken, um den Bericht für die Aufgabe anzuzeigen.Das Fenster Berichte ist für Benutzer ohne Root-Rechte nur verfügbar, wenn die allgemeine Programmeinstellung UIReportsForRootOnly auf No gesetzt ist. Ansonsten ist das FensterBerichte nur für root-Benutzer verfügbar."," Untersuchungsaufgaben starten und beenden ","161997.htm");
Page[149]=new Array("Update-Aufgaben starten und beenden","Sie können Aufgaben zum Update, Rollback eines Datenbanken-Updates und Update Software-Distribution über die grafische Benutzeroberfläche von Kaspersky Endpoint Security starten bzw. beenden.","So starten bzw. beenden Sie eine Update-Aufgabe oder Aufgabe zur Update-Verteilung:","Öffnen Sie das Programmhauptfenster.Klicken Sie im Programmhauptfenster auf Update, um das Fenster Update zu öffnen.Führen Sie eine der folgenden Aktionen aus:Wenn Sie eine Aufgabe starten möchten, klicken Sie neben der betreffenden Aufgabe auf Starten.Der Fortschritt der laufenden Aufgabe wird angezeigt. ","Wenn die Update-Aufgabe erfolgreich abgeschlossen wurde, wird der Link Update des Rollbacks verfügbar und Sie können ein Rollback des letzten Updates durchführen.","Wenn Sie eine Aufgabe beenden möchten, klicken Sie neben der betreffenden Aufgabe auf Halt.Die Aufgabe wird angehalten.","Bei Bedarf können Sie auf Bericht anzeigen klicken, um den Bericht für die Aufgabe anzuzeigen.Das Fenster Berichte ist für Benutzer ohne Root-Rechte nur verfügbar, wenn die allgemeine Programmeinstellung UIReportsForRootOnly auf No gesetzt ist. Ansonsten ist das FensterBerichte nur für root-Benutzer verfügbar.","So führen Sie die Aufgabe für das Rollback eines Datenbanken-Updates aus:","Öffnen Sie das Programmhauptfenster.Klicken Sie im Programmhauptfenster auf Update, um das Fenster Update zu öffnen.Klicken Sie im Abschnitt Update auf den Link Update des Rollbacks, um ein Rollback des letzten erfolgreichen Datenbanken-Updates durchzuführen."," Update-Aufgaben starten und beenden ","165426.htm");
Page[150]=new Array("Programmkomponenten aktivieren und deaktivieren","Sie können die Komponenten für Echtzeitschutz, Firewall-Verwaltung, Anti-Cryptor und Überwachung der Datei-Integrität über die grafische Benutzeroberfläche von Kaspersky Endpoint Security jederzeit aktivieren und deaktivieren. .","Wenn eine Komponente aktiviert ist, ist die Schaltfläche Deaktivieren verfügbar. Standardmäßig ist nur der Echtzeitschutz aktiviert.","Wenn eine Komponente deaktiviert ist, ist die Schaltfläche Aktivieren verfügbar.","So aktivieren bzw. deaktivieren Sie eine Komponente:","Öffnen Sie das Programmhauptfenster.Klicken Sie im unteren Bereich des Programmhauptfensters auf die Schaltfläche Einstellungen.Das Fenster Einstellungen wird geöffnet.","Führen Sie im Fenster Einstellungen die folgenden Schritte für die gewünschte Komponente durch:Wenn Sie eine Komponente aktivieren möchten, klicken Sie auf Aktivieren.Wenn Sie eine Komponente deaktivieren möchten, klicken Sie auf Deaktivieren."," Programmkomponenten aktivieren und deaktivieren ","162000.htm");
Page[151]=new Array("Die Teilnahme am Kaspersky Security Network verwalten","Sie können die Teilnahme an Kaspersky Security Network jederzeit verwalten.","So aktivieren Sie Kaspersky Security Network:","Öffnen Sie das Programmhauptfenster.Klicken Sie im unteren Bereich des Programmhauptfensters auf die Schaltfläche Einstellungen.Das Fenster Einstellungen wird geöffnet.","Wählen Sie im Fenster Einstellungen eine der folgenden Optionen aus:Kaspersky Security Network mit Statistiken—Kaspersky Security Network zu aktivieren, Informationen aus der Wissensdatenbank abrufen und anonyme Statistiken und Informationen über die Arten und Quellen neuer Bedrohungen senden.Kaspersky Security Network ohne Statistiken—Informationen aus der Wissensdatenbank abrufen, jedoch keine anonymen Statistiken und Informationen über die Arten und Quellen neuer Bedrohungen senden.Klicken Sie auf die Schaltfläche Aktivieren.Lesen Sie im Fenster Teilnahme an Kaspersky Security Network die Erklärung zu Kaspersky Security Network sorgfältig, und wählen Sie eine der folgenden Optionen:Ich bestätige, dass ich die Bedingungen dieses KSN vollständig gelesen und verstanden habe und diese akzeptiere—Zur Aktivierung von Kaspersky Security Network.Ich bin mit den Bedingungen dieser Erklärung zu KSN nicht einverstanden—Zum Deaktivieren der Nutzung von Kaspersky Security Network.Klicken Sie auf OK.Die Schaltfläche OK ist bei Auswahl der Option Nicht ausgewählt nicht verfügbar.","So deaktivieren Sie Kaspersky Security Network:","Öffnen Sie das Programmhauptfenster.Klicken Sie im unteren Bereich des Programmhauptfensters auf die Schaltfläche Einstellungen.Das Fenster Einstellungen wird geöffnet.","Klicken Sie im Fenster Einstellungen auf die Schaltfläche Deaktivieren.Führen Sie im folgenden Fenster eine der folgenden Aktionen aus:Klicken Sie auf Ja, um die Deaktivierung von Kaspersky Security Network zu bestätigen.Klicken Sie auf Abbrechen, um die Teilnahme am Kaspersky Security Network fortzusetzen."," Die Teilnahme am Kaspersky Security Network verwalten ","165428.htm");
Page[152]=new Array("Berichte erstellen","In diesem Abschnitt wird beschrieben, wie Sie in der grafischen Benutzeroberfläche von Kaspersky Endpoint Security Berichte anzeigen können."," Berichte erstellen ","161993.htm");
Page[153]=new Array("Prinzipien der Berichtsverwaltung","Das Fenster Berichte ist für Benutzer ohne Root-Rechte nur verfügbar, wenn die allgemeine Programmeinstellung UIReportsForRootOnly auf No gesetzt ist. Ansonsten ist das FensterBerichte nur für root-Benutzer verfügbar.","Informationen zur Ausführung der Aufgaben von Kaspersky Endpoint Security werden in Berichten erfasst.","Berichtdaten werden als Tabelle angezeigt, die eine Liste von Ereignissen enthält. Jede Zeile der Tabelle enthält Informationen über ein separates Ereignis. Ereignisattribute befinden sich in den Tabellenspalten. Ereignisse, die während der Ausführung verschiedener Aufgaben protokolliert werden, haben unterschiedliche Attribute.","Die folgenden Berichte, die in einem Menü auf der linken Seite aufgelistet sind, stehen zur Verfügung:","Statistisch. Enthält statistische Angaben der Aufgabe zum Echtzeitschutz und der Aufgaben zur Untersuchung auf Befehl. Durch Klicken auf Neu laden können Sie den angezeigten Bericht aktualisieren.Sobald die Aufgabe beendet wird, werden die Statistikdaten der Aufgabe zum Echtzeitschutz zurückgesetzt. Es erfolgt kein Zurücksetzen der Statistiken für die Aufgabe zur Untersuchung auf Befehl, sondern die Statistikdatenmenge wird erhöht, während das Programm auf dem Computer installiert wird.","Systemprüfung. Dieser Bericht enthält Informationen über Ereignisse, die während der Interaktion des Benutzers mit dem Programm auftreten. Er enthält außerdem Informationen über Ereignisse, die während des allgemeinen Programmbetriebs auftreten.Bedrohungsschutz. Diese Berichte enthalten Informationen über Ereignisse, die während der Ausführung der folgenden Komponenten von Kaspersky Endpoint Security protokolliert werden:Anti-CryptorÜberwachung der Datei-IntegritätFirewall-VerwaltungDatei-Anti-VirusOn-Demand-Aufgaben. Diese Berichte enthalten Informationen über Ereignisse, die während der Ausführung der folgenden Kaspersky Endpoint Security-Aufgaben protokolliert werden:UntersuchungsaufgabenUpdateIntegritätsprüfungIn Berichten werden folgende Wichtigkeitsstufen für Ereignisse verwendet:","Informative Ereignisse. Formale Ereignisse, die normalerweise keine wichtigen Informationen enthalten.Wichtige Ereignisse. Ereignisse, die Aufmerksamkeit erfordern, weil sie auf wichtige Situationen im Betrieb von Kaspersky Endpoint Security hindeuten.Kritische Ereignisse. Ereignisse von kritischer Bedeutung, die auf Probleme beim Betrieb von Kaspersky Endpoint Security oder auf Schwachstellen beim Schutz des Computers des Benutzers hindeuten.Für eine zweckmäßige Verarbeitung von Berichten können Sie die auf dem Bildschirm gezeigten Daten folgendermaßen ändern:","Filtern Sie die Ereignisliste nach Zeitraum.Suchen Sie mithilfe der Suchfunktion nach einem bestimmten Ereignis.Zeigen Sie das ausgewählte Ereignis in einem separaten Abschnitt an."," Prinzipien der Berichtsverwaltung ","161992.htm");
Page[154]=new Array("Berichte anzeigen","Das Fenster Berichte ist für Benutzer ohne Root-Rechte nur verfügbar, wenn die allgemeine Programmeinstellung UIReportsForRootOnly auf No gesetzt ist. Ansonsten ist das FensterBerichte nur für root-Benutzer verfügbar.","So zeigen Sie Berichte an:","Öffnen Sie das Programmhauptfenster.Klicken Sie im unteren Bereich des Programmhauptfensters auf die Schaltfläche Berichte.Das Fenster Berichte wird geöffnet.","Um einen bestimmten Bericht anzuzeigen, wählen Sie im linken Bereich des Fensters Berichte die betreffende Aufgabe aus der Liste der Aufgaben.Ein Bericht wird im rechten Bereich des Fensters angezeigt und enthält eine Liste von Ereignissen bei der Ausführung der ausgewählten Aufgabe von Kaspersky Endpoint Security.","Standardmäßig werden die Ereignisse in aufsteigender Reihenfolge, nach den Werten in der Spalte Datum sortiert. Sie können eine andere Reihenfolge wählen, indem Sie auf die gewünschte Spaltenüberschrift klicken.","Um eine detaillierte Zusammenfassung jedes Ereignisses in einem Bericht anzuzeigen, wählen Sie das entsprechende Ereignis im Bericht aus.Die Zusammenfassung der Ereignisse wird im unteren Bereich des Fensters angezeigt."," Berichte anzeigen ","161994.htm");
Page[155]=new Array("Objekte im Speicher anzeigen","Um Objekte anzuzeigen, die von Kaspersky Endpoint Security in den Speicher verschoben wurden, gehen Sie wie folgt vor:","Öffnen Sie das Programmhauptfenster.Klicken Sie auf die Schaltfläche Speicher.Im folgenden Fenster werden Informationen zu Objekten im Speicher werden angezeigt.","Sie können folgende Informationen zu Objekten im Speicher anzeigen:","Name der Bedrohung.Den vollständigen Pfad zu einem Objekt.Das Datum, an dem ein Objekt in den Speicher verschoben wurde.Das Datum, an dem ein Objekt aus dem Speicher gelöscht wird. Dieses Feld wird angezeigt, wenn die Einstellung DaysToLive festgelegt ist.Die Objektgröße.Sie können Objekte aus dem Speicher in ihren ursprünglichen Verzeichnissen wiederherstellen. Sie können auch Objekte aus dem Speicher löschen. Gelöschte Objekte können in der Zukunft nicht wiederhergestellt werden. Informationen über diese Aktionen werden im Ereignisprotokoll festgehalten. "," Objekte im Speicher anzeigen ","161999.htm");
Page[156]=new Array("Protokolldatei erstellen","So erstellen Sie eine Protokolldatei:","Öffnen Sie das Programmhauptfenster.Klicken Sie auf die Schaltfläche Support.Klicken Sie im Fenster Support auf Ablaufverfolgung.Wählen Sie in der Dropdown-Liste Ebene eine Genauigkeitsstufe.Sie sollten sich bei der Festlegung der erforderlichen Genauigkeitsstufe an die Empfehlung eines Experten des technischen Supports halten. Standardmäßig hat die Genauigkeitsstufe den Wert Diagnose (300).","Um den Protokolliervorgang zu starten, klicken Sie auf Aktivieren.Um den Protokolliervorgang zu stoppen, klicken Sie auf Deaktivieren.Die erstellten Protokolldateien werden im Verzeichnis /var/log/kaspersky/kesl/ gespeichert."," Protokolldatei erstellen ","166209.htm");
Page[157]=new Array("Kontaktaufnahme mit dem Technischen Support","Dieser Abschnitt beschreibt, wie Sie technischen Support erhalten, und nennt die Voraussetzungen, die dafür erfüllt sein müssen.","In diesem AbschnittSo erhalten Sie technischen Support.Technischer Support am TelefonTechnischer Support über das Kaspersky CompanyAccountVerwendung einer Protokolldatei und eines AVZ-Skripts"," Kontaktaufnahme mit dem Technischen Support ","70331.htm");
Page[158]=new Array("So erhalten Sie technischen Support.","Sollten Sie in der Dokumentation des Programms und in einer der anderen Informationsquellen zum Programm keine Lösung für Ihr Problem finden, so empfehlen wir Ihnen, sich an den Technischen Support von Kaspersky Lab wenden. Die Mitarbeiter des Technischen Support beantworten Ihre sämtlichen Fragen zur Installation und Verwendung des Programms.","Bitte beachten Sie die Support-Regeln, bevor Sie sich an den Technischen Support wenden.","Eine Kontaktaufnahme mit den Support-Experten ist auf folgende Weise möglich:","Telefonisch. Auf diese Weise können Sie mit den Experten unseres russischsprachigen oder internationalen Technischen Support Kontakt aufnehmen.Anfrage aus dem Portal My Kaspersky senden. Auf diese Weise können Sie mithilfe des Anfrageformulars Kontakt mit unseren Experten aufnehmen.Der Technische Support steht nur Benutzern zur Verfügung, die eine Lizenz für die Nutzung des Programms haben. Für die Benutzer von Testversionen ist der Technische Support nicht verfügbar."," So erhalten Sie technischen Support. ","85903.htm");
Page[159]=new Array("Technischer Support am Telefon","Sie können die Spezialisten des Technischen Supports aus den meisten Regionen der Welt anrufen. Informationen über die Möglichkeiten für den Erhalt technischen Supports in Ihrer Region finden Sie auf der Website des Technischen Supports von Kaspersky Lab.","Bitte beachten Sie die Support-Regeln, bevor Sie sich an den Technischen Support wenden."," Technischer Support am Telefon ","70152.htm");
Page[160]=new Array("Technischer Support über das Kaspersky CompanyAccount","Kaspersky CompanyAccount ist ein Webdienst für Unternehmen, die Programme von Kaspersky Lab verwenden. Das Portal Kaspersky CompanyAccount dient der Kontaktaufnahme mit den Spezialisten von Kaspersky Lab über elektronische Anfragen. Sie können Kaspersky CompanyAccount verwenden, um den Status Ihrer Online-Anfragen zu verfolgen sowie deren Verlauf zu speichern.","Sie können alle Mitarbeiter Ihrer Organisation im Rahmen eines Benutzerkontos für Kaspersky CompanyAccount registrieren. Mithilfe eines Benutzerkontos können Sie die elektronischen Anfragen der registrierten Mitarbeiter an Kaspersky Lab zentral kontrollieren, sowie die Berechtigungen dieser Mitarbeiter für Kaspersky CompanyAccount verwalten.","Das Portal Kaspersky CompanyAccount ist in folgenden Sprachen verfügbar:","EnglischSpanischItalienischDeutschPolnischPortugiesischRussischFranzösischJapanisch.Weitere Informationen über Kaspersky CompanyAccount finden Sie auf der Website des Technischen Supports."," Technischer Support &#xFC;ber das Kaspersky CompanyAccount ","68417.htm");
Page[161]=new Array("Verwendung einer Protokolldatei und eines AVZ-Skripts","Nachdem Sie ein Problem an den Technischen Support von Kaspersky Lab gemeldet haben, werden Sie möglicherweise aufgefordert, einen Bericht mit Informationen über die Ausführung von Kaspersky Endpoint Security zu erstellen und an den Technischen Support von Kaspersky Lab zu senden. Spezialisten des Technischen Supports können Sie auch bitten, eine Protokolldatei zu erstellen. Mithilfe der Protokolldatei kann die Ausführung von Programmbefehlen Schritt für Schritt untersucht und festgestellt werden, wann Fehler auftreten.","Nachdem die Spezialisten des Technischen Supports die von Ihnen gesendeten Daten analysiert haben, können sie ein AVZ-Skript erstellen und an Sie senden. Durch die Ausführung von AVZ-Skripten ist es möglich, aktive Prozesse auf Bedrohungen zu analysieren, den Computer nach Bedrohungen zu durchsuchen, infizierte Dateien zu desinfizieren oder zu löschen und Systemuntersuchungsberichte zu erstellen."," Verwendung einer Protokolldatei und eines AVZ-Skripts ","73375.htm");
Page[162]=new Array("Anhänge","Dieser Abschnitt enthält Informationen, die den Haupttext des Dokuments ergänzen.","In diesem AbschnittStandardaufgabenkonfigurationsdateienEinstellungen für gemeinsame Arbeit: Kaspersky Anti-Virus für Linux Mail ServerRückgabecodes der Befehlszeile"," Anh&#xE4;nge ","161364.htm");
Page[163]=new Array("Standardaufgabenkonfigurationsdateien","Dieser Abschnitt enthält die Standardkonfigurationsdateien für Aufgaben in Kaspersky Endpoint Security.","Sie können Konfigurationsdateien jederzeit ändern. Ferner können Sie Einstellungswerte über die Befehlszeile ändern."," Standardaufgabenkonfigurationsdateien ","161365.htm");
Page[164]=new Array("Regeln zum Ändern von Konfigurationsdateien in Kaspersky Endpoint Security","Beachten Sie folgende Regeln zum Bearbeiten von Konfigurationsdateien:","Sie müssen alle obligatorischen Einstellungen in der Konfigurationsdatei angeben. Sie können individuelle Aufgabeneinstellungen ohne Datei mithilfe der Befehlszeile angeben.Wenn eine Einstellung zu einem bestimmten Abschnitt gehört, dürfen Sie ihn nur dort platzieren. Innerhalb der Grenzen eines Abschnitts können Sie die Einstellungen in beliebiger Reihenfolge anordnen.Schließen Sie Namen der Abschnitte in eckige Klammern [ ] ein.Geben Sie die Einstellungswerte im Format Name der Einstellung=Wert an (Leerzeichen im Namen und in den Werten einer Einstellung werden nicht verarbeitet).","Beispiel:","[ScanScope.item_0000]","AreaDesc=Home","AreaMask.item_0000=*doc","Path=/home","Leerzeichen und Tabulator werden vor dem ersten Anführungszeichen und nach dem letzten Anführungszeichen des Zeilenwerts sowie am Anfang und Ende des Zeilenwerts, der nicht in Anführungszeichen steht, ignoriert.","Wenn Sie einem Parameter mehrere Werte zuweisen müssen, wiederholen Sie die Einstellung entsprechend der Anzahl der Werte, die Sie angeben möchten.","Beispiel:","AreaMask.item_0000=*xml","AreaMask.item_0001=*doc","Beachten Sie bei der Angabe von Werten für folgende Einstellungstypen die Groß- und Kleinschreibung:Namen (Masken) von zu untersuchenden und auszuschließenden ObjektenNamen (Masken) von BedrohungenFür die Werten der verbleibenden Einstellungen ist die Groß- und Kleinschreibung unwesentlich.","Geben Sie die Werte für Boolesche Einstellungen folgendermaßen an: Yes– No.Verwenden Sie Anführungszeichen, um Werte für Zeichenfolgen mit Leerzeichen einzuschließen, (z.B. Namen von Dateien oder Verzeichnissen und ihre Pfade, Datum und Zeit im Format \"JJJJ-MM-TT HH:MM:SS\").Alle anderen Werte können Sie sowohl mit als auch ohne Anführungszeichen eingeben.","Beispiel:","AreaDesc=\"Mail-Datenbanken untersuchen\"","Ein einzelnes Anführungszeichen am Beginn oder am Ende einer Zeile gilt als Fehler."," Regeln zum &#xC4;ndern von Konfigurationsdateien in Kaspersky Endpoint Security ","161266.htm");
Page[165]=new Array("Konfigurationsdatei der Aufgabe zum Echtzeitschutz","ScanArchived=No","ScanSfxArchived=No","ScanMailBases=No","ScanPlainMail=No","TimeLimit=60","SizeLimit=0","FirstAction=Recommended","SecondAction=Block","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","ScanByAccessType=SmartCheck","[ScanScope.item_0000]","AreaDesc=Alle Objekte","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," Konfigurationsdatei der Aufgabe zum Echtzeitschutz ","161366.htm");
Page[166]=new Array("Konfigurationsdatei der Aufgaben zur Untersuchung auf Befehl","ScanArchived=Yes","ScanSfxArchived=Yes","ScanMailBases=No","ScanPlainMail=No","TimeLimit=0","SizeLimit=0","FirstAction=Recommended","SecondAction=Skip","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","[ScanScope.item_0000]","AreaDesc=Alle Objekte","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," Konfigurationsdatei der Aufgaben zur Untersuchung auf Befehl ","161367.htm");
Page[167]=new Array("Konfigurationsdatei der Aufgabe zur benutzerdefinierten Untersuchung","ScanArchived=Yes","ScanSfxArchived=Yes","ScanMailBases=No","ScanPlainMail=No","TimeLimit=0","SizeLimit=0","FirstAction=Recommended","SecondAction=Skip","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","[ScanScope.item_0000]","AreaDesc=Alle Objekte","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," Konfigurationsdatei der Aufgabe zur benutzerdefinierten Untersuchung ","161368.htm");
Page[168]=new Array("Konfigurationsdatei der Aufgabe zur Untersuchung des Bootsektors","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","Action=Cure"," Konfigurationsdatei der Aufgabe zur Untersuchung des Bootsektors ","161369.htm");
Page[169]=new Array("Konfigurationsdatei der Aufgabe zur Untersuchung des Arbeitsspeichers","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportUnprocessedObjects=No","Action=Cure"," Konfigurationsdatei der Aufgabe zur Untersuchung des Arbeitsspeichers ","161370.htm");
Page[170]=new Array("Konfigurationsdatei der Update-Aufgabe","SourceType=\"KLServers\"","UseKLServersWhenUnavailable=Yes","IgnoreProxySettingsForKLServers=No","IgnoreProxySettingsForCustomSources=No","ApplicationUpdateMode=DownloadOnly","ConnectionTimeout=10"," Konfigurationsdatei der Update-Aufgabe ","161371.htm");
Page[171]=new Array("Konfigurationsdatei der Aufgabe zum Kopieren von Updates","SourceType=KLServers","UseKLServersWhenUnavailable=Yes","ConnectionTimeout=10","ApplicationUpdateMode=DownloadOnly"," Konfigurationsdatei der Aufgabe zum Kopieren von Updates ","161372.htm");
Page[172]=new Array("Konfigurationsdatei der Aufgabe zur Speicherverwaltung","DaysToLive=90","BackupSizeLimit=0","BackupFolder=/var/opt/kaspersky/kesl/common/objects-backup/"," Konfigurationsdatei der Aufgabe zur Speicherverwaltung ","161373.htm");
Page[173]=new Array("Konfigurationsdatei der Firewall-Verwaltungsaufgabe","DefaultIncomingAction=Erlauben","DefaultIncomingPacketAction=Erlauben","[NetworkZonesTrusted]","[NetworkZonesLocal]","[NetworkZonesPublic]"," Konfigurationsdatei der Firewall-Verwaltungsaufgabe ","161374.htm");
Page[174]=new Array("Konfigurationsdatei der Aufgabe zur Überwachung der Datei-Integrität","UseExcludeMasks=No","[ScanScope.item_0000]","AreaDesc=Kaspersky internal objects","UseScanArea=Yes","Path=/opt/kaspersky/kesl/","AreaMask.item_0000=*"," Konfigurationsdatei der Aufgabe zur &#xDC;berwachung der Datei-Integrit&#xE4;t ","161375.htm");
Page[175]=new Array("Konfigurationsdatei der Aufgabe zum Schutz vor Verschlüsselung","UseHostBlocker=yes","BlockTime=30","UseExcludeMasks=no","[ScanScope.item_0000]","AreaDesc=AllSharedFolders","UseScanArea=yes","Path=AllShared","AreaMask.item_0000=*"," Konfigurationsdatei der Aufgabe zum Schutz vor Verschl&#xFC;sselung ","161376.htm");
Page[176]=new Array("Einstellungen für gemeinsame Arbeit: Kaspersky Anti-Virus für Linux Mail Server","Gehen Sie folgendermaßen vor, um die gemeinsame Ausführung von Kaspersky Endpoint Security 10 und Kaspersky Anti-Virus für Linux Mail Server anzupassen:","Speichern Sie die Einstellungen der Aufgabe zum Echtzeitschutz in der Konfigurationsdatei mithilfe des folgenden Befehls:kesl-control --get-settings 1 --file <vollständiger Dateipfad>","Öffnen Sie die erstellte Konfigurationsdatei zum Bearbeiten.Fügen Sie der erstellten Datei folgenden Abschnitt hinzu:[ExcludedFromScanScope.item_#]","Path=</var/opt/kaspersky/klms>","Wiederholen Sie den oben genannten Abschnitt für alle Mail-Agenten, die mit Kaspersky Anti-Virus für Linux Mail Server integriert wurden.Um das temporäre Verzeichnis für Filter und Dienste von Kaspersky Anti-Virus für Linux Mail Server von der Untersuchung auszuschließen, fügen Sie der erstellten Datei folgenden Abschnitt hinzu:[ExcludedFromScanScope.item_#]","Path=/tmp/klmstmp","Speichern Sie die Änderungen in der Konfigurationsdatei.Importieren Sie die Einstellungen aus der Konfigurationsdatei in die Aufgabe zum Echtzeitschutz mithilfe des folgenden Befehls:kesl-control --set-settings 1 --file <vollständiger Dateipfad>"," Einstellungen f&#xFC;r gemeinsame Arbeit: Kaspersky Anti-Virus f&#xFC;r Linux Mail Server ","161377.htm");
Page[177]=new Array("Rückgabecodes der Befehlszeile","In diesem Abschnitt werden die Rückgabecodes der Befehlszeile beschrieben.","0 – Befehl/Aufgabe erfolgreich ausgeführt","1 – Allgemeiner Fehler in den Argumenten des Befehls","2 – Fehler in den übergebenen Programmeinstellungen","64 – Kaspersky Endpoint Security wird nicht ausgeführt","66 – Antiviren-Datenbanken wurden nicht heruntergeladen (wird nur vom Befehl --app-info) verwendet","67 – Aktivierung 2.0 wurde aufgrund von Netzwerkproblemen fehlerhaft abgeschlossen","68 – Befehlsausführung unmöglich, da das Programm gemäß einer Richtlinie ausgeführt wird","128 – Unbekannter Fehler","65 – Alle übrigen Fehler"," R&#xFC;ckgabecodes der Befehlszeile ","161378.htm");
Page[178]=new Array("AO Kaspersky Lab","Kaspersky Lab ist ein weltweit anerkannter Anbieter von Systemen zum Schutz von Computern vor digitalen Bedrohungen, einschließlich Viren und anderer Schadsoftware, unerwünschten E-Mails (Spam) sowie Netzwerk- und Hacking-Angriffen.","Seit 2008 gehört Kaspersky Lab international zu den vier führenden Unternehmen im Bereich der IT-Sicherheit für Endbenutzer (Rating des \"IDC Worldwide Endpoint Security Revenue by Vendor\"). Kaspersky Lab ist der bevorzugte Anbieter von Computerschutzsystemen für Privatanwender in Russland (IDC Endpoint Tracker 2014).","Kaspersky Lab wurde 1997 in Russland gegründet. Inzwischen ist das Unternehmen zu einer internationalen Unternehmensgruppe mit 38 Büros in 33 Ländern gewachsen. Das Unternehmen beschäftigt über 3.000 hochspezialisierte Spezialisten.","Produkte. Die Produkte von Kaspersky Lab schützen sowohl Heimanwender als auch Firmennetzwerke.","Die Palette der Heimanwender-Produkte umfasst Sicherheitsprogramme für Desktops, Laptops, Tablets, Smartphones und andere mobile Geräte.","Das Unternehmen bietet Schutz- und Steuerungslösungen und -technologien für Workstations und mobile Geräte, virtuelle Maschinen, File- und Webserver, Mail-Gateways und Firewalls. Zum Portfolio des Unternehmens gehören auch spezialisierte Produkte zum Schutz vor DDoS-Angriffen, zum Schutz von industriellen Steuerungssystemen und zur Verhinderung von Finanzbetrug. In Verbindung mit zentralisierten Administrationstools ermöglichen es diese Lösungen, netzwerkweit einen effektiven automatisierten Schutz vor Computerbedrohungen aufzubauen. Die Produkte von Kaspersky Lab sind von großen Testlabors zertifiziert, mit Software verschiedener Hersteller kompatibel und für den Einsatz auf vielen Hardware-Plattformen optimiert.","Die Virenanalysten von Kaspersky Lab sind rund um die Uhr im Einsatz. Sie finden und analysieren jeden Tag Hunderttausende neue Computerbedrohungen und entwickeln Tools, um diese Gefahren zu erkennen und zu desinfizieren. Diese Informationen fließen in die Datenbanken ein, auf welche die Programme von Kaspersky Lab zurückgreifen.","Technologien. Viele Technologien, die für eine moderne Antiviren-Anwendung unerlässlich sind, wurden ursprünglich von Kaspersky Lab entwickelt. Es ist kein Zufall, dass viele andere Entwickler die Kaspersky Anti-Virus-Engine in ihren Produkten verwenden, darunter auch: Alcatel-Lucent, Alt-N, Asus, BAE Systems, Blue Coat, Check Point, Cisco Meraki, Clearswift, D-Link, Facebook, General Dynamics, H3C, Juniper Networks, Lenovo, Microsoft, NETGEAR, Openwave Messaging, Parallels, Qualcomm, Samsung, Stormshield, Toshiba, Trustwave, Vertu und ZyXEL. Eine Vielzahl von innovativen Technologien des Unternehmens ist durch Patente geschützt.","Leistungen. Im Verlauf eines kontinuierlichen Kampfes mit Computerbedrohungen hat Kaspersky Lab Hunderte von Auszeichnungen erworben. Nach Tests und Untersuchungen des renommierten österreichischen Testlabors AV-Comparatives im Jahr 2014 belegte Kaspersky Lab bei der Anzahl der erworbenen Advanced+-Zertifikate einen Platz unter den ersten beiden Anbietern und wurde schließlich mit dem Prädikat „Top Rated“ ausgezeichnet. Die höchste Auszeichnung stellt für Kaspersky Lab aber das Vertrauen seiner Benutzer auf der ganzen Welt dar. Die Produkte und Technologien des Unternehmens schützen mehr als 400 Millionen Nutzer und mehr als 270.000 Unternehmenskunden."," ","Website von Kaspersky Lab:","https://www.kaspersky.de ","Virenenzyklopädie:","https://securelist.com ","Viren-Labor:","https://virusdesk.kaspersky.com (zur Auswertung verdächtiger Dateien und Websites)","Webforum von Kaspersky Lab:","https://forum.kaspersky.com/index.php?/forum/26-deutschsprachiges-benutzer-forum/ "," "," AO Kaspersky Lab ","34744.htm");
Page[179]=new Array("Informationen über den Code von Drittherstellern","Informationen über den Code von Drittherstellern finden Sie in der Datei legal_notices.txt, die sich im Installationsverzeichnis des Programms befindet."," Informationen &#xFC;ber den Code von Drittherstellern ","161380.htm");
Page[180]=new Array("Markeninformationen","Eingetragene Marken und Dienstleistungszeichen sind Eigentum der jeweiligen Rechteinhaber.","Core ist ein Markenzeichen der Intel Corporation in den USA und/oder in anderen Ländern.","Linux ist ein in den USA und/oder in anderen Ländern eingetragenes Markenzeichen von Linus Torvalds.","Microsoft, Outlook, Outlook Express und Windows sind in den USA und in anderen Ländern eingetragene Marken der Microsoft Corporation.","Novell ist ein in den USA und in anderen Ländern eingetragenes Markenzeichen von Novell Inc.","Oracle ist ein eingetragenes Markenzeichen von Oracle und/oder von verbundenen Unternehmen.","Red Hat, Red Hat Enterprise Linux und CentOS sind in den USA und in anderen Ländern eingetragene Marken von Red Hat Inc.","Debian ist eine registrierte Marke von Software in the Public Interest, Inc.","SUSE ist ein in den USA und in anderen Ländern eingetragenes Markenzeichen von SUSE LLC."," Markeninformationen ","161381.htm");
Page[181]=new Array("Ein Code, den Sie beim Kauf einer Lizenz für Kaspersky Endpoint Security erhalten. Dieser Code wird für die Aktivierung des Programms benötigt.","Der Aktivierungscode besteht aus einer eindeutigen Folge von zwanzig lateinischen Zeichen und Ziffern im Format XXXXX-XXXXX-XXXXX-XXXXX.","Aktivierungscode","95897.htm#o112627");
Page[182]=new Array("Ein Schlüssel, der momentan vom Programm verwendet wird.","Aktiver Schlüssel","95897.htm#o111595");
Page[183]=new Array("Ein Schlüssel, der das Recht auf Nutzung des Programms bestätigt, jedoch im Augenblick nicht aktiviert ist.","Reserveschlüssel","95897.htm#o111599");
Page[184]=new Array("Eine Auswahl von Computern mit gemeinsamen Funktionen, auf denen eine gemeinsame Auswahl von Programmen von Kaspersky Lab installiert ist. Computer sind gruppiert, damit sie komfortabel als einzelne Einheit verwaltet werden können. Eine Gruppe kann andere Gruppen beinhalten. Es ist möglich, Gruppenrichtlinien und Gruppenaufgaben für jedes installierte Programm in der Gruppe zu erstellen.","Administrationsgruppe","95897.htm#o112575");
Page[185]=new Array("Eine Komponente von Kaspersky Security Center, die Informationen über alle Programme von Kaspersky Lab, die innerhalb des Unternehmensnetzwerks installiert sind, zentral speichert. Sie kann auch zur Verwaltung dieser Programme verwendet werden.","Administrationsserver","95897.htm#o112576");
Page[186]=new Array("Datenbanken, die Informationen über Bedrohungen der Computersicherheit enthalten, die Kaspersky Lab zum Veröffentlichungsdatum der Antiviren-Datenbanken bekannt waren. Einträge in Antiviren-Datenbanken ermöglichen die Erkennung von bösartigem Code in untersuchten Objekten. Die Antiviren-Datenbanken werden von Kaspersky Lab-Spezialisten erstellt und stündlich aktualisiert.","Antiviren-Datenbanken","95897.htm#o111582");
Page[187]=new Array("Eine spezielle Komponente, die die Schnittstelle für die Programmverwaltung über die Verwaltungskonsole bereitstellt. Jedes Programm hat sein eigenes Plug-in. Es ist in allen Kaspersky Lab-Programmen enthalten, die mit Kaspersky Endpoint Security verwaltet werden können.","Verwaltungs-Plug-in des Programms","95897.htm#o112588");
Page[188]=new Array("Ein spezieller Speicher für Sicherungskopien von Dateien, die vor dem Versuch der Desinfektion oder Löschung erstellt werden.","Backup","95897.htm#o112592");
Page[189]=new Array("Ein Verfahren zur Verarbeitung von infizierten Objekten, das zu einer vollständigen oder teilweisen Wiederherstellung von Daten führt. Nicht alle infizierten Objekte können desinfiziert werden.","Desinfektion","95897.htm#o112629");
Page[190]=new Array("Eine Ausnahme ist ein Objekt, das von einem Kaspersky Lab-Programm von der Untersuchung ausgeschlossen wird. Sie können Dateien bestimmter Formate, Dateimasken, einen bestimmten Bereich (z. B. Ordner oder Programm), Programmprozesse oder Objekte nach Bedrohungstyp gemäß der Klassifikation der Virenenzyklopädie von der Untersuchung ausschließen. Jeder Aufgabe kann eine Reihe von Ausnahmen zugeordnet werden.","Ausnahme","95897.htm#o112624");
Page[191]=new Array("Eine Situation, in der ein Programm von Kaspersky Lab ein nicht infiziertes Objekt als infiziert betrachtet, weil dessen Code dem eines Virus ähnelt.","Falsch positiv","95897.htm#o112631");
Page[192]=new Array("Darstellung eines Dateinamens mit Hilfe von Wildcards. Die Standard-Wildcards, die in Dateimasken verwendet werden, sind „*“ und „?“, wobei „*“ für eine beliebige Anzahl beliebiger Zeichen steht und „?“ für ein beliebiges einzelnes Zeichen.","Dateimaske","95897.htm#o111603");
Page[193]=new Array("Eine Aufgabe, die für eine Administrationsgruppe definiert und auf allen Client-Computern ausgeführt wird, die in dieser Administrationsgruppe enthalten sind.","Gruppenaufgabe","95897.htm#o112572");
Page[194]=new Array("Ein Objekt, das aufgrund seiner Struktur oder seines Formats von Angreifern als „Behälter“ zum Speichern und Verbreiten von bösartigem Code verwendet werden kann. In der Regel sind das ausführbare Dateien mit Dateierweiterungen wie .com, .exe und .dll. Das Risiko des Eindringens von bösartigem Code in solche Dateien ist ziemlich hoch.","Infizierbares Objekt","95897.htm#o112644");
Page[195]=new Array("Ein Objekt, bei dem ein Teil des Codes vollständig mit einem Teil des Codes bekannter Schadsoftware übereinstimmt. Kaspersky Lab rät davon ab, auf solche Objekte zuzugreifen.","Infiziertes Objekt.","95897.htm#o112621");
Page[196]=new Array("Eine Liste der HTTP- und FTP-Server von Kaspersky Lab, von denen das Programm Datenbanken-Updates auf mobile Geräte herunterlädt.","Kaspersky-Lab-Update-Server","95897.htm#o112658");
Page[197]=new Array("Ein zeitlich begrenztes Nutzungsrecht für ein Programm, das Ihnen auf Basis eines Endbenutzer-Lizenzvertrags überlassen wird.","Lizenz","95897.htm#o135751");
Page[198]=new Array("Ein Dokument, das von Kaspersky Lab gemeinsam mit einer Schlüsseldatei oder einem Aktivierungscode bereitgestellt wird. Dieses Dokument enthält Informationen über die bereitgestellte Lizenz.","Lizenzzertifikat","95897.htm#o166042");
Page[199]=new Array("Eine Richtlinie bestimmt die Einstellungen eines Programms und verwaltet den Zugriff auf die Konfiguration eines auf Computern innerhalb einer Administrationsgruppe installierten Programms. Für jedes Programm muss eine eigene Richtlinie erstellt werden. Sie können eine unbegrenzte Anzahl von unterschiedlichen Richtlinie für ein auf den Computern der einzelnen Administrationsgruppen installiertes Programm erstellen, es kann jedoch innerhalb einer Administrationsgruppe gleichzeitig nur eine Richtlinie übernommen werden.","Richtlinie","95897.htm#o111585");
Page[200]=new Array("Programmeinstellungen, die für alle Aufgabentypen gleich sind und den Gesamtbetrieb des Programms regeln, zum Beispiel Leistungseinstellungen, Berichtseinstellungen und Backup-Einstellungen.","Programmeinstellungen","95897.htm#o112587");
Page[201]=new Array("Ein Computernetzwerkservice, der Benutzern ermöglicht, indirekte Anforderungen an andere Netzwerkdienste durchzuführen. Zuerst stellt ein Benutzer eine Verbindung zu einem Proxyserver her und fordert eine Ressource (z. B. eine Datei) an, die sich auf einem anderen Server befindet. Dann stellt der Proxyserver entweder eine Verbindung zum angegebenen Server her und ruft die Ressource von dort ab, oder gibt die Ressource aus dem eigenen Cache zurück (falls der Proxyserver über einen eigenen Cache verfügt). In einigen Fälle können die Benutzer-Anfrage oder die Server-Antwort vom Proxyserver zu bestimmten Zwecken verändert werden.","Proxyserver","95897.htm#o112649");
Page[202]=new Array("Programmausführungsmodus, in dem Objekte in Echtzeit auf bösartigen Code untersucht werden.","Das Programm fängt sämtliche Versuche ab, ein Objekt zu öffnen (zum Lesen, Schreiben oder Ausführen) und untersucht das Objekt auf Bedrohungen. Nicht infizierte Objekte werden an den Benutzer weitergegeben; Objekte, die Bedrohungen oder möglicherweise infizierte Objekte enthalten, werden entsprechend den Aufgabeneinstellungen (desinfiziert, gelöscht oder unter Quarantäne gestellt) verarbeitet.","Echtzeitschutz ","95897.htm#o112643");
Page[203]=new Array("Ermöglicht die Nutzung des Programms innerhalb der gewählten Einstellungen (Verfallsdatum und Anzahl der Geräte). Sie können Ihr Abonnement unterbrechen oder fortsetzen, es automatisch verlängern oder kündigen.","Abonnement","95897.htm#o142586");
Page[204]=new Array("Funktionen, die von Kaspersky Lab ausgeführt werden, sind als Aufgaben implementiert, wie z. B.: Echtzeitschutz für Dateien, Vollständige Untersuchung und Datenbanken-Update.","Aufgabe","95897.htm#o112579");
Page[205]=new Array("Eine Aufgabe, die für eine Gruppe von Client-Computern aus beliebigen Administrationsgruppen zugewiesen und auf diesen Hosts ausgeführt wird.","Aufgabe für bestimmte Computer","95897.htm#o112571");
Page[206]=new Array("Programmeinstellungen, die spezifisch für die einzelnen Aufgabentypen sind.","Aufgabeneinstellungen","95897.htm#o112586");
Page[207]=new Array("Eine Funktion, die von einem Kaspersky Lab-Programm ausgeführt wird, um den Computerschutz auf dem neuesten Stand zu halten. Während des Updates lädt ein Programm Updates für seine Datenbanken und Module von den Update-Servern von Kaspersky Lab herunter und installiert und wendet sie automatisch an.","Update","95897.htm#o111604");
var PageCount=208;
var parsedMainTitle = 'Kaspersky Endpoint Security 10 Service Pack 1 f&#xFC;r Linux ';
(function () {
    var maxTextLength = 0;
    var fakeDiv = $('<div/>');
    var text;
    var pageSearch = _.map(Page, function (page) {
        return {
            link: page[page.length - 1],
            title: page[page.length - 2],
            text: _.map(page.slice(0, page.length - 2), function(item) {
                text = fakeDiv.html(item).text();
                maxTextLength = Math.max(maxTextLength, text.length);

                return text;
            })
        };
    });

    fakeDiv.remove();

    window.search = function (searchWord, searchWordMinLength) {
        //console.time('search');
        var result = {
            found: false,
            isInit: false,
            results: [],
            resultsCount: 0
        };

        if (searchWord !== '') {
            result.searchWord = searchWord;

            var searchLength = searchWord.length > 5 ? searchWord.length - 2 : searchWordMinLength;

            var fuseOptions = {
                //verbose: true,
                shouldSort: true,
                includeScore: true,
                includeMatches: true,
                minMatchCharLength: searchLength,
                tokenize: true,
                matchAllTokens: true,
                findAllMatches: true,
                threshold: 0.2,
                location: 0,
                distance: maxTextLength,
                keys: ['text', 'title']
            };

            var fuse = new Fuse(pageSearch, fuseOptions);
            var currentResults = fuse.search(searchWord);
            var searchRegExp = new RegExp(searchWord, 'gi');

            if (currentResults.length) {
                result.found = true;
                result.results = _.chain(currentResults)
                    // .filter(function(result) {
                    //     return result.matches.length;
                    // })
                    .map(function (result) {
                        var item = result.item;

                        return {
                            title: item.title.replace(searchRegExp, '<mark>$&</mark>'),
                            link: item.link,
                            texts: _.reduce(result.matches, function(previous, searchResult) {
                                if (searchResult.key === 'text') {
                                    previous.push(searchResult.value.replace(searchRegExp, '<mark>$&</mark>'));
                                }

                                return previous;
                            }, [])
                        }
                    })
                    .value();

                result.resultsCount = result.results.length;
            }
        }

        //console.timeEnd('search');
        return result;
    };

    /*
    #    result = {
    #        found: true
    #        isInit: false
    #        results: {
    #            "12345.htm": {
    #                {
    #                    title: 'Страница 1'
    #                    texts: [
    #                               "В этом тексте было найдено <mark>#{searchWord}</mark>",
    #                               "В этом тексте тоже было найдено <mark>#{searchWord}</mark>"
    #                           ]
    #                    link: '#'
    #                }
    #                {
    #                    title: 'Страница 8962'
    #                    texts: [
    #                               "Здесь текст, а в нём встречается <mark>#{searchWord}</mark>",
    #                               "Здесь тоже текст, и в нём тоже встречается <mark>#{searchWord}</mark>"
    #                           ]
    #                    link: '#'
    #                }
    #            }
    #        }
    #    }
    */
})();

if (typeof String.prototype.trim !== 'function') {
    String.prototype.trim = function () {
        return this.replace(/^\s+|\s+$/g, '');
    };
}

window.loadParent = function () {};

// hide content to avoid blink
window.document.documentElement.style.display = 'none';

$(function () {
    var $aside, $container, $content, $header, $modalContent, $modalHeader, $overlay, $pageTitle,
        $tooltip, $tooltipContent, tooltipButton;

    $.support.cors = true;
    $.fx.speeds._default = 200;

    var options = {
        helpers: {
            media_hv_min: 568,
            media_hv_middle: 874,
            media_mobile: 768
        },
        isMac: Boolean(window['IsMacVersion']),
        isMacProject: Boolean(window['isMacProject']),
        isIE7: Boolean(navigator.appVersion.match('MSIE 7.')),
        isIE8: Boolean(navigator.appVersion.match('MSIE 8.')),
        isIE9: Boolean(navigator.appVersion.match('MSIE 9.')),
        isIE10: Boolean(navigator.appVersion.match('MSIE 10.')),
        isOperaMini: Object.prototype.toString.call(window["operamini"]) === "[object OperaMini]",
        isFileProtocol: window.location.protocol === 'file:',
        isAllInOne: window.location.pathname.match(/(all-in-one\.htm)[l]?$/),
        searchWord: getParam('searchWord', true),
        searchWordMinLength: 3
    };

    if (window.Customization) {
        _.each(window.Localization, function(item, key) {
            if (_.isObject(window.Customization[key])) {
                window.Localization[key] = window.Customization[key].value;
            }
        });
    }

    setParam('searchWord', null, true);

    var HELP = window.HELP = $.extend(true, window.HELP, options);
    var $window = $(window);
    var html = document.documentElement;
    var $html = $(html);
    var $head = $(document.head);
    var $body = $(document.body);
    var title = $html.find('title').text();

    $body.removeClass("no-js");

    var ContainerTemplateFunction = _.template(ContainerTemplate);
    var HeaderTemplateFunction = _.template(HeaderTemplate);
    var FooterTemplateFunction = _.template(FooterTemplate);
    var AsideTemplateFunction = _.template(AsideTemplate);
    var SearchResultsTemplateFunction = _.template(SearchResultsTemplate);
    var MobileSearchResultsTemplateFunction = _.template(MobileSearchResultsTemplate);
    var LangListTemplateFunction = _.template(LangListTemplate);
    var VersionsTemplateFunction = _.template(VersionsTemplate);
    var IndexLiteralsTemplateFunction = _.template(IndexLiteralsTemplate);
    var MenuTemplateFunction = _.template(MenuTemplate);
    var AllInOneMenuTemplateFunction = _.template(AllInOneMenuTemplate);
    var CustomStylesTemplateFunction = _.template(CustomStylesTemplate);

    window.parsedMainTitle = window.parsedMainTitle || "Kaspersky Online Help";
    window.toggleBlock = toggleBlock;
    window.showAll = showAll;
    window.hideAll = hideAll;
    window.togglePopup = togglePopup;
    window.showPopup = showTooltip;
    window.hidePopup = hideTooltip;

    function getParam(param, inSession) {
        if (localStorageChecker()) {
            if (inSession && window.sessionStorage) {
                return window.sessionStorage.getItem(param);
            }

            return store(param);
        }

        return null;
    }

    function setParam(param, value, inSession) {
        if (localStorageChecker()) {
            if (value === void 0) {
                value = null;
            }

            if (inSession && window.sessionStorage) {
                if (value === null) {
                    window.sessionStorage.removeItem(param);
                } else {
                    window.sessionStorage.setItem(param, value);
                }
            } else {
                store(param, value);
            }
        }
    }

    function toggleBlock(id) {
        if (!HELP.isAllInOne) {
            var $block = $('#d' + id);
            var $toggler = $('#h' + id);

            if ($block.length > 0 && $toggler.length > 0) {
                $block.slideToggle();
                $toggler.toggleClass('is-expanded');
                $window.resize();
            }
        }
    }

    function showAll() {
        $('.expandingblock').slideDown();
        $('.expandingblocktemplate').addClass('is-expanded');
        $window.resize();
    }

    function hideAll() {
        $('.expandingblock').slideUp();
        $('.expandingblocktemplate').removeClass('is-expanded');
        $window.resize();
    }

    function togglePopup(id, legacyblockname, show) {
        switch (show) {
            case true:
                showTooltip(id, legacyblockname);
                break;
            case false:
                hideTooltip();
                break;
            default:
                toggleTooltip(id, legacyblockname);
        }
    }

    function calcTooltipPosition() {
        if (tooltipButton) {
            var body = document.body;
            var delta = 30;
            var offset = 10;

            if (options.isIE7 || options.isIE8) {
                offset = 0;
            }

            var bodyHeight = body.clientHeight;
            var bodyWidth = body.clientWidth;
            var linkRect = tooltipButton.getBoundingClientRect();
            var tooltip = $tooltip[0];
            var isToTop = linkRect.top > bodyHeight - linkRect.bottom;
            var isToLeft = linkRect.left > bodyWidth - linkRect.right;
            var coords = {
                top: isToTop ? "" : linkRect.bottom + offset,
                bottom: isToTop ? bodyHeight - linkRect.top + offset : "",
                left: isToLeft ? "" : linkRect.left - delta,
                right: isToLeft ? bodyWidth - linkRect.right - delta : ""
            };

            $tooltip.toggleClass("is-to-top", isToTop).toggleClass("is-to-left", isToLeft).css(coords);

            var tooltipRect = tooltip.getBoundingClientRect();
            coords = {};

            var isOverlapLeft = tooltipRect.left < delta;
            var isOverlapRight = tooltipRect.right > bodyWidth - delta;

            if (isOverlapLeft) {
                coords.left = delta;
            }

            if (isOverlapRight) {
                coords.right = delta;
            }

            if (isOverlapLeft || isOverlapRight) {
                coords.width = "auto";
            } else {
                coords.width = "";
            }

            $tooltip.css(coords);
            tooltipRect = tooltip.getBoundingClientRect();
            coords = {};

            var isOverlapTop = tooltipRect.top < delta;
            var isOverlapBottom = tooltipRect.bottom > bodyHeight - delta;

            if (isOverlapTop) {
                coords.top = delta;
            }

            if (isOverlapBottom) {
                coords.bottom = delta;
            }

            $tooltip.css(coords);
            if (options.isIE7 || options.isIE8) {
                return $tooltip.height(Math.min($tooltipContent[0] != null ? $tooltipContent[0].scrollHeight : void 0, 200));
            }
        }
    }

    function calcHomeBtnVisibility($viewport) {
        return setTimeout(function () {
            var $homeBtn = $viewport.find('.bt-home');

            var calcHeight;
            if ($homeBtn.hasClass('is-shown')) {
                var btn = $homeBtn[0];
                var style = btn.currentStyle || window.getComputedStyle(btn);
                calcHeight = btn.offsetHeight + parseInt(style.marginTop) + parseInt(style.marginBottom);
            } else {
                calcHeight = 0;
            }

            var showBtn = $viewport[0].offsetHeight < $viewport[0].scrollHeight - calcHeight;

            $homeBtn.toggleClass('is-shown', showBtn);
        }, 400);
    }

    function verifyMenuVisiblity($asidePlaceholder) {
        if (window.matchMedia) {
            var mq = window.matchMedia('screen and (max-width: 767px)');

            if (!mq.matches) {
                //$asidePlaceholder.removeClass('is-hidden');
            } else {
                $('.js-tab-link').eq(0).click();
            }
        }
    }

    function showTooltip(id, btnId) {
        if ($tooltip.data("id") !== id) {
            var content = document.getElementById("d" + id).innerHTML;
            $tooltip.data("id", id);
            $tooltipContent.html(content);
        }

        tooltipButton = document.getElementById(btnId);
        $tooltip.show();

        calcTooltipPosition();
    }

    function hideTooltip() {
        return $tooltip.hide();
    }

    function toggleTooltip(id, btnId) {
        if ($tooltip.data("id") !== id || $tooltip.css("display") === "none") {
            showTooltip(id, btnId);
        } else {
            hideTooltip();
        }
    }

    function bindEvents() {
        var $asidePlaceholder = $('.js_aside_placeholder');
        var $menuItems = $('.js_menu_item');
        var $mobileSearch = $('.js_mobile_search_result');
        var $viewport = $('.js_main');
        var mobileMenuToggle = function (button) {
            if (!$mobileSearch.hasClass('is-hidden')) {
                $mobileSearch.addClass('is-hidden');
            }

            $asidePlaceholder.toggleClass('is-active');
            $(button).toggleClass('is-active');
        };

        $('.js_burger').on('click', function (event) {
            event.preventDefault();
            mobileMenuToggle(this);
        });

        $body.on('click', '.js_mobile_menu_deeper', function (event) {
            event.preventDefault();
            mobileMenuShowItem($(this).data('id'));
        });

        $body.on('click', '.bt-home', function (event) {
            event.preventDefault();

            $(".js_content, .js_main").animate({
                scrollTop: 0
            }, '500', 'swing');
        });

        $body.on('click', '.js-tab-link', function () {
            if (!$(this).hasClass('js_search_tab')) {
                delete HELP.searchWord;
                setParam('searchWord', null, true);
            }
        });

        $window.on('resize', function () {
            calcTooltipPosition();
            calcHomeBtnVisibility($('.js_main'));
            verifyMenuVisiblity($asidePlaceholder);
            calcAsideWidth($asidePlaceholder);
        });

        $viewport.on("scroll", calcTooltipPosition);

        $body.on('click', 'a', function (event) {
            var $self = $(this);
            var url = $self.attr('href');

            if (HELP.isAllInOne) {
                if (url) {
                    var hash = url.match( /(.*)\.html?$/ );
                    if (hash && hash[1]) {
                        scrollToHash(hash[1]);

                        if (window.history && window.history.pushState) {
                            window.history.pushState({
                                url: url,
                                hash: hash[1]
                            }, document.title, location.pathname + '#' + hash[1]);
                        }

                        event.stopPropagation();
                        event.preventDefault();

                        trackPage();

                        return;
                    }
                }
            }

            if (window.matchMedia) {
                var mq = window.matchMedia('screen and (max-width: 767px)');
                if (mq.matches) {
                    var toggleSiblings = $self.siblings('.js_contents_toggle');
                    if (toggleSiblings.length > 0 && !$self.hasClass('js_menu_link_direct')) {
                        toggleSiblings.trigger('click');
                        event.preventDefault();
                        return;
                    }
                }
            }

            if (url && url !== '#') {
                var localUrlRegExp = /([\w_]+\.htm)[l]?(#[\w]+(.htm))?/i;
                var urlMatches = url.match(localUrlRegExp);
                var isLocalUrl = Boolean(urlMatches && urlMatches[2] && urlMatches[3]);
                var isLocalAnchor = urlMatches && urlMatches[2] && !urlMatches[3];

                if ($self.closest('.js_search_result_wrapper')) {
                    setParam('searchWord', HELP.searchWord, true);
                }

                if (localStorageChecker()) {
                    var $view = $('.js_tabs_viewport');

                    if ($view.length) {
                        window['localStorage']['asideScrollPosition'] = $view[0].scrollTop;
                    }

                    var $opened_menus = $('.js_contents_toggle.is-toggled+.js_menu_link');

                    if ($opened_menus.length) {
                        window['localStorage']['openedMenus'] = _.map($opened_menus, function (a) {
                            return $(a).attr('href');
                        });
                    }
                }

                if (isLocalUrl) {
                    if ($tooltip) {
                        $tooltip.hide();
                    }

                    var targetUrl = url;
                    var titlePageMatch = location.pathname.match(/(title\.htm)[l]?$/);

                    //if (titlePageMatch && titlePageMatch[1] === "title.htm") {
                    if (HELP.isMacProject) {
                        targetUrl = "./pgs/" + urlMatches[2].slice(1);
                        if (HELP.isFileProtocol) {
                            $self.attr('href', targetUrl);
                        }
                    }

                    if (!HELP.isFileProtocol) {
                        event.preventDefault();

                        setNavigation(HELP.isMacProject ? urlMatches[2].slice(1) : url);

                        loadContent(targetUrl, true, null, url);

                        if (window.matchMedia && mq && mq.matches) {
                            $('.js_aside_placeholder').removeClass('is-active');
                            $('.js_burger').removeClass('is-active');
                            $('.js_mobile_aside').addClass('is-hidden');
                        }

                        $('.js_home').toggleClass('is-active', HELP.nav.home.url === HELP.nav.currentPage.url);
                    }
                } else if (isLocalAnchor) {
                    if (window.matchMedia && mq && mq.matches) {
                        $('.js_aside_placeholder').removeClass('is-active');
                        $('.js_burger').removeClass('is-active');
                        $('.js_mobile_aside').addClass('is-hidden');
                    }
                } else if ($self.hasClass('hyperlinktemplate') && url.indexOf('mailto') !== 0) {
                    if (window.confirm(HELP.localization.ExternalLinkText)) {
                        return;
                    }

                    event.preventDefault();
                }
            } else {
                event.preventDefault();
            }
        });

        $body.on('click', '.js_menu_link, .js_menu_link_direct', function () {
            var $self = $(this);
            delete HELP.searchWord;
            setParam('searchWord', null, true);

            if (!$self.prev().hasClass('js_contents_toggle')) {
                $menuItems.removeClass('is-active');
            }

            $self.children('.js_contents_toggle').addClass('is-toggled').siblings('.js_contents_level').slideDown();
            $self.closest('.js_menu_item').addClass('is-active');

            var href = $self.attr('href');
            var topicRegExp = /[\w_]+\.htm/;
            var hashRegExp = /#([\w_]+)/;

            if (href.indexOf('#') > -1) {
                var locationMatch = location.pathname.match(topicRegExp);
                var hrefMatch = href.match(topicRegExp);
                var hash = href.match(hashRegExp)[1];
                event.preventDefault();

                if (!(locationMatch.length && hrefMatch.length && locationMatch[0] === hrefMatch[0])) {
                    loadContent(href, true, function() {
                        if (hash) {
                            scrollToHash(hash);
                        }
                    });
                }

                if (hash) {
                    scrollToHash(hash);

                    if (!HELP.isMacProject && window.history && window.history.pushState) {
                        window.history.pushState({
                            url: href,
                            hash: hash
                        }, document.title, href);
                    }
                }
            }
        });

        $body.on('click', '.js_home_link', function () {
            $('.js-tab-link').eq(0).trigger('click');
        });

        $(window).on('popstate', function (event) {
            var state = event.originalEvent.state;

            if (state && state.url) {
                if (!HELP.isAllInOne) {
                    loadContent(state.url, false, scroll, state.originalUrl);
                    setNavigation(state.url);
                } else {
                    scroll();
                    trackPage();
                }
            }

            function scroll() {
                if (state.hash) {
                    $(".js_menu_item").removeClass('is-active');
                    var $menuItem = $(".js_menu_link[href='" + state.hash + ".htm']").closest('.js_menu_item');
                    autoScrollContents($menuItem);

                    scrollToHash(state.hash);
                }
            }
        });

        $body.on('click', '.js_modal_close', function () {
            $overlay.removeClass('is-visible');
        }).on('click', '.js_overlay', function (event) {
            if (!$(event.target).closest('.js_modal').length) {
                $overlay.removeClass('is-visible');
            }
        });

        $body.on('click', '.js_print_section', function() {
            var currentUrl = window.location.pathname.match(/\/(\w+\.\w+)$/)[1];
            //window.location.href = 'all-in-one.htm?sectionUrl=' + currentUrl;
            window.open('all-in-one.htm?sectionUrl=' + currentUrl);
        });

        if (!HELP.isAllInOne) {
            var xStart = null;
            var yStart = null;

            $body.on('touchstart', '.js_content', function(event) {

                var tableInTopic = $(event.target).closest('.tableintopic');
                if (tableInTopic.length && tableInTopic.width() > tableInTopic.parent().width()) {
                    return;
                }

                var touch = event.originalEvent.touches[0];
                if (touch) {
                    xStart = touch.clientX;
                    yStart = touch.clientY;
                }
            });

            $body.on('touchmove', '.js_content', function(event) {
                if (!xStart || !yStart) {
                    return;
                }

                var touch = event.originalEvent.touches[0];
                var xEnd = touch.clientX;
                var yEnd = touch.clientY;
                var xDiff = xStart - xEnd ;
                var yDiff = yStart - yEnd;

                if (Math.abs(xDiff) > Math.abs(yDiff) && Math.abs(xDiff) > 50) {
                    if (xDiff > 0 && HELP.nav.nextPage) {
                        $('.js_container').addClass('is-loading');
                        $('.js_main').addClass('swipe-left');
                        setTimeout(function () {
                            $('.js_next_link').click();
                        }, 350);
                    } else if(xDiff < 0 && HELP.nav.prevPage) {
                        $('.js_container').addClass('is-loading');
                        $('.js_main').addClass('swipe-right');
                        setTimeout(function () {
                            $('.js_prev_link').click();
                        }, 350);
                    }

                    xStart = null;
                    yStart = null;
                }
            });
        }
    }

    /*
    #* Языки в хэдере --------------------------------------------------------------------------------------------------
     */
    function loadLangs() {
        if (!window.Langs) {
            $('.js_selector_mobile_langs').remove();
            return;
        }

        var currentId = 'no id';
        var currentName = 'no name';
        var locLangs = window.LangsLocalization;

        window.Langs.forEach(function(item) {
            if (locLangs && locLangs[item.id]) {
                item.name = locLangs[item.id];
            }

            if (item.id === document.documentElement.lang) {
                HELP.currentLangId = currentId = item.id;
                HELP.currentLangCode = currentName = item.name;

                if (~['ja-JP', 'ko-KR', 'zh-Hans', 'zh-Hant'].indexOf(HELP.currentLangId)) {
                    HELP.searchWordMinLength = 2;
                }
            }
        });

        if (window.Langs.length < 2) {
            $('.js_selector_mobile_langs').remove();
            return;
        }

        var isMac = Boolean(window.location.pathname.match(/pgs\/[\w_\.]+/));
        var isMacTitle = Boolean(window.location.pathname.match(/title\.html?$/));
        var LangListHtml = LangListTemplateFunction({
            langs: window.Langs,
            currentLang: {
                name: currentName,
                id: currentId
            },
            localization: HELP.localization,
            isMac: isMac,
            isMacTitle: isMacTitle
        });

        $header.find('.js_header_lang_list').html(LangListHtml);
        $('.js_selector_mobile_langs').html(LangListHtml).find('.js_dropdown').addClass('dropdown_large');

        $body.on('click', '.js_lang_item', function (event) {
            event.preventDefault();

            var $element = $(this);
            var langId = $element.data('lang-id');
            var path = window.location.pathname;
            var currentFolder = window.location.pathname.match(/([\w]+|[\w\.-]+)(\/pgs)?\/[\w_]+.html?/)[1];

            window.location.href  = path.replace("/" + currentFolder + "/", "/" + langId + "/");
        });
    }

    function triggerSearch() {
        if (HELP.helpers.searchTimeout) {
            clearTimeout(HELP.helpers.searchTimeout);
        }

        HELP.helpers.searchTimeout = setTimeout(function () {
            var searchWord = $('.js_search_text').val().trim();

            if (searchWord.length < HELP.searchWordMinLength) {
                delete HELP.searchWord;
                setParam('searchWord', null, true);

                searchWord = null;

                $('.js-menu-content, .js_search').show();
                $('.js-search-content, .js_search_clear').hide();
            } else {
                HELP.searchWord = searchWord;
                setParam('searchWord', searchWord, true);

                var resultObj = search(searchWord, HELP.searchWordMinLength);
                resultObj.localization = HELP.localization;
                resultObj.isMacProject = HELP.isMacProject;

                var searchResultsHtml = SearchResultsTemplateFunction(resultObj);

                $('.js-menu-content, .js_search').hide();
                $('.js-search-content, .js_search_clear').show();
                //$('.js_search_tab').trigger('click');

                $('.js_search_result_wrapper').html(searchResultsHtml);
            }
        }, 300);
    }

    /*
    #* Левое меню ------------------------------------------------------------------------------------------------------
     */
    function loadMenu(menu) {
        if (!window['Toc']) {
            return;
        }

        var flatMenu = [];
        var currentUrl = HELP.isAllInOne || HELP.isMacProject ?
            /#([\w_]+)/.exec(location.hash) : /\/([\w_]+\.\w+$)/.exec(location.pathname);
        var currentPage = {};
        var currentLevel, parentPage;

        if (currentUrl && currentUrl[1]) {
            currentUrl = currentUrl[1];
        }

        function buildMenu(menu, level, parentId) {
            var isCurrentMenuLevelActive;
            level = level || 0;

            _.each(menu, function (item) {
                item.level = level;
                if (item.url && item.url.match(/#|(title\.html?)/)) {
                    return;
                }

                if (item.hidden) {
                    return;
                }

                flatMenu.push(item);

                if (item.url === currentUrl || item.url === currentUrl + '.htm') {
                    item.isActive = true;
                    currentPage = item;
                    currentLevel = level;
                }

                if (item.children) {
                    item.childIsActive = buildMenu(item.children, level + 1, item.id);
                }

                if (item.isActive || item.childIsActive) {
                    isCurrentMenuLevelActive = true;
                }

                if (level > 0 && parentId) {
                    return item.parentId = parentId;
                }
            });

            return isCurrentMenuLevelActive;
        }

        buildMenu(menu);

        var i, j, ref, item, prevSection, nextSection;
        for (i = j = 0, ref = flatMenu.length - 1; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
            item = flatMenu[i];
            if (item.url === currentUrl || item.url === currentUrl + '.htm') {
                if (i > 0) {
                    prevSection = flatMenu[i - 1];
                }

                if (i !== flatMenu.length - 1) {
                    nextSection = flatMenu[i + 1];
                }
            }
        }

        if (!currentPage.url) {
            nextSection = flatMenu[0];
        }

        window.HELP = $.extend(true, window.HELP, {
            nav: {
                menu: menu,
                flatMenu: flatMenu,
                home: flatMenu[0],
                currentPage: currentPage,
                currentLevel: currentLevel,
                parentPage: parentPage,
                prevPage: prevSection,
                nextPage: nextSection
            }
        });

        var $homeBtn = $body.find('.js_home');
        var $homeBtnLink = $homeBtn.find('.js_home_link');

        if (HELP.nav.home) {
            $homeBtnLink.attr('href', HELP.nav.home.url);
        }

        if (HELP.isAllInOne) {
            $(window).on('load', function() {
                setTimeout(function() {
                    scrollToHash(currentUrl);
                });
            });
        }

        buildLinks($container);

        var MenuHtml = MenuTemplateFunction({
            menu: menu,
            localization: HELP.localization,
            isMacProject: HELP.isMacProject
        });

        $aside.find('.js_menu').html(MenuHtml);

        $('.js_search_text').on('keyup', function (event) {
            if (event.keyCode === 27) {
                $('.js-tab-link').eq(0).click();
                $(this).val('');
            } else {

            }
            triggerSearch();
        });

        $('.js_search_clear').on('click', function () {
            $('.js_search_text').val('');
            triggerSearch();
        });

        $('.js_mobile_search_button').on('click', function () {
            var $this = $(this);
            var $result = $('.js_mobile_search_result');
            var $input = $('.js_mobile_search_input');
            var $clearBtn = $('.js_mobile_search_clear');
            var isShow = !$input.hasClass('is-hidden');

            if (isShow) {
                if ($input.val().length > 0) {
                    var searchWord = $input.val().trim();
                    var resultObj = search(searchWord, HELP.searchWordMinLength);

                    resultObj.localization = HELP.localization;
                    resultObj.isMacProject = HELP.isMacProject;
                    var mobileSearchResultsHtml = MobileSearchResultsTemplateFunction(resultObj);

                    $result.html(mobileSearchResultsHtml).removeClass('is-hidden').addClass('is-active');

                    setTimeout(function () {
                        $('.js_aside_placeholder').removeClass('is-active');
                        $('.js_burger').removeClass('is-active');
                    });
                } else {
                    $result.removeClass('is-active').addClass('is-hidden');
                }

                /*$this.removeClass('is-active');
                $input.addClass('is-hidden');
                $clearBtn.addClass('is-hidden');*/
            } else {
                $input.removeClass('is-hidden');
                $clearBtn.removeClass('is-hidden');
                $this.addClass('is-active');

                if (!$result.is(':empty')) {
                    $result.removeClass('is-hidden').addClass('is-active');
                }

                setTimeout(function () {
                    $input.focus();
                }, 100);
            }
        });

        $('.js_mobile_search_clear').on('click', function () {
            var $searchBtn = $('.js_mobile_search_button');
            var $result = $('.js_mobile_search_result');
            var $input = $('.js_mobile_search_input');

            if ($input.val().length > 0) {
                $input.val('');
                HELP.searchWord = null;
                setParam('searchWord', null, true);

                $result.empty();
            }

            $searchBtn.removeClass('is-active');
            $result.addClass('is-hidden');
            $input.addClass('is-hidden');
            $(this).addClass('is-hidden');
        });

        var triggerMobileSearch = _.debounce(function() {
            $('.js_mobile_search_button').trigger('click');
        }, 350);

        $('.js_mobile_search_input').on('keyup', function (event) {
            if (event.keyCode === 13) {
                $('.js_mobile_search_button').trigger('click');
            // } else {
            //     triggerMobileSearch();
            }
        });

        $('.js_contents_toggle').on('click', function (event) {
            event.preventDefault();

            var $toggler = $(this);
            $toggler.toggleClass('is-toggled');

            if ($toggler.hasClass('is-toggled')) {
                $toggler.siblings('.contents').slideDown();
            } else {
                $toggler.siblings('.contents').slideUp();
            }
        });

        $('.js_dropdown_btn').on('click', function (event) {
            event.preventDefault();

            var $list = $(this).siblings('.js_dropdown_list');

            $list.css({
                maxHeight: html.clientHeight - $list.offset().top - this.clientHeight
            }).toggleClass('dropdown__list--opened');

            $body.on('click.dropdown', function (event) {
                if (!$(event.target).closest('.js_dropdown').length) {
                    $list.toggleClass('dropdown__list--opened');
                    $body.off('click.dropdown');
                }
            });
        });

        bindEvents();
    }

    function loadContent(url, saveToHistory, callback, originalUrl) {
        if (saveToHistory == null) {
            saveToHistory = true;
        }

        var loadingTimeout = setTimeout(function () {
            $('.js_container').addClass('is-loading');
        }, 300);

        $.ajax(url, {
            crossDomain: true,
            dataType: "html",
            success: function (response) {
                if (saveToHistory && window.history && window.history.pushState) {
                    window.history.pushState({
                        url: url,
                        originalUrl: originalUrl
                    }, null, originalUrl || url);
                }

                var frameHtml = processHtml(response);
                var langMatches = frameHtml.match(/\slang="(.+?)"/);

                if ((langMatches != null ? langMatches.length : void 0) > 1 && langMatches[1] !== HELP.currentLangId) {
                    window.location = HELP.isMacProject ? originalUrl : url;
                    return;
                }

                var $cont = $(frameHtml).filter('.cont');
                $content.html($cont);

                $(".js_content, .js_main").animate({
                    scrollTop: 0
                }, '200', 'swing');

                title = $cont.find('.heading1, .heading2, .heading3, .heading4').first().text();
                document.title = title;
                $(".js_menu_item").removeClass('is-active');

                var scrollToUrl = HELP.isMacProject ? originalUrl : url || HELP.nav.currentPage.url;
                var $menuItem = $(".js_menu_link[href='" + scrollToUrl + "']").closest('.js_menu_item');
                var $index = $('.js_index_literals');
                var $indexLinks = $index.find('.indexlink > a');
                $indexLinks.removeClass('is-active').filter("[href='" + url + "']").addClass('is-active');

                autoScrollContents($menuItem);
                processContent($container);

                if (loadingTimeout) {
                    clearTimeout(loadingTimeout);
                }

                if (callback && typeof callback === 'function') {
                    callback();
                }

                $('.js_container').removeClass('is-loading');
                $('.js_main').removeClass('swipe-left swipe-right');

                trackPage();
            },
            error: function () {
                window.history.back();
                return window.location = url;
            }
        });
    }

    function processHtml(content, menu) {
        if (menu) {
            var AllInOneMenuHtml = AllInOneMenuTemplateFunction({
                menu: menu,
                localization: HELP.localization
            });
            var resultContent = $();

            menu.forEach(getContent);

            function getContent(item) {
                resultContent = resultContent.add('#' + item.o + ', [name=' + item.o + ']');

                if (item.children) {
                    item.children.forEach(getContent);
                }
            }

            content = AllInOneMenuHtml + $('<div/>').html(resultContent).html();
        }

        if (typeof content === 'string') {
            content = content.replace(/[™®]|&reg;|&#8482;|&#174;/g, '');

            if (HELP.isMacProject) {
                content = content.replace(/"title.htm#([\w]+.htm)"/gi,'"index.htm#$1"');
            }

            if (HELP.searchWord) {
                var searchRegExp = new RegExp(escapeRegExp(HELP.searchWord) + '(?!([^<]+)?>)', "ig");
                content = content.replace(searchRegExp, "<mark>$&</mark>");
            }
        }

        return content;
    }

    function processContent($container) {
        $container.find('.links').remove();
        buildLinks($container);

        $container.find('.cont').toggleClass('mactitlepage', Boolean(location.pathname.match(/title\.htm/)));
        $container.find('style').remove();

        if (!HELP.isAllInOne) {
            $container.find('.popuponclick, .expandingblock').each(function () {
                var $self = $(this);
                var $toggler = $($self.attr('id').replace('d', '#h'));

                if ($toggler.length > 0) {
                    var $wrapper = $toggler.closest(".settingdescr");

                    if ($wrapper.length === 0) {
                        $wrapper = $toggler.parent();
                    }

                    $wrapper.append($self);

                    if ($self.hasClass('expandingblock')) {
                        $wrapper.addClass('expandingblock-wrapper');

                        var img = $toggler.next('img');

                        if (img.length) {
                            $toggler.append(img);
                        }
                    }
                }
            });
        }

        $container.find('.cont [title]').each(function(index, item) {
            var classes = item.className;
            var $item = $(item);

            if (!$item.is('img') &&
                classes.indexOf('hyperlinktemplate') === -1 &&
                classes.indexOf('crossreferencetemplate') === -1) {
                $item.removeAttr('title');
            }
        });

        $container.find('.hyperlinktemplate').each(function() {
            var $self = $(this);
            var $siblingLink = $self.next('span').find('.hyperlinktemplate');

            if ($siblingLink.length) {
                var text = $siblingLink.text();
                $self.append($siblingLink.parent().text(text));
            }
        });

        var $tables = $container.find(".tableintopic");
        $tables.wrap("<div class='tableintopic-wrapper'/>");
        var $tableRows = $tables.find('tr');
        $tableRows.filter(':nth-child(2n)').addClass('is-even');
        $tableRows.filter(':nth-child(2n+1)').addClass('is-odd');

        $container.find('.popuponhover, .popuponclick').each(function () {
            var $self = $(this);
            var $toggler = $($self.attr('id').replace('d', '#h'));

            if ($toggler.length > 0) {
                return $toggler.wrap("<div class='link-wrapper'/>").after($self);
            }
        });

        $container.find('.js_feedback_link').attr('href', getMailtoLink());

        $container.find('.program').each(function(index, item) {
            var $item = $(item);
            if (!$item.parent().hasClass('js_code')) {
                var siblings = $(item).nextUntil(':not(.program)').addBack();

                if (siblings.length > 1) {
                    siblings.wrapAll('<div class="js_code"></div>');
                    siblings.after('\n');
                }
            }
        });

        $container.find('.exampleheading, .examplebodytext, .exampleheadingblue2015, .examplebodytextblue2015')
            .parent().each(function(index, item) {
                $(item).addClass('example-wrapper');
            });

        setTimeout(function() {
            $container.find('.js_code').each(function(index, item) {
                window.hljs.highlightBlock(item);
            });
        });

        $window.resize();
    }

    function buildLinks($container) {
        $pageTitle = $container.find('.heading1, .heading2, .heading3, .heading4').first();
        var $homeBtn = $container.find('.bt-home');
        var $prevBtnPlaceholder = $container.find('.js_prev_btn_placeholder');
        var $nextBtnPlaceholder = $container.find('.js_next_btn_placeholder');
        var PageTitleTemplateFunction = _.template(PageTitleTemplate);
        var BottomLinksTemlateFunctions = _.template(BottomLinksTemplate);
        var NextLinkTemplateTemlateFunctions = _.template(NextLinkTemplate);
        var PrevLinkTemplateTemlateFunctions = _.template(PrevLinkTemplate);

        if (HELP.nav) {
            var PageTitleHtml = PageTitleTemplateFunction({
                titleHtml: $pageTitle.html(),
                localization: HELP.localization
            });

            $pageTitle.html(PageTitleHtml);

            if (!HELP.isAllInOne) {
                var NextLinkHtml = NextLinkTemplateTemlateFunctions({
                    nextPage: HELP.nav.nextPage,
                    isMacProject: HELP.isMacProject
                });

                var PrevLinkHtml = PrevLinkTemplateTemlateFunctions({
                    prevPage: HELP.nav.prevPage,
                    isMacProject: HELP.isMacProject
                });

                $prevBtnPlaceholder.html(PrevLinkHtml);
                $nextBtnPlaceholder.html(NextLinkHtml);

                if ($homeBtn.length === 1) {
                    $homeBtn = $homeBtn.first();

                    var BottomLinksHtmls = BottomLinksTemlateFunctions({
                        homeBtnHtml: $homeBtn[0].outerHTML,
                        localization: HELP.localization,
                        serviceInfo: {
                            id:  HELP.isMacProject ? window.location.hash.slice(1) : window.location.pathname.match(/\/(\w+)\.htm/)[1],
                            reviewDate: window.reviewDate ? (new Date(window.reviewDate)).toLocaleString(HELP.currentLangId, {
                                year: 'numeric',
                                month: 'short',
                                day: 'numeric'
                            }) : null
                        }
                    });

                    $homeBtn.replaceWith(BottomLinksHtmls);
                }
            } else {
                $('.js_all_in_one_header').text(HELP.localization.TableOfContents);
            }
        }
    }

    function autoScrollContents($target, animateSpeed) {
        if (animateSpeed == null) {
            animateSpeed = 2;
        }

        if (!$target || !$target.length) {
            return;
        }

        var $view = $('.js_tabs_viewport');
        var $menuItem = $view.find('.js-menu-content:not(.is-hidden)').find($target);

        if (!$menuItem.length || !$view.length) {
            return;
        }

        var targetTop;
        if (localStorageChecker() && window['localStorage']['asideScrollPosition'] !== void 0) {
            targetTop = window['localStorage']['asideScrollPosition'];
            setParam('asideScrollPosition', null);
            var isFromLocalStorage = true;
        } else {
            var view = $view[0];
            var delta1 = view.clientHeight / 5;
            var delta2 = view.clientHeight / 4;
            var isOverBottom = $menuItem.offset().top > view.clientHeight + $view.offset().top - delta1;
            var isOverTop = $menuItem.offset().top < $view.offset().top + delta1 + $menuItem[0].offsetHeight;
            var targetDelta;
            if (isOverBottom) {
                targetDelta = $menuItem.offset().top - $view.offset().top - view.clientHeight + delta2;
            } else if (isOverTop) {
                targetDelta = $menuItem.offset().top - $view.offset().top - delta2 - $menuItem[0].offsetHeight;
            }
            targetTop = view.scrollTop + targetDelta;
        }

        var scrollingDuration = Math.min(animateSpeed * Math.abs(targetDelta), 1500);
        if (isFromLocalStorage || isOverTop || isOverBottom) {
            $view.animate({
                scrollTop: targetTop
            }, scrollingDuration, 'swing');
        }

        $menuItem
            .addClass('is-active')
            .parents('.js_contents_level')
            .add($menuItem.children('.js_contents_level'))
            .slideDown()
            .siblings('.js_contents_toggle')
            .addClass('is-toggled');
    }

    function loadVersions() {
        var url = window.location.pathname.split('/');
        var productKey = url[1];
        var currentVersionUrl = url[2];
        var product =
            _.findWhere(HELP.localization.products_b2c, {url: productKey}) ||
            _.findWhere(HELP.localization.products_b2b, {url: productKey});
        var $productLogo = $('.js_product_logo');

        if (!product) {
            return;
        }

        $productLogo.addClass('top-bar__product_' + product.icon);

        var currentVersion;
        _.some(product.versions, function(item) {
            if (item.url.split('/')[0] === currentVersionUrl) {
                currentVersion = item;
                return true;
            }
            return false;
        });

        if (currentVersion && product.versions.length > 1) {
            var VersionsResultsHtml = VersionsTemplateFunction({
                currentVersion: currentVersion,
                versions: product.versions
            });

            $header.find('.js_header_versions_list').html(VersionsResultsHtml);
            $('.js_selector_mobile_versions')
                .html(VersionsResultsHtml).find('.js_dropdown').addClass('dropdown_large');

            $header.on('click', '.js_version_item', function (event) {
                event.preventDefault();

                var versionUrl = $(this).data('version-url');
                /*var path = window.location.pathname.split('/');
                var currentPage = path[path.length - 1];

                window.location.href  = '/' + productKey + '/' + versionUrl + '/' + currentPage;*/
                window.location.href = '/' + productKey + '/' + versionUrl;
            });
        } else {
            $('.js_selector_mobile_versions').remove();
        }
    }

    function calcAsideWidth(aside) {
        aside.children().width(aside.width());
    }

    function getMailtoLink() {
        return 'mailto://?subject=Shared from Kaspersky Online Help: "' +
            window.parsedMainTitle + ' - ' + window.document.title + '"&body=' + window.parsedMainTitle +
            ' - ' + window.document.title + '%0A' + window.location.href;
    }

    function findSection(menuList, sectionUrl) {
        var result =[];

        menuList.forEach(function(item) {
            if (item.url === sectionUrl) {
                result.push(item);
            } else if (item.children) {
                result = result.concat(findSection(item.children, sectionUrl));
            }
        });

        return result;
    }

    function scrollToHash(hash) {
        var $target = $("[name='" + hash + "'], #" + hash);
        var $main = $('.js_main');

        if ($target.length) {
            $main.animate({
                scrollTop: $target[0].offsetTop - $main[0].offsetTop
            }, '500', 'swing');

            document.documentElement.scrollTop = 0;
        }
    }

    function escapeRegExp(text) {
        return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    }

    function localStorageChecker() {
        // localstorage & sessionstorage falls with error in EDGE for local files
        try {
            return Boolean(window.localStorage);
        } catch (e) {
            return false;
        }
    }

    function trackPage() {
        if (window._gaq) {
            window._gaq.push(['_trackPageview', location.pathname + location.search + location.hash]);
        }
    }

    function setNavigation(url) {
        _.each(HELP.nav.flatMenu, function (item, index) {
            if (item.url === url) {
                HELP.nav.currentPage = item;

                if (index > 0) {
                    HELP.nav.prevPage = HELP.nav.flatMenu[index - 1];
                } else {
                    HELP.nav.prevPage = null;
                }

                if (index !== HELP.nav.flatMenu.length - 1) {
                    HELP.nav.nextPage = HELP.nav.flatMenu[index + 1];
                } else {
                    HELP.nav.nextPage = null;
                }
            }
        });
    }

    /*
    #* Первичный рендеринг --------------------------------------------------------------------------------------------------
     */
    function firstRender() {
        var $footer, $menuItem, arrOpenedMenus, i, j;
        var sectionUrl = location.search.split('sectionUrl=')[1];
        var menu = window['Toc'];

        if (sectionUrl) {
            menu = findSection(menu, sectionUrl);
        }

        HELP.localization = window.Localization || {};
        HELP.customization = window.Customization || {};
                
        $html.toggleClass('ie7', HELP.isIE7).toggleClass('ie8', HELP.isIE8)
             .toggleClass('ie9', HELP.isIE9).toggleClass('ie10', HELP.isIE10)
             .toggleClass('is-opera-mini', HELP.isOperaMini)
             .toggleClass('is-offline', HELP.isFileProtocol);

        if (window['HelpViewer'] !== void 0 && window.sessionStorage && JSON.parse && window.sessionStorage.getItem('isTOCHidden') && JSON.parse(window.sessionStorage.getItem('isTOCHidden'))) {
            $html.removeClass('is-menu-shown');
        }

        if (location.hostname === 'localhost' || location.hostname === 'stage.help.kaspersky.com') {
            $html.addClass('is-test-mode');
        }

        var containerHtml = ContainerTemplateFunction({
            localization: HELP.localization
        });

        var parsedMainTitle = window.parsedMainTitle;
        if (parsedMainTitle.indexOf('Kaspersky') === 0) {
            var titlePreffix = parsedMainTitle.slice(0, 9);
            parsedMainTitle = parsedMainTitle.slice(10, parsedMainTitle.length);
        }

        var headerHtml = HeaderTemplateFunction({
            titlePreffix: titlePreffix || '',
            title: parsedMainTitle,
            localization: HELP.localization,
            customization: HELP.customization,
            isAllInOne: HELP.isAllInOne,
            isOffline: HELP.isFileProtocol
        });

        var footerHtml = FooterTemplateFunction({
            localization: HELP.localization,
            customization: HELP.customization
        });

        var asideHtml = AsideTemplateFunction({
            localization: HELP.localization
        });

        if (window.Customization) {
            var customStyles = CustomStylesTemplateFunction({
                customization: HELP.customization
            });

            $head.append(customStyles);
        }

        $container = $(containerHtml);
        $header = $(headerHtml);
        $footer = $(footerHtml);
        $aside = $(asideHtml);

        var $headerPlaceholder = $container.find('.js_header_placeholder');
        var $asidePlaceholder = $container.find('.js_aside_placeholder');
        var $footerPlaceholder = $container.find('.js_footer_placeholder');

        $headerPlaceholder.append($header);
        $asidePlaceholder.append($aside);
        $footerPlaceholder.append($footer);
        $content = $container.find('.js_content');
        $content.append(processHtml($body.html(), sectionUrl ? menu : null));
        $body.html($container);
        processContent($container);
        $body.addClass('js_tabs');

        var $viewport = $('<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">');
        $head.append($viewport);
        $html.find('base').remove();

        if ($.inArray($html.attr('lang'), ['ar-AE', 'fa-IR']) > -1) {
            $html.attr('dir', 'rtl');
        } else {
            $html.attr('dir', 'ltr');
        }

        FastClick.attach(document.body);

        $overlay = $body.find('.js_overlay');
        loadLangs();
        loadVersions();
        loadMenu(menu);

        if (HELP.searchWord) {
            $body.find('.js_search_text').val(HELP.searchWord);
            triggerSearch();
        }

        if (HELP.nav.currentPage && HELP.nav.currentPage.url) {
            $menuItem = $(".js_menu_link[href='" + HELP.nav.currentPage.url + "']").closest('.js_menu_item');
            autoScrollContents($menuItem, 0);
        }

        var localUrlRegExp = /([\w_]+\.htm)[l]?(#[\w]+(.htm))?/i;
        var urlMatches = window.location.href.match(localUrlRegExp);
        if (HELP.isMacProject && urlMatches[2] && urlMatches[3]) {
            loadContent("./pgs/" + urlMatches[2].slice(1), false, null, urlMatches[0]);
        } else if (window.history && window.history.replaceState && !HELP.isAllInOne) {
            var initialUrl = /\/([\w_-]+\.\w+$)/.exec(location.pathname)[1];
            window.history.replaceState({
                url: initialUrl
            }, null, initialUrl);
        }

        $modalContent = $overlay.find('.js_modal_content');
        $modalHeader = $overlay.find('.js_modal_header');
        $tooltip = $body.find('.js_tooltip');
        $tooltipContent = $body.find('.js_tooltip_content');

        setTimeout(function () {
            $html.show();
            $window.resize();
        }, 100);

        if (HELP.isIE7 || HELP.isIE8) {
            setTimeout(function () {
                calcAsideWidth($asidePlaceholder);
            }, 500);
        }

        $(".downloadhyperlinktemplate").attr("download", "").addClass("hyperlinktemplate");
    }

    firstRender();
});