/*!
 * https://github.com/es-shims/es5-shim
 * @license es5-shim Copyright 2009-2015 by contributors, MIT License
 * see https://github.com/es-shims/es5-shim/blob/master/LICENSE
 */

// vim: ts=4 sts=4 sw=4 expandtab

// Add semicolon to prevent IIFE from being passed as argument to concatenated code.
;

// UMD (Universal Module Definition)
// see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
(function (root, factory) {
    'use strict';

    /* global define, exports, module */
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals (root is window)
        root.returnExports = factory();
    }
}(this, function () {

/**
 * Brings an environment as close to ECMAScript 5 compliance
 * as is possible with the facilities of erstwhile engines.
 *
 * Annotated ES5: http://es5.github.com/ (specific links below)
 * ES5 Spec: http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf
 * Required reading: http://javascriptweblog.wordpress.com/2011/12/05/extending-javascript-natives/
 */

// Shortcut to an often accessed properties, in order to avoid multiple
// dereference that costs universally. This also holds a reference to known-good
// functions.
var $Array = Array;
var ArrayPrototype = $Array.prototype;
var $Object = Object;
var ObjectPrototype = $Object.prototype;
var $Function = Function;
var FunctionPrototype = $Function.prototype;
var $String = String;
var StringPrototype = $String.prototype;
var $Number = Number;
var NumberPrototype = $Number.prototype;
var array_slice = ArrayPrototype.slice;
var array_splice = ArrayPrototype.splice;
var array_push = ArrayPrototype.push;
var array_unshift = ArrayPrototype.unshift;
var array_concat = ArrayPrototype.concat;
var array_join = ArrayPrototype.join;
var call = FunctionPrototype.call;
var apply = FunctionPrototype.apply;
var max = Math.max;
var min = Math.min;

// Having a toString local variable name breaks in Opera so use to_string.
var to_string = ObjectPrototype.toString;

/* global Symbol */
/* eslint-disable one-var-declaration-per-line, no-redeclare */
var hasToStringTag = typeof Symbol === 'function' && typeof Symbol.toStringTag === 'symbol';
var isCallable; /* inlined from https://npmjs.com/is-callable */ var fnToStr = Function.prototype.toString, constructorRegex = /^\s*class /, isES6ClassFn = function isES6ClassFn(value) { try { var fnStr = fnToStr.call(value); var singleStripped = fnStr.replace(/\/\/.*\n/g, ''); var multiStripped = singleStripped.replace(/\/\*[.\s\S]*\*\//g, ''); var spaceStripped = multiStripped.replace(/\n/mg, ' ').replace(/ {2}/g, ' '); return constructorRegex.test(spaceStripped); } catch (e) { return false; /* not a function */ } }, tryFunctionObject = function tryFunctionObject(value) { try { if (isES6ClassFn(value)) { return false; } fnToStr.call(value); return true; } catch (e) { return false; } }, fnClass = '[object Function]', genClass = '[object GeneratorFunction]', isCallable = function isCallable(value) { if (!value) { return false; } if (typeof value !== 'function' && typeof value !== 'object') { return false; } if (hasToStringTag) { return tryFunctionObject(value); } if (isES6ClassFn(value)) { return false; } var strClass = to_string.call(value); return strClass === fnClass || strClass === genClass; };

var isRegex; /* inlined from https://npmjs.com/is-regex */ var regexExec = RegExp.prototype.exec, tryRegexExec = function tryRegexExec(value) { try { regexExec.call(value); return true; } catch (e) { return false; } }, regexClass = '[object RegExp]'; isRegex = function isRegex(value) { if (typeof value !== 'object') { return false; } return hasToStringTag ? tryRegexExec(value) : to_string.call(value) === regexClass; };
var isString; /* inlined from https://npmjs.com/is-string */ var strValue = String.prototype.valueOf, tryStringObject = function tryStringObject(value) { try { strValue.call(value); return true; } catch (e) { return false; } }, stringClass = '[object String]'; isString = function isString(value) { if (typeof value === 'string') { return true; } if (typeof value !== 'object') { return false; } return hasToStringTag ? tryStringObject(value) : to_string.call(value) === stringClass; };
/* eslint-enable one-var-declaration-per-line, no-redeclare */

/* inlined from http://npmjs.com/define-properties */
var supportsDescriptors = $Object.defineProperty && (function () {
    try {
        var obj = {};
        $Object.defineProperty(obj, 'x', { enumerable: false, value: obj });
        for (var _ in obj) { return false; }
        return obj.x === obj;
    } catch (e) { /* this is ES3 */
        return false;
    }
}());
var defineProperties = (function (has) {
  // Define configurable, writable, and non-enumerable props
  // if they don't exist.
  var defineProperty;
  if (supportsDescriptors) {
      defineProperty = function (object, name, method, forceAssign) {
          if (!forceAssign && (name in object)) { return; }
          $Object.defineProperty(object, name, {
              configurable: true,
              enumerable: false,
              writable: true,
              value: method
          });
      };
  } else {
      defineProperty = function (object, name, method, forceAssign) {
          if (!forceAssign && (name in object)) { return; }
          object[name] = method;
      };
  }
  return function defineProperties(object, map, forceAssign) {
      for (var name in map) {
          if (has.call(map, name)) {
            defineProperty(object, name, map[name], forceAssign);
          }
      }
  };
}(ObjectPrototype.hasOwnProperty));

//
// Util
// ======
//

/* replaceable with https://npmjs.com/package/es-abstract /helpers/isPrimitive */
var isPrimitive = function isPrimitive(input) {
    var type = typeof input;
    return input === null || (type !== 'object' && type !== 'function');
};

var isActualNaN = $Number.isNaN || function (x) { return x !== x; };

var ES = {
    // ES5 9.4
    // http://es5.github.com/#x9.4
    // http://jsperf.com/to-integer
    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToInteger */
    ToInteger: function ToInteger(num) {
        var n = +num;
        if (isActualNaN(n)) {
            n = 0;
        } else if (n !== 0 && n !== (1 / 0) && n !== -(1 / 0)) {
            n = (n > 0 || -1) * Math.floor(Math.abs(n));
        }
        return n;
    },

    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToPrimitive */
    ToPrimitive: function ToPrimitive(input) {
        var val, valueOf, toStr;
        if (isPrimitive(input)) {
            return input;
        }
        valueOf = input.valueOf;
        if (isCallable(valueOf)) {
            val = valueOf.call(input);
            if (isPrimitive(val)) {
                return val;
            }
        }
        toStr = input.toString;
        if (isCallable(toStr)) {
            val = toStr.call(input);
            if (isPrimitive(val)) {
                return val;
            }
        }
        throw new TypeError();
    },

    // ES5 9.9
    // http://es5.github.com/#x9.9
    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToObject */
    ToObject: function (o) {
        if (o == null) { // this matches both null and undefined
            throw new TypeError("can't convert " + o + ' to object');
        }
        return $Object(o);
    },

    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToUint32 */
    ToUint32: function ToUint32(x) {
        return x >>> 0;
    }
};

//
// Function
// ========
//

// ES-5 15.3.4.5
// http://es5.github.com/#x15.3.4.5

var Empty = function Empty() {};

defineProperties(FunctionPrototype, {
    bind: function bind(that) { // .length is 1
        // 1. Let Target be the this value.
        var target = this;
        // 2. If IsCallable(Target) is false, throw a TypeError exception.
        if (!isCallable(target)) {
            throw new TypeError('Function.prototype.bind called on incompatible ' + target);
        }
        // 3. Let A be a new (possibly empty) internal list of all of the
        //   argument values provided after thisArg (arg1, arg2 etc), in order.
        // XXX slicedArgs will stand in for "A" if used
        var args = array_slice.call(arguments, 1); // for normal call
        // 4. Let F be a new native ECMAScript object.
        // 11. Set the [[Prototype]] internal property of F to the standard
        //   built-in Function prototype object as specified in 15.3.3.1.
        // 12. Set the [[Call]] internal property of F as described in
        //   15.3.4.5.1.
        // 13. Set the [[Construct]] internal property of F as described in
        //   15.3.4.5.2.
        // 14. Set the [[HasInstance]] internal property of F as described in
        //   15.3.4.5.3.
        var bound;
        var binder = function () {

            if (this instanceof bound) {
                // 15.3.4.5.2 [[Construct]]
                // When the [[Construct]] internal method of a function object,
                // F that was created using the bind function is called with a
                // list of arguments ExtraArgs, the following steps are taken:
                // 1. Let target be the value of F's [[TargetFunction]]
                //   internal property.
                // 2. If target has no [[Construct]] internal method, a
                //   TypeError exception is thrown.
                // 3. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Construct]] internal
                //   method of target providing args as the arguments.

                var result = apply.call(
                    target,
                    this,
                    array_concat.call(args, array_slice.call(arguments))
                );
                if ($Object(result) === result) {
                    return result;
                }
                return this;

            } else {
                // 15.3.4.5.1 [[Call]]
                // When the [[Call]] internal method of a function object, F,
                // which was created using the bind function is called with a
                // this value and a list of arguments ExtraArgs, the following
                // steps are taken:
                // 1. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 2. Let boundThis be the value of F's [[BoundThis]] internal
                //   property.
                // 3. Let target be the value of F's [[TargetFunction]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Call]] internal method
                //   of target providing boundThis as the this value and
                //   providing args as the arguments.

                // equiv: target.call(this, ...boundArgs, ...args)
                return apply.call(
                    target,
                    that,
                    array_concat.call(args, array_slice.call(arguments))
                );

            }

        };

        // 15. If the [[Class]] internal property of Target is "Function", then
        //     a. Let L be the length property of Target minus the length of A.
        //     b. Set the length own property of F to either 0 or L, whichever is
        //       larger.
        // 16. Else set the length own property of F to 0.

        var boundLength = max(0, target.length - args.length);

        // 17. Set the attributes of the length own property of F to the values
        //   specified in 15.3.5.1.
        var boundArgs = [];
        for (var i = 0; i < boundLength; i++) {
            array_push.call(boundArgs, '$' + i);
        }

        // XXX Build a dynamic function with desired amount of arguments is the only
        // way to set the length property of a function.
        // In environments where Content Security Policies enabled (Chrome extensions,
        // for ex.) all use of eval or Function costructor throws an exception.
        // However in all of these environments Function.prototype.bind exists
        // and so this code will never be executed.
        bound = $Function('binder', 'return function (' + array_join.call(boundArgs, ',') + '){ return binder.apply(this, arguments); }')(binder);

        if (target.prototype) {
            Empty.prototype = target.prototype;
            bound.prototype = new Empty();
            // Clean up dangling references.
            Empty.prototype = null;
        }

        // TODO
        // 18. Set the [[Extensible]] internal property of F to true.

        // TODO
        // 19. Let thrower be the [[ThrowTypeError]] function Object (13.2.3).
        // 20. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "caller", PropertyDescriptor {[[Get]]: thrower, [[Set]]:
        //   thrower, [[Enumerable]]: false, [[Configurable]]: false}, and
        //   false.
        // 21. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "arguments", PropertyDescriptor {[[Get]]: thrower,
        //   [[Set]]: thrower, [[Enumerable]]: false, [[Configurable]]: false},
        //   and false.

        // TODO
        // NOTE Function objects created using Function.prototype.bind do not
        // have a prototype property or the [[Code]], [[FormalParameters]], and
        // [[Scope]] internal properties.
        // XXX can't delete prototype in pure-js.

        // 22. Return F.
        return bound;
    }
});

// _Please note: Shortcuts are defined after `Function.prototype.bind` as we
// use it in defining shortcuts.
var owns = call.bind(ObjectPrototype.hasOwnProperty);
var toStr = call.bind(ObjectPrototype.toString);
var arraySlice = call.bind(array_slice);
var arraySliceApply = apply.bind(array_slice);
var strSlice = call.bind(StringPrototype.slice);
var strSplit = call.bind(StringPrototype.split);
var strIndexOf = call.bind(StringPrototype.indexOf);
var pushCall = call.bind(array_push);
var isEnum = call.bind(ObjectPrototype.propertyIsEnumerable);
var arraySort = call.bind(ArrayPrototype.sort);

//
// Array
// =====
//

var isArray = $Array.isArray || function isArray(obj) {
    return toStr(obj) === '[object Array]';
};

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.13
// Return len+argCount.
// [bugfix, ielt8]
// IE < 8 bug: [].unshift(0) === undefined but should be "1"
var hasUnshiftReturnValueBug = [].unshift(0) !== 1;
defineProperties(ArrayPrototype, {
    unshift: function () {
        array_unshift.apply(this, arguments);
        return this.length;
    }
}, hasUnshiftReturnValueBug);

// ES5 15.4.3.2
// http://es5.github.com/#x15.4.3.2
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/isArray
defineProperties($Array, { isArray: isArray });

// The IsCallable() check in the Array functions
// has been replaced with a strict check on the
// internal class of the object to trap cases where
// the provided function was actually a regular
// expression literal, which in V8 and
// JavaScriptCore is a typeof "function".  Only in
// V8 are regular expression literals permitted as
// reduce parameters, so it is desirable in the
// general case for the shim to match the more
// strict and common behavior of rejecting regular
// expressions.

// ES5 15.4.4.18
// http://es5.github.com/#x15.4.4.18
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/array/forEach

// Check failure of by-index access of string characters (IE < 9)
// and failure of `0 in boxedString` (Rhino)
var boxedString = $Object('a');
var splitString = boxedString[0] !== 'a' || !(0 in boxedString);

var properlyBoxesContext = function properlyBoxed(method) {
    // Check node 0.6.21 bug where third parameter is not boxed
    var properlyBoxesNonStrict = true;
    var properlyBoxesStrict = true;
    var threwException = false;
    if (method) {
        try {
            method.call('foo', function (_, __, context) {
                if (typeof context !== 'object') { properlyBoxesNonStrict = false; }
            });

            method.call([1], function () {
                'use strict';

                properlyBoxesStrict = typeof this === 'string';
            }, 'x');
        } catch (e) {
            threwException = true;
        }
    }
    return !!method && !threwException && properlyBoxesNonStrict && properlyBoxesStrict;
};

defineProperties(ArrayPrototype, {
    forEach: function forEach(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var i = -1;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
          T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.forEach callback must be a function');
        }

        while (++i < length) {
            if (i in self) {
                // Invoke the callback function with call, passing arguments:
                // context, property value, property key, thisArg object
                if (typeof T === 'undefined') {
                    callbackfn(self[i], i, object);
                } else {
                    callbackfn.call(T, self[i], i, object);
                }
            }
        }
    }
}, !properlyBoxesContext(ArrayPrototype.forEach));

// ES5 15.4.4.19
// http://es5.github.com/#x15.4.4.19
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/map
defineProperties(ArrayPrototype, {
    map: function map(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var result = $Array(length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.map callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                if (typeof T === 'undefined') {
                    result[i] = callbackfn(self[i], i, object);
                } else {
                    result[i] = callbackfn.call(T, self[i], i, object);
                }
            }
        }
        return result;
    }
}, !properlyBoxesContext(ArrayPrototype.map));

// ES5 15.4.4.20
// http://es5.github.com/#x15.4.4.20
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/filter
defineProperties(ArrayPrototype, {
    filter: function filter(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var result = [];
        var value;
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.filter callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                value = self[i];
                if (typeof T === 'undefined' ? callbackfn(value, i, object) : callbackfn.call(T, value, i, object)) {
                    pushCall(result, value);
                }
            }
        }
        return result;
    }
}, !properlyBoxesContext(ArrayPrototype.filter));

// ES5 15.4.4.16
// http://es5.github.com/#x15.4.4.16
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/every
defineProperties(ArrayPrototype, {
    every: function every(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.every callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self && !(typeof T === 'undefined' ? callbackfn(self[i], i, object) : callbackfn.call(T, self[i], i, object))) {
                return false;
            }
        }
        return true;
    }
}, !properlyBoxesContext(ArrayPrototype.every));

// ES5 15.4.4.17
// http://es5.github.com/#x15.4.4.17
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/some
defineProperties(ArrayPrototype, {
    some: function some(callbackfn/*, thisArg */) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.some callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self && (typeof T === 'undefined' ? callbackfn(self[i], i, object) : callbackfn.call(T, self[i], i, object))) {
                return true;
            }
        }
        return false;
    }
}, !properlyBoxesContext(ArrayPrototype.some));

// ES5 15.4.4.21
// http://es5.github.com/#x15.4.4.21
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduce
var reduceCoercesToObject = false;
if (ArrayPrototype.reduce) {
    reduceCoercesToObject = typeof ArrayPrototype.reduce.call('es5', function (_, __, ___, list) { return list; }) === 'object';
}
defineProperties(ArrayPrototype, {
    reduce: function reduce(callbackfn/*, initialValue*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.reduce callback must be a function');
        }

        // no value to return if no initial value and an empty array
        if (length === 0 && arguments.length === 1) {
            throw new TypeError('reduce of empty array with no initial value');
        }

        var i = 0;
        var result;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i++];
                    break;
                }

                // if array contains no values, no initial value to return
                if (++i >= length) {
                    throw new TypeError('reduce of empty array with no initial value');
                }
            } while (true);
        }

        for (; i < length; i++) {
            if (i in self) {
                result = callbackfn(result, self[i], i, object);
            }
        }

        return result;
    }
}, !reduceCoercesToObject);

// ES5 15.4.4.22
// http://es5.github.com/#x15.4.4.22
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduceRight
var reduceRightCoercesToObject = false;
if (ArrayPrototype.reduceRight) {
    reduceRightCoercesToObject = typeof ArrayPrototype.reduceRight.call('es5', function (_, __, ___, list) { return list; }) === 'object';
}
defineProperties(ArrayPrototype, {
    reduceRight: function reduceRight(callbackfn/*, initial*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.reduceRight callback must be a function');
        }

        // no value to return if no initial value, empty array
        if (length === 0 && arguments.length === 1) {
            throw new TypeError('reduceRight of empty array with no initial value');
        }

        var result;
        var i = length - 1;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i--];
                    break;
                }

                // if array contains no values, no initial value to return
                if (--i < 0) {
                    throw new TypeError('reduceRight of empty array with no initial value');
                }
            } while (true);
        }

        if (i < 0) {
            return result;
        }

        do {
            if (i in self) {
                result = callbackfn(result, self[i], i, object);
            }
        } while (i--);

        return result;
    }
}, !reduceRightCoercesToObject);

// ES5 15.4.4.14
// http://es5.github.com/#x15.4.4.14
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/indexOf
var hasFirefox2IndexOfBug = ArrayPrototype.indexOf && [0, 1].indexOf(1, 2) !== -1;
defineProperties(ArrayPrototype, {
    indexOf: function indexOf(searchElement/*, fromIndex */) {
        var self = splitString && isString(this) ? strSplit(this, '') : ES.ToObject(this);
        var length = ES.ToUint32(self.length);

        if (length === 0) {
            return -1;
        }

        var i = 0;
        if (arguments.length > 1) {
            i = ES.ToInteger(arguments[1]);
        }

        // handle negative indices
        i = i >= 0 ? i : max(0, length + i);
        for (; i < length; i++) {
            if (i in self && self[i] === searchElement) {
                return i;
            }
        }
        return -1;
    }
}, hasFirefox2IndexOfBug);

// ES5 15.4.4.15
// http://es5.github.com/#x15.4.4.15
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/lastIndexOf
var hasFirefox2LastIndexOfBug = ArrayPrototype.lastIndexOf && [0, 1].lastIndexOf(0, -3) !== -1;
defineProperties(ArrayPrototype, {
    lastIndexOf: function lastIndexOf(searchElement/*, fromIndex */) {
        var self = splitString && isString(this) ? strSplit(this, '') : ES.ToObject(this);
        var length = ES.ToUint32(self.length);

        if (length === 0) {
            return -1;
        }
        var i = length - 1;
        if (arguments.length > 1) {
            i = min(i, ES.ToInteger(arguments[1]));
        }
        // handle negative indices
        i = i >= 0 ? i : length - Math.abs(i);
        for (; i >= 0; i--) {
            if (i in self && searchElement === self[i]) {
                return i;
            }
        }
        return -1;
    }
}, hasFirefox2LastIndexOfBug);

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.12
var spliceNoopReturnsEmptyArray = (function () {
    var a = [1, 2];
    var result = a.splice();
    return a.length === 2 && isArray(result) && result.length === 0;
}());
defineProperties(ArrayPrototype, {
    // Safari 5.0 bug where .splice() returns undefined
    splice: function splice(start, deleteCount) {
        if (arguments.length === 0) {
            return [];
        } else {
            return array_splice.apply(this, arguments);
        }
    }
}, !spliceNoopReturnsEmptyArray);

var spliceWorksWithEmptyObject = (function () {
    var obj = {};
    ArrayPrototype.splice.call(obj, 0, 0, 1);
    return obj.length === 1;
}());
defineProperties(ArrayPrototype, {
    splice: function splice(start, deleteCount) {
        if (arguments.length === 0) { return []; }
        var args = arguments;
        this.length = max(ES.ToInteger(this.length), 0);
        if (arguments.length > 0 && typeof deleteCount !== 'number') {
            args = arraySlice(arguments);
            if (args.length < 2) {
                pushCall(args, this.length - start);
            } else {
                args[1] = ES.ToInteger(deleteCount);
            }
        }
        return array_splice.apply(this, args);
    }
}, !spliceWorksWithEmptyObject);
var spliceWorksWithLargeSparseArrays = (function () {
    // Per https://github.com/es-shims/es5-shim/issues/295
    // Safari 7/8 breaks with sparse arrays of size 1e5 or greater
    var arr = new $Array(1e5);
    // note: the index MUST be 8 or larger or the test will false pass
    arr[8] = 'x';
    arr.splice(1, 1);
    // note: this test must be defined *after* the indexOf shim
    // per https://github.com/es-shims/es5-shim/issues/313
    return arr.indexOf('x') === 7;
}());
var spliceWorksWithSmallSparseArrays = (function () {
    // Per https://github.com/es-shims/es5-shim/issues/295
    // Opera 12.15 breaks on this, no idea why.
    var n = 256;
    var arr = [];
    arr[n] = 'a';
    arr.splice(n + 1, 0, 'b');
    return arr[n] === 'a';
}());
defineProperties(ArrayPrototype, {
    splice: function splice(start, deleteCount) {
        var O = ES.ToObject(this);
        var A = [];
        var len = ES.ToUint32(O.length);
        var relativeStart = ES.ToInteger(start);
        var actualStart = relativeStart < 0 ? max((len + relativeStart), 0) : min(relativeStart, len);
        var actualDeleteCount = min(max(ES.ToInteger(deleteCount), 0), len - actualStart);

        var k = 0;
        var from;
        while (k < actualDeleteCount) {
            from = $String(actualStart + k);
            if (owns(O, from)) {
                A[k] = O[from];
            }
            k += 1;
        }

        var items = arraySlice(arguments, 2);
        var itemCount = items.length;
        var to;
        if (itemCount < actualDeleteCount) {
            k = actualStart;
            var maxK = len - actualDeleteCount;
            while (k < maxK) {
                from = $String(k + actualDeleteCount);
                to = $String(k + itemCount);
                if (owns(O, from)) {
                    O[to] = O[from];
                } else {
                    delete O[to];
                }
                k += 1;
            }
            k = len;
            var minK = len - actualDeleteCount + itemCount;
            while (k > minK) {
                delete O[k - 1];
                k -= 1;
            }
        } else if (itemCount > actualDeleteCount) {
            k = len - actualDeleteCount;
            while (k > actualStart) {
                from = $String(k + actualDeleteCount - 1);
                to = $String(k + itemCount - 1);
                if (owns(O, from)) {
                    O[to] = O[from];
                } else {
                    delete O[to];
                }
                k -= 1;
            }
        }
        k = actualStart;
        for (var i = 0; i < items.length; ++i) {
            O[k] = items[i];
            k += 1;
        }
        O.length = len - actualDeleteCount + itemCount;

        return A;
    }
}, !spliceWorksWithLargeSparseArrays || !spliceWorksWithSmallSparseArrays);

var originalJoin = ArrayPrototype.join;
var hasStringJoinBug;
try {
    hasStringJoinBug = Array.prototype.join.call('123', ',') !== '1,2,3';
} catch (e) {
    hasStringJoinBug = true;
}
if (hasStringJoinBug) {
    defineProperties(ArrayPrototype, {
        join: function join(separator) {
            var sep = typeof separator === 'undefined' ? ',' : separator;
            return originalJoin.call(isString(this) ? strSplit(this, '') : this, sep);
        }
    }, hasStringJoinBug);
}

var hasJoinUndefinedBug = [1, 2].join(undefined) !== '1,2';
if (hasJoinUndefinedBug) {
    defineProperties(ArrayPrototype, {
        join: function join(separator) {
            var sep = typeof separator === 'undefined' ? ',' : separator;
            return originalJoin.call(this, sep);
        }
    }, hasJoinUndefinedBug);
}

var pushShim = function push(item) {
    var O = ES.ToObject(this);
    var n = ES.ToUint32(O.length);
    var i = 0;
    while (i < arguments.length) {
        O[n + i] = arguments[i];
        i += 1;
    }
    O.length = n + i;
    return n + i;
};

var pushIsNotGeneric = (function () {
    var obj = {};
    var result = Array.prototype.push.call(obj, undefined);
    return result !== 1 || obj.length !== 1 || typeof obj[0] !== 'undefined' || !owns(obj, 0);
}());
defineProperties(ArrayPrototype, {
    push: function push(item) {
        if (isArray(this)) {
            return array_push.apply(this, arguments);
        }
        return pushShim.apply(this, arguments);
    }
}, pushIsNotGeneric);

// This fixes a very weird bug in Opera 10.6 when pushing `undefined
var pushUndefinedIsWeird = (function () {
    var arr = [];
    var result = arr.push(undefined);
    return result !== 1 || arr.length !== 1 || typeof arr[0] !== 'undefined' || !owns(arr, 0);
}());
defineProperties(ArrayPrototype, { push: pushShim }, pushUndefinedIsWeird);

// ES5 15.2.3.14
// http://es5.github.io/#x15.4.4.10
// Fix boxed string bug
defineProperties(ArrayPrototype, {
    slice: function (start, end) {
        var arr = isString(this) ? strSplit(this, '') : this;
        return arraySliceApply(arr, arguments);
    }
}, splitString);

var sortIgnoresNonFunctions = (function () {
    try {
        [1, 2].sort(null);
        [1, 2].sort({});
        return true;
    } catch (e) { /**/ }
    return false;
}());
var sortThrowsOnRegex = (function () {
    // this is a problem in Firefox 4, in which `typeof /a/ === 'function'`
    try {
        [1, 2].sort(/a/);
        return false;
    } catch (e) { /**/ }
    return true;
}());
var sortIgnoresUndefined = (function () {
    // applies in IE 8, for one.
    try {
        [1, 2].sort(undefined);
        return true;
    } catch (e) { /**/ }
    return false;
}());
defineProperties(ArrayPrototype, {
    sort: function sort(compareFn) {
        if (typeof compareFn === 'undefined') {
            return arraySort(this);
        }
        if (!isCallable(compareFn)) {
            throw new TypeError('Array.prototype.sort callback must be a function');
        }
        return arraySort(this, compareFn);
    }
}, sortIgnoresNonFunctions || !sortIgnoresUndefined || !sortThrowsOnRegex);

//
// Object
// ======
//

// ES5 15.2.3.14
// http://es5.github.com/#x15.2.3.14

// http://whattheheadsaid.com/2010/10/a-safer-object-keys-compatibility-implementation
var hasDontEnumBug = !({ 'toString': null }).propertyIsEnumerable('toString');
var hasProtoEnumBug = function () {}.propertyIsEnumerable('prototype');
var hasStringEnumBug = !owns('x', '0');
var equalsConstructorPrototype = function (o) {
    var ctor = o.constructor;
    return ctor && ctor.prototype === o;
};
var blacklistedKeys = {
    $window: true,
    $console: true,
    $parent: true,
    $self: true,
    $frame: true,
    $frames: true,
    $frameElement: true,
    $webkitIndexedDB: true,
    $webkitStorageInfo: true,
    $external: true
};
var hasAutomationEqualityBug = (function () {
    /* globals window */
    if (typeof window === 'undefined') { return false; }
    for (var k in window) {
        try {
            if (!blacklistedKeys['$' + k] && owns(window, k) && window[k] !== null && typeof window[k] === 'object') {
                equalsConstructorPrototype(window[k]);
            }
        } catch (e) {
            return true;
        }
    }
    return false;
}());
var equalsConstructorPrototypeIfNotBuggy = function (object) {
    if (typeof window === 'undefined' || !hasAutomationEqualityBug) { return equalsConstructorPrototype(object); }
    try {
        return equalsConstructorPrototype(object);
    } catch (e) {
        return false;
    }
};
var dontEnums = [
    'toString',
    'toLocaleString',
    'valueOf',
    'hasOwnProperty',
    'isPrototypeOf',
    'propertyIsEnumerable',
    'constructor'
];
var dontEnumsLength = dontEnums.length;

// taken directly from https://github.com/ljharb/is-arguments/blob/master/index.js
// can be replaced with require('is-arguments') if we ever use a build process instead
var isStandardArguments = function isArguments(value) {
    return toStr(value) === '[object Arguments]';
};
var isLegacyArguments = function isArguments(value) {
    return value !== null &&
        typeof value === 'object' &&
        typeof value.length === 'number' &&
        value.length >= 0 &&
        !isArray(value) &&
        isCallable(value.callee);
};
var isArguments = isStandardArguments(arguments) ? isStandardArguments : isLegacyArguments;

defineProperties($Object, {
    keys: function keys(object) {
        var isFn = isCallable(object);
        var isArgs = isArguments(object);
        var isObject = object !== null && typeof object === 'object';
        var isStr = isObject && isString(object);

        if (!isObject && !isFn && !isArgs) {
            throw new TypeError('Object.keys called on a non-object');
        }

        var theKeys = [];
        var skipProto = hasProtoEnumBug && isFn;
        if ((isStr && hasStringEnumBug) || isArgs) {
            for (var i = 0; i < object.length; ++i) {
                pushCall(theKeys, $String(i));
            }
        }

        if (!isArgs) {
            for (var name in object) {
                if (!(skipProto && name === 'prototype') && owns(object, name)) {
                    pushCall(theKeys, $String(name));
                }
            }
        }

        if (hasDontEnumBug) {
            var skipConstructor = equalsConstructorPrototypeIfNotBuggy(object);
            for (var j = 0; j < dontEnumsLength; j++) {
                var dontEnum = dontEnums[j];
                if (!(skipConstructor && dontEnum === 'constructor') && owns(object, dontEnum)) {
                    pushCall(theKeys, dontEnum);
                }
            }
        }
        return theKeys;
    }
});

var keysWorksWithArguments = $Object.keys && (function () {
    // Safari 5.0 bug
    return $Object.keys(arguments).length === 2;
}(1, 2));
var keysHasArgumentsLengthBug = $Object.keys && (function () {
    var argKeys = $Object.keys(arguments);
    return arguments.length !== 1 || argKeys.length !== 1 || argKeys[0] !== 1;
}(1));
var originalKeys = $Object.keys;
defineProperties($Object, {
    keys: function keys(object) {
        if (isArguments(object)) {
            return originalKeys(arraySlice(object));
        } else {
            return originalKeys(object);
        }
    }
}, !keysWorksWithArguments || keysHasArgumentsLengthBug);

//
// Date
// ====
//

var hasNegativeMonthYearBug = new Date(-3509827329600292).getUTCMonth() !== 0;
var aNegativeTestDate = new Date(-1509842289600292);
var aPositiveTestDate = new Date(1449662400000);
var hasToUTCStringFormatBug = aNegativeTestDate.toUTCString() !== 'Mon, 01 Jan -45875 11:59:59 GMT';
var hasToDateStringFormatBug;
var hasToStringFormatBug;
var timeZoneOffset = aNegativeTestDate.getTimezoneOffset();
if (timeZoneOffset < -720) {
    hasToDateStringFormatBug = aNegativeTestDate.toDateString() !== 'Tue Jan 02 -45875';
    hasToStringFormatBug = !(/^Thu Dec 10 2015 \d\d:\d\d:\d\d GMT[-\+]\d\d\d\d(?: |$)/).test(aPositiveTestDate.toString());
} else {
    hasToDateStringFormatBug = aNegativeTestDate.toDateString() !== 'Mon Jan 01 -45875';
    hasToStringFormatBug = !(/^Wed Dec 09 2015 \d\d:\d\d:\d\d GMT[-\+]\d\d\d\d(?: |$)/).test(aPositiveTestDate.toString());
}

var originalGetFullYear = call.bind(Date.prototype.getFullYear);
var originalGetMonth = call.bind(Date.prototype.getMonth);
var originalGetDate = call.bind(Date.prototype.getDate);
var originalGetUTCFullYear = call.bind(Date.prototype.getUTCFullYear);
var originalGetUTCMonth = call.bind(Date.prototype.getUTCMonth);
var originalGetUTCDate = call.bind(Date.prototype.getUTCDate);
var originalGetUTCDay = call.bind(Date.prototype.getUTCDay);
var originalGetUTCHours = call.bind(Date.prototype.getUTCHours);
var originalGetUTCMinutes = call.bind(Date.prototype.getUTCMinutes);
var originalGetUTCSeconds = call.bind(Date.prototype.getUTCSeconds);
var originalGetUTCMilliseconds = call.bind(Date.prototype.getUTCMilliseconds);
var dayName = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
var monthName = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
var daysInMonth = function daysInMonth(month, year) {
    return originalGetDate(new Date(year, month, 0));
};

defineProperties(Date.prototype, {
    getFullYear: function getFullYear() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        if (year < 0 && originalGetMonth(this) > 11) {
            return year + 1;
        }
        return year;
    },
    getMonth: function getMonth() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        var month = originalGetMonth(this);
        if (year < 0 && month > 11) {
            return 0;
        }
        return month;
    },
    getDate: function getDate() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        var month = originalGetMonth(this);
        var date = originalGetDate(this);
        if (year < 0 && month > 11) {
            if (month === 12) {
                return date;
            }
            var days = daysInMonth(0, year + 1);
            return (days - date) + 1;
        }
        return date;
    },
    getUTCFullYear: function getUTCFullYear() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        if (year < 0 && originalGetUTCMonth(this) > 11) {
            return year + 1;
        }
        return year;
    },
    getUTCMonth: function getUTCMonth() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        var month = originalGetUTCMonth(this);
        if (year < 0 && month > 11) {
            return 0;
        }
        return month;
    },
    getUTCDate: function getUTCDate() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        var month = originalGetUTCMonth(this);
        var date = originalGetUTCDate(this);
        if (year < 0 && month > 11) {
            if (month === 12) {
                return date;
            }
            var days = daysInMonth(0, year + 1);
            return (days - date) + 1;
        }
        return date;
    }
}, hasNegativeMonthYearBug);

defineProperties(Date.prototype, {
    toUTCString: function toUTCString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = originalGetUTCDay(this);
        var date = originalGetUTCDate(this);
        var month = originalGetUTCMonth(this);
        var year = originalGetUTCFullYear(this);
        var hour = originalGetUTCHours(this);
        var minute = originalGetUTCMinutes(this);
        var second = originalGetUTCSeconds(this);
        return dayName[day] + ', ' +
            (date < 10 ? '0' + date : date) + ' ' +
            monthName[month] + ' ' +
            year + ' ' +
            (hour < 10 ? '0' + hour : hour) + ':' +
            (minute < 10 ? '0' + minute : minute) + ':' +
            (second < 10 ? '0' + second : second) + ' GMT';
    }
}, hasNegativeMonthYearBug || hasToUTCStringFormatBug);

// Opera 12 has `,`
defineProperties(Date.prototype, {
    toDateString: function toDateString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = this.getDay();
        var date = this.getDate();
        var month = this.getMonth();
        var year = this.getFullYear();
        return dayName[day] + ' ' +
            monthName[month] + ' ' +
            (date < 10 ? '0' + date : date) + ' ' +
            year;
    }
}, hasNegativeMonthYearBug || hasToDateStringFormatBug);

// can't use defineProperties here because of toString enumeration issue in IE <= 8
if (hasNegativeMonthYearBug || hasToStringFormatBug) {
    Date.prototype.toString = function toString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = this.getDay();
        var date = this.getDate();
        var month = this.getMonth();
        var year = this.getFullYear();
        var hour = this.getHours();
        var minute = this.getMinutes();
        var second = this.getSeconds();
        var timezoneOffset = this.getTimezoneOffset();
        var hoursOffset = Math.floor(Math.abs(timezoneOffset) / 60);
        var minutesOffset = Math.floor(Math.abs(timezoneOffset) % 60);
        return dayName[day] + ' ' +
            monthName[month] + ' ' +
            (date < 10 ? '0' + date : date) + ' ' +
            year + ' ' +
            (hour < 10 ? '0' + hour : hour) + ':' +
            (minute < 10 ? '0' + minute : minute) + ':' +
            (second < 10 ? '0' + second : second) + ' GMT' +
            (timezoneOffset > 0 ? '-' : '+') +
            (hoursOffset < 10 ? '0' + hoursOffset : hoursOffset) +
            (minutesOffset < 10 ? '0' + minutesOffset : minutesOffset);
    };
    if (supportsDescriptors) {
        $Object.defineProperty(Date.prototype, 'toString', {
            configurable: true,
            enumerable: false,
            writable: true
        });
    }
}

// ES5 15.9.5.43
// http://es5.github.com/#x15.9.5.43
// This function returns a String value represent the instance in time
// represented by this Date object. The format of the String is the Date Time
// string format defined in 15.9.1.15. All fields are present in the String.
// The time zone is always UTC, denoted by the suffix Z. If the time value of
// this object is not a finite Number a RangeError exception is thrown.
var negativeDate = -62198755200000;
var negativeYearString = '-000001';
var hasNegativeDateBug = Date.prototype.toISOString && new Date(negativeDate).toISOString().indexOf(negativeYearString) === -1;
var hasSafari51DateBug = Date.prototype.toISOString && new Date(-1).toISOString() !== '1969-12-31T23:59:59.999Z';

var getTime = call.bind(Date.prototype.getTime);

defineProperties(Date.prototype, {
    toISOString: function toISOString() {
        if (!isFinite(this) || !isFinite(getTime(this))) {
            // Adope Photoshop requires the second check.
            throw new RangeError('Date.prototype.toISOString called on non-finite value.');
        }

        var year = originalGetUTCFullYear(this);

        var month = originalGetUTCMonth(this);
        // see https://github.com/es-shims/es5-shim/issues/111
        year += Math.floor(month / 12);
        month = (month % 12 + 12) % 12;

        // the date time string format is specified in 15.9.1.15.
        var result = [month + 1, originalGetUTCDate(this), originalGetUTCHours(this), originalGetUTCMinutes(this), originalGetUTCSeconds(this)];
        year = (
            (year < 0 ? '-' : (year > 9999 ? '+' : '')) +
            strSlice('00000' + Math.abs(year), (0 <= year && year <= 9999) ? -4 : -6)
        );

        for (var i = 0; i < result.length; ++i) {
          // pad months, days, hours, minutes, and seconds to have two digits.
          result[i] = strSlice('00' + result[i], -2);
        }
        // pad milliseconds to have three digits.
        return (
            year + '-' + arraySlice(result, 0, 2).join('-') +
            'T' + arraySlice(result, 2).join(':') + '.' +
            strSlice('000' + originalGetUTCMilliseconds(this), -3) + 'Z'
        );
    }
}, hasNegativeDateBug || hasSafari51DateBug);

// ES5 15.9.5.44
// http://es5.github.com/#x15.9.5.44
// This function provides a String representation of a Date object for use by
// JSON.stringify (15.12.3).
var dateToJSONIsSupported = (function () {
    try {
        return Date.prototype.toJSON &&
            new Date(NaN).toJSON() === null &&
            new Date(negativeDate).toJSON().indexOf(negativeYearString) !== -1 &&
            Date.prototype.toJSON.call({ // generic
                toISOString: function () { return true; }
            });
    } catch (e) {
        return false;
    }
}());
if (!dateToJSONIsSupported) {
    Date.prototype.toJSON = function toJSON(key) {
        // When the toJSON method is called with argument key, the following
        // steps are taken:

        // 1.  Let O be the result of calling ToObject, giving it the this
        // value as its argument.
        // 2. Let tv be ES.ToPrimitive(O, hint Number).
        var O = $Object(this);
        var tv = ES.ToPrimitive(O);
        // 3. If tv is a Number and is not finite, return null.
        if (typeof tv === 'number' && !isFinite(tv)) {
            return null;
        }
        // 4. Let toISO be the result of calling the [[Get]] internal method of
        // O with argument "toISOString".
        var toISO = O.toISOString;
        // 5. If IsCallable(toISO) is false, throw a TypeError exception.
        if (!isCallable(toISO)) {
            throw new TypeError('toISOString property is not callable');
        }
        // 6. Return the result of calling the [[Call]] internal method of
        //  toISO with O as the this value and an empty argument list.
        return toISO.call(O);

        // NOTE 1 The argument is ignored.

        // NOTE 2 The toJSON function is intentionally generic; it does not
        // require that its this value be a Date object. Therefore, it can be
        // transferred to other kinds of objects for use as a method. However,
        // it does require that any such object have a toISOString method. An
        // object is free to use the argument key to filter its
        // stringification.
    };
}

// ES5 15.9.4.2
// http://es5.github.com/#x15.9.4.2
// based on work shared by Daniel Friesen (dantman)
// http://gist.github.com/303249
var supportsExtendedYears = Date.parse('+033658-09-27T01:46:40.000Z') === 1e15;
var acceptsInvalidDates = !isNaN(Date.parse('2012-04-04T24:00:00.500Z')) || !isNaN(Date.parse('2012-11-31T23:59:59.000Z')) || !isNaN(Date.parse('2012-12-31T23:59:60.000Z'));
var doesNotParseY2KNewYear = isNaN(Date.parse('2000-01-01T00:00:00.000Z'));
if (doesNotParseY2KNewYear || acceptsInvalidDates || !supportsExtendedYears) {
    // XXX global assignment won't work in embeddings that use
    // an alternate object for the context.
    /* global Date: true */
    /* eslint-disable no-undef */
    var maxSafeUnsigned32Bit = Math.pow(2, 31) - 1;
    var hasSafariSignedIntBug = isActualNaN(new Date(1970, 0, 1, 0, 0, 0, maxSafeUnsigned32Bit + 1).getTime());
    /* eslint-disable no-implicit-globals */
    Date = (function (NativeDate) {
    /* eslint-enable no-implicit-globals */
    /* eslint-enable no-undef */
        // Date.length === 7
        var DateShim = function Date(Y, M, D, h, m, s, ms) {
            var length = arguments.length;
            var date;
            if (this instanceof NativeDate) {
                var seconds = s;
                var millis = ms;
                if (hasSafariSignedIntBug && length >= 7 && ms > maxSafeUnsigned32Bit) {
                    // work around a Safari 8/9 bug where it treats the seconds as signed
                    var msToShift = Math.floor(ms / maxSafeUnsigned32Bit) * maxSafeUnsigned32Bit;
                    var sToShift = Math.floor(msToShift / 1e3);
                    seconds += sToShift;
                    millis -= sToShift * 1e3;
                }
                date = length === 1 && $String(Y) === Y ? // isString(Y)
                    // We explicitly pass it through parse:
                    new NativeDate(DateShim.parse(Y)) :
                    // We have to manually make calls depending on argument
                    // length here
                    length >= 7 ? new NativeDate(Y, M, D, h, m, seconds, millis) :
                    length >= 6 ? new NativeDate(Y, M, D, h, m, seconds) :
                    length >= 5 ? new NativeDate(Y, M, D, h, m) :
                    length >= 4 ? new NativeDate(Y, M, D, h) :
                    length >= 3 ? new NativeDate(Y, M, D) :
                    length >= 2 ? new NativeDate(Y, M) :
                    length >= 1 ? new NativeDate(Y instanceof NativeDate ? +Y : Y) :
                                  new NativeDate();
            } else {
                date = NativeDate.apply(this, arguments);
            }
            if (!isPrimitive(date)) {
              // Prevent mixups with unfixed Date object
              defineProperties(date, { constructor: DateShim }, true);
            }
            return date;
        };

        // 15.9.1.15 Date Time String Format.
        var isoDateExpression = new RegExp('^' +
            '(\\d{4}|[+-]\\d{6})' + // four-digit year capture or sign +
                                      // 6-digit extended year
            '(?:-(\\d{2})' + // optional month capture
            '(?:-(\\d{2})' + // optional day capture
            '(?:' + // capture hours:minutes:seconds.milliseconds
                'T(\\d{2})' + // hours capture
                ':(\\d{2})' + // minutes capture
                '(?:' + // optional :seconds.milliseconds
                    ':(\\d{2})' + // seconds capture
                    '(?:(\\.\\d{1,}))?' + // milliseconds capture
                ')?' +
            '(' + // capture UTC offset component
                'Z|' + // UTC capture
                '(?:' + // offset specifier +/-hours:minutes
                    '([-+])' + // sign capture
                    '(\\d{2})' + // hours offset capture
                    ':(\\d{2})' + // minutes offset capture
                ')' +
            ')?)?)?)?' +
        '$');

        var months = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365];

        var dayFromMonth = function dayFromMonth(year, month) {
            var t = month > 1 ? 1 : 0;
            return (
                months[month] +
                Math.floor((year - 1969 + t) / 4) -
                Math.floor((year - 1901 + t) / 100) +
                Math.floor((year - 1601 + t) / 400) +
                365 * (year - 1970)
            );
        };

        var toUTC = function toUTC(t) {
            var s = 0;
            var ms = t;
            if (hasSafariSignedIntBug && ms > maxSafeUnsigned32Bit) {
                // work around a Safari 8/9 bug where it treats the seconds as signed
                var msToShift = Math.floor(ms / maxSafeUnsigned32Bit) * maxSafeUnsigned32Bit;
                var sToShift = Math.floor(msToShift / 1e3);
                s += sToShift;
                ms -= sToShift * 1e3;
            }
            return $Number(new NativeDate(1970, 0, 1, 0, 0, s, ms));
        };

        // Copy any custom methods a 3rd party library may have added
        for (var key in NativeDate) {
            if (owns(NativeDate, key)) {
                DateShim[key] = NativeDate[key];
            }
        }

        // Copy "native" methods explicitly; they may be non-enumerable
        defineProperties(DateShim, {
            now: NativeDate.now,
            UTC: NativeDate.UTC
        }, true);
        DateShim.prototype = NativeDate.prototype;
        defineProperties(DateShim.prototype, {
            constructor: DateShim
        }, true);

        // Upgrade Date.parse to handle simplified ISO 8601 strings
        var parseShim = function parse(string) {
            var match = isoDateExpression.exec(string);
            if (match) {
                // parse months, days, hours, minutes, seconds, and milliseconds
                // provide default values if necessary
                // parse the UTC offset component
                var year = $Number(match[1]),
                    month = $Number(match[2] || 1) - 1,
                    day = $Number(match[3] || 1) - 1,
                    hour = $Number(match[4] || 0),
                    minute = $Number(match[5] || 0),
                    second = $Number(match[6] || 0),
                    millisecond = Math.floor($Number(match[7] || 0) * 1000),
                    // When time zone is missed, local offset should be used
                    // (ES 5.1 bug)
                    // see https://bugs.ecmascript.org/show_bug.cgi?id=112
                    isLocalTime = Boolean(match[4] && !match[8]),
                    signOffset = match[9] === '-' ? 1 : -1,
                    hourOffset = $Number(match[10] || 0),
                    minuteOffset = $Number(match[11] || 0),
                    result;
                var hasMinutesOrSecondsOrMilliseconds = minute > 0 || second > 0 || millisecond > 0;
                if (
                    hour < (hasMinutesOrSecondsOrMilliseconds ? 24 : 25) &&
                    minute < 60 && second < 60 && millisecond < 1000 &&
                    month > -1 && month < 12 && hourOffset < 24 &&
                    minuteOffset < 60 && // detect invalid offsets
                    day > -1 &&
                    day < (dayFromMonth(year, month + 1) - dayFromMonth(year, month))
                ) {
                    result = (
                        (dayFromMonth(year, month) + day) * 24 +
                        hour +
                        hourOffset * signOffset
                    ) * 60;
                    result = (
                        (result + minute + minuteOffset * signOffset) * 60 +
                        second
                    ) * 1000 + millisecond;
                    if (isLocalTime) {
                        result = toUTC(result);
                    }
                    if (-8.64e15 <= result && result <= 8.64e15) {
                        return result;
                    }
                }
                return NaN;
            }
            return NativeDate.parse.apply(this, arguments);
        };
        defineProperties(DateShim, { parse: parseShim });

        return DateShim;
    }(Date));
    /* global Date: false */
}

// ES5 15.9.4.4
// http://es5.github.com/#x15.9.4.4
if (!Date.now) {
    Date.now = function now() {
        return new Date().getTime();
    };
}

//
// Number
// ======
//

// ES5.1 15.7.4.5
// http://es5.github.com/#x15.7.4.5
var hasToFixedBugs = NumberPrototype.toFixed && (
  (0.00008).toFixed(3) !== '0.000' ||
  (0.9).toFixed(0) !== '1' ||
  (1.255).toFixed(2) !== '1.25' ||
  (1000000000000000128).toFixed(0) !== '1000000000000000128'
);

var toFixedHelpers = {
  base: 1e7,
  size: 6,
  data: [0, 0, 0, 0, 0, 0],
  multiply: function multiply(n, c) {
      var i = -1;
      var c2 = c;
      while (++i < toFixedHelpers.size) {
          c2 += n * toFixedHelpers.data[i];
          toFixedHelpers.data[i] = c2 % toFixedHelpers.base;
          c2 = Math.floor(c2 / toFixedHelpers.base);
      }
  },
  divide: function divide(n) {
      var i = toFixedHelpers.size;
      var c = 0;
      while (--i >= 0) {
          c += toFixedHelpers.data[i];
          toFixedHelpers.data[i] = Math.floor(c / n);
          c = (c % n) * toFixedHelpers.base;
      }
  },
  numToString: function numToString() {
      var i = toFixedHelpers.size;
      var s = '';
      while (--i >= 0) {
          if (s !== '' || i === 0 || toFixedHelpers.data[i] !== 0) {
              var t = $String(toFixedHelpers.data[i]);
              if (s === '') {
                  s = t;
              } else {
                  s += strSlice('0000000', 0, 7 - t.length) + t;
              }
          }
      }
      return s;
  },
  pow: function pow(x, n, acc) {
      return (n === 0 ? acc : (n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc)));
  },
  log: function log(x) {
      var n = 0;
      var x2 = x;
      while (x2 >= 4096) {
          n += 12;
          x2 /= 4096;
      }
      while (x2 >= 2) {
          n += 1;
          x2 /= 2;
      }
      return n;
  }
};

var toFixedShim = function toFixed(fractionDigits) {
    var f, x, s, m, e, z, j, k;

    // Test for NaN and round fractionDigits down
    f = $Number(fractionDigits);
    f = isActualNaN(f) ? 0 : Math.floor(f);

    if (f < 0 || f > 20) {
        throw new RangeError('Number.toFixed called with invalid number of decimals');
    }

    x = $Number(this);

    if (isActualNaN(x)) {
        return 'NaN';
    }

    // If it is too big or small, return the string value of the number
    if (x <= -1e21 || x >= 1e21) {
        return $String(x);
    }

    s = '';

    if (x < 0) {
        s = '-';
        x = -x;
    }

    m = '0';

    if (x > 1e-21) {
        // 1e-21 < x < 1e21
        // -70 < log2(x) < 70
        e = toFixedHelpers.log(x * toFixedHelpers.pow(2, 69, 1)) - 69;
        z = (e < 0 ? x * toFixedHelpers.pow(2, -e, 1) : x / toFixedHelpers.pow(2, e, 1));
        z *= 0x10000000000000; // Math.pow(2, 52);
        e = 52 - e;

        // -18 < e < 122
        // x = z / 2 ^ e
        if (e > 0) {
            toFixedHelpers.multiply(0, z);
            j = f;

            while (j >= 7) {
                toFixedHelpers.multiply(1e7, 0);
                j -= 7;
            }

            toFixedHelpers.multiply(toFixedHelpers.pow(10, j, 1), 0);
            j = e - 1;

            while (j >= 23) {
                toFixedHelpers.divide(1 << 23);
                j -= 23;
            }

            toFixedHelpers.divide(1 << j);
            toFixedHelpers.multiply(1, 1);
            toFixedHelpers.divide(2);
            m = toFixedHelpers.numToString();
        } else {
            toFixedHelpers.multiply(0, z);
            toFixedHelpers.multiply(1 << (-e), 0);
            m = toFixedHelpers.numToString() + strSlice('0.00000000000000000000', 2, 2 + f);
        }
    }

    if (f > 0) {
        k = m.length;

        if (k <= f) {
            m = s + strSlice('0.0000000000000000000', 0, f - k + 2) + m;
        } else {
            m = s + strSlice(m, 0, k - f) + '.' + strSlice(m, k - f);
        }
    } else {
        m = s + m;
    }

    return m;
};
defineProperties(NumberPrototype, { toFixed: toFixedShim }, hasToFixedBugs);

var hasToPrecisionUndefinedBug = (function () {
    try {
        return 1.0.toPrecision(undefined) === '1';
    } catch (e) {
        return true;
    }
}());
var originalToPrecision = NumberPrototype.toPrecision;
defineProperties(NumberPrototype, {
    toPrecision: function toPrecision(precision) {
        return typeof precision === 'undefined' ? originalToPrecision.call(this) : originalToPrecision.call(this, precision);
    }
}, hasToPrecisionUndefinedBug);

//
// String
// ======
//

// ES5 15.5.4.14
// http://es5.github.com/#x15.5.4.14

// [bugfix, IE lt 9, firefox 4, Konqueror, Opera, obscure browsers]
// Many browsers do not split properly with regular expressions or they
// do not perform the split correctly under obscure conditions.
// See http://blog.stevenlevithan.com/archives/cross-browser-split
// I've tested in many browsers and this seems to cover the deviant ones:
//    'ab'.split(/(?:ab)*/) should be ["", ""], not [""]
//    '.'.split(/(.?)(.?)/) should be ["", ".", "", ""], not ["", ""]
//    'tesst'.split(/(s)*/) should be ["t", undefined, "e", "s", "t"], not
//       [undefined, "t", undefined, "e", ...]
//    ''.split(/.?/) should be [], not [""]
//    '.'.split(/()()/) should be ["."], not ["", "", "."]

if (
    'ab'.split(/(?:ab)*/).length !== 2 ||
    '.'.split(/(.?)(.?)/).length !== 4 ||
    'tesst'.split(/(s)*/)[1] === 't' ||
    'test'.split(/(?:)/, -1).length !== 4 ||
    ''.split(/.?/).length ||
    '.'.split(/()()/).length > 1
) {
    (function () {
        var compliantExecNpcg = typeof (/()??/).exec('')[1] === 'undefined'; // NPCG: nonparticipating capturing group
        var maxSafe32BitInt = Math.pow(2, 32) - 1;

        StringPrototype.split = function (separator, limit) {
            var string = String(this);
            if (typeof separator === 'undefined' && limit === 0) {
                return [];
            }

            // If `separator` is not a regex, use native split
            if (!isRegex(separator)) {
                return strSplit(this, separator, limit);
            }

            var output = [];
            var flags = (separator.ignoreCase ? 'i' : '') +
                        (separator.multiline ? 'm' : '') +
                        (separator.unicode ? 'u' : '') + // in ES6
                        (separator.sticky ? 'y' : ''), // Firefox 3+ and ES6
                lastLastIndex = 0,
                // Make `global` and avoid `lastIndex` issues by working with a copy
                separator2, match, lastIndex, lastLength;
            var separatorCopy = new RegExp(separator.source, flags + 'g');
            if (!compliantExecNpcg) {
                // Doesn't need flags gy, but they don't hurt
                separator2 = new RegExp('^' + separatorCopy.source + '$(?!\\s)', flags);
            }
            /* Values for `limit`, per the spec:
             * If undefined: 4294967295 // maxSafe32BitInt
             * If 0, Infinity, or NaN: 0
             * If positive number: limit = Math.floor(limit); if (limit > 4294967295) limit -= 4294967296;
             * If negative number: 4294967296 - Math.floor(Math.abs(limit))
             * If other: Type-convert, then use the above rules
             */
            var splitLimit = typeof limit === 'undefined' ? maxSafe32BitInt : ES.ToUint32(limit);
            match = separatorCopy.exec(string);
            while (match) {
                // `separatorCopy.lastIndex` is not reliable cross-browser
                lastIndex = match.index + match[0].length;
                if (lastIndex > lastLastIndex) {
                    pushCall(output, strSlice(string, lastLastIndex, match.index));
                    // Fix browsers whose `exec` methods don't consistently return `undefined` for
                    // nonparticipating capturing groups
                    if (!compliantExecNpcg && match.length > 1) {
                        /* eslint-disable no-loop-func */
                        match[0].replace(separator2, function () {
                            for (var i = 1; i < arguments.length - 2; i++) {
                                if (typeof arguments[i] === 'undefined') {
                                    match[i] = void 0;
                                }
                            }
                        });
                        /* eslint-enable no-loop-func */
                    }
                    if (match.length > 1 && match.index < string.length) {
                        array_push.apply(output, arraySlice(match, 1));
                    }
                    lastLength = match[0].length;
                    lastLastIndex = lastIndex;
                    if (output.length >= splitLimit) {
                        break;
                    }
                }
                if (separatorCopy.lastIndex === match.index) {
                    separatorCopy.lastIndex++; // Avoid an infinite loop
                }
                match = separatorCopy.exec(string);
            }
            if (lastLastIndex === string.length) {
                if (lastLength || !separatorCopy.test('')) {
                    pushCall(output, '');
                }
            } else {
                pushCall(output, strSlice(string, lastLastIndex));
            }
            return output.length > splitLimit ? arraySlice(output, 0, splitLimit) : output;
        };
    }());

// [bugfix, chrome]
// If separator is undefined, then the result array contains just one String,
// which is the this value (converted to a String). If limit is not undefined,
// then the output array is truncated so that it contains no more than limit
// elements.
// "0".split(undefined, 0) -> []
} else if ('0'.split(void 0, 0).length) {
    StringPrototype.split = function split(separator, limit) {
        if (typeof separator === 'undefined' && limit === 0) { return []; }
        return strSplit(this, separator, limit);
    };
}

var str_replace = StringPrototype.replace;
var replaceReportsGroupsCorrectly = (function () {
    var groups = [];
    'x'.replace(/x(.)?/g, function (match, group) {
        pushCall(groups, group);
    });
    return groups.length === 1 && typeof groups[0] === 'undefined';
}());

if (!replaceReportsGroupsCorrectly) {
    StringPrototype.replace = function replace(searchValue, replaceValue) {
        var isFn = isCallable(replaceValue);
        var hasCapturingGroups = isRegex(searchValue) && (/\)[*?]/).test(searchValue.source);
        if (!isFn || !hasCapturingGroups) {
            return str_replace.call(this, searchValue, replaceValue);
        } else {
            var wrappedReplaceValue = function (match) {
                var length = arguments.length;
                var originalLastIndex = searchValue.lastIndex;
                searchValue.lastIndex = 0;
                var args = searchValue.exec(match) || [];
                searchValue.lastIndex = originalLastIndex;
                pushCall(args, arguments[length - 2], arguments[length - 1]);
                return replaceValue.apply(this, args);
            };
            return str_replace.call(this, searchValue, wrappedReplaceValue);
        }
    };
}

// ECMA-262, 3rd B.2.3
// Not an ECMAScript standard, although ECMAScript 3rd Edition has a
// non-normative section suggesting uniform semantics and it should be
// normalized across all browsers
// [bugfix, IE lt 9] IE < 9 substr() with negative value not working in IE
var string_substr = StringPrototype.substr;
var hasNegativeSubstrBug = ''.substr && '0b'.substr(-1) !== 'b';
defineProperties(StringPrototype, {
    substr: function substr(start, length) {
        var normalizedStart = start;
        if (start < 0) {
            normalizedStart = max(this.length + start, 0);
        }
        return string_substr.call(this, normalizedStart, length);
    }
}, hasNegativeSubstrBug);

// ES5 15.5.4.20
// whitespace from: http://es5.github.io/#x15.5.4.20
var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003' +
    '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028' +
    '\u2029\uFEFF';
var zeroWidth = '\u200b';
var wsRegexChars = '[' + ws + ']';
var trimBeginRegexp = new RegExp('^' + wsRegexChars + wsRegexChars + '*');
var trimEndRegexp = new RegExp(wsRegexChars + wsRegexChars + '*$');
var hasTrimWhitespaceBug = StringPrototype.trim && (ws.trim() || !zeroWidth.trim());
defineProperties(StringPrototype, {
    // http://blog.stevenlevithan.com/archives/faster-trim-javascript
    // http://perfectionkills.com/whitespace-deviations/
    trim: function trim() {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        return $String(this).replace(trimBeginRegexp, '').replace(trimEndRegexp, '');
    }
}, hasTrimWhitespaceBug);
var trim = call.bind(String.prototype.trim);

var hasLastIndexBug = StringPrototype.lastIndexOf && 'abcあい'.lastIndexOf('あい', 2) !== -1;
defineProperties(StringPrototype, {
    lastIndexOf: function lastIndexOf(searchString) {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        var S = $String(this);
        var searchStr = $String(searchString);
        var numPos = arguments.length > 1 ? $Number(arguments[1]) : NaN;
        var pos = isActualNaN(numPos) ? Infinity : ES.ToInteger(numPos);
        var start = min(max(pos, 0), S.length);
        var searchLen = searchStr.length;
        var k = start + searchLen;
        while (k > 0) {
            k = max(0, k - searchLen);
            var index = strIndexOf(strSlice(S, k, start + searchLen), searchStr);
            if (index !== -1) {
                return k + index;
            }
        }
        return -1;
    }
}, hasLastIndexBug);

var originalLastIndexOf = StringPrototype.lastIndexOf;
defineProperties(StringPrototype, {
    lastIndexOf: function lastIndexOf(searchString) {
        return originalLastIndexOf.apply(this, arguments);
    }
}, StringPrototype.lastIndexOf.length !== 1);

// ES-5 15.1.2.2
/* eslint-disable radix */
if (parseInt(ws + '08') !== 8 || parseInt(ws + '0x16') !== 22) {
/* eslint-enable radix */
    /* global parseInt: true */
    parseInt = (function (origParseInt) {
        var hexRegex = /^[\-+]?0[xX]/;
        return function parseInt(str, radix) {
            var string = trim(str);
            var defaultedRadix = $Number(radix) || (hexRegex.test(string) ? 16 : 10);
            return origParseInt(string, defaultedRadix);
        };
    }(parseInt));
}

// https://es5.github.io/#x15.1.2.3
if (1 / parseFloat('-0') !== -Infinity) {
    /* global parseFloat: true */
    parseFloat = (function (origParseFloat) {
        return function parseFloat(string) {
            var inputString = trim(string);
            var result = origParseFloat(inputString);
            return result === 0 && strSlice(inputString, 0, 1) === '-' ? -0 : result;
        };
    }(parseFloat));
}

if (String(new RangeError('test')) !== 'RangeError: test') {
    var errorToStringShim = function toString() {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        var name = this.name;
        if (typeof name === 'undefined') {
            name = 'Error';
        } else if (typeof name !== 'string') {
            name = $String(name);
        }
        var msg = this.message;
        if (typeof msg === 'undefined') {
            msg = '';
        } else if (typeof msg !== 'string') {
            msg = $String(msg);
        }
        if (!name) {
            return msg;
        }
        if (!msg) {
            return name;
        }
        return name + ': ' + msg;
    };
    // can't use defineProperties here because of toString enumeration issue in IE <= 8
    Error.prototype.toString = errorToStringShim;
}

if (supportsDescriptors) {
    var ensureNonEnumerable = function (obj, prop) {
        if (isEnum(obj, prop)) {
            var desc = Object.getOwnPropertyDescriptor(obj, prop);
            desc.enumerable = false;
            Object.defineProperty(obj, prop, desc);
        }
    };
    ensureNonEnumerable(Error.prototype, 'message');
    if (Error.prototype.message !== '') {
      Error.prototype.message = '';
    }
    ensureNonEnumerable(Error.prototype, 'name');
}

if (String(/a/mig) !== '/a/gim') {
    var regexToString = function toString() {
        var str = '/' + this.source + '/';
        if (this.global) {
            str += 'g';
        }
        if (this.ignoreCase) {
            str += 'i';
        }
        if (this.multiline) {
            str += 'm';
        }
        return str;
    };
    // can't use defineProperties here because of toString enumeration issue in IE <= 8
    RegExp.prototype.toString = regexToString;
}

}));

/*!
 * https://github.com/es-shims/es5-shim
 * @license es5-shim Copyright 2009-2015 by contributors, MIT License
 * see https://github.com/es-shims/es5-shim/blob/master/LICENSE
 */

// vim: ts=4 sts=4 sw=4 expandtab

// Add semicolon to prevent IIFE from being passed as argument to concatenated code.
;

// UMD (Universal Module Definition)
// see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
(function (root, factory) {
    'use strict';

    /* global define, exports, module */
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals (root is window)
        root.returnExports = factory();
    }
}(this, function () {

    var call = Function.call;
    var prototypeOfObject = Object.prototype;
    var owns = call.bind(prototypeOfObject.hasOwnProperty);
    var isEnumerable = call.bind(prototypeOfObject.propertyIsEnumerable);
    var toStr = call.bind(prototypeOfObject.toString);

    // If JS engine supports accessors creating shortcuts.
    var defineGetter;
    var defineSetter;
    var lookupGetter;
    var lookupSetter;
    var supportsAccessors = owns(prototypeOfObject, '__defineGetter__');
    if (supportsAccessors) {
        /* eslint-disable no-underscore-dangle, no-restricted-properties */
        defineGetter = call.bind(prototypeOfObject.__defineGetter__);
        defineSetter = call.bind(prototypeOfObject.__defineSetter__);
        lookupGetter = call.bind(prototypeOfObject.__lookupGetter__);
        lookupSetter = call.bind(prototypeOfObject.__lookupSetter__);
        /* eslint-enable no-underscore-dangle, no-restricted-properties */
    }

    var isPrimitive = function isPrimitive(o) {
        return o == null || (typeof o !== 'object' && typeof o !== 'function');
    };

    // ES5 15.2.3.2
    // http://es5.github.com/#x15.2.3.2
    if (!Object.getPrototypeOf) {
        // https://github.com/es-shims/es5-shim/issues#issue/2
        // http://ejohn.org/blog/objectgetprototypeof/
        // recommended by fschaefer on github
        //
        // sure, and webreflection says ^_^
        // ... this will nerever possibly return null
        // ... Opera Mini breaks here with infinite loops
        Object.getPrototypeOf = function getPrototypeOf(object) {
            // eslint-disable-next-line no-proto
            var proto = object.__proto__;
            if (proto || proto === null) {
                return proto;
            } else if (toStr(object.constructor) === '[object Function]') {
                return object.constructor.prototype;
            } else if (object instanceof Object) {
                return prototypeOfObject;
            } else {
                // Correctly return null for Objects created with `Object.create(null)`
                // (shammed or native) or `{ __proto__: null}`.  Also returns null for
                // cross-realm objects on browsers that lack `__proto__` support (like
                // IE <11), but that's the best we can do.
                return null;
            }
        };
    }

    // ES5 15.2.3.3
    // http://es5.github.com/#x15.2.3.3

    var doesGetOwnPropertyDescriptorWork = function doesGetOwnPropertyDescriptorWork(object) {
        try {
            object.sentinel = 0;
            return Object.getOwnPropertyDescriptor(object, 'sentinel').value === 0;
        } catch (exception) {
            return false;
        }
    };

    // check whether getOwnPropertyDescriptor works if it's given. Otherwise, shim partially.
    if (Object.defineProperty) {
        var getOwnPropertyDescriptorWorksOnObject = doesGetOwnPropertyDescriptorWork({});
        var getOwnPropertyDescriptorWorksOnDom = typeof document === 'undefined' ||
            doesGetOwnPropertyDescriptorWork(document.createElement('div'));
        if (!getOwnPropertyDescriptorWorksOnDom || !getOwnPropertyDescriptorWorksOnObject) {
            var getOwnPropertyDescriptorFallback = Object.getOwnPropertyDescriptor;
        }
    }

    if (!Object.getOwnPropertyDescriptor || getOwnPropertyDescriptorFallback) {
        var ERR_NON_OBJECT = 'Object.getOwnPropertyDescriptor called on a non-object: ';

        /* eslint-disable no-proto */
        Object.getOwnPropertyDescriptor = function getOwnPropertyDescriptor(object, property) {
            if (isPrimitive(object)) {
                throw new TypeError(ERR_NON_OBJECT + object);
            }

            // make a valiant attempt to use the real getOwnPropertyDescriptor
            // for I8's DOM elements.
            if (getOwnPropertyDescriptorFallback) {
                try {
                    return getOwnPropertyDescriptorFallback.call(Object, object, property);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            var descriptor;

            // If object does not owns property return undefined immediately.
            if (!owns(object, property)) {
                return descriptor;
            }

            // If object has a property then it's for sure `configurable`, and
            // probably `enumerable`. Detect enumerability though.
            descriptor = {
                enumerable: isEnumerable(object, property),
                configurable: true
            };

            // If JS engine supports accessor properties then property may be a
            // getter or setter.
            if (supportsAccessors) {
                // Unfortunately `__lookupGetter__` will return a getter even
                // if object has own non getter property along with a same named
                // inherited getter. To avoid misbehavior we temporary remove
                // `__proto__` so that `__lookupGetter__` will return getter only
                // if it's owned by an object.
                var prototype = object.__proto__;
                var notPrototypeOfObject = object !== prototypeOfObject;
                // avoid recursion problem, breaking in Opera Mini when
                // Object.getOwnPropertyDescriptor(Object.prototype, 'toString')
                // or any other Object.prototype accessor
                if (notPrototypeOfObject) {
                    object.__proto__ = prototypeOfObject;
                }

                var getter = lookupGetter(object, property);
                var setter = lookupSetter(object, property);

                if (notPrototypeOfObject) {
                    // Once we have getter and setter we can put values back.
                    object.__proto__ = prototype;
                }

                if (getter || setter) {
                    if (getter) {
                        descriptor.get = getter;
                    }
                    if (setter) {
                        descriptor.set = setter;
                    }
                    // If it was accessor property we're done and return here
                    // in order to avoid adding `value` to the descriptor.
                    return descriptor;
                }
            }

            // If we got this far we know that object has an own property that is
            // not an accessor so we set it as a value and return descriptor.
            descriptor.value = object[property];
            descriptor.writable = true;
            return descriptor;
        };
        /* eslint-enable no-proto */
    }

    // ES5 15.2.3.4
    // http://es5.github.com/#x15.2.3.4
    if (!Object.getOwnPropertyNames) {
        Object.getOwnPropertyNames = function getOwnPropertyNames(object) {
            return Object.keys(object);
        };
    }

    // ES5 15.2.3.5
    // http://es5.github.com/#x15.2.3.5
    if (!Object.create) {

        // Contributed by Brandon Benvie, October, 2012
        var createEmpty;
        var supportsProto = !({ __proto__: null } instanceof Object);
        // the following produces false positives
        // in Opera Mini => not a reliable check
        // Object.prototype.__proto__ === null

        // Check for document.domain and active x support
        // No need to use active x approach when document.domain is not set
        // see https://github.com/es-shims/es5-shim/issues/150
        // variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
        /* global ActiveXObject */
        var shouldUseActiveX = function shouldUseActiveX() {
            // return early if document.domain not set
            if (!document.domain) {
                return false;
            }

            try {
                return !!new ActiveXObject('htmlfile');
            } catch (exception) {
                return false;
            }
        };

        // This supports IE8 when document.domain is used
        // see https://github.com/es-shims/es5-shim/issues/150
        // variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
        var getEmptyViaActiveX = function getEmptyViaActiveX() {
            var empty;
            var xDoc;

            xDoc = new ActiveXObject('htmlfile');

            var script = 'script';
            xDoc.write('<' + script + '></' + script + '>');
            xDoc.close();

            empty = xDoc.parentWindow.Object.prototype;
            xDoc = null;

            return empty;
        };

        // The original implementation using an iframe
        // before the activex approach was added
        // see https://github.com/es-shims/es5-shim/issues/150
        var getEmptyViaIFrame = function getEmptyViaIFrame() {
            var iframe = document.createElement('iframe');
            var parent = document.body || document.documentElement;
            var empty;

            iframe.style.display = 'none';
            parent.appendChild(iframe);
            // eslint-disable-next-line no-script-url
            iframe.src = 'javascript:';

            empty = iframe.contentWindow.Object.prototype;
            parent.removeChild(iframe);
            iframe = null;

            return empty;
        };

        /* global document */
        if (supportsProto || typeof document === 'undefined') {
            createEmpty = function () {
                return { __proto__: null };
            };
        } else {
            // In old IE __proto__ can't be used to manually set `null`, nor does
            // any other method exist to make an object that inherits from nothing,
            // aside from Object.prototype itself. Instead, create a new global
            // object and *steal* its Object.prototype and strip it bare. This is
            // used as the prototype to create nullary objects.
            createEmpty = function () {
                // Determine which approach to use
                // see https://github.com/es-shims/es5-shim/issues/150
                var empty = shouldUseActiveX() ? getEmptyViaActiveX() : getEmptyViaIFrame();

                delete empty.constructor;
                delete empty.hasOwnProperty;
                delete empty.propertyIsEnumerable;
                delete empty.isPrototypeOf;
                delete empty.toLocaleString;
                delete empty.toString;
                delete empty.valueOf;

                var Empty = function Empty() {};
                Empty.prototype = empty;
                // short-circuit future calls
                createEmpty = function () {
                    return new Empty();
                };
                return new Empty();
            };
        }

        Object.create = function create(prototype, properties) {

            var object;
            var Type = function Type() {}; // An empty constructor.

            if (prototype === null) {
                object = createEmpty();
            } else {
                if (prototype !== null && isPrimitive(prototype)) {
                    // In the native implementation `parent` can be `null`
                    // OR *any* `instanceof Object`  (Object|Function|Array|RegExp|etc)
                    // Use `typeof` tho, b/c in old IE, DOM elements are not `instanceof Object`
                    // like they are in modern browsers. Using `Object.create` on DOM elements
                    // is...err...probably inappropriate, but the native version allows for it.
                    throw new TypeError('Object prototype may only be an Object or null'); // same msg as Chrome
                }
                Type.prototype = prototype;
                object = new Type();
                // IE has no built-in implementation of `Object.getPrototypeOf`
                // neither `__proto__`, but this manually setting `__proto__` will
                // guarantee that `Object.getPrototypeOf` will work as expected with
                // objects created using `Object.create`
                // eslint-disable-next-line no-proto
                object.__proto__ = prototype;
            }

            if (properties !== void 0) {
                Object.defineProperties(object, properties);
            }

            return object;
        };
    }

    // ES5 15.2.3.6
    // http://es5.github.com/#x15.2.3.6

    // Patch for WebKit and IE8 standard mode
    // Designed by hax <hax.github.com>
    // related issue: https://github.com/es-shims/es5-shim/issues#issue/5
    // IE8 Reference:
    //     http://msdn.microsoft.com/en-us/library/dd282900.aspx
    //     http://msdn.microsoft.com/en-us/library/dd229916.aspx
    // WebKit Bugs:
    //     https://bugs.webkit.org/show_bug.cgi?id=36423

    var doesDefinePropertyWork = function doesDefinePropertyWork(object) {
        try {
            Object.defineProperty(object, 'sentinel', {});
            return 'sentinel' in object;
        } catch (exception) {
            return false;
        }
    };

    // check whether defineProperty works if it's given. Otherwise,
    // shim partially.
    if (Object.defineProperty) {
        var definePropertyWorksOnObject = doesDefinePropertyWork({});
        var definePropertyWorksOnDom = typeof document === 'undefined' ||
            doesDefinePropertyWork(document.createElement('div'));
        if (!definePropertyWorksOnObject || !definePropertyWorksOnDom) {
            var definePropertyFallback = Object.defineProperty,
                definePropertiesFallback = Object.defineProperties;
        }
    }

    if (!Object.defineProperty || definePropertyFallback) {
        var ERR_NON_OBJECT_DESCRIPTOR = 'Property description must be an object: ';
        var ERR_NON_OBJECT_TARGET = 'Object.defineProperty called on non-object: ';
        var ERR_ACCESSORS_NOT_SUPPORTED = 'getters & setters can not be defined on this javascript engine';

        Object.defineProperty = function defineProperty(object, property, descriptor) {
            if (isPrimitive(object)) {
                throw new TypeError(ERR_NON_OBJECT_TARGET + object);
            }
            if (isPrimitive(descriptor)) {
                throw new TypeError(ERR_NON_OBJECT_DESCRIPTOR + descriptor);
            }
            // make a valiant attempt to use the real defineProperty
            // for I8's DOM elements.
            if (definePropertyFallback) {
                try {
                    return definePropertyFallback.call(Object, object, property, descriptor);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            // If it's a data property.
            if ('value' in descriptor) {
                // fail silently if 'writable', 'enumerable', or 'configurable'
                // are requested but not supported
                /*
                // alternate approach:
                if ( // can't implement these features; allow false but not true
                    ('writable' in descriptor && !descriptor.writable) ||
                    ('enumerable' in descriptor && !descriptor.enumerable) ||
                    ('configurable' in descriptor && !descriptor.configurable)
                ))
                    throw new RangeError(
                        'This implementation of Object.defineProperty does not support configurable, enumerable, or writable.'
                    );
                */

                if (supportsAccessors && (lookupGetter(object, property) || lookupSetter(object, property))) {
                    // As accessors are supported only on engines implementing
                    // `__proto__` we can safely override `__proto__` while defining
                    // a property to make sure that we don't hit an inherited
                    // accessor.
                    /* eslint-disable no-proto */
                    var prototype = object.__proto__;
                    object.__proto__ = prototypeOfObject;
                    // Deleting a property anyway since getter / setter may be
                    // defined on object itself.
                    delete object[property];
                    object[property] = descriptor.value;
                    // Setting original `__proto__` back now.
                    object.__proto__ = prototype;
                    /* eslint-enable no-proto */
                } else {
                    object[property] = descriptor.value;
                }
            } else {
                var hasGetter = 'get' in descriptor;
                var hasSetter = 'set' in descriptor;
                if (!supportsAccessors && (hasGetter || hasSetter)) {
                    throw new TypeError(ERR_ACCESSORS_NOT_SUPPORTED);
                }
                // If we got that far then getters and setters can be defined !!
                if (hasGetter) {
                    defineGetter(object, property, descriptor.get);
                }
                if (hasSetter) {
                    defineSetter(object, property, descriptor.set);
                }
            }
            return object;
        };
    }

    // ES5 15.2.3.7
    // http://es5.github.com/#x15.2.3.7
    if (!Object.defineProperties || definePropertiesFallback) {
        Object.defineProperties = function defineProperties(object, properties) {
            // make a valiant attempt to use the real defineProperties
            if (definePropertiesFallback) {
                try {
                    return definePropertiesFallback.call(Object, object, properties);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            Object.keys(properties).forEach(function (property) {
                if (property !== '__proto__') {
                    Object.defineProperty(object, property, properties[property]);
                }
            });
            return object;
        };
    }

    // ES5 15.2.3.8
    // http://es5.github.com/#x15.2.3.8
    if (!Object.seal) {
        Object.seal = function seal(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.seal can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // ES5 15.2.3.9
    // http://es5.github.com/#x15.2.3.9
    if (!Object.freeze) {
        Object.freeze = function freeze(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.freeze can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // detect a Rhino bug and patch it
    try {
        Object.freeze(function () {});
    } catch (exception) {
        Object.freeze = (function (freezeObject) {
            return function freeze(object) {
                if (typeof object === 'function') {
                    return object;
                } else {
                    return freezeObject(object);
                }
            };
        }(Object.freeze));
    }

    // ES5 15.2.3.10
    // http://es5.github.com/#x15.2.3.10
    if (!Object.preventExtensions) {
        Object.preventExtensions = function preventExtensions(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.preventExtensions can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // ES5 15.2.3.11
    // http://es5.github.com/#x15.2.3.11
    if (!Object.isSealed) {
        Object.isSealed = function isSealed(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.isSealed can only be called on Objects.');
            }
            return false;
        };
    }

    // ES5 15.2.3.12
    // http://es5.github.com/#x15.2.3.12
    if (!Object.isFrozen) {
        Object.isFrozen = function isFrozen(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.isFrozen can only be called on Objects.');
            }
            return false;
        };
    }

    // ES5 15.2.3.13
    // http://es5.github.com/#x15.2.3.13
    if (!Object.isExtensible) {
        Object.isExtensible = function isExtensible(object) {
            // 1. If Type(O) is not Object throw a TypeError exception.
            if (Object(object) !== object) {
                throw new TypeError('Object.isExtensible can only be called on Objects.');
            }
            // 2. Return the Boolean value of the [[Extensible]] internal property of O.
            var name = '';
            while (owns(object, name)) {
                name += '?';
            }
            object[name] = true;
            var returnValue = owns(object, name);
            delete object[name];
            return returnValue;
        };
    }

}));
/*!
 * jQuery JavaScript Library v1.11.3
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2015-04-28T16:19Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper window is present,
		// execute the factory and get jQuery
		// For environments that do not inherently posses a window with a document
		// (such as Node.js), expose a jQuery-making factory as module.exports
		// This accentuates the need for the creation of a real window
		// e.g. var jQuery = require("jquery")(window);
		// See ticket #14549 for more info
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Can't do this because several apps including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
// Support: Firefox 18+
//

var deletedIds = [];

var slice = deletedIds.slice;

var concat = deletedIds.concat;

var push = deletedIds.push;

var indexOf = deletedIds.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	version = "1.11.3",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1, IE<9
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: deletedIds.sort,
	splice: deletedIds.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var src, copyIsArray, copy, name, options, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		/* jshint eqeqeq: false */
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		// adding 1 corrects loss of precision from parseFloat (#15100)
		return !jQuery.isArray( obj ) && (obj - parseFloat( obj ) + 1) >= 0;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	isPlainObject: function( obj ) {
		var key;

		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!hasOwn.call(obj, "constructor") &&
				!hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Support: IE<9
		// Handle iteration over inherited properties before own properties.
		if ( support.ownLast ) {
			for ( key in obj ) {
				return hasOwn.call( obj, key );
			}
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.
		for ( key in obj ) {}

		return key === undefined || hasOwn.call( obj, key );
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && jQuery.trim( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1, IE<9
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		var len;

		if ( arr ) {
			if ( indexOf ) {
				return indexOf.call( arr, elem, i );
			}

			len = arr.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in arr && arr[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		while ( j < len ) {
			first[ i++ ] = second[ j++ ];
		}

		// Support: IE<9
		// Workaround casting of .length to NaN on otherwise arraylike objects (e.g., NodeLists)
		if ( len !== len ) {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var args, proxy, tmp;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: function() {
		return +( new Date() );
	},

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {

	// Support: iOS 8.2 (not reproducible in simulator)
	// `in` check used to prevent JIT error (gh-2145)
	// hasOwn isn't used here due to false negatives
	// regarding Nodelist length in IE
	var length = "length" in obj && obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v2.2.0-pre
 * http://sizzlejs.com/
 *
 * Copyright 2008, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-12-16
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + 1 * new Date(),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf as it's faster than native
	// http://jsperf.com/thor-indexof-vs-for/5
	indexOf = function( list, elem ) {
		var i = 0,
			len = list.length;
		for ( ; i < len; i++ ) {
			if ( list[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rwhitespace = new RegExp( whitespace + "+", "g" ),
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	},

	// Used for iframes
	// See setDocument()
	// Removing the function wrapper causes a "Permission Denied"
	// error in IE
	unloadHandler = function() {
		setDocument();
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];
	nodeType = context.nodeType;

	if ( typeof selector !== "string" || !selector ||
		nodeType !== 1 && nodeType !== 9 && nodeType !== 11 ) {

		return results;
	}

	if ( !seed && documentIsHTML ) {

		// Try to shortcut find operations when possible (e.g., not under DocumentFragment)
		if ( nodeType !== 11 && (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType !== 1 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== "undefined" && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare, parent,
		doc = node ? node.ownerDocument || node : preferredDoc;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;
	parent = doc.defaultView;

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", unloadHandler, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", unloadHandler );
		}
	}

	/* Support tests
	---------------------------------------------------------------------- */
	documentIsHTML = !isXML( doc );

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties
	// (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Support: IE<9
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName );

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== "undefined" && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( tag );

			// DocumentFragment nodes don't have gEBTN
			} else if ( support.qsa ) {
				return context.querySelectorAll( tag );
			}
		} :

		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				// By happy coincidence, a (broken) gEBTN appears on DocumentFragment nodes too
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			docElem.appendChild( div ).innerHTML = "<a id='" + expando + "'></a>" +
				"<select id='" + expando + "-\f]' msallowcapture=''>" +
				"<option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowcapture^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Support: Chrome<29, Android<4.2+, Safari<7.0+, iOS<7.0+, PhantomJS<1.9.7+
			if ( !div.querySelectorAll( "[id~=" + expando + "-]" ).length ) {
				rbuggyQSA.push("~=");
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}

			// Support: Safari 8+, iOS 8+
			// https://bugs.webkit.org/show_bug.cgi?id=136851
			// In-page `selector#id sibing-combinator selector` fails
			if ( !div.querySelectorAll( "a#" + expando + "+*" ).length ) {
				rbuggyQSA.push(".#.+[+~]");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch (e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== "undefined" && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result.replace( rwhitespace, " " ) + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					// Don't keep the element (issue #299)
					input[0] = null;
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			text = text.replace( runescape, funescape );
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			var ret = ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
			// Avoid hanging onto element (issue #299)
			checkContext = null;
			return ret;
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome 14-35+
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			ret = [],
			self = this,
			len = self.length;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var i,
			targets = jQuery( target, this ),
			len = targets.length;

		return this.filter(function() {
			for ( i = 0; i < len; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.first().prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	do {
		cur = cur[ dir ];
	} while ( cur && cur.nodeType !== 1 );

	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				ret = jQuery.unique( ret );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				ret = ret.reverse();
			}
		}

		return this.pushStack( ret );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Flag to know if list is currently firing
		firing,
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );

					} else if ( !(--remaining) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// if we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( !document.body ) {
			return setTimeout( jQuery.ready );
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * Clean-up method for dom ready events
 */
function detach() {
	if ( document.addEventListener ) {
		document.removeEventListener( "DOMContentLoaded", completed, false );
		window.removeEventListener( "load", completed, false );

	} else {
		document.detachEvent( "onreadystatechange", completed );
		window.detachEvent( "onload", completed );
	}
}

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	// readyState === "complete" is good enough for us to call the dom ready in oldIE
	if ( document.addEventListener || event.type === "load" || document.readyState === "complete" ) {
		detach();
		jQuery.ready();
	}
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// we once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		// Standards-based browsers support DOMContentLoaded
		} else if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );

		// If IE event model is used
		} else {
			// Ensure firing before onload, maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", completed );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", completed );

			// If IE and not a frame
			// continually check to see if the document is ready
			var top = false;

			try {
				top = window.frameElement == null && document.documentElement;
			} catch(e) {}

			if ( top && top.doScroll ) {
				(function doScrollCheck() {
					if ( !jQuery.isReady ) {

						try {
							// Use the trick by Diego Perini
							// http://javascript.nwbox.com/IEContentLoaded/
							top.doScroll("left");
						} catch(e) {
							return setTimeout( doScrollCheck, 50 );
						}

						// detach all dom ready events
						detach();

						// and execute any waiting functions
						jQuery.ready();
					}
				})();
			}
		}
	}
	return readyList.promise( obj );
};


var strundefined = typeof undefined;



// Support: IE<9
// Iteration over object's inherited properties before its own
var i;
for ( i in jQuery( support ) ) {
	break;
}
support.ownLast = i !== "0";

// Note: most support tests are defined in their respective modules.
// false until the test is run
support.inlineBlockNeedsLayout = false;

// Execute ASAP in case we need to set body.style.zoom
jQuery(function() {
	// Minified: var a,b,c,d
	var val, div, body, container;

	body = document.getElementsByTagName( "body" )[ 0 ];
	if ( !body || !body.style ) {
		// Return for frameset docs that don't have a body
		return;
	}

	// Setup
	div = document.createElement( "div" );
	container = document.createElement( "div" );
	container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
	body.appendChild( container ).appendChild( div );

	if ( typeof div.style.zoom !== strundefined ) {
		// Support: IE<8
		// Check if natively block-level elements act like inline-block
		// elements when setting their display to 'inline' and giving
		// them layout
		div.style.cssText = "display:inline;margin:0;border:0;padding:1px;width:1px;zoom:1";

		support.inlineBlockNeedsLayout = val = div.offsetWidth === 3;
		if ( val ) {
			// Prevent IE 6 from affecting layout for positioned elements #11048
			// Prevent IE from shrinking the body in IE 7 mode #12869
			// Support: IE<8
			body.style.zoom = 1;
		}
	}

	body.removeChild( container );
});




(function() {
	var div = document.createElement( "div" );

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( elem ) {
	var noData = jQuery.noData[ (elem.nodeName + " ").toLowerCase() ],
		nodeType = +elem.nodeType || 1;

	// Do not set data on non-element DOM nodes because it will not be cleared (#8335).
	return nodeType !== 1 && nodeType !== 9 ?
		false :

		// Nodes accept data unless otherwise specified; rejection can be conditional
		!noData || noData !== true && elem.getAttribute("classid") === noData;
};


var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	var name;
	for ( name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}

function internalData( elem, name, data, pvt /* Internal Use Only */ ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var ret, thisCache,
		internalKey = jQuery.expando,

		// We have to handle DOM nodes and JS objects differently because IE6-7
		// can't GC object references properly across the DOM-JS boundary
		isNode = elem.nodeType,

		// Only DOM nodes need the global jQuery cache; JS object data is
		// attached directly to the object so GC can occur automatically
		cache = isNode ? jQuery.cache : elem,

		// Only defining an ID for JS objects if its cache already exists allows
		// the code to shortcut on the same path as a DOM node with no cache
		id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey;

	// Avoid doing any more work than we need to when trying to get data on an
	// object that has no data at all
	if ( (!id || !cache[id] || (!pvt && !cache[id].data)) && data === undefined && typeof name === "string" ) {
		return;
	}

	if ( !id ) {
		// Only DOM nodes need a new unique ID for each element since their data
		// ends up in the global cache
		if ( isNode ) {
			id = elem[ internalKey ] = deletedIds.pop() || jQuery.guid++;
		} else {
			id = internalKey;
		}
	}

	if ( !cache[ id ] ) {
		// Avoid exposing jQuery metadata on plain JS objects when the object
		// is serialized using JSON.stringify
		cache[ id ] = isNode ? {} : { toJSON: jQuery.noop };
	}

	// An object can be passed to jQuery.data instead of a key/value pair; this gets
	// shallow copied over onto the existing cache
	if ( typeof name === "object" || typeof name === "function" ) {
		if ( pvt ) {
			cache[ id ] = jQuery.extend( cache[ id ], name );
		} else {
			cache[ id ].data = jQuery.extend( cache[ id ].data, name );
		}
	}

	thisCache = cache[ id ];

	// jQuery data() is stored in a separate object inside the object's internal data
	// cache in order to avoid key collisions between internal data and user-defined
	// data.
	if ( !pvt ) {
		if ( !thisCache.data ) {
			thisCache.data = {};
		}

		thisCache = thisCache.data;
	}

	if ( data !== undefined ) {
		thisCache[ jQuery.camelCase( name ) ] = data;
	}

	// Check for both converted-to-camel and non-converted data property names
	// If a data property was specified
	if ( typeof name === "string" ) {

		// First Try to find as-is property data
		ret = thisCache[ name ];

		// Test for null|undefined property data
		if ( ret == null ) {

			// Try to find the camelCased property
			ret = thisCache[ jQuery.camelCase( name ) ];
		}
	} else {
		ret = thisCache;
	}

	return ret;
}

function internalRemoveData( elem, name, pvt ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var thisCache, i,
		isNode = elem.nodeType,

		// See jQuery.data for more information
		cache = isNode ? jQuery.cache : elem,
		id = isNode ? elem[ jQuery.expando ] : jQuery.expando;

	// If there is already no cache entry for this object, there is no
	// purpose in continuing
	if ( !cache[ id ] ) {
		return;
	}

	if ( name ) {

		thisCache = pvt ? cache[ id ] : cache[ id ].data;

		if ( thisCache ) {

			// Support array or space separated string names for data keys
			if ( !jQuery.isArray( name ) ) {

				// try the string as a key before any manipulation
				if ( name in thisCache ) {
					name = [ name ];
				} else {

					// split the camel cased version by spaces unless a key with the spaces exists
					name = jQuery.camelCase( name );
					if ( name in thisCache ) {
						name = [ name ];
					} else {
						name = name.split(" ");
					}
				}
			} else {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = name.concat( jQuery.map( name, jQuery.camelCase ) );
			}

			i = name.length;
			while ( i-- ) {
				delete thisCache[ name[i] ];
			}

			// If there is no data left in the cache, we want to continue
			// and let the cache object itself get destroyed
			if ( pvt ? !isEmptyDataObject(thisCache) : !jQuery.isEmptyObject(thisCache) ) {
				return;
			}
		}
	}

	// See jQuery.data for more information
	if ( !pvt ) {
		delete cache[ id ].data;

		// Don't destroy the parent cache unless the internal data object
		// had been the only thing left in it
		if ( !isEmptyDataObject( cache[ id ] ) ) {
			return;
		}
	}

	// Destroy the cache
	if ( isNode ) {
		jQuery.cleanData( [ elem ], true );

	// Use delete when supported for expandos or `cache` is not a window per isWindow (#10080)
	/* jshint eqeqeq: false */
	} else if ( support.deleteExpando || cache != cache.window ) {
		/* jshint eqeqeq: true */
		delete cache[ id ];

	// When all else fails, null
	} else {
		cache[ id ] = null;
	}
}

jQuery.extend({
	cache: {},

	// The following elements (space-suffixed to avoid Object.prototype collisions)
	// throw uncatchable exceptions if you attempt to set expando properties
	noData: {
		"applet ": true,
		"embed ": true,
		// ...but Flash objects (which have this classid) *can* handle expandos
		"object ": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data ) {
		return internalData( elem, name, data );
	},

	removeData: function( elem, name ) {
		return internalRemoveData( elem, name );
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return internalData( elem, name, data, true );
	},

	_removeData: function( elem, name ) {
		return internalRemoveData( elem, name, true );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[0],
			attrs = elem && elem.attributes;

		// Special expections of .data basically thwart jQuery.access,
		// so implement the relevant behavior ourselves

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		return arguments.length > 1 ?

			// Sets one value
			this.each(function() {
				jQuery.data( this, key, value );
			}) :

			// Gets one value
			// Try to fetch any internally stored data first
			elem ? dataAttr( elem, key, jQuery.data( elem, key ) ) : undefined;
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray(data) ) {
					queue = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// not intended for public consumption - generates a queueHooks object, or returns the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return jQuery._data( elem, key ) || jQuery._data( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				jQuery._removeData( elem, type + "queue" );
				jQuery._removeData( elem, key );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = jQuery._data( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};



// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		length = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < length; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			length ? fn( elems[0], key ) : emptyGet;
};
var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	// Minified: var a,b,c
	var input = document.createElement( "input" ),
		div = document.createElement( "div" ),
		fragment = document.createDocumentFragment();

	// Setup
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";

	// IE strips leading whitespace when .innerHTML is used
	support.leadingWhitespace = div.firstChild.nodeType === 3;

	// Make sure that tbody elements aren't automatically inserted
	// IE will insert them into empty tables
	support.tbody = !div.getElementsByTagName( "tbody" ).length;

	// Make sure that link elements get serialized correctly by innerHTML
	// This requires a wrapper element in IE
	support.htmlSerialize = !!div.getElementsByTagName( "link" ).length;

	// Makes sure cloning an html5 element does not cause problems
	// Where outerHTML is undefined, this still works
	support.html5Clone =
		document.createElement( "nav" ).cloneNode( true ).outerHTML !== "<:nav></:nav>";

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	input.type = "checkbox";
	input.checked = true;
	fragment.appendChild( input );
	support.appendChecked = input.checked;

	// Make sure textarea (and checkbox) defaultValue is properly cloned
	// Support: IE6-IE11+
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;

	// #11217 - WebKit loses check when the name is after the checked attribute
	fragment.appendChild( div );
	div.innerHTML = "<input type='radio' checked='checked' name='t'/>";

	// Support: Safari 5.1, iOS 5.1, Android 4.x, Android 2.3
	// old WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<9
	// Opera does not clone events (and typeof div.attachEvent === undefined).
	// IE9-10 clones events bound via attachEvent, but they don't trigger with .click()
	support.noCloneEvent = true;
	if ( div.attachEvent ) {
		div.attachEvent( "onclick", function() {
			support.noCloneEvent = false;
		});

		div.cloneNode( true ).click();
	}

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}
})();


(function() {
	var i, eventName,
		div = document.createElement( "div" );

	// Support: IE<9 (lack submit/change bubble), Firefox 23+ (lack focusin event)
	for ( i in { submit: true, change: true, focusin: true }) {
		eventName = "on" + i;

		if ( !(support[ i + "Bubbles" ] = eventName in window) ) {
			// Beware of CSP restrictions (https://developer.mozilla.org/en/Security/CSP)
			div.setAttribute( eventName, "t" );
			support[ i + "Bubbles" ] = div.attributes[ eventName ].expando === false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


var rformElems = /^(?:input|select|textarea)$/i,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {
		var tmp, events, t, handleObjIn,
			special, eventHandle, handleObj,
			handlers, type, namespaces, origType,
			elemData = jQuery._data( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {
		var j, handleObj, tmp,
			origCount, t, events,
			special, handlers, type,
			namespaces, origType,
			elemData = jQuery.hasData( elem ) && jQuery._data( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery._removeData( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		var handle, ontype, cur,
			bubbleType, special, tmp, i,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && elem[ type ] && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					try {
						elem[ type ]();
					} catch ( e ) {
						// IE<9 dies on focus/blur to hidden element (#1486,#12518)
						// only reproducible on winXP IE8 native, not IE9 in IE8 mode
					}
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, ret, handleObj, matched, j,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( jQuery._data( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var sel, handleObj, matches, i,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			/* jshint eqeqeq: false */
			for ( ; cur != this; cur = cur.parentNode || this ) {
				/* jshint eqeqeq: true */

				// Don't check non-elements (#13208)
				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.nodeType === 1 && (cur.disabled !== true || event.type !== "click") ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: IE<9
		// Fix target property (#1925)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Support: Chrome 23+, Safari?
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// Support: IE<9
		// For mouse/key events, metaKey==false if it's undefined (#3368, #11328)
		event.metaKey = !!event.metaKey;

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var body, eventDoc, doc,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					try {
						this.focus();
						return false;
					} catch ( e ) {
						// Support: IE<9
						// If we error on focus to hidden element (#1486, #12518),
						// let .trigger() run the handlers
					}
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( jQuery.nodeName( this, "input" ) && this.type === "checkbox" && this.click ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		var name = "on" + type;

		if ( elem.detachEvent ) {

			// #8545, #7054, preventing memory leaks for custom events in IE6-8
			// detachEvent needed property on element, by name of that event, to properly expose it to GC
			if ( typeof elem[ name ] === strundefined ) {
				elem[ name ] = null;
			}

			elem.detachEvent( name, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: IE < 9, Android < 4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;
		if ( !e ) {
			return;
		}

		// If preventDefault exists, run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// Support: IE
		// Otherwise set the returnValue property of the original event to false
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;
		if ( !e ) {
			return;
		}
		// If stopPropagation exists, run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}

		// Support: IE
		// Set the cancelBubble property of the original event to true
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !jQuery._data( form, "submitBubbles" ) ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					jQuery._data( form, "submitBubbles", true );
				}
			});
			// return undefined since we don't need an event listener
		},

		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
						}
						// Allow triggered, simulated change events (#11500)
						jQuery.event.simulate( "change", this, event, true );
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !jQuery._data( elem, "changeBubbles" ) ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					jQuery._data( elem, "changeBubbles", true );
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return !rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				jQuery._data( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					jQuery._removeData( doc, fix );
				} else {
					jQuery._data( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var type, origFn;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
		safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:null|\d+)"/g,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		area: [ 1, "<map>", "</map>" ],
		param: [ 1, "<object>", "</object>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		// IE6-8 can't serialize link, script, style, or any html5 (NoScope) tags,
		// unless wrapped in a div with non-breaking characters in front of it.
		_default: support.htmlSerialize ? [ 0, "", "" ] : [ 1, "X<div>", "</div>"  ]
	},
	safeFragment = createSafeFragment( document ),
	fragmentDiv = safeFragment.appendChild( document.createElement("div") );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

function getAll( context, tag ) {
	var elems, elem,
		i = 0,
		found = typeof context.getElementsByTagName !== strundefined ? context.getElementsByTagName( tag || "*" ) :
			typeof context.querySelectorAll !== strundefined ? context.querySelectorAll( tag || "*" ) :
			undefined;

	if ( !found ) {
		for ( found = [], elems = context.childNodes || context; (elem = elems[i]) != null; i++ ) {
			if ( !tag || jQuery.nodeName( elem, tag ) ) {
				found.push( elem );
			} else {
				jQuery.merge( found, getAll( elem, tag ) );
			}
		}
	}

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], found ) :
		found;
}

// Used in buildFragment, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( rcheckableType.test( elem.type ) ) {
		elem.defaultChecked = elem.checked;
	}
}

// Support: IE<8
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (jQuery.find.attr( elem, "type" ) !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );
	if ( match ) {
		elem.type = match[1];
	} else {
		elem.removeAttribute("type");
	}
	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var elem,
		i = 0;
	for ( ; (elem = elems[i]) != null; i++ ) {
		jQuery._data( elem, "globalEval", !refElements || jQuery._data( refElements[i], "globalEval" ) );
	}
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function fixCloneNodeIssues( src, dest ) {
	var nodeName, e, data;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 copies events bound via attachEvent when using cloneNode.
	if ( !support.noCloneEvent && dest[ jQuery.expando ] ) {
		data = jQuery._data( dest );

		for ( e in data.events ) {
			jQuery.removeEvent( dest, e, data.handle );
		}

		// Event data gets referenced instead of copied if the expando gets copied too
		dest.removeAttribute( jQuery.expando );
	}

	// IE blanks contents when cloning scripts, and tries to evaluate newly-set text
	if ( nodeName === "script" && dest.text !== src.text ) {
		disableScript( dest ).text = src.text;
		restoreScript( dest );

	// IE6-10 improperly clones children of object elements using classid.
	// IE10 throws NoModificationAllowedError if parent is null, #12132.
	} else if ( nodeName === "object" ) {
		if ( dest.parentNode ) {
			dest.outerHTML = src.outerHTML;
		}

		// This path appears unavoidable for IE9. When cloning an object
		// element in IE9, the outerHTML strategy above is not sufficient.
		// If the src has innerHTML and the destination does not,
		// copy the src.innerHTML into the dest.innerHTML. #10324
		if ( support.html5Clone && ( src.innerHTML && !jQuery.trim(dest.innerHTML) ) ) {
			dest.innerHTML = src.innerHTML;
		}

	} else if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set

		dest.defaultChecked = dest.checked = src.checked;

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.defaultSelected = dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var destElements, node, clone, i, srcElements,
			inPage = jQuery.contains( elem.ownerDocument, elem );

		if ( support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ) {
			clone = elem.cloneNode( true );

		// IE<=8 does not properly clone detached, unknown element nodes
		} else {
			fragmentDiv.innerHTML = elem.outerHTML;
			fragmentDiv.removeChild( clone = fragmentDiv.firstChild );
		}

		if ( (!support.noCloneEvent || !support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			// Fix all IE cloning issues
			for ( i = 0; (node = srcElements[i]) != null; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					fixCloneNodeIssues( node, destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0; (node = srcElements[i]) != null; i++ ) {
					cloneCopyEvent( node, destElements[i] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		destElements = srcElements = node = null;

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var j, elem, contains,
			tmp, tag, tbody, wrap,
			l = elems.length,

			// Ensure a safe fragment
			safe = createSafeFragment( context ),

			nodes = [],
			i = 0;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || safe.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = (rtagName.exec( elem ) || [ "", "" ])[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;

					tmp.innerHTML = wrap[1] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[2];

					// Descend through wrappers to the right content
					j = wrap[0];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Manually add leading whitespace removed by IE
					if ( !support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						nodes.push( context.createTextNode( rleadingWhitespace.exec( elem )[0] ) );
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						elem = tag === "table" && !rtbody.test( elem ) ?
							tmp.firstChild :

							// String was a bare <thead> or <tfoot>
							wrap[1] === "<table>" && !rtbody.test( elem ) ?
								tmp :
								0;

						j = elem && elem.childNodes.length;
						while ( j-- ) {
							if ( jQuery.nodeName( (tbody = elem.childNodes[j]), "tbody" ) && !tbody.childNodes.length ) {
								elem.removeChild( tbody );
							}
						}
					}

					jQuery.merge( nodes, tmp.childNodes );

					// Fix #12392 for WebKit and IE > 9
					tmp.textContent = "";

					// Fix #12392 for oldIE
					while ( tmp.firstChild ) {
						tmp.removeChild( tmp.firstChild );
					}

					// Remember the top-level container for proper cleanup
					tmp = safe.lastChild;
				}
			}
		}

		// Fix #11356: Clear elements from fragment
		if ( tmp ) {
			safe.removeChild( tmp );
		}

		// Reset defaultChecked for any radios and checkboxes
		// about to be appended to the DOM in IE 6/7 (#8060)
		if ( !support.appendChecked ) {
			jQuery.grep( getAll( nodes, "input" ), fixDefaultChecked );
		}

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( safe.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		tmp = null;

		return safe;
	},

	cleanData: function( elems, /* internal */ acceptData ) {
		var elem, type, id, data,
			i = 0,
			internalKey = jQuery.expando,
			cache = jQuery.cache,
			deleteExpando = support.deleteExpando,
			special = jQuery.event.special;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( acceptData || jQuery.acceptData( elem ) ) {

				id = elem[ internalKey ];
				data = id && cache[ id ];

				if ( data ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}

					// Remove cache only if it was not already removed by jQuery.event.remove
					if ( cache[ id ] ) {

						delete cache[ id ];

						// IE does not allow us to delete expando properties from nodes,
						// nor does it have a removeAttribute function on Document nodes;
						// we must handle all of these cases
						if ( deleteExpando ) {
							delete elem[ internalKey ];

						} else if ( typeof elem.removeAttribute !== strundefined ) {
							elem.removeAttribute( internalKey );

						} else {
							elem[ internalKey ] = null;
						}

						deletedIds.push( id );
					}
				}
			}
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {

			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem, false ) );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}

			// If this is a select, ensure that it displays empty (#12336)
			// Support: IE<9
			if ( elem.options && jQuery.nodeName( elem, "select" ) ) {
				elem.options.length = 0;
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					undefined;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( support.htmlSerialize || !rnoshimcache.test( value )  ) &&
				( support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ (rtagName.exec( value ) || [ "", "" ])[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var first, node, hasScripts,
			scripts, doc, fragment,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[0],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[0] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[i], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!jQuery._data( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( ( node.text || node.textContent || node.innerHTML || "" ).replace( rcleanScript, "" ) );
							}
						}
					}
				}

				// Fix #11809: Avoid leaking memory
				fragment = first = null;
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			i = 0,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone(true);
			jQuery( insert[i] )[ original ]( elems );

			// Modern browsers can apply jQuery collections as arrays, but oldIE needs a .get()
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optmization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = ( iframe[ 0 ].contentWindow || iframe[ 0 ].contentDocument ).document;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}


(function() {
	var shrinkWrapBlocksVal;

	support.shrinkWrapBlocks = function() {
		if ( shrinkWrapBlocksVal != null ) {
			return shrinkWrapBlocksVal;
		}

		// Will be changed later if needed.
		shrinkWrapBlocksVal = false;

		// Minified: var b,c,d
		var div, body, container;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		// Support: IE6
		// Check if elements with layout shrink-wrap their children
		if ( typeof div.style.zoom !== strundefined ) {
			// Reset CSS: box-sizing; display; margin; border
			div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;" +
				"padding:1px;width:1px;zoom:1";
			div.appendChild( document.createElement( "div" ) ).style.width = "5px";
			shrinkWrapBlocksVal = div.offsetWidth !== 3;
		}

		body.removeChild( container );

		return shrinkWrapBlocksVal;
	};

})();
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );



var getStyles, curCSS,
	rposition = /^(top|right|bottom|left)$/;

if ( window.getComputedStyle ) {
	getStyles = function( elem ) {
		// Support: IE<=11+, Firefox<=30+ (#15098, #14150)
		// IE throws on elements created in popups
		// FF meanwhile throws on frame elements through "defaultView.getComputedStyle"
		if ( elem.ownerDocument.defaultView.opener ) {
			return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
		}

		return window.getComputedStyle( elem, null );
	};

	curCSS = function( elem, name, computed ) {
		var width, minWidth, maxWidth, ret,
			style = elem.style;

		computed = computed || getStyles( elem );

		// getPropertyValue is only needed for .css('filter') in IE9, see #12537
		ret = computed ? computed.getPropertyValue( name ) || computed[ name ] : undefined;

		if ( computed ) {

			if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
				ret = jQuery.style( elem, name );
			}

			// A tribute to the "awesome hack by Dean Edwards"
			// Chrome < 17 and Safari 5.0 uses "computed value" instead of "used value" for margin-right
			// Safari 5.1.7 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
			// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
			if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

				// Remember the original values
				width = style.width;
				minWidth = style.minWidth;
				maxWidth = style.maxWidth;

				// Put in the new values to get a computed value out
				style.minWidth = style.maxWidth = style.width = ret;
				ret = computed.width;

				// Revert the changed values
				style.width = width;
				style.minWidth = minWidth;
				style.maxWidth = maxWidth;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "";
	};
} else if ( document.documentElement.currentStyle ) {
	getStyles = function( elem ) {
		return elem.currentStyle;
	};

	curCSS = function( elem, name, computed ) {
		var left, rs, rsLeft, ret,
			style = elem.style;

		computed = computed || getStyles( elem );
		ret = computed ? computed[ name ] : undefined;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && style[ name ] ) {
			ret = style[ name ];
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		// but not position css attributes, as those are proportional to the parent element instead
		// and we can't measure the parent instead because it might trigger a "stacking dolls" problem
		if ( rnumnonpx.test( ret ) && !rposition.test( name ) ) {

			// Remember the original values
			left = style.left;
			rs = elem.runtimeStyle;
			rsLeft = rs && rs.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				rs.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				rs.left = rsLeft;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "" || "auto";
	};
}




function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			var condition = conditionFn();

			if ( condition == null ) {
				// The test was not ready at this point; screw the hook this time
				// but check again when needed next time.
				return;
			}

			if ( condition ) {
				// Hook not needed (or it's not possible to use it due to missing dependency),
				// remove it.
				// Since there are no other hooks for marginRight, remove the whole object.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.

			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	// Minified: var b,c,d,e,f,g, h,i
	var div, style, a, pixelPositionVal, boxSizingReliableVal,
		reliableHiddenOffsetsVal, reliableMarginRightVal;

	// Setup
	div = document.createElement( "div" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName( "a" )[ 0 ];
	style = a && a.style;

	// Finish early in limited (non-browser) environments
	if ( !style ) {
		return;
	}

	style.cssText = "float:left;opacity:.5";

	// Support: IE<9
	// Make sure that element opacity exists (as opposed to filter)
	support.opacity = style.opacity === "0.5";

	// Verify style float existence
	// (IE uses styleFloat instead of cssFloat)
	support.cssFloat = !!style.cssFloat;

	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	// Support: Firefox<29, Android 2.3
	// Vendor-prefix box-sizing
	support.boxSizing = style.boxSizing === "" || style.MozBoxSizing === "" ||
		style.WebkitBoxSizing === "";

	jQuery.extend(support, {
		reliableHiddenOffsets: function() {
			if ( reliableHiddenOffsetsVal == null ) {
				computeStyleTests();
			}
			return reliableHiddenOffsetsVal;
		},

		boxSizingReliable: function() {
			if ( boxSizingReliableVal == null ) {
				computeStyleTests();
			}
			return boxSizingReliableVal;
		},

		pixelPosition: function() {
			if ( pixelPositionVal == null ) {
				computeStyleTests();
			}
			return pixelPositionVal;
		},

		// Support: Android 2.3
		reliableMarginRight: function() {
			if ( reliableMarginRightVal == null ) {
				computeStyleTests();
			}
			return reliableMarginRightVal;
		}
	});

	function computeStyleTests() {
		// Minified: var b,c,d,j
		var div, body, container, contents;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";

		// Support: IE<9
		// Assume reasonable values in the absence of getComputedStyle
		pixelPositionVal = boxSizingReliableVal = false;
		reliableMarginRightVal = true;

		// Check for getComputedStyle so that this code is not run in IE<9.
		if ( window.getComputedStyle ) {
			pixelPositionVal = ( window.getComputedStyle( div, null ) || {} ).top !== "1%";
			boxSizingReliableVal =
				( window.getComputedStyle( div, null ) || { width: "4px" } ).width === "4px";

			// Support: Android 2.3
			// Div with explicit width and no margin-right incorrectly
			// gets computed margin-right based on width of container (#3333)
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			contents = div.appendChild( document.createElement( "div" ) );

			// Reset CSS: box-sizing; display; margin; border; padding
			contents.style.cssText = div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
			contents.style.marginRight = contents.style.width = "0";
			div.style.width = "1px";

			reliableMarginRightVal =
				!parseFloat( ( window.getComputedStyle( contents, null ) || {} ).marginRight );

			div.removeChild( contents );
		}

		// Support: IE8
		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		div.innerHTML = "<table><tr><td></td><td>t</td></tr></table>";
		contents = div.getElementsByTagName( "td" );
		contents[ 0 ].style.cssText = "margin:0;border:0;padding:0;display:none";
		reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		if ( reliableHiddenOffsetsVal ) {
			contents[ 0 ].style.display = "";
			contents[ 1 ].style.display = "none";
			reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		}

		body.removeChild( container );
	}

})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
		ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity\s*=\s*([^)]*)/,

	// swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// see here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];


// return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// check for vendor prefixed names
	var capName = name.charAt(0).toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = jQuery._data( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = jQuery._data( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display && display !== "none" || !hidden ) {
				jQuery._data( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// at this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// at this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// at this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// we need the check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox && ( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set. See: #7116
			if ( value == null || value !== value ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Fixes #8908, it can be done more correctly by specifing setters in cssHooks,
			// but it would mean to define eight (for every problematic property) identical functions
			if ( !support.clearCloneStyle && value === "" && name.indexOf("background") === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {

				// Support: IE
				// Swallow errors from 'invalid' CSS values (#5509)
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var num, val, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		//convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Return, converting to number if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				// certain elements can have dimension info if we invisibly show them
				// however, it must have a current display style that would benefit from this
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

if ( !support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( 0.01 * parseFloat( RegExp.$1 ) ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			// if value === "", then remove inline opacity #12685
			if ( ( value >= 1 || value === "" ) &&
					jQuery.trim( filter.replace( ralpha, "" ) ) === "" &&
					style.removeAttribute ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there is no filter style applied in a css rule or unset inline opacity, we are done
				if ( value === "" || currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			// Work around by temporarily setting element display to inline-block
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails
			// so, simple values such as "10px" are parsed to Float.
			// complex values such as "rotate(1rad)" are returned as is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// use step hook for back compat - use cssHook if its there - use .style if its
			// available and use plain properties where available
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE <=9
// Panic based approach to setting things on disconnected nodes

Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*
					// Use a string for doubling factor so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur()
				// And breaking the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		attrs = { height: type },
		i = 0;

	// if we include width, step value is 1 to do all cssExpand values,
	// if we don't include width, step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// we're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = jQuery._data( elem, "fxshow" );

	// handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// doing this makes sure that the complete handler will be called
			// before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE does not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			jQuery._data( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {

			// inline-level elements accept inline-block;
			// block-level elements need to be inline with layout
			if ( !support.inlineBlockNeedsLayout || defaultDisplay( elem.nodeName ) === "inline" ) {
				style.display = "inline-block";
			} else {
				style.zoom = 1;
			}
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		if ( !support.shrinkWrapBlocks() ) {
			anim.always(function() {
				style.overflow = opts.overflow[ 0 ];
				style.overflowX = opts.overflow[ 1 ];
				style.overflowY = opts.overflow[ 2 ];
			});
		}
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = jQuery._data( elem, "fxshow", {} );
		}

		// store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;
			jQuery._removeData( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// not quite $.extend, this wont overwrite keys already present.
			// also - reusing 'index' from above because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// archaic crash bug won't allow us to use 1 - ( 0.5 || 0 ) (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// if we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// resolve when we played the last frame
				// otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {
	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || jQuery._data( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = jQuery._data( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = jQuery._data( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// enable finishing flag on private data
			data.finish = true;

			// empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		timers = jQuery.timers,
		i = 0;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	// Minified: var a,b,c,d,e
	var input, div, select, a, opt;

	// Setup
	div = document.createElement( "div" );
	div.setAttribute( "className", "t" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName("a")[ 0 ];

	// First batch of tests.
	select = document.createElement("select");
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName("input")[ 0 ];

	a.style.cssText = "top:1px";

	// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
	support.getSetAttribute = div.className !== "t";

	// Get the style information from getAttribute
	// (IE uses .cssText instead)
	support.style = /top/.test( a.getAttribute("style") );

	// Make sure that URLs aren't manipulated
	// (IE normalizes it by default)
	support.hrefNormalized = a.getAttribute("href") === "/a";

	// Check the default checkbox/radio value ("" on WebKit; "on" elsewhere)
	support.checkOn = !!input.value;

	// Make sure that a selected-by-default option has a working selected property.
	// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
	support.optSelected = opt.selected;

	// Tests for enctype support on a form (#6743)
	support.enctype = !!document.createElement("form").enctype;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE8 only
	// Check if we can trust getAttribute("value")
	input = document.createElement( "input" );
	input.setAttribute( "value", "" );
	support.input = input.getAttribute( "value" ) === "";

	// Check if an input maintains its value after becoming a radio
	input.value = "t";
	input.setAttribute( "type", "radio" );
	support.radioValue = input.value === "t";
})();


var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// oldIE doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];

					if ( jQuery.inArray( jQuery.valHooks.option.get( option ), values ) >= 0 ) {

						// Support: IE6
						// When new option element is added to select box we need to
						// force reflow of newly added node in order to workaround delay
						// of initialization properties
						try {
							option.selected = optionSet = true;

						} catch ( _ ) {

							// Will be executed only in IE6
							option.scrollHeight;
						}

					} else {
						option.selected = false;
					}
				}

				// Force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}

				return options;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			// Support: Webkit
			// "" is returned instead of "on" if a value isn't specified
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle,
	ruseDefault = /^(?:checked|selected)$/i,
	getSetAttribute = support.getSetAttribute,
	getSetInput = support.input;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
						elem[ propName ] = false;
					// Support: IE<9
					// Also clear defaultChecked/defaultSelected (if appropriate)
					} else {
						elem[ jQuery.camelCase( "default-" + name ) ] =
							elem[ propName ] = false;
					}

				// See #9699 for explanation of this approach (setting first, then removal)
				} else {
					jQuery.attr( elem, name, "" );
				}

				elem.removeAttribute( getSetAttribute ? name : propName );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to default in case type is set after value during creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hook for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
			// IE<8 needs the *property* name
			elem.setAttribute( !getSetAttribute && jQuery.propFix[ name ] || name, name );

		// Use defaultChecked and defaultSelected for oldIE
		} else {
			elem[ jQuery.camelCase( "default-" + name ) ] = elem[ name ] = true;
		}

		return name;
	}
};

// Retrieve booleans specially
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {

	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = getSetInput && getSetAttribute || !ruseDefault.test( name ) ?
		function( elem, name, isXML ) {
			var ret, handle;
			if ( !isXML ) {
				// Avoid an infinite loop by temporarily removing this function from the getter
				handle = attrHandle[ name ];
				attrHandle[ name ] = ret;
				ret = getter( elem, name, isXML ) != null ?
					name.toLowerCase() :
					null;
				attrHandle[ name ] = handle;
			}
			return ret;
		} :
		function( elem, name, isXML ) {
			if ( !isXML ) {
				return elem[ jQuery.camelCase( "default-" + name ) ] ?
					name.toLowerCase() :
					null;
			}
		};
});

// fix oldIE attroperties
if ( !getSetInput || !getSetAttribute ) {
	jQuery.attrHooks.value = {
		set: function( elem, value, name ) {
			if ( jQuery.nodeName( elem, "input" ) ) {
				// Does not return so that setAttribute is also used
				elem.defaultValue = value;
			} else {
				// Use nodeHook if defined (#1954); otherwise setAttribute is fine
				return nodeHook && nodeHook.set( elem, value, name );
			}
		}
	};
}

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = {
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				elem.setAttributeNode(
					(ret = elem.ownerDocument.createAttribute( name ))
				);
			}

			ret.value = value += "";

			// Break association with cloned elements by also using setAttribute (#9646)
			if ( name === "value" || value === elem.getAttribute( name ) ) {
				return value;
			}
		}
	};

	// Some attributes are constructed with empty-string values when not defined
	attrHandle.id = attrHandle.name = attrHandle.coords =
		function( elem, name, isXML ) {
			var ret;
			if ( !isXML ) {
				return (ret = elem.getAttributeNode( name )) && ret.value !== "" ?
					ret.value :
					null;
			}
		};

	// Fixing value retrieval on a button requires this module
	jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret = elem.getAttributeNode( name );
			if ( ret && ret.specified ) {
				return ret.value;
			}
		},
		set: nodeHook.set
	};

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		set: function( elem, value, name ) {
			nodeHook.set( elem, value === "" ? false : value, name );
		}
	};

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		};
	});
}

if ( !support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Note: IE uppercases css property names, but if we were to .toLowerCase()
			// .cssText, that would destroy case senstitivity in URL's, like in "background"
			return elem.style.cssText || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = value + "" );
		}
	};
}




var rfocusable = /^(?:input|select|textarea|button|object)$/i,
	rclickable = /^(?:a|area)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				// Use proper attribute retrieval(#12072)
				var tabindex = jQuery.find.attr( elem, "tabindex" );

				return tabindex ?
					parseInt( tabindex, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						-1;
			}
		}
	}
});

// Some attributes require a special call on IE
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !support.hrefNormalized ) {
	// href/src property should get the full normalized URL (#10299/#12915)
	jQuery.each([ "href", "src" ], function( i, name ) {
		jQuery.propHooks[ name ] = {
			get: function( elem ) {
				return elem.getAttribute( name, 4 );
			}
		};
	});
}

// Support: Safari, IE9+
// mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});

// IE6/7 call enctype encoding
if ( !support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = arguments.length === 0 || typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed "false",
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



var rvalidtokens = /(,)|(\[|{)|(}|])|"(?:[^"\\\r\n]|\\["\\\/bfnrt]|\\u[\da-fA-F]{4})*"\s*:?|true|false|null|-?(?!0\d)\d+(?:\.\d+|)(?:[eE][+-]?\d+|)/g;

jQuery.parseJSON = function( data ) {
	// Attempt to parse using the native JSON parser first
	if ( window.JSON && window.JSON.parse ) {
		// Support: Android 2.3
		// Workaround failure to string-cast null input
		return window.JSON.parse( data + "" );
	}

	var requireNonComma,
		depth = null,
		str = jQuery.trim( data + "" );

	// Guard against invalid (and possibly dangerous) input by ensuring that nothing remains
	// after removing valid tokens
	return str && !jQuery.trim( str.replace( rvalidtokens, function( token, comma, open, close ) {

		// Force termination if we see a misplaced comma
		if ( requireNonComma && comma ) {
			depth = 0;
		}

		// Perform no more replacements after returning to outermost depth
		if ( depth === 0 ) {
			return token;
		}

		// Commas must not follow "[", "{", or ","
		requireNonComma = open || comma;

		// Determine new depth
		// array/object open ("[" or "{"): depth += true - false (increment)
		// array/object close ("]" or "}"): depth += false - true (decrement)
		// other cases ("," or primitive): depth += true - true (numeric cast)
		depth += !close - !open;

		// Remove this token
		return "";
	}) ) ?
		( Function( "return " + str ) )() :
		jQuery.error( "Invalid JSON: " + data );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	try {
		if ( window.DOMParser ) { // Standard
			tmp = new DOMParser();
			xml = tmp.parseFromString( data, "text/xml" );
		} else { // IE
			xml = new ActiveXObject( "Microsoft.XMLDOM" );
			xml.async = "false";
			xml.loadXML( data );
		}
	} catch( e ) {
		xml = undefined;
	}
	if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	// Document location
	ajaxLocParts,
	ajaxLocation,

	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat("*");

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType.charAt( 0 ) === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var deep, key,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {
	var firstDataType, ct, finalDataType, type,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

			// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Cross-domain detection vars
			parts,
			// Loop variable
			i,
			// URL without anti-cache param
			cacheURL,
			// Response headers as string
			responseHeadersString,
			// timeout handle
			timeoutTimer,

			// To know if global events are to be dispatched
			fireGlobals,

			transport,
			// Response headers
			responseHeaders,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		// Don't fire events if jQuery.event is undefined in an AMD-usage scenario (#15118)
		fireGlobals = jQuery.event && s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0 ||
		(!support.reliableHiddenOffsets() &&
			((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
};

jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;
			// Use .is(":disabled") so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject !== undefined ?
	// Support: IE6+
	function() {

		// XHR cannot access local files, always use ActiveX for that case
		return !this.isLocal &&

			// Support: IE7-8
			// oldIE XHR does not support non-RFC2616 methods (#13240)
			// See http://msdn.microsoft.com/en-us/library/ie/ms536648(v=vs.85).aspx
			// and http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html#sec9
			// Although this check for six methods instead of eight
			// since IE also does not support "trace" and "connect"
			/^(get|post|head|put|delete|options)$/i.test( this.type ) &&

			createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

var xhrId = 0,
	xhrCallbacks = {},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE<10
// Open requests must be manually aborted on unload (#5280)
// See https://support.microsoft.com/kb/2856746 for more info
if ( window.attachEvent ) {
	window.attachEvent( "onunload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]( undefined, true );
		}
	});
}

// Determine support properties
support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
xhrSupported = support.ajax = !!xhrSupported;

// Create transport if the browser can provide an xhr
if ( xhrSupported ) {

	jQuery.ajaxTransport(function( options ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !options.crossDomain || support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {
					var i,
						xhr = options.xhr(),
						id = ++xhrId;

					// Open the socket
					xhr.open( options.type, options.url, options.async, options.username, options.password );

					// Apply custom fields if provided
					if ( options.xhrFields ) {
						for ( i in options.xhrFields ) {
							xhr[ i ] = options.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( options.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( options.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !options.crossDomain && !headers["X-Requested-With"] ) {
						headers["X-Requested-With"] = "XMLHttpRequest";
					}

					// Set headers
					for ( i in headers ) {
						// Support: IE<9
						// IE's ActiveXObject throws a 'Type Mismatch' exception when setting
						// request header to a null-value.
						//
						// To keep consistent with other XHR implementations, cast the value
						// to string and ignore `undefined`.
						if ( headers[ i ] !== undefined ) {
							xhr.setRequestHeader( i, headers[ i ] + "" );
						}
					}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( options.hasContent && options.data ) || null );

					// Listener
					callback = function( _, isAbort ) {
						var status, statusText, responses;

						// Was never called and is aborted or complete
						if ( callback && ( isAbort || xhr.readyState === 4 ) ) {
							// Clean up
							delete xhrCallbacks[ id ];
							callback = undefined;
							xhr.onreadystatechange = jQuery.noop;

							// Abort manually if needed
							if ( isAbort ) {
								if ( xhr.readyState !== 4 ) {
									xhr.abort();
								}
							} else {
								responses = {};
								status = xhr.status;

								// Support: IE<10
								// Accessing binary-data responseText throws an exception
								// (#11426)
								if ( typeof xhr.responseText === "string" ) {
									responses.text = xhr.responseText;
								}

								// Firefox throws an exception when accessing
								// statusText for faulty cross-domain requests
								try {
									statusText = xhr.statusText;
								} catch( e ) {
									// We normalize with Webkit giving an empty statusText
									statusText = "";
								}

								// Filter status for non standard behaviors

								// If the request is local and we have data: assume a success
								// (success with no data won't get notified, that's the best we
								// can do given current implementations)
								if ( !status && options.isLocal && !options.crossDomain ) {
									status = responses.text ? 200 : 404;
								// IE - #1450: sometimes returns 1223 when it should be 204
								} else if ( status === 1223 ) {
									status = 204;
								}
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, xhr.getAllResponseHeaders() );
						}
					};

					if ( !options.async ) {
						// if we're in sync mode we fire the callback
						callback();
					} else if ( xhr.readyState === 4 ) {
						// (IE6 & IE7) if it's in cache and has been
						// retrieved directly we need to fire the callback
						setTimeout( callback );
					} else {
						// Add to the list of active xhr callbacks
						xhr.onreadystatechange = xhrCallbacks[ id ] = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback( undefined, true );
					}
				}
			};
		}
	});
}

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject( "Microsoft.XMLHTTP" );
	} catch( e ) {}
}




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || jQuery("head")[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement("script");

				script.async = true;

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( script.parentNode ) {
							script.parentNode.removeChild( script );
						}

						// Dereference the script
						script = null;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};

				// Circumvent IE6 bugs with base elements (#2709 and #4378) by prepending
				// Use native DOM manipulation to avoid our domManip AJAX trickery
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( undefined, true );
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, response, type,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off, url.length ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};





var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			jQuery.inArray("auto", [ curCSSTop, curCSSLeft ] ) > -1;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			box = { top: 0, left: 0 },
			elem = this[ 0 ],
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// If we don't have gBCR, just use 0,0 rather than error
		// BlackBerry 5, iOS 3 (original iPhone)
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top  + ( win.pageYOffset || docElem.scrollTop )  - ( docElem.clientTop  || 0 ),
			left: box.left + ( win.pageXOffset || docElem.scrollLeft ) - ( docElem.clientLeft || 0 )
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			parentOffset = { top: 0, left: 0 },
			elem = this[ 0 ];

		// fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// we assume that getBoundingClientRect is available when computed position is fixed
			offset = elem.getBoundingClientRect();
		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top  += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		return {
			top:  offset.top  - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true)
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					win.document.documentElement[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// getComputedStyle returns percent when specified for top/left/bottom/right
// rather than make the css module depend on the offset module, we just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// if curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height], whichever is greatest
					// unfortunately, this causes bug #3838 in IE6/8 only, but there is currently no good, small way to fix it.
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in
// AMD (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));

//     Underscore.js 1.8.3
//     http://underscorejs.org
//     (c) 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
//     Underscore may be freely distributed under the MIT license.

(function() {

  // Baseline setup
  // --------------

  // Establish the root object, `window` (`self`) in the browser, or `global` on the server.
  // We use `self` instead of `window` for `WebWorker` support.
  var root = typeof self === 'object' && self.self === self && self ||
            typeof global === 'object' && global.global === global && global;

  // Save the previous value of the `_` variable.
  var previousUnderscore = root._;

  // Save bytes in the minified (but not gzipped) version:
  var ArrayProto = Array.prototype, ObjProto = Object.prototype;

  // Create quick reference variables for speed access to core prototypes.
  var
    push = ArrayProto.push,
    slice = ArrayProto.slice,
    toString = ObjProto.toString,
    hasOwnProperty = ObjProto.hasOwnProperty;

  // All **ECMAScript 5** native function implementations that we hope to use
  // are declared here.
  var
    nativeIsArray = Array.isArray,
    nativeKeys = Object.keys,
    nativeCreate = Object.create;

  // Naked function reference for surrogate-prototype-swapping.
  var Ctor = function(){};

  // Create a safe reference to the Underscore object for use below.
  var _ = function(obj) {
    if (obj instanceof _) return obj;
    if (!(this instanceof _)) return new _(obj);
    this._wrapped = obj;
  };

  // Export the Underscore object for **Node.js**, with
  // backwards-compatibility for their old module API. If we're in
  // the browser, add `_` as a global object.
  if (typeof exports !== 'undefined') {
    if (typeof module !== 'undefined' && module.exports) {
      exports = module.exports = _;
    }
    exports._ = _;
  } else {
    root._ = _;
  }

  // Current version.
  _.VERSION = '1.8.3';

  // Internal function that returns an efficient (for current engines) version
  // of the passed-in callback, to be repeatedly applied in other Underscore
  // functions.
  var optimizeCb = function(func, context, argCount) {
    if (context === void 0) return func;
    switch (argCount == null ? 3 : argCount) {
      case 1: return function(value) {
        return func.call(context, value);
      };
      case 2: return function(value, other) {
        return func.call(context, value, other);
      };
      case 3: return function(value, index, collection) {
        return func.call(context, value, index, collection);
      };
      case 4: return function(accumulator, value, index, collection) {
        return func.call(context, accumulator, value, index, collection);
      };
    }
    return function() {
      return func.apply(context, arguments);
    };
  };

  // A mostly-internal function to generate callbacks that can be applied
  // to each element in a collection, returning the desired result — either
  // identity, an arbitrary callback, a property matcher, or a property accessor.
  var cb = function(value, context, argCount) {
    if (value == null) return _.identity;
    if (_.isFunction(value)) return optimizeCb(value, context, argCount);
    if (_.isObject(value)) return _.matcher(value);
    return _.property(value);
  };
  _.iteratee = function(value, context) {
    return cb(value, context, Infinity);
  };

  // Similar to ES6's rest param (http://ariya.ofilabs.com/2013/03/es6-and-rest-parameter.html)
  // This accumulates the arguments passed into an array, after a given index.
  var restArgs = function(func, startIndex) {
    startIndex = startIndex == null ? func.length - 1 : +startIndex;
    return function() {
      var length = Math.max(arguments.length - startIndex, 0);
      var rest = Array(length);
      var index;
      for (index = 0; index < length; index++) {
        rest[index] = arguments[index + startIndex];
      }
      switch (startIndex) {
        case 0: return func.call(this, rest);
        case 1: return func.call(this, arguments[0], rest);
        case 2: return func.call(this, arguments[0], arguments[1], rest);
      }
      var args = Array(startIndex + 1);
      for (index = 0; index < startIndex; index++) {
        args[index] = arguments[index];
      }
      args[startIndex] = rest;
      return func.apply(this, args);
    };
  };

  // An internal function for creating a new object that inherits from another.
  var baseCreate = function(prototype) {
    if (!_.isObject(prototype)) return {};
    if (nativeCreate) return nativeCreate(prototype);
    Ctor.prototype = prototype;
    var result = new Ctor;
    Ctor.prototype = null;
    return result;
  };

  var property = function(key) {
    return function(obj) {
      return obj == null ? void 0 : obj[key];
    };
  };

  // Helper for collection methods to determine whether a collection
  // should be iterated as an array or as an object
  // Related: http://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength
  // Avoids a very nasty iOS 8 JIT bug on ARM-64. #2094
  var MAX_ARRAY_INDEX = Math.pow(2, 53) - 1;
  var getLength = property('length');
  var isArrayLike = function(collection) {
    var length = getLength(collection);
    return typeof length == 'number' && length >= 0 && length <= MAX_ARRAY_INDEX;
  };

  // Collection Functions
  // --------------------

  // The cornerstone, an `each` implementation, aka `forEach`.
  // Handles raw objects in addition to array-likes. Treats all
  // sparse array-likes as if they were dense.
  _.each = _.forEach = function(obj, iteratee, context) {
    iteratee = optimizeCb(iteratee, context);
    var i, length;
    if (isArrayLike(obj)) {
      for (i = 0, length = obj.length; i < length; i++) {
        iteratee(obj[i], i, obj);
      }
    } else {
      var keys = _.keys(obj);
      for (i = 0, length = keys.length; i < length; i++) {
        iteratee(obj[keys[i]], keys[i], obj);
      }
    }
    return obj;
  };

  // Return the results of applying the iteratee to each element.
  _.map = _.collect = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length,
        results = Array(length);
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      results[index] = iteratee(obj[currentKey], currentKey, obj);
    }
    return results;
  };

  // Create a reducing function iterating left or right.
  var createReduce = function(dir) {
    // Optimized iterator function as using arguments.length
    // in the main function will deoptimize the, see #1991.
    var reducer = function(obj, iteratee, memo, initial) {
      var keys = !isArrayLike(obj) && _.keys(obj),
          length = (keys || obj).length,
          index = dir > 0 ? 0 : length - 1;
      if (!initial) {
        memo = obj[keys ? keys[index] : index];
        index += dir;
      }
      for (; index >= 0 && index < length; index += dir) {
        var currentKey = keys ? keys[index] : index;
        memo = iteratee(memo, obj[currentKey], currentKey, obj);
      }
      return memo;
    };

    return function(obj, iteratee, memo, context) {
      var initial = arguments.length >= 3;
      return reducer(obj, optimizeCb(iteratee, context, 4), memo, initial);
    };
  };

  // **Reduce** builds up a single result from a list of values, aka `inject`,
  // or `foldl`.
  _.reduce = _.foldl = _.inject = createReduce(1);

  // The right-associative version of reduce, also known as `foldr`.
  _.reduceRight = _.foldr = createReduce(-1);

  // Return the first value which passes a truth test. Aliased as `detect`.
  _.find = _.detect = function(obj, predicate, context) {
    var key;
    if (isArrayLike(obj)) {
      key = _.findIndex(obj, predicate, context);
    } else {
      key = _.findKey(obj, predicate, context);
    }
    if (key !== void 0 && key !== -1) return obj[key];
  };

  // Return all the elements that pass a truth test.
  // Aliased as `select`.
  _.filter = _.select = function(obj, predicate, context) {
    var results = [];
    predicate = cb(predicate, context);
    _.each(obj, function(value, index, list) {
      if (predicate(value, index, list)) results.push(value);
    });
    return results;
  };

  // Return all the elements for which a truth test fails.
  _.reject = function(obj, predicate, context) {
    return _.filter(obj, _.negate(cb(predicate)), context);
  };

  // Determine whether all of the elements match a truth test.
  // Aliased as `all`.
  _.every = _.all = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length;
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      if (!predicate(obj[currentKey], currentKey, obj)) return false;
    }
    return true;
  };

  // Determine if at least one element in the object matches a truth test.
  // Aliased as `any`.
  _.some = _.any = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length;
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      if (predicate(obj[currentKey], currentKey, obj)) return true;
    }
    return false;
  };

  // Determine if the array or object contains a given item (using `===`).
  // Aliased as `includes` and `include`.
  _.contains = _.includes = _.include = function(obj, item, fromIndex, guard) {
    if (!isArrayLike(obj)) obj = _.values(obj);
    if (typeof fromIndex != 'number' || guard) fromIndex = 0;
    return _.indexOf(obj, item, fromIndex) >= 0;
  };

  // Invoke a method (with arguments) on every item in a collection.
  _.invoke = restArgs(function(obj, method, args) {
    var isFunc = _.isFunction(method);
    return _.map(obj, function(value) {
      var func = isFunc ? method : value[method];
      return func == null ? func : func.apply(value, args);
    });
  });

  // Convenience version of a common use case of `map`: fetching a property.
  _.pluck = function(obj, key) {
    return _.map(obj, _.property(key));
  };

  // Convenience version of a common use case of `filter`: selecting only objects
  // containing specific `key:value` pairs.
  _.where = function(obj, attrs) {
    return _.filter(obj, _.matcher(attrs));
  };

  // Convenience version of a common use case of `find`: getting the first object
  // containing specific `key:value` pairs.
  _.findWhere = function(obj, attrs) {
    return _.find(obj, _.matcher(attrs));
  };

  // Return the maximum element (or element-based computation).
  _.max = function(obj, iteratee, context) {
    var result = -Infinity, lastComputed = -Infinity,
        value, computed;
    if (iteratee == null && obj != null) {
      obj = isArrayLike(obj) ? obj : _.values(obj);
      for (var i = 0, length = obj.length; i < length; i++) {
        value = obj[i];
        if (value > result) {
          result = value;
        }
      }
    } else {
      iteratee = cb(iteratee, context);
      _.each(obj, function(v, index, list) {
        computed = iteratee(v, index, list);
        if (computed > lastComputed || computed === -Infinity && result === -Infinity) {
          result = v;
          lastComputed = computed;
        }
      });
    }
    return result;
  };

  // Return the minimum element (or element-based computation).
  _.min = function(obj, iteratee, context) {
    var result = Infinity, lastComputed = Infinity,
        value, computed;
    if (iteratee == null && obj != null) {
      obj = isArrayLike(obj) ? obj : _.values(obj);
      for (var i = 0, length = obj.length; i < length; i++) {
        value = obj[i];
        if (value < result) {
          result = value;
        }
      }
    } else {
      iteratee = cb(iteratee, context);
      _.each(obj, function(v, index, list) {
        computed = iteratee(v, index, list);
        if (computed < lastComputed || computed === Infinity && result === Infinity) {
          result = v;
          lastComputed = computed;
        }
      });
    }
    return result;
  };

  // Shuffle a collection.
  _.shuffle = function(obj) {
    return _.sample(obj, Infinity);
  };

  // Sample **n** random values from a collection using the modern version of the
  // [Fisher-Yates shuffle](http://en.wikipedia.org/wiki/Fisher–Yates_shuffle).
  // If **n** is not specified, returns a single random element.
  // The internal `guard` argument allows it to work with `map`.
  _.sample = function(obj, n, guard) {
    if (n == null || guard) {
      if (!isArrayLike(obj)) obj = _.values(obj);
      return obj[_.random(obj.length - 1)];
    }
    var sample = isArrayLike(obj) ? _.clone(obj) : _.values(obj);
    var length = getLength(sample);
    n = Math.max(Math.min(n, length), 0);
    var last = length - 1;
    for (var index = 0; index < n; index++) {
      var rand = _.random(index, last);
      var temp = sample[index];
      sample[index] = sample[rand];
      sample[rand] = temp;
    }
    return sample.slice(0, n);
  };

  // Sort the object's values by a criterion produced by an iteratee.
  _.sortBy = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    return _.pluck(_.map(obj, function(value, index, list) {
      return {
        value: value,
        index: index,
        criteria: iteratee(value, index, list)
      };
    }).sort(function(left, right) {
      var a = left.criteria;
      var b = right.criteria;
      if (a !== b) {
        if (a > b || a === void 0) return 1;
        if (a < b || b === void 0) return -1;
      }
      return left.index - right.index;
    }), 'value');
  };

  // An internal function used for aggregate "group by" operations.
  var group = function(behavior, partition) {
    return function(obj, iteratee, context) {
      var result = partition ? [[], []] : {};
      iteratee = cb(iteratee, context);
      _.each(obj, function(value, index) {
        var key = iteratee(value, index, obj);
        behavior(result, value, key);
      });
      return result;
    };
  };

  // Groups the object's values by a criterion. Pass either a string attribute
  // to group by, or a function that returns the criterion.
  _.groupBy = group(function(result, value, key) {
    if (_.has(result, key)) result[key].push(value); else result[key] = [value];
  });

  // Indexes the object's values by a criterion, similar to `groupBy`, but for
  // when you know that your index values will be unique.
  _.indexBy = group(function(result, value, key) {
    result[key] = value;
  });

  // Counts instances of an object that group by a certain criterion. Pass
  // either a string attribute to count by, or a function that returns the
  // criterion.
  _.countBy = group(function(result, value, key) {
    if (_.has(result, key)) result[key]++; else result[key] = 1;
  });

  // Safely create a real, live array from anything iterable.
  _.toArray = function(obj) {
    if (!obj) return [];
    if (_.isArray(obj)) return slice.call(obj);
    if (isArrayLike(obj)) return _.map(obj, _.identity);
    return _.values(obj);
  };

  // Return the number of elements in an object.
  _.size = function(obj) {
    if (obj == null) return 0;
    return isArrayLike(obj) ? obj.length : _.keys(obj).length;
  };

  // Split a collection into two arrays: one whose elements all satisfy the given
  // predicate, and one whose elements all do not satisfy the predicate.
  _.partition = group(function(result, value, pass) {
    result[pass ? 0 : 1].push(value);
  }, true);

  // Array Functions
  // ---------------

  // Get the first element of an array. Passing **n** will return the first N
  // values in the array. Aliased as `head` and `take`. The **guard** check
  // allows it to work with `_.map`.
  _.first = _.head = _.take = function(array, n, guard) {
    if (array == null) return void 0;
    if (n == null || guard) return array[0];
    return _.initial(array, array.length - n);
  };

  // Returns everything but the last entry of the array. Especially useful on
  // the arguments object. Passing **n** will return all the values in
  // the array, excluding the last N.
  _.initial = function(array, n, guard) {
    return slice.call(array, 0, Math.max(0, array.length - (n == null || guard ? 1 : n)));
  };

  // Get the last element of an array. Passing **n** will return the last N
  // values in the array.
  _.last = function(array, n, guard) {
    if (array == null) return void 0;
    if (n == null || guard) return array[array.length - 1];
    return _.rest(array, Math.max(0, array.length - n));
  };

  // Returns everything but the first entry of the array. Aliased as `tail` and `drop`.
  // Especially useful on the arguments object. Passing an **n** will return
  // the rest N values in the array.
  _.rest = _.tail = _.drop = function(array, n, guard) {
    return slice.call(array, n == null || guard ? 1 : n);
  };

  // Trim out all falsy values from an array.
  _.compact = function(array) {
    return _.filter(array, _.identity);
  };

  // Internal implementation of a recursive `flatten` function.
  var flatten = function(input, shallow, strict, output) {
    output = output || [];
    var idx = output.length;
    for (var i = 0, length = getLength(input); i < length; i++) {
      var value = input[i];
      if (isArrayLike(value) && (_.isArray(value) || _.isArguments(value))) {
        //flatten current level of array or arguments object
        if (shallow) {
          var j = 0, len = value.length;
          while (j < len) output[idx++] = value[j++];
        } else {
          flatten(value, shallow, strict, output);
          idx = output.length;
        }
      } else if (!strict) {
        output[idx++] = value;
      }
    }
    return output;
  };

  // Flatten out an array, either recursively (by default), or just one level.
  _.flatten = function(array, shallow) {
    return flatten(array, shallow, false);
  };

  // Return a version of the array that does not contain the specified value(s).
  _.without = restArgs(function(array, otherArrays) {
    return _.difference(array, otherArrays);
  });

  // Produce a duplicate-free version of the array. If the array has already
  // been sorted, you have the option of using a faster algorithm.
  // Aliased as `unique`.
  _.uniq = _.unique = function(array, isSorted, iteratee, context) {
    if (!_.isBoolean(isSorted)) {
      context = iteratee;
      iteratee = isSorted;
      isSorted = false;
    }
    if (iteratee != null) iteratee = cb(iteratee, context);
    var result = [];
    var seen = [];
    for (var i = 0, length = getLength(array); i < length; i++) {
      var value = array[i],
          computed = iteratee ? iteratee(value, i, array) : value;
      if (isSorted) {
        if (!i || seen !== computed) result.push(value);
        seen = computed;
      } else if (iteratee) {
        if (!_.contains(seen, computed)) {
          seen.push(computed);
          result.push(value);
        }
      } else if (!_.contains(result, value)) {
        result.push(value);
      }
    }
    return result;
  };

  // Produce an array that contains the union: each distinct element from all of
  // the passed-in arrays.
  _.union = restArgs(function(arrays) {
    return _.uniq(flatten(arrays, true, true));
  });

  // Produce an array that contains every item shared between all the
  // passed-in arrays.
  _.intersection = function(array) {
    var result = [];
    var argsLength = arguments.length;
    for (var i = 0, length = getLength(array); i < length; i++) {
      var item = array[i];
      if (_.contains(result, item)) continue;
      var j;
      for (j = 1; j < argsLength; j++) {
        if (!_.contains(arguments[j], item)) break;
      }
      if (j === argsLength) result.push(item);
    }
    return result;
  };

  // Take the difference between one array and a number of other arrays.
  // Only the elements present in just the first array will remain.
  _.difference = restArgs(function(array, rest) {
    rest = flatten(rest, true, true);
    return _.filter(array, function(value){
      return !_.contains(rest, value);
    });
  });

  // Complement of _.zip. Unzip accepts an array of arrays and groups
  // each array's elements on shared indices
  _.unzip = function(array) {
    var length = array && _.max(array, getLength).length || 0;
    var result = Array(length);

    for (var index = 0; index < length; index++) {
      result[index] = _.pluck(array, index);
    }
    return result;
  };

  // Zip together multiple lists into a single array -- elements that share
  // an index go together.
  _.zip = restArgs(_.unzip);

  // Converts lists into objects. Pass either a single array of `[key, value]`
  // pairs, or two parallel arrays of the same length -- one of keys, and one of
  // the corresponding values.
  _.object = function(list, values) {
    var result = {};
    for (var i = 0, length = getLength(list); i < length; i++) {
      if (values) {
        result[list[i]] = values[i];
      } else {
        result[list[i][0]] = list[i][1];
      }
    }
    return result;
  };

  // Generator function to create the findIndex and findLastIndex functions
  var createPredicateIndexFinder = function(dir) {
    return function(array, predicate, context) {
      predicate = cb(predicate, context);
      var length = getLength(array);
      var index = dir > 0 ? 0 : length - 1;
      for (; index >= 0 && index < length; index += dir) {
        if (predicate(array[index], index, array)) return index;
      }
      return -1;
    };
  };

  // Returns the first index on an array-like that passes a predicate test
  _.findIndex = createPredicateIndexFinder(1);
  _.findLastIndex = createPredicateIndexFinder(-1);

  // Use a comparator function to figure out the smallest index at which
  // an object should be inserted so as to maintain order. Uses binary search.
  _.sortedIndex = function(array, obj, iteratee, context) {
    iteratee = cb(iteratee, context, 1);
    var value = iteratee(obj);
    var low = 0, high = getLength(array);
    while (low < high) {
      var mid = Math.floor((low + high) / 2);
      if (iteratee(array[mid]) < value) low = mid + 1; else high = mid;
    }
    return low;
  };

  // Generator function to create the indexOf and lastIndexOf functions
  var createIndexFinder = function(dir, predicateFind, sortedIndex) {
    return function(array, item, idx) {
      var i = 0, length = getLength(array);
      if (typeof idx == 'number') {
        if (dir > 0) {
          i = idx >= 0 ? idx : Math.max(idx + length, i);
        } else {
          length = idx >= 0 ? Math.min(idx + 1, length) : idx + length + 1;
        }
      } else if (sortedIndex && idx && length) {
        idx = sortedIndex(array, item);
        return array[idx] === item ? idx : -1;
      }
      if (item !== item) {
        idx = predicateFind(slice.call(array, i, length), _.isNaN);
        return idx >= 0 ? idx + i : -1;
      }
      for (idx = dir > 0 ? i : length - 1; idx >= 0 && idx < length; idx += dir) {
        if (array[idx] === item) return idx;
      }
      return -1;
    };
  };

  // Return the position of the first occurrence of an item in an array,
  // or -1 if the item is not included in the array.
  // If the array is large and already in sort order, pass `true`
  // for **isSorted** to use binary search.
  _.indexOf = createIndexFinder(1, _.findIndex, _.sortedIndex);
  _.lastIndexOf = createIndexFinder(-1, _.findLastIndex);

  // Generate an integer Array containing an arithmetic progression. A port of
  // the native Python `range()` function. See
  // [the Python documentation](http://docs.python.org/library/functions.html#range).
  _.range = function(start, stop, step) {
    if (stop == null) {
      stop = start || 0;
      start = 0;
    }
    step = step || 1;

    var length = Math.max(Math.ceil((stop - start) / step), 0);
    var range = Array(length);

    for (var idx = 0; idx < length; idx++, start += step) {
      range[idx] = start;
    }

    return range;
  };

  // Function (ahem) Functions
  // ------------------

  // Determines whether to execute a function as a constructor
  // or a normal function with the provided arguments
  var executeBound = function(sourceFunc, boundFunc, context, callingContext, args) {
    if (!(callingContext instanceof boundFunc)) return sourceFunc.apply(context, args);
    var self = baseCreate(sourceFunc.prototype);
    var result = sourceFunc.apply(self, args);
    if (_.isObject(result)) return result;
    return self;
  };

  // Create a function bound to a given object (assigning `this`, and arguments,
  // optionally). Delegates to **ECMAScript 5**'s native `Function.bind` if
  // available.
  _.bind = restArgs(function(func, context, args) {
    if (!_.isFunction(func)) throw new TypeError('Bind must be called on a function');
    var bound = restArgs(function(callArgs) {
      return executeBound(func, bound, context, this, args.concat(callArgs));
    });
    return bound;
  });

  // Partially apply a function by creating a version that has had some of its
  // arguments pre-filled, without changing its dynamic `this` context. _ acts
  // as a placeholder by default, allowing any combination of arguments to be
  // pre-filled. Set `_.partial.placeholder` for a custom placeholder argument.
  _.partial = restArgs(function(func, boundArgs) {
    var placeholder = _.partial.placeholder;
    var bound = function() {
      var position = 0, length = boundArgs.length;
      var args = Array(length);
      for (var i = 0; i < length; i++) {
        args[i] = boundArgs[i] === placeholder ? arguments[position++] : boundArgs[i];
      }
      while (position < arguments.length) args.push(arguments[position++]);
      return executeBound(func, bound, this, this, args);
    };
    return bound;
  });

  _.partial.placeholder = _;

  // Bind a number of an object's methods to that object. Remaining arguments
  // are the method names to be bound. Useful for ensuring that all callbacks
  // defined on an object belong to it.
  _.bindAll = restArgs(function(obj, keys) {
    keys = flatten(keys, false, false);
    var index = keys.length;
    if (index < 1) throw new Error('bindAll must be passed function names');
    while (index--) {
      var key = keys[index];
      obj[key] = _.bind(obj[key], obj);
    }
  });

  // Memoize an expensive function by storing its results.
  _.memoize = function(func, hasher) {
    var memoize = function(key) {
      var cache = memoize.cache;
      var address = '' + (hasher ? hasher.apply(this, arguments) : key);
      if (!_.has(cache, address)) cache[address] = func.apply(this, arguments);
      return cache[address];
    };
    memoize.cache = {};
    return memoize;
  };

  // Delays a function for the given number of milliseconds, and then calls
  // it with the arguments supplied.
  _.delay = restArgs(function(func, wait, args) {
    return setTimeout(function(){
      return func.apply(null, args);
    }, wait);
  });

  // Defers a function, scheduling it to run after the current call stack has
  // cleared.
  _.defer = _.partial(_.delay, _, 1);

  // Returns a function, that, when invoked, will only be triggered at most once
  // during a given window of time. Normally, the throttled function will run
  // as much as it can, without ever going more than once per `wait` duration;
  // but if you'd like to disable the execution on the leading edge, pass
  // `{leading: false}`. To disable execution on the trailing edge, ditto.
  _.throttle = function(func, wait, options) {
    var context, args, result;
    var timeout = null;
    var previous = 0;
    if (!options) options = {};
    var later = function() {
      previous = options.leading === false ? 0 : _.now();
      timeout = null;
      result = func.apply(context, args);
      if (!timeout) context = args = null;
    };
    return function() {
      var now = _.now();
      if (!previous && options.leading === false) previous = now;
      var remaining = wait - (now - previous);
      context = this;
      args = arguments;
      if (remaining <= 0 || remaining > wait) {
        if (timeout) {
          clearTimeout(timeout);
          timeout = null;
        }
        previous = now;
        result = func.apply(context, args);
        if (!timeout) context = args = null;
      } else if (!timeout && options.trailing !== false) {
        timeout = setTimeout(later, remaining);
      }
      return result;
    };
  };

  // Returns a function, that, as long as it continues to be invoked, will not
  // be triggered. The function will be called after it stops being called for
  // N milliseconds. If `immediate` is passed, trigger the function on the
  // leading edge, instead of the trailing.
  _.debounce = function(func, wait, immediate) {
    var timeout, args, context, timestamp, result;

    var later = function() {
      var last = _.now() - timestamp;

      if (last < wait && last >= 0) {
        timeout = setTimeout(later, wait - last);
      } else {
        timeout = null;
        if (!immediate) {
          result = func.apply(context, args);
          if (!timeout) context = args = null;
        }
      }
    };

    return function() {
      context = this;
      args = arguments;
      timestamp = _.now();
      var callNow = immediate && !timeout;
      if (!timeout) timeout = setTimeout(later, wait);
      if (callNow) {
        result = func.apply(context, args);
        context = args = null;
      }

      return result;
    };
  };

  // Returns the first function passed as an argument to the second,
  // allowing you to adjust arguments, run code before and after, and
  // conditionally execute the original function.
  _.wrap = function(func, wrapper) {
    return _.partial(wrapper, func);
  };

  // Returns a negated version of the passed-in predicate.
  _.negate = function(predicate) {
    return function() {
      return !predicate.apply(this, arguments);
    };
  };

  // Returns a function that is the composition of a list of functions, each
  // consuming the return value of the function that follows.
  _.compose = function() {
    var args = arguments;
    var start = args.length - 1;
    return function() {
      var i = start;
      var result = args[start].apply(this, arguments);
      while (i--) result = args[i].call(this, result);
      return result;
    };
  };

  // Returns a function that will only be executed on and after the Nth call.
  _.after = function(times, func) {
    return function() {
      if (--times < 1) {
        return func.apply(this, arguments);
      }
    };
  };

  // Returns a function that will only be executed up to (but not including) the Nth call.
  _.before = function(times, func) {
    var memo;
    return function() {
      if (--times > 0) {
        memo = func.apply(this, arguments);
      }
      if (times <= 1) func = null;
      return memo;
    };
  };

  // Returns a function that will be executed at most one time, no matter how
  // often you call it. Useful for lazy initialization.
  _.once = _.partial(_.before, 2);

  _.restArgs = restArgs;

  // Object Functions
  // ----------------

  // Keys in IE < 9 that won't be iterated by `for key in ...` and thus missed.
  var hasEnumBug = !{toString: null}.propertyIsEnumerable('toString');
  var nonEnumerableProps = ['valueOf', 'isPrototypeOf', 'toString',
                      'propertyIsEnumerable', 'hasOwnProperty', 'toLocaleString'];

  var collectNonEnumProps = function(obj, keys) {
    var nonEnumIdx = nonEnumerableProps.length;
    var constructor = obj.constructor;
    var proto = _.isFunction(constructor) && constructor.prototype || ObjProto;

    // Constructor is a special case.
    var prop = 'constructor';
    if (_.has(obj, prop) && !_.contains(keys, prop)) keys.push(prop);

    while (nonEnumIdx--) {
      prop = nonEnumerableProps[nonEnumIdx];
      if (prop in obj && obj[prop] !== proto[prop] && !_.contains(keys, prop)) {
        keys.push(prop);
      }
    }
  };

  // Retrieve the names of an object's own properties.
  // Delegates to **ECMAScript 5**'s native `Object.keys`
  _.keys = function(obj) {
    if (!_.isObject(obj)) return [];
    if (nativeKeys) return nativeKeys(obj);
    var keys = [];
    for (var key in obj) if (_.has(obj, key)) keys.push(key);
    // Ahem, IE < 9.
    if (hasEnumBug) collectNonEnumProps(obj, keys);
    return keys;
  };

  // Retrieve all the property names of an object.
  _.allKeys = function(obj) {
    if (!_.isObject(obj)) return [];
    var keys = [];
    for (var key in obj) keys.push(key);
    // Ahem, IE < 9.
    if (hasEnumBug) collectNonEnumProps(obj, keys);
    return keys;
  };

  // Retrieve the values of an object's properties.
  _.values = function(obj) {
    var keys = _.keys(obj);
    var length = keys.length;
    var values = Array(length);
    for (var i = 0; i < length; i++) {
      values[i] = obj[keys[i]];
    }
    return values;
  };

  // Returns the results of applying the iteratee to each element of the object
  // In contrast to _.map it returns an object
  _.mapObject = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    var keys = _.keys(obj),
      length = keys.length,
      results = {};
    for (var index = 0; index < length; index++) {
      var currentKey = keys[index];
      results[currentKey] = iteratee(obj[currentKey], currentKey, obj);
    }
    return results;
  };

  // Convert an object into a list of `[key, value]` pairs.
  _.pairs = function(obj) {
    var keys = _.keys(obj);
    var length = keys.length;
    var pairs = Array(length);
    for (var i = 0; i < length; i++) {
      pairs[i] = [keys[i], obj[keys[i]]];
    }
    return pairs;
  };

  // Invert the keys and values of an object. The values must be serializable.
  _.invert = function(obj) {
    var result = {};
    var keys = _.keys(obj);
    for (var i = 0, length = keys.length; i < length; i++) {
      result[obj[keys[i]]] = keys[i];
    }
    return result;
  };

  // Return a sorted list of the function names available on the object.
  // Aliased as `methods`
  _.functions = _.methods = function(obj) {
    var names = [];
    for (var key in obj) {
      if (_.isFunction(obj[key])) names.push(key);
    }
    return names.sort();
  };

  // An internal function for creating assigner functions.
  var createAssigner = function(keysFunc, undefinedOnly) {
    return function(obj) {
      var length = arguments.length;
      if (length < 2 || obj == null) return obj;
      for (var index = 1; index < length; index++) {
        var source = arguments[index],
            keys = keysFunc(source),
            l = keys.length;
        for (var i = 0; i < l; i++) {
          var key = keys[i];
          if (!undefinedOnly || obj[key] === void 0) obj[key] = source[key];
        }
      }
      return obj;
    };
  };

  // Extend a given object with all the properties in passed-in object(s).
  _.extend = createAssigner(_.allKeys);

  // Assigns a given object with all the own properties in the passed-in object(s)
  // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
  _.extendOwn = _.assign = createAssigner(_.keys);

  // Returns the first key on an object that passes a predicate test
  _.findKey = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = _.keys(obj), key;
    for (var i = 0, length = keys.length; i < length; i++) {
      key = keys[i];
      if (predicate(obj[key], key, obj)) return key;
    }
  };

  // Internal pick helper function to determine if `obj` has key `key`.
  var keyInObj = function(value, key, obj) {
    return key in obj;
  };

  // Return a copy of the object only containing the whitelisted properties.
  _.pick = restArgs(function(obj, keys) {
    var result = {}, iteratee = keys[0];
    if (obj == null) return result;
    if (_.isFunction(iteratee)) {
      if (keys.length > 1) iteratee = optimizeCb(iteratee, keys[1]);
      keys = _.allKeys(obj);
    } else {
      iteratee = keyInObj;
      keys = flatten(keys, false, false);
      obj = Object(obj);
    }
    for (var i = 0, length = keys.length; i < length; i++) {
      var key = keys[i];
      var value = obj[key];
      if (iteratee(value, key, obj)) result[key] = value;
    }
    return result;
  });

   // Return a copy of the object without the blacklisted properties.
  _.omit = restArgs(function(obj, keys) {
    var iteratee = keys[0], context;
    if (_.isFunction(iteratee)) {
      iteratee = _.negate(iteratee);
      if (keys.length > 1) context = keys[1];
    } else {
      keys = _.map(flatten(keys, false, false), String);
      iteratee = function(value, key) {
        return !_.contains(keys, key);
      };
    }
    return _.pick(obj, iteratee, context);
  });

  // Fill in a given object with default properties.
  _.defaults = createAssigner(_.allKeys, true);

  // Creates an object that inherits from the given prototype object.
  // If additional properties are provided then they will be added to the
  // created object.
  _.create = function(prototype, props) {
    var result = baseCreate(prototype);
    if (props) _.extendOwn(result, props);
    return result;
  };

  // Create a (shallow-cloned) duplicate of an object.
  _.clone = function(obj) {
    if (!_.isObject(obj)) return obj;
    return _.isArray(obj) ? obj.slice() : _.extend({}, obj);
  };

  // Invokes interceptor with the obj, and then returns obj.
  // The primary purpose of this method is to "tap into" a method chain, in
  // order to perform operations on intermediate results within the chain.
  _.tap = function(obj, interceptor) {
    interceptor(obj);
    return obj;
  };

  // Returns whether an object has a given set of `key:value` pairs.
  _.isMatch = function(object, attrs) {
    var keys = _.keys(attrs), length = keys.length;
    if (object == null) return !length;
    var obj = Object(object);
    for (var i = 0; i < length; i++) {
      var key = keys[i];
      if (attrs[key] !== obj[key] || !(key in obj)) return false;
    }
    return true;
  };


  // Internal recursive comparison function for `isEqual`.
  var eq, deepEq;
  eq = function(a, b, aStack, bStack) {
    // Identical objects are equal. `0 === -0`, but they aren't identical.
    // See the [Harmony `egal` proposal](http://wiki.ecmascript.org/doku.php?id=harmony:egal).
    if (a === b) return a !== 0 || 1 / a === 1 / b;
    // A strict comparison is necessary because `null == undefined`.
    if (a == null || b == null) return a === b;
    // `NaN`s are equivalent, but non-reflexive.
    if (a !== a) return b !== b;
    // Exhaust primitive checks
    var type = typeof a;
    if (type !== 'function' && type !== 'object' && typeof b !== 'object') return false;
    return deepEq(a, b, aStack, bStack);
  };

  // Internal recursive comparison function for `isEqual`.
  deepEq = function(a, b, aStack, bStack) {
    // Unwrap any wrapped objects.
    if (a instanceof _) a = a._wrapped;
    if (b instanceof _) b = b._wrapped;
    // Compare `[[Class]]` names.
    var className = toString.call(a);
    if (className !== toString.call(b)) return false;
    switch (className) {
      // Strings, numbers, regular expressions, dates, and booleans are compared by value.
      case '[object RegExp]':
      // RegExps are coerced to strings for comparison (Note: '' + /a/i === '/a/i')
      case '[object String]':
        // Primitives and their corresponding object wrappers are equivalent; thus, `"5"` is
        // equivalent to `new String("5")`.
        return '' + a === '' + b;
      case '[object Number]':
        // `NaN`s are equivalent, but non-reflexive.
        // Object(NaN) is equivalent to NaN
        if (+a !== +a) return +b !== +b;
        // An `egal` comparison is performed for other numeric values.
        return +a === 0 ? 1 / +a === 1 / b : +a === +b;
      case '[object Date]':
      case '[object Boolean]':
        // Coerce dates and booleans to numeric primitive values. Dates are compared by their
        // millisecond representations. Note that invalid dates with millisecond representations
        // of `NaN` are not equivalent.
        return +a === +b;
    }

    var areArrays = className === '[object Array]';
    if (!areArrays) {
      if (typeof a != 'object' || typeof b != 'object') return false;

      // Objects with different constructors are not equivalent, but `Object`s or `Array`s
      // from different frames are.
      var aCtor = a.constructor, bCtor = b.constructor;
      if (aCtor !== bCtor && !(_.isFunction(aCtor) && aCtor instanceof aCtor &&
                               _.isFunction(bCtor) && bCtor instanceof bCtor)
                          && ('constructor' in a && 'constructor' in b)) {
        return false;
      }
    }
    // Assume equality for cyclic structures. The algorithm for detecting cyclic
    // structures is adapted from ES 5.1 section 15.12.3, abstract operation `JO`.

    // Initializing stack of traversed objects.
    // It's done here since we only need them for objects and arrays comparison.
    aStack = aStack || [];
    bStack = bStack || [];
    var length = aStack.length;
    while (length--) {
      // Linear search. Performance is inversely proportional to the number of
      // unique nested structures.
      if (aStack[length] === a) return bStack[length] === b;
    }

    // Add the first object to the stack of traversed objects.
    aStack.push(a);
    bStack.push(b);

    // Recursively compare objects and arrays.
    if (areArrays) {
      // Compare array lengths to determine if a deep comparison is necessary.
      length = a.length;
      if (length !== b.length) return false;
      // Deep compare the contents, ignoring non-numeric properties.
      while (length--) {
        if (!eq(a[length], b[length], aStack, bStack)) return false;
      }
    } else {
      // Deep compare objects.
      var keys = _.keys(a), key;
      length = keys.length;
      // Ensure that both objects contain the same number of properties before comparing deep equality.
      if (_.keys(b).length !== length) return false;
      while (length--) {
        // Deep compare each member
        key = keys[length];
        if (!(_.has(b, key) && eq(a[key], b[key], aStack, bStack))) return false;
      }
    }
    // Remove the first object from the stack of traversed objects.
    aStack.pop();
    bStack.pop();
    return true;
  };

  // Perform a deep comparison to check if two objects are equal.
  _.isEqual = function(a, b) {
    return eq(a, b);
  };

  // Is a given array, string, or object empty?
  // An "empty" object has no enumerable own-properties.
  _.isEmpty = function(obj) {
    if (obj == null) return true;
    if (isArrayLike(obj) && (_.isArray(obj) || _.isString(obj) || _.isArguments(obj))) return obj.length === 0;
    return _.keys(obj).length === 0;
  };

  // Is a given value a DOM element?
  _.isElement = function(obj) {
    return !!(obj && obj.nodeType === 1);
  };

  // Is a given value an array?
  // Delegates to ECMA5's native Array.isArray
  _.isArray = nativeIsArray || function(obj) {
    return toString.call(obj) === '[object Array]';
  };

  // Is a given variable an object?
  _.isObject = function(obj) {
    var type = typeof obj;
    return type === 'function' || type === 'object' && !!obj;
  };

  // Add some isType methods: isArguments, isFunction, isString, isNumber, isDate, isRegExp, isError.
  _.each(['Arguments', 'Function', 'String', 'Number', 'Date', 'RegExp', 'Error'], function(name) {
    _['is' + name] = function(obj) {
      return toString.call(obj) === '[object ' + name + ']';
    };
  });

  // Define a fallback version of the method in browsers (ahem, IE < 9), where
  // there isn't any inspectable "Arguments" type.
  if (!_.isArguments(arguments)) {
    _.isArguments = function(obj) {
      return _.has(obj, 'callee');
    };
  }

  // Optimize `isFunction` if appropriate. Work around some typeof bugs in old v8,
  // IE 11 (#1621), and in Safari 8 (#1929).
  if (typeof /./ != 'function' && typeof Int8Array != 'object') {
    _.isFunction = function(obj) {
      return typeof obj == 'function' || false;
    };
  }

  // Is a given object a finite number?
  _.isFinite = function(obj) {
    return isFinite(obj) && !isNaN(parseFloat(obj));
  };

  // Is the given value `NaN`? (NaN is the only number which does not equal itself).
  _.isNaN = function(obj) {
    return _.isNumber(obj) && obj !== +obj;
  };

  // Is a given value a boolean?
  _.isBoolean = function(obj) {
    return obj === true || obj === false || toString.call(obj) === '[object Boolean]';
  };

  // Is a given value equal to null?
  _.isNull = function(obj) {
    return obj === null;
  };

  // Is a given variable undefined?
  _.isUndefined = function(obj) {
    return obj === void 0;
  };

  // Shortcut function for checking if an object has a given property directly
  // on itself (in other words, not on a prototype).
  _.has = function(obj, key) {
    return obj != null && hasOwnProperty.call(obj, key);
  };

  // Utility Functions
  // -----------------

  // Run Underscore.js in *noConflict* mode, returning the `_` variable to its
  // previous owner. Returns a reference to the Underscore object.
  _.noConflict = function() {
    root._ = previousUnderscore;
    return this;
  };

  // Keep the identity function around for default iteratees.
  _.identity = function(value) {
    return value;
  };

  // Predicate-generating functions. Often useful outside of Underscore.
  _.constant = function(value) {
    return function() {
      return value;
    };
  };

  _.noop = function(){};

  _.property = property;

  // Generates a function for a given object that returns a given property.
  _.propertyOf = function(obj) {
    return obj == null ? function(){} : function(key) {
      return obj[key];
    };
  };

  // Returns a predicate for checking whether an object has a given set of
  // `key:value` pairs.
  _.matcher = _.matches = function(attrs) {
    attrs = _.extendOwn({}, attrs);
    return function(obj) {
      return _.isMatch(obj, attrs);
    };
  };

  // Run a function **n** times.
  _.times = function(n, iteratee, context) {
    var accum = Array(Math.max(0, n));
    iteratee = optimizeCb(iteratee, context, 1);
    for (var i = 0; i < n; i++) accum[i] = iteratee(i);
    return accum;
  };

  // Return a random integer between min and max (inclusive).
  _.random = function(min, max) {
    if (max == null) {
      max = min;
      min = 0;
    }
    return min + Math.floor(Math.random() * (max - min + 1));
  };

  // A (possibly faster) way to get the current timestamp as an integer.
  _.now = Date.now || function() {
    return new Date().getTime();
  };

   // List of HTML entities for escaping.
  var escapeMap = {
    '&': '&amp;',
    '<': '&lt;',
    '>': '&gt;',
    '"': '&quot;',
    "'": '&#x27;',
    '`': '&#x60;'
  };
  var unescapeMap = _.invert(escapeMap);

  // Functions for escaping and unescaping strings to/from HTML interpolation.
  var createEscaper = function(map) {
    var escaper = function(match) {
      return map[match];
    };
    // Regexes for identifying a key that needs to be escaped
    var source = '(?:' + _.keys(map).join('|') + ')';
    var testRegexp = RegExp(source);
    var replaceRegexp = RegExp(source, 'g');
    return function(string) {
      string = string == null ? '' : '' + string;
      return testRegexp.test(string) ? string.replace(replaceRegexp, escaper) : string;
    };
  };
  _.escape = createEscaper(escapeMap);
  _.unescape = createEscaper(unescapeMap);

  // If the value of the named `property` is a function then invoke it with the
  // `object` as context; otherwise, return it.
  _.result = function(object, prop, fallback) {
    var value = object == null ? void 0 : object[prop];
    if (value === void 0) {
      value = fallback;
    }
    return _.isFunction(value) ? value.call(object) : value;
  };

  // Generate a unique integer id (unique within the entire client session).
  // Useful for temporary DOM ids.
  var idCounter = 0;
  _.uniqueId = function(prefix) {
    var id = ++idCounter + '';
    return prefix ? prefix + id : id;
  };

  // By default, Underscore uses ERB-style template delimiters, change the
  // following template settings to use alternative delimiters.
  _.templateSettings = {
    evaluate: /<%([\s\S]+?)%>/g,
    interpolate: /<%=([\s\S]+?)%>/g,
    escape: /<%-([\s\S]+?)%>/g
  };

  // When customizing `templateSettings`, if you don't want to define an
  // interpolation, evaluation or escaping regex, we need one that is
  // guaranteed not to match.
  var noMatch = /(.)^/;

  // Certain characters need to be escaped so that they can be put into a
  // string literal.
  var escapes = {
    "'": "'",
    '\\': '\\',
    '\r': 'r',
    '\n': 'n',
    '\u2028': 'u2028',
    '\u2029': 'u2029'
  };

  var escapeRegExp = /\\|'|\r|\n|\u2028|\u2029/g;

  var escapeChar = function(match) {
    return '\\' + escapes[match];
  };

  // JavaScript micro-templating, similar to John Resig's implementation.
  // Underscore templating handles arbitrary delimiters, preserves whitespace,
  // and correctly escapes quotes within interpolated code.
  // NB: `oldSettings` only exists for backwards compatibility.
  _.template = function(text, settings, oldSettings) {
    if (!settings && oldSettings) settings = oldSettings;
    settings = _.defaults({}, settings, _.templateSettings);

    // Combine delimiters into one regular expression via alternation.
    var matcher = RegExp([
      (settings.escape || noMatch).source,
      (settings.interpolate || noMatch).source,
      (settings.evaluate || noMatch).source
    ].join('|') + '|$', 'g');

    // Compile the template source, escaping string literals appropriately.
    var index = 0;
    var source = "__p+='";
    text.replace(matcher, function(match, escape, interpolate, evaluate, offset) {
      source += text.slice(index, offset).replace(escapeRegExp, escapeChar);
      index = offset + match.length;

      if (escape) {
        source += "'+\n((__t=(" + escape + "))==null?'':_.escape(__t))+\n'";
      } else if (interpolate) {
        source += "'+\n((__t=(" + interpolate + "))==null?'':__t)+\n'";
      } else if (evaluate) {
        source += "';\n" + evaluate + "\n__p+='";
      }

      // Adobe VMs need the match returned to produce the correct offest.
      return match;
    });
    source += "';\n";

    // If a variable is not specified, place data values in local scope.
    if (!settings.variable) source = 'with(obj||{}){\n' + source + '}\n';

    source = "var __t,__p='',__j=Array.prototype.join," +
      "print=function(){__p+=__j.call(arguments,'');};\n" +
      source + 'return __p;\n';

    var render;
    try {
      render = new Function(settings.variable || 'obj', '_', source);
    } catch (e) {
      e.source = source;
      throw e;
    }

    var template = function(data) {
      return render.call(this, data, _);
    };

    // Provide the compiled source as a convenience for precompilation.
    var argument = settings.variable || 'obj';
    template.source = 'function(' + argument + '){\n' + source + '}';

    return template;
  };

  // Add a "chain" function. Start chaining a wrapped Underscore object.
  _.chain = function(obj) {
    var instance = _(obj);
    instance._chain = true;
    return instance;
  };

  // OOP
  // ---------------
  // If Underscore is called as a function, it returns a wrapped object that
  // can be used OO-style. This wrapper holds altered versions of all the
  // underscore functions. Wrapped objects may be chained.

  // Helper function to continue chaining intermediate results.
  var chainResult = function(instance, obj) {
    return instance._chain ? _(obj).chain() : obj;
  };

  // Add your own custom functions to the Underscore object.
  _.mixin = function(obj) {
    _.each(_.functions(obj), function(name) {
      var func = _[name] = obj[name];
      _.prototype[name] = function() {
        var args = [this._wrapped];
        push.apply(args, arguments);
        return chainResult(this, func.apply(_, args));
      };
    });
  };

  // Add all of the Underscore functions to the wrapper object.
  _.mixin(_);

  // Add all mutator Array functions to the wrapper.
  _.each(['pop', 'push', 'reverse', 'shift', 'sort', 'splice', 'unshift'], function(name) {
    var method = ArrayProto[name];
    _.prototype[name] = function() {
      var obj = this._wrapped;
      method.apply(obj, arguments);
      if ((name === 'shift' || name === 'splice') && obj.length === 0) delete obj[0];
      return chainResult(this, obj);
    };
  });

  // Add all accessor Array functions to the wrapper.
  _.each(['concat', 'join', 'slice'], function(name) {
    var method = ArrayProto[name];
    _.prototype[name] = function() {
      return chainResult(this, method.apply(this._wrapped, arguments));
    };
  });

  // Extracts the result from a wrapped and chained object.
  _.prototype.value = function() {
    return this._wrapped;
  };

  // Provide unwrapping proxy for some methods used in engine operations
  // such as arithmetic and JSON stringification.
  _.prototype.valueOf = _.prototype.toJSON = _.prototype.value;

  _.prototype.toString = function() {
    return '' + this._wrapped;
  };

  // AMD registration happens at the end for compatibility with AMD loaders
  // that may not enforce next-turn semantics on modules. Even though general
  // practice for AMD registration is to be anonymous, underscore registers
  // as a named module because, like jQuery, it is a base library that is
  // popular enough to be bundled in a third party lib, but not be part of
  // an AMD load request. Those cases could generate an error when an
  // anonymous define() is called outside of a loader request.
  if (typeof define === 'function' && define.amd) {
    define('underscore', [], function() {
      return _;
    });
  }
}());

;(function () {
	'use strict';

	/**
	 * @preserve FastClick: polyfill to remove click delays on browsers with touch UIs.
	 *
	 * @codingstandard ftlabs-jsv2
	 * @copyright The Financial Times Limited [All Rights Reserved]
	 * @license MIT License (see LICENSE.txt)
	 */

	/*jslint browser:true, node:true*/
	/*global define, Event, Node*/


	/**
	 * Instantiate fast-clicking listeners on the specified layer.
	 *
	 * @constructor
	 * @param {Element} layer The layer to listen on
	 * @param {Object} [options={}] The options to override the defaults
	 */
	function FastClick(layer, options) {
		var oldOnClick;

		options = options || {};

		/**
		 * Whether a click is currently being tracked.
		 *
		 * @type boolean
		 */
		this.trackingClick = false;


		/**
		 * Timestamp for when click tracking started.
		 *
		 * @type number
		 */
		this.trackingClickStart = 0;


		/**
		 * The element being tracked for a click.
		 *
		 * @type EventTarget
		 */
		this.targetElement = null;


		/**
		 * X-coordinate of touch start event.
		 *
		 * @type number
		 */
		this.touchStartX = 0;


		/**
		 * Y-coordinate of touch start event.
		 *
		 * @type number
		 */
		this.touchStartY = 0;


		/**
		 * ID of the last touch, retrieved from Touch.identifier.
		 *
		 * @type number
		 */
		this.lastTouchIdentifier = 0;


		/**
		 * Touchmove boundary, beyond which a click will be cancelled.
		 *
		 * @type number
		 */
		this.touchBoundary = options.touchBoundary || 10;


		/**
		 * The FastClick layer.
		 *
		 * @type Element
		 */
		this.layer = layer;

		/**
		 * The minimum time between tap(touchstart and touchend) events
		 *
		 * @type number
		 */
		this.tapDelay = options.tapDelay || 200;

		/**
		 * The maximum time for a tap
		 *
		 * @type number
		 */
		this.tapTimeout = options.tapTimeout || 700;

		if (FastClick.notNeeded(layer)) {
			return;
		}

		// Some old versions of Android don't have Function.prototype.bind
		function bind(method, context) {
			return function() { return method.apply(context, arguments); };
		}


		var methods = ['onMouse', 'onClick', 'onTouchStart', 'onTouchMove', 'onTouchEnd', 'onTouchCancel'];
		var context = this;
		for (var i = 0, l = methods.length; i < l; i++) {
			context[methods[i]] = bind(context[methods[i]], context);
		}

		// Set up event handlers as required
		if (deviceIsAndroid) {
			layer.addEventListener('mouseover', this.onMouse, true);
			layer.addEventListener('mousedown', this.onMouse, true);
			layer.addEventListener('mouseup', this.onMouse, true);
		}

		layer.addEventListener('click', this.onClick, true);
		layer.addEventListener('touchstart', this.onTouchStart, false);
		layer.addEventListener('touchmove', this.onTouchMove, false);
		layer.addEventListener('touchend', this.onTouchEnd, false);
		layer.addEventListener('touchcancel', this.onTouchCancel, false);

		// Hack is required for browsers that don't support Event#stopImmediatePropagation (e.g. Android 2)
		// which is how FastClick normally stops click events bubbling to callbacks registered on the FastClick
		// layer when they are cancelled.
		if (!Event.prototype.stopImmediatePropagation) {
			layer.removeEventListener = function(type, callback, capture) {
				var rmv = Node.prototype.removeEventListener;
				if (type === 'click') {
					rmv.call(layer, type, callback.hijacked || callback, capture);
				} else {
					rmv.call(layer, type, callback, capture);
				}
			};

			layer.addEventListener = function(type, callback, capture) {
				var adv = Node.prototype.addEventListener;
				if (type === 'click') {
					adv.call(layer, type, callback.hijacked || (callback.hijacked = function(event) {
						if (!event.propagationStopped) {
							callback(event);
						}
					}), capture);
				} else {
					adv.call(layer, type, callback, capture);
				}
			};
		}

		// If a handler is already declared in the element's onclick attribute, it will be fired before
		// FastClick's onClick handler. Fix this by pulling out the user-defined handler function and
		// adding it as listener.
		if (typeof layer.onclick === 'function') {

			// Android browser on at least 3.2 requires a new reference to the function in layer.onclick
			// - the old one won't work if passed to addEventListener directly.
			oldOnClick = layer.onclick;
			layer.addEventListener('click', function(event) {
				oldOnClick(event);
			}, false);
			layer.onclick = null;
		}
	}

	/**
	* Windows Phone 8.1 fakes user agent string to look like Android and iPhone.
	*
	* @type boolean
	*/
	var deviceIsWindowsPhone = navigator.userAgent.indexOf("Windows Phone") >= 0;

	/**
	 * Android requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsAndroid = navigator.userAgent.indexOf('Android') > 0 && !deviceIsWindowsPhone;


	/**
	 * iOS requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsIOS = /iP(ad|hone|od)/.test(navigator.userAgent) && !deviceIsWindowsPhone;


	/**
	 * iOS 4 requires an exception for select elements.
	 *
	 * @type boolean
	 */
	var deviceIsIOS4 = deviceIsIOS && (/OS 4_\d(_\d)?/).test(navigator.userAgent);


	/**
	 * iOS 6.0-7.* requires the target element to be manually derived
	 *
	 * @type boolean
	 */
	var deviceIsIOSWithBadTarget = deviceIsIOS && (/OS [6-7]_\d/).test(navigator.userAgent);

	/**
	 * BlackBerry requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsBlackBerry10 = navigator.userAgent.indexOf('BB10') > 0;

	/**
	 * Determine whether a given element requires a native click.
	 *
	 * @param {EventTarget|Element} target Target DOM element
	 * @returns {boolean} Returns true if the element needs a native click
	 */
	FastClick.prototype.needsClick = function(target) {
		switch (target.nodeName.toLowerCase()) {

		// Don't send a synthetic click to disabled inputs (issue #62)
		case 'button':
		case 'select':
		case 'textarea':
			if (target.disabled) {
				return true;
			}

			break;
		case 'input':

			// File inputs need real clicks on iOS 6 due to a browser bug (issue #68)
			if ((deviceIsIOS && target.type === 'file') || target.disabled) {
				return true;
			}

			break;
		case 'label':
		case 'iframe': // iOS8 homescreen apps can prevent events bubbling into frames
		case 'video':
			return true;
		}

		return (/\bneedsclick\b/).test(target.className);
	};


	/**
	 * Determine whether a given element requires a call to focus to simulate click into element.
	 *
	 * @param {EventTarget|Element} target Target DOM element
	 * @returns {boolean} Returns true if the element requires a call to focus to simulate native click.
	 */
	FastClick.prototype.needsFocus = function(target) {
		switch (target.nodeName.toLowerCase()) {
		case 'textarea':
			return true;
		case 'select':
			return !deviceIsAndroid;
		case 'input':
			switch (target.type) {
			case 'button':
			case 'checkbox':
			case 'file':
			case 'image':
			case 'radio':
			case 'submit':
				return false;
			}

			// No point in attempting to focus disabled inputs
			return !target.disabled && !target.readOnly;
		default:
			return (/\bneedsfocus\b/).test(target.className);
		}
	};


	/**
	 * Send a click event to the specified element.
	 *
	 * @param {EventTarget|Element} targetElement
	 * @param {Event} event
	 */
	FastClick.prototype.sendClick = function(targetElement, event) {
		var clickEvent, touch;

		// On some Android devices activeElement needs to be blurred otherwise the synthetic click will have no effect (#24)
		if (document.activeElement && document.activeElement !== targetElement) {
			document.activeElement.blur();
		}

		touch = event.changedTouches[0];

		// Synthesise a click event, with an extra attribute so it can be tracked
		clickEvent = document.createEvent('MouseEvents');
		clickEvent.initMouseEvent(this.determineEventType(targetElement), true, true, window, 1, touch.screenX, touch.screenY, touch.clientX, touch.clientY, false, false, false, false, 0, null);
		clickEvent.forwardedTouchEvent = true;
		targetElement.dispatchEvent(clickEvent);
	};

	FastClick.prototype.determineEventType = function(targetElement) {

		//Issue #159: Android Chrome Select Box does not open with a synthetic click event
		if (deviceIsAndroid && targetElement.tagName.toLowerCase() === 'select') {
			return 'mousedown';
		}

		return 'click';
	};


	/**
	 * @param {EventTarget|Element} targetElement
	 */
	FastClick.prototype.focus = function(targetElement) {
		var length;

		// Issue #160: on iOS 7, some input elements (e.g. date datetime month) throw a vague TypeError on setSelectionRange. These elements don't have an integer value for the selectionStart and selectionEnd properties, but unfortunately that can't be used for detection because accessing the properties also throws a TypeError. Just check the type instead. Filed as Apple bug #15122724.
		if (deviceIsIOS && targetElement.setSelectionRange && targetElement.type.indexOf('date') !== 0 && targetElement.type !== 'time' && targetElement.type !== 'month') {
			length = targetElement.value.length;
			targetElement.setSelectionRange(length, length);
		} else {
			targetElement.focus();
		}
	};


	/**
	 * Check whether the given target element is a child of a scrollable layer and if so, set a flag on it.
	 *
	 * @param {EventTarget|Element} targetElement
	 */
	FastClick.prototype.updateScrollParent = function(targetElement) {
		var scrollParent, parentElement;

		scrollParent = targetElement.fastClickScrollParent;

		// Attempt to discover whether the target element is contained within a scrollable layer. Re-check if the
		// target element was moved to another parent.
		if (!scrollParent || !scrollParent.contains(targetElement)) {
			parentElement = targetElement;
			do {
				if (parentElement.scrollHeight > parentElement.offsetHeight) {
					scrollParent = parentElement;
					targetElement.fastClickScrollParent = parentElement;
					break;
				}

				parentElement = parentElement.parentElement;
			} while (parentElement);
		}

		// Always update the scroll top tracker if possible.
		if (scrollParent) {
			scrollParent.fastClickLastScrollTop = scrollParent.scrollTop;
		}
	};


	/**
	 * @param {EventTarget} targetElement
	 * @returns {Element|EventTarget}
	 */
	FastClick.prototype.getTargetElementFromEventTarget = function(eventTarget) {

		// On some older browsers (notably Safari on iOS 4.1 - see issue #56) the event target may be a text node.
		if (eventTarget.nodeType === Node.TEXT_NODE) {
			return eventTarget.parentNode;
		}

		return eventTarget;
	};


	/**
	 * On touch start, record the position and scroll offset.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchStart = function(event) {
		var targetElement, touch, selection;

		// Ignore multiple touches, otherwise pinch-to-zoom is prevented if both fingers are on the FastClick element (issue #111).
		if (event.targetTouches.length > 1) {
			return true;
		}

		targetElement = this.getTargetElementFromEventTarget(event.target);
		touch = event.targetTouches[0];

		if (deviceIsIOS) {

			// Only trusted events will deselect text on iOS (issue #49)
			selection = window.getSelection();
			if (selection.rangeCount && !selection.isCollapsed) {
				return true;
			}

			if (!deviceIsIOS4) {

				// Weird things happen on iOS when an alert or confirm dialog is opened from a click event callback (issue #23):
				// when the user next taps anywhere else on the page, new touchstart and touchend events are dispatched
				// with the same identifier as the touch event that previously triggered the click that triggered the alert.
				// Sadly, there is an issue on iOS 4 that causes some normal touch events to have the same identifier as an
				// immediately preceeding touch event (issue #52), so this fix is unavailable on that platform.
				// Issue 120: touch.identifier is 0 when Chrome dev tools 'Emulate touch events' is set with an iOS device UA string,
				// which causes all touch events to be ignored. As this block only applies to iOS, and iOS identifiers are always long,
				// random integers, it's safe to to continue if the identifier is 0 here.
				if (touch.identifier && touch.identifier === this.lastTouchIdentifier) {
					event.preventDefault();
					return false;
				}

				this.lastTouchIdentifier = touch.identifier;

				// If the target element is a child of a scrollable layer (using -webkit-overflow-scrolling: touch) and:
				// 1) the user does a fling scroll on the scrollable layer
				// 2) the user stops the fling scroll with another tap
				// then the event.target of the last 'touchend' event will be the element that was under the user's finger
				// when the fling scroll was started, causing FastClick to send a click event to that layer - unless a check
				// is made to ensure that a parent layer was not scrolled before sending a synthetic click (issue #42).
				this.updateScrollParent(targetElement);
			}
		}

		this.trackingClick = true;
		this.trackingClickStart = event.timeStamp;
		this.targetElement = targetElement;

		this.touchStartX = touch.pageX;
		this.touchStartY = touch.pageY;

		// Prevent phantom clicks on fast double-tap (issue #36)
		if ((event.timeStamp - this.lastClickTime) < this.tapDelay) {
			event.preventDefault();
		}

		return true;
	};


	/**
	 * Based on a touchmove event object, check whether the touch has moved past a boundary since it started.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.touchHasMoved = function(event) {
		var touch = event.changedTouches[0], boundary = this.touchBoundary;

		if (Math.abs(touch.pageX - this.touchStartX) > boundary || Math.abs(touch.pageY - this.touchStartY) > boundary) {
			return true;
		}

		return false;
	};


	/**
	 * Update the last position.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchMove = function(event) {
		if (!this.trackingClick) {
			return true;
		}

		// If the touch has moved, cancel the click tracking
		if (this.targetElement !== this.getTargetElementFromEventTarget(event.target) || this.touchHasMoved(event)) {
			this.trackingClick = false;
			this.targetElement = null;
		}

		return true;
	};


	/**
	 * Attempt to find the labelled control for the given label element.
	 *
	 * @param {EventTarget|HTMLLabelElement} labelElement
	 * @returns {Element|null}
	 */
	FastClick.prototype.findControl = function(labelElement) {

		// Fast path for newer browsers supporting the HTML5 control attribute
		if (labelElement.control !== undefined) {
			return labelElement.control;
		}

		// All browsers under test that support touch events also support the HTML5 htmlFor attribute
		if (labelElement.htmlFor) {
			return document.getElementById(labelElement.htmlFor);
		}

		// If no for attribute exists, attempt to retrieve the first labellable descendant element
		// the list of which is defined here: http://www.w3.org/TR/html5/forms.html#category-label
		return labelElement.querySelector('button, input:not([type=hidden]), keygen, meter, output, progress, select, textarea');
	};


	/**
	 * On touch end, determine whether to send a click event at once.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchEnd = function(event) {
		var forElement, trackingClickStart, targetTagName, scrollParent, touch, targetElement = this.targetElement;

		if (!this.trackingClick) {
			return true;
		}

		// Prevent phantom clicks on fast double-tap (issue #36)
		if ((event.timeStamp - this.lastClickTime) < this.tapDelay) {
			this.cancelNextClick = true;
			return true;
		}

		if ((event.timeStamp - this.trackingClickStart) > this.tapTimeout) {
			return true;
		}

		// Reset to prevent wrong click cancel on input (issue #156).
		this.cancelNextClick = false;

		this.lastClickTime = event.timeStamp;

		trackingClickStart = this.trackingClickStart;
		this.trackingClick = false;
		this.trackingClickStart = 0;

		// On some iOS devices, the targetElement supplied with the event is invalid if the layer
		// is performing a transition or scroll, and has to be re-detected manually. Note that
		// for this to function correctly, it must be called *after* the event target is checked!
		// See issue #57; also filed as rdar://13048589 .
		if (deviceIsIOSWithBadTarget) {
			touch = event.changedTouches[0];

			// In certain cases arguments of elementFromPoint can be negative, so prevent setting targetElement to null
			targetElement = document.elementFromPoint(touch.pageX - window.pageXOffset, touch.pageY - window.pageYOffset) || targetElement;
			targetElement.fastClickScrollParent = this.targetElement.fastClickScrollParent;
		}

		targetTagName = targetElement.tagName.toLowerCase();
		if (targetTagName === 'label') {
			forElement = this.findControl(targetElement);
			if (forElement) {
				this.focus(targetElement);
				if (deviceIsAndroid) {
					return false;
				}

				targetElement = forElement;
			}
		} else if (this.needsFocus(targetElement)) {

			// Case 1: If the touch started a while ago (best guess is 100ms based on tests for issue #36) then focus will be triggered anyway. Return early and unset the target element reference so that the subsequent click will be allowed through.
			// Case 2: Without this exception for input elements tapped when the document is contained in an iframe, then any inputted text won't be visible even though the value attribute is updated as the user types (issue #37).
			if ((event.timeStamp - trackingClickStart) > 100 || (deviceIsIOS && window.top !== window && targetTagName === 'input')) {
				this.targetElement = null;
				return false;
			}

			this.focus(targetElement);
			this.sendClick(targetElement, event);

			// Select elements need the event to go through on iOS 4, otherwise the selector menu won't open.
			// Also this breaks opening selects when VoiceOver is active on iOS6, iOS7 (and possibly others)
			if (!deviceIsIOS || targetTagName !== 'select') {
				this.targetElement = null;
				event.preventDefault();
			}

			return false;
		}

		if (deviceIsIOS && !deviceIsIOS4) {

			// Don't send a synthetic click event if the target element is contained within a parent layer that was scrolled
			// and this tap is being used to stop the scrolling (usually initiated by a fling - issue #42).
			scrollParent = targetElement.fastClickScrollParent;
			if (scrollParent && scrollParent.fastClickLastScrollTop !== scrollParent.scrollTop) {
				return true;
			}
		}

		// Prevent the actual click from going though - unless the target node is marked as requiring
		// real clicks or if it is in the whitelist in which case only non-programmatic clicks are permitted.
		if (!this.needsClick(targetElement)) {
			event.preventDefault();
			this.sendClick(targetElement, event);
		}

		return false;
	};


	/**
	 * On touch cancel, stop tracking the click.
	 *
	 * @returns {void}
	 */
	FastClick.prototype.onTouchCancel = function() {
		this.trackingClick = false;
		this.targetElement = null;
	};


	/**
	 * Determine mouse events which should be permitted.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onMouse = function(event) {

		// If a target element was never set (because a touch event was never fired) allow the event
		if (!this.targetElement) {
			return true;
		}

		if (event.forwardedTouchEvent) {
			return true;
		}

		// Programmatically generated events targeting a specific element should be permitted
		if (!event.cancelable) {
			return true;
		}

		// Derive and check the target element to see whether the mouse event needs to be permitted;
		// unless explicitly enabled, prevent non-touch click events from triggering actions,
		// to prevent ghost/doubleclicks.
		if (!this.needsClick(this.targetElement) || this.cancelNextClick) {

			// Prevent any user-added listeners declared on FastClick element from being fired.
			if (event.stopImmediatePropagation) {
				event.stopImmediatePropagation();
			} else {

				// Part of the hack for browsers that don't support Event#stopImmediatePropagation (e.g. Android 2)
				event.propagationStopped = true;
			}

			// Cancel the event
			event.stopPropagation();
			event.preventDefault();

			return false;
		}

		// If the mouse event is permitted, return true for the action to go through.
		return true;
	};


	/**
	 * On actual clicks, determine whether this is a touch-generated click, a click action occurring
	 * naturally after a delay after a touch (which needs to be cancelled to avoid duplication), or
	 * an actual click which should be permitted.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onClick = function(event) {
		var permitted;

		// It's possible for another FastClick-like library delivered with third-party code to fire a click event before FastClick does (issue #44). In that case, set the click-tracking flag back to false and return early. This will cause onTouchEnd to return early.
		if (this.trackingClick) {
			this.targetElement = null;
			this.trackingClick = false;
			return true;
		}

		// Very odd behaviour on iOS (issue #18): if a submit element is present inside a form and the user hits enter in the iOS simulator or clicks the Go button on the pop-up OS keyboard the a kind of 'fake' click event will be triggered with the submit-type input element as the target.
		if (event.target.type === 'submit' && event.detail === 0) {
			return true;
		}

		permitted = this.onMouse(event);

		// Only unset targetElement if the click is not permitted. This will ensure that the check for !targetElement in onMouse fails and the browser's click doesn't go through.
		if (!permitted) {
			this.targetElement = null;
		}

		// If clicks are permitted, return true for the action to go through.
		return permitted;
	};


	/**
	 * Remove all FastClick's event listeners.
	 *
	 * @returns {void}
	 */
	FastClick.prototype.destroy = function() {
		var layer = this.layer;

		if (deviceIsAndroid) {
			layer.removeEventListener('mouseover', this.onMouse, true);
			layer.removeEventListener('mousedown', this.onMouse, true);
			layer.removeEventListener('mouseup', this.onMouse, true);
		}

		layer.removeEventListener('click', this.onClick, true);
		layer.removeEventListener('touchstart', this.onTouchStart, false);
		layer.removeEventListener('touchmove', this.onTouchMove, false);
		layer.removeEventListener('touchend', this.onTouchEnd, false);
		layer.removeEventListener('touchcancel', this.onTouchCancel, false);
	};


	/**
	 * Check whether FastClick is needed.
	 *
	 * @param {Element} layer The layer to listen on
	 */
	FastClick.notNeeded = function(layer) {
		var metaViewport;
		var chromeVersion;
		var blackberryVersion;
		var firefoxVersion;

		// Devices that don't support touch don't need FastClick
		if (typeof window.ontouchstart === 'undefined') {
			return true;
		}

		// Chrome version - zero for other browsers
		chromeVersion = +(/Chrome\/([0-9]+)/.exec(navigator.userAgent) || [,0])[1];

		if (chromeVersion) {

			if (deviceIsAndroid) {
				metaViewport = document.querySelector('meta[name=viewport]');

				if (metaViewport) {
					// Chrome on Android with user-scalable="no" doesn't need FastClick (issue #89)
					if (metaViewport.content.indexOf('user-scalable=no') !== -1) {
						return true;
					}
					// Chrome 32 and above with width=device-width or less don't need FastClick
					if (chromeVersion > 31 && document.documentElement.scrollWidth <= window.outerWidth) {
						return true;
					}
				}

			// Chrome desktop doesn't need FastClick (issue #15)
			} else {
				return true;
			}
		}

		if (deviceIsBlackBerry10) {
			blackberryVersion = navigator.userAgent.match(/Version\/([0-9]*)\.([0-9]*)/);

			// BlackBerry 10.3+ does not require Fastclick library.
			// https://github.com/ftlabs/fastclick/issues/251
			if (blackberryVersion[1] >= 10 && blackberryVersion[2] >= 3) {
				metaViewport = document.querySelector('meta[name=viewport]');

				if (metaViewport) {
					// user-scalable=no eliminates click delay.
					if (metaViewport.content.indexOf('user-scalable=no') !== -1) {
						return true;
					}
					// width=device-width (or less than device-width) eliminates click delay.
					if (document.documentElement.scrollWidth <= window.outerWidth) {
						return true;
					}
				}
			}
		}

		// IE10 with -ms-touch-action: none or manipulation, which disables double-tap-to-zoom (issue #97)
		if (layer.style.msTouchAction === 'none' || layer.style.touchAction === 'manipulation') {
			return true;
		}

		// Firefox version - zero for other browsers
		firefoxVersion = +(/Firefox\/([0-9]+)/.exec(navigator.userAgent) || [,0])[1];

		if (firefoxVersion >= 27) {
			// Firefox 27+ does not have tap delay if the content is not zoomable - https://bugzilla.mozilla.org/show_bug.cgi?id=922896

			metaViewport = document.querySelector('meta[name=viewport]');
			if (metaViewport && (metaViewport.content.indexOf('user-scalable=no') !== -1 || document.documentElement.scrollWidth <= window.outerWidth)) {
				return true;
			}
		}

		// IE11: prefixed -ms-touch-action is no longer supported and it's recomended to use non-prefixed version
		// http://msdn.microsoft.com/en-us/library/windows/apps/Hh767313.aspx
		if (layer.style.touchAction === 'none' || layer.style.touchAction === 'manipulation') {
			return true;
		}

		return false;
	};


	/**
	 * Factory method for creating a FastClick object
	 *
	 * @param {Element} layer The layer to listen on
	 * @param {Object} [options={}] The options to override the defaults
	 */
	FastClick.attach = function(layer, options) {
		return new FastClick(layer, options);
	};


	if (typeof define === 'function' && typeof define.amd === 'object' && define.amd) {

		// AMD. Register as an anonymous module.
		define(function() {
			return FastClick;
		});
	} else if (typeof module !== 'undefined' && module.exports) {
		module.exports = FastClick.attach;
		module.exports.FastClick = FastClick;
	} else {
		window.FastClick = FastClick;
	}
}());

/**
 * Simple localStorage with Cookie Fallback
 * v.1.0.0
 *
 * USAGE:
 * ----------------------------------------
 * Set New / Modify:
 *   store('my_key', 'some_value');
 *
 * Retrieve:
 *   store('my_key');
 *
 * Delete / Remove:
 *   store('my_key', null);
 */
 
var store = function store(key, value) {
 
    var lsSupport = false;
    
    // Check for native support
    if (window['localStorage']) {
        lsSupport = true;
    }
    
    // If value is detected, set new or modify store
    if (typeof value !== "undefined" && value !== null) {
        // Convert object values to JSON
        if ( typeof value === 'object' ) {
            value = JSON.stringify(value);
        }
        // Set the store
        if (lsSupport) { // Native support
            window['localStorage'].setItem(key, value);
        } else { // Use Cookie
            createCookie(key, value, 30);
        }
    }
    
    // No value supplied, return value
    if (typeof value === "undefined") {
        // Get value
        if (lsSupport) { // Native support
            data = window['localStorage'].getItem(key);
        } else { // Use cookie 
            data = readCookie(key);
        }
        
        // Try to parse JSON...
        try {
           data = JSON.parse(data);
        }
        catch(e) {
           data = data;
        }
        
        return data;
        
    }
    
    // Null specified, remove store
    if (value === null) {
        if (lsSupport) { // Native support
            window['localStorage'].removeItem(key);
        } else { // Use cookie
            createCookie(key, '', -1);
        }
    }
    
    /**
     * Creates new cookie or removes cookie with negative expiration
     * @param  key       The key or identifier for the store
     * @param  value     Contents of the store
     * @param  exp       Expiration - creation defaults to 30 days
     */
    
    function createCookie(key, value, exp) {
        var date = new Date();
        date.setTime(date.getTime() + (exp * 24 * 60 * 60 * 1000));
        var expires = "; expires=" + date.toGMTString();
        document.cookie = key + "=" + value + expires + "; path=/";
    }
    
    /**
     * Returns contents of cookie
     * @param  key       The key or identifier for the store
     */
    
    function readCookie(key) {
        var nameEQ = key + "=";
        var ca = document.cookie.split(';');
        for (var i = 0, max = ca.length; i < max; i++) {
            var c = ca[i];
            while (c.charAt(0) === ' ') c = c.substring(1, c.length);
            if (c.indexOf(nameEQ) === 0) return c.substring(nameEQ.length, c.length);
        }
        return null;
    }
    
};
/*! highlight.js v9.12.0 | BSD3 License | git.io/hljslicense */
!function(e){var t="object"==typeof window&&window||"object"==typeof self&&self;"undefined"!=typeof exports?e(exports):t&&(t.hljs=e({}),"function"==typeof define&&define.amd&&define([],function(){return t.hljs}))}(function(e){function t(e){return e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;")}function r(e){return e.nodeName.toLowerCase()}function a(e,t){var r=e&&e.exec(t);return r&&0===r.index}function n(e){return E.test(e)}function i(e){var t,r,a,i,s=e.className+" ";if(s+=e.parentNode?e.parentNode.className:"",r=M.exec(s))return w(r[1])?r[1]:"no-highlight";for(s=s.split(/\s+/),t=0,a=s.length;a>t;t++)if(i=s[t],n(i)||w(i))return i}function s(e){var t,r={},a=Array.prototype.slice.call(arguments,1);for(t in e)r[t]=e[t];return a.forEach(function(e){for(t in e)r[t]=e[t]}),r}function c(e){var t=[];return function a(e,n){for(var i=e.firstChild;i;i=i.nextSibling)3===i.nodeType?n+=i.nodeValue.length:1===i.nodeType&&(t.push({event:"start",offset:n,node:i}),n=a(i,n),r(i).match(/br|hr|img|input/)||t.push({event:"stop",offset:n,node:i}));return n}(e,0),t}function o(e,a,n){function i(){return e.length&&a.length?e[0].offset!==a[0].offset?e[0].offset<a[0].offset?e:a:"start"===a[0].event?e:a:e.length?e:a}function s(e){function a(e){return" "+e.nodeName+'="'+t(e.value).replace('"',"&quot;")+'"'}u+="<"+r(e)+N.map.call(e.attributes,a).join("")+">"}function c(e){u+="</"+r(e)+">"}function o(e){("start"===e.event?s:c)(e.node)}for(var l=0,u="",d=[];e.length||a.length;){var b=i();if(u+=t(n.substring(l,b[0].offset)),l=b[0].offset,b===e){d.reverse().forEach(c);do o(b.splice(0,1)[0]),b=i();while(b===e&&b.length&&b[0].offset===l);d.reverse().forEach(s)}else"start"===b[0].event?d.push(b[0].node):d.pop(),o(b.splice(0,1)[0])}return u+t(n.substr(l))}function l(e){return e.v&&!e.cached_variants&&(e.cached_variants=e.v.map(function(t){return s(e,{v:null},t)})),e.cached_variants||e.eW&&[s(e)]||[e]}function u(e){function t(e){return e&&e.source||e}function r(r,a){return new RegExp(t(r),"m"+(e.cI?"i":"")+(a?"g":""))}function a(n,i){if(!n.compiled){if(n.compiled=!0,n.k=n.k||n.bK,n.k){var s={},c=function(t,r){e.cI&&(r=r.toLowerCase()),r.split(" ").forEach(function(e){var r=e.split("|");s[r[0]]=[t,r[1]?Number(r[1]):1]})};"string"==typeof n.k?c("keyword",n.k):k(n.k).forEach(function(e){c(e,n.k[e])}),n.k=s}n.lR=r(n.l||/\w+/,!0),i&&(n.bK&&(n.b="\\b("+n.bK.split(" ").join("|")+")\\b"),n.b||(n.b=/\B|\b/),n.bR=r(n.b),n.e||n.eW||(n.e=/\B|\b/),n.e&&(n.eR=r(n.e)),n.tE=t(n.e)||"",n.eW&&i.tE&&(n.tE+=(n.e?"|":"")+i.tE)),n.i&&(n.iR=r(n.i)),null==n.r&&(n.r=1),n.c||(n.c=[]),n.c=Array.prototype.concat.apply([],n.c.map(function(e){return l("self"===e?n:e)})),n.c.forEach(function(e){a(e,n)}),n.starts&&a(n.starts,i);var o=n.c.map(function(e){return e.bK?"\\.?("+e.b+")\\.?":e.b}).concat([n.tE,n.i]).map(t).filter(Boolean);n.t=o.length?r(o.join("|"),!0):{exec:function(){return null}}}}a(e)}function d(e,r,n,i){function s(e,t){var r,n;for(r=0,n=t.c.length;n>r;r++)if(a(t.c[r].bR,e))return t.c[r]}function c(e,t){if(a(e.eR,t)){for(;e.endsParent&&e.parent;)e=e.parent;return e}return e.eW?c(e.parent,t):void 0}function o(e,t){return!n&&a(t.iR,e)}function l(e,t){var r=v.cI?t[0].toLowerCase():t[0];return e.k.hasOwnProperty(r)&&e.k[r]}function p(e,t,r,a){var n=a?"":L.classPrefix,i='<span class="'+n,s=r?"":R;return i+=e+'">',i+t+s}function m(){var e,r,a,n;if(!N.k)return t(E);for(n="",r=0,N.lR.lastIndex=0,a=N.lR.exec(E);a;)n+=t(E.substring(r,a.index)),e=l(N,a),e?(M+=e[1],n+=p(e[0],t(a[0]))):n+=t(a[0]),r=N.lR.lastIndex,a=N.lR.exec(E);return n+t(E.substr(r))}function f(){var e="string"==typeof N.sL;if(e&&!x[N.sL])return t(E);var r=e?d(N.sL,E,!0,k[N.sL]):b(E,N.sL.length?N.sL:void 0);return N.r>0&&(M+=r.r),e&&(k[N.sL]=r.top),p(r.language,r.value,!1,!0)}function g(){C+=null!=N.sL?f():m(),E=""}function _(e){C+=e.cN?p(e.cN,"",!0):"",N=Object.create(e,{parent:{value:N}})}function h(e,t){if(E+=e,null==t)return g(),0;var r=s(t,N);if(r)return r.skip?E+=t:(r.eB&&(E+=t),g(),r.rB||r.eB||(E=t)),_(r,t),r.rB?0:t.length;var a=c(N,t);if(a){var n=N;n.skip?E+=t:(n.rE||n.eE||(E+=t),g(),n.eE&&(E=t));do N.cN&&(C+=R),N.skip||(M+=N.r),N=N.parent;while(N!==a.parent);return a.starts&&_(a.starts,""),n.rE?0:t.length}if(o(t,N))throw new Error('Illegal lexeme "'+t+'" for mode "'+(N.cN||"<unnamed>")+'"');return E+=t,t.length||1}var v=w(e);if(!v)throw new Error('Unknown language: "'+e+'"');u(v);var y,N=i||v,k={},C="";for(y=N;y!==v;y=y.parent)y.cN&&(C=p(y.cN,"",!0)+C);var E="",M=0;try{for(var B,S,$=0;;){if(N.t.lastIndex=$,B=N.t.exec(r),!B)break;S=h(r.substring($,B.index),B[0]),$=B.index+S}for(h(r.substr($)),y=N;y.parent;y=y.parent)y.cN&&(C+=R);return{r:M,value:C,language:e,top:N}}catch(A){if(A.message&&-1!==A.message.indexOf("Illegal"))return{r:0,value:t(r)};throw A}}function b(e,r){r=r||L.languages||k(x);var a={r:0,value:t(e)},n=a;return r.filter(w).forEach(function(t){var r=d(t,e,!1);r.language=t,r.r>n.r&&(n=r),r.r>a.r&&(n=a,a=r)}),n.language&&(a.second_best=n),a}function p(e){return L.tabReplace||L.useBR?e.replace(B,function(e,t){return L.useBR&&"\n"===e?"<br>":L.tabReplace?t.replace(/\t/g,L.tabReplace):""}):e}function m(e,t,r){var a=t?C[t]:r,n=[e.trim()];return e.match(/\bhljs\b/)||n.push("hljs"),-1===e.indexOf(a)&&n.push(a),n.join(" ").trim()}function f(e){var t,r,a,s,l,u=i(e);n(u)||(L.useBR?(t=document.createElementNS("http://www.w3.org/1999/xhtml","div"),t.innerHTML=e.innerHTML.replace(/\n/g,"").replace(/<br[ \/]*>/g,"\n")):t=e,l=t.textContent,a=u?d(u,l,!0):b(l),r=c(t),r.length&&(s=document.createElementNS("http://www.w3.org/1999/xhtml","div"),s.innerHTML=a.value,a.value=o(r,c(s),l)),a.value=p(a.value),e.innerHTML=a.value,e.className=m(e.className,u,a.language),e.result={language:a.language,re:a.r},a.second_best&&(e.second_best={language:a.second_best.language,re:a.second_best.r}))}function g(e){L=s(L,e)}function _(){if(!_.called){_.called=!0;var e=document.querySelectorAll("pre code");N.forEach.call(e,f)}}function h(){addEventListener("DOMContentLoaded",_,!1),addEventListener("load",_,!1)}function v(t,r){var a=x[t]=r(e);a.aliases&&a.aliases.forEach(function(e){C[e]=t})}function y(){return k(x)}function w(e){return e=(e||"").toLowerCase(),x[e]||x[C[e]]}var N=[],k=Object.keys,x={},C={},E=/^(no-?highlight|plain|text)$/i,M=/\blang(?:uage)?-([\w-]+)\b/i,B=/((^(<[^>]+>|\t|)+|(?:\n)))/gm,R="</span>",L={classPrefix:"hljs-",tabReplace:null,useBR:!1,languages:void 0};return e.highlight=d,e.highlightAuto=b,e.fixMarkup=p,e.highlightBlock=f,e.configure=g,e.initHighlighting=_,e.initHighlightingOnLoad=h,e.registerLanguage=v,e.listLanguages=y,e.getLanguage=w,e.inherit=s,e.IR="[a-zA-Z]\\w*",e.UIR="[a-zA-Z_]\\w*",e.NR="\\b\\d+(\\.\\d+)?",e.CNR="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",e.BNR="\\b(0b[01]+)",e.RSR="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",e.BE={b:"\\\\[\\s\\S]",r:0},e.ASM={cN:"string",b:"'",e:"'",i:"\\n",c:[e.BE]},e.QSM={cN:"string",b:'"',e:'"',i:"\\n",c:[e.BE]},e.PWM={b:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},e.C=function(t,r,a){var n=e.inherit({cN:"comment",b:t,e:r,c:[]},a||{});return n.c.push(e.PWM),n.c.push({cN:"doctag",b:"(?:TODO|FIXME|NOTE|BUG|XXX):",r:0}),n},e.CLCM=e.C("//","$"),e.CBCM=e.C("/\\*","\\*/"),e.HCM=e.C("#","$"),e.NM={cN:"number",b:e.NR,r:0},e.CNM={cN:"number",b:e.CNR,r:0},e.BNM={cN:"number",b:e.BNR,r:0},e.CSSNM={cN:"number",b:e.NR+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",r:0},e.RM={cN:"regexp",b:/\//,e:/\/[gimuy]*/,i:/\n/,c:[e.BE,{b:/\[/,e:/\]/,r:0,c:[e.BE]}]},e.TM={cN:"title",b:e.IR,r:0},e.UTM={cN:"title",b:e.UIR,r:0},e.METHOD_GUARD={b:"\\.\\s*"+e.UIR,r:0},e.registerLanguage("apache",function(e){var t={cN:"number",b:"[\\$%]\\d+"};return{aliases:["apacheconf"],cI:!0,c:[e.HCM,{cN:"section",b:"</?",e:">"},{cN:"attribute",b:/\w+/,r:0,k:{nomarkup:"order deny allow setenv rewriterule rewriteengine rewritecond documentroot sethandler errordocument loadmodule options header listen serverroot servername"},starts:{e:/$/,r:0,k:{literal:"on off all"},c:[{cN:"meta",b:"\\s\\[",e:"\\]$"},{cN:"variable",b:"[\\$%]\\{",e:"\\}",c:["self",t]},t,e.QSM]}}],i:/\S/}}),e.registerLanguage("bash",function(e){var t={cN:"variable",v:[{b:/\$[\w\d#@][\w\d_]*/},{b:/\$\{(.*?)}/}]},r={cN:"string",b:/"/,e:/"/,c:[e.BE,t,{cN:"variable",b:/\$\(/,e:/\)/,c:[e.BE]}]},a={cN:"string",b:/'/,e:/'/};return{aliases:["sh","zsh"],l:/\b-?[a-z\._]+\b/,k:{keyword:"if then else elif fi for while in do done case esac function",literal:"true false",built_in:"break cd continue eval exec exit export getopts hash pwd readonly return shift test times trap umask unset alias bind builtin caller command declare echo enable help let local logout mapfile printf read readarray source type typeset ulimit unalias set shopt autoload bg bindkey bye cap chdir clone comparguments compcall compctl compdescribe compfiles compgroups compquote comptags comptry compvalues dirs disable disown echotc echoti emulate fc fg float functions getcap getln history integer jobs kill limit log noglob popd print pushd pushln rehash sched setcap setopt stat suspend ttyctl unfunction unhash unlimit unsetopt vared wait whence where which zcompile zformat zftp zle zmodload zparseopts zprof zpty zregexparse zsocket zstyle ztcp",_:"-ne -eq -lt -gt -f -d -e -s -l -a"},c:[{cN:"meta",b:/^#![^\n]+sh\s*$/,r:10},{cN:"function",b:/\w[\w\d_]*\s*\(\s*\)\s*\{/,rB:!0,c:[e.inherit(e.TM,{b:/\w[\w\d_]*/})],r:0},e.HCM,r,a,t]}}),e.registerLanguage("coffeescript",function(e){var t={keyword:"in if for while finally new do return else break catch instanceof throw try this switch continue typeof delete debugger super yield import export from as default await then unless until loop of by when and or is isnt not",literal:"true false null undefined yes no on off",built_in:"npm require console print module global window document"},r="[A-Za-z$_][0-9A-Za-z$_]*",a={cN:"subst",b:/#\{/,e:/}/,k:t},n=[e.BNM,e.inherit(e.CNM,{starts:{e:"(\\s*/)?",r:0}}),{cN:"string",v:[{b:/'''/,e:/'''/,c:[e.BE]},{b:/'/,e:/'/,c:[e.BE]},{b:/"""/,e:/"""/,c:[e.BE,a]},{b:/"/,e:/"/,c:[e.BE,a]}]},{cN:"regexp",v:[{b:"///",e:"///",c:[a,e.HCM]},{b:"//[gim]*",r:0},{b:/\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/}]},{b:"@"+r},{sL:"javascript",eB:!0,eE:!0,v:[{b:"```",e:"```"},{b:"`",e:"`"}]}];a.c=n;var i=e.inherit(e.TM,{b:r}),s="(\\(.*\\))?\\s*\\B[-=]>",c={cN:"params",b:"\\([^\\(]",rB:!0,c:[{b:/\(/,e:/\)/,k:t,c:["self"].concat(n)}]};return{aliases:["coffee","cson","iced"],k:t,i:/\/\*/,c:n.concat([e.C("###","###"),e.HCM,{cN:"function",b:"^\\s*"+r+"\\s*=\\s*"+s,e:"[-=]>",rB:!0,c:[i,c]},{b:/[:\(,=]\s*/,r:0,c:[{cN:"function",b:s,e:"[-=]>",rB:!0,c:[c]}]},{cN:"class",bK:"class",e:"$",i:/[:="\[\]]/,c:[{bK:"extends",eW:!0,i:/[:="\[\]]/,c:[i]},i]},{b:r+":",e:":",rB:!0,rE:!0,r:0}])}}),e.registerLanguage("cpp",function(e){var t={cN:"keyword",b:"\\b[a-z\\d_]*_t\\b"},r={cN:"string",v:[{b:'(u8?|U)?L?"',e:'"',i:"\\n",c:[e.BE]},{b:'(u8?|U)?R"',e:'"',c:[e.BE]},{b:"'\\\\?.",e:"'",i:"."}]},a={cN:"number",v:[{b:"\\b(0b[01']+)"},{b:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{b:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],r:0},n={cN:"meta",b:/#\s*[a-z]+\b/,e:/$/,k:{"meta-keyword":"if else elif endif define undef warning error line pragma ifdef ifndef include"},c:[{b:/\\\n/,r:0},e.inherit(r,{cN:"meta-string"}),{cN:"meta-string",b:/<[^\n>]*>/,e:/$/,i:"\\n"},e.CLCM,e.CBCM]},i=e.IR+"\\s*\\(",s={keyword:"int float while private char catch import module export virtual operator sizeof dynamic_cast|10 typedef const_cast|10 const for static_cast|10 union namespace unsigned long volatile static protected bool template mutable if public friend do goto auto void enum else break extern using asm case typeid short reinterpret_cast|10 default double register explicit signed typename try this switch continue inline delete alignof constexpr decltype noexcept static_assert thread_local restrict _Bool complex _Complex _Imaginary atomic_bool atomic_char atomic_schar atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong atomic_ullong new throw return and or not",built_in:"std string cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap array shared_ptr abort abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr",literal:"true false nullptr NULL"},c=[t,e.CLCM,e.CBCM,a,r];return{aliases:["c","cc","h","c++","h++","hpp"],k:s,i:"</",c:c.concat([n,{b:"\\b(deque|list|queue|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<",e:">",k:s,c:["self",t]},{b:e.IR+"::",k:s},{v:[{b:/=/,e:/;/},{b:/\(/,e:/\)/},{bK:"new throw return else",e:/;/}],k:s,c:c.concat([{b:/\(/,e:/\)/,k:s,c:c.concat(["self"]),r:0}]),r:0},{cN:"function",b:"("+e.IR+"[\\*&\\s]+)+"+i,rB:!0,e:/[{;=]/,eE:!0,k:s,i:/[^\w\s\*&]/,c:[{b:i,rB:!0,c:[e.TM],r:0},{cN:"params",b:/\(/,e:/\)/,k:s,r:0,c:[e.CLCM,e.CBCM,r,a,t]},e.CLCM,e.CBCM,n]},{cN:"class",bK:"class struct",e:/[{;:]/,c:[{b:/</,e:/>/,c:["self"]},e.TM]}]),exports:{preprocessor:n,strings:r,k:s}}}),e.registerLanguage("cs",function(e){var t={keyword:"abstract as base bool break byte case catch char checked const continue decimal default delegate do double enum event explicit extern finally fixed float for foreach goto if implicit in int interface internal is lock long nameof object operator out override params private protected public readonly ref sbyte sealed short sizeof stackalloc static string struct switch this try typeof uint ulong unchecked unsafe ushort using virtual void volatile while add alias ascending async await by descending dynamic equals from get global group into join let on orderby partial remove select set value var where yield",literal:"null false true"},r={cN:"string",b:'@"',e:'"',c:[{b:'""'}]},a=e.inherit(r,{i:/\n/}),n={cN:"subst",b:"{",e:"}",k:t},i=e.inherit(n,{i:/\n/}),s={cN:"string",b:/\$"/,e:'"',i:/\n/,c:[{b:"{{"},{b:"}}"},e.BE,i]},c={cN:"string",b:/\$@"/,e:'"',c:[{b:"{{"},{b:"}}"},{b:'""'},n]},o=e.inherit(c,{i:/\n/,c:[{b:"{{"},{b:"}}"},{b:'""'},i]});n.c=[c,s,r,e.ASM,e.QSM,e.CNM,e.CBCM],i.c=[o,s,a,e.ASM,e.QSM,e.CNM,e.inherit(e.CBCM,{i:/\n/})];var l={v:[c,s,r,e.ASM,e.QSM]},u=e.IR+"(<"+e.IR+"(\\s*,\\s*"+e.IR+")*>)?(\\[\\])?";return{aliases:["csharp"],k:t,i:/::/,c:[e.C("///","$",{rB:!0,c:[{cN:"doctag",v:[{b:"///",r:0},{b:"<!--|-->"},{b:"</?",e:">"}]}]}),e.CLCM,e.CBCM,{cN:"meta",b:"#",e:"$",k:{"meta-keyword":"if else elif endif define undef warning error line region endregion pragma checksum"}},l,e.CNM,{bK:"class interface",e:/[{;=]/,i:/[^\s:]/,c:[e.TM,e.CLCM,e.CBCM]},{bK:"namespace",e:/[{;=]/,i:/[^\s:]/,c:[e.inherit(e.TM,{b:"[a-zA-Z](\\.?\\w)*"}),e.CLCM,e.CBCM]},{cN:"meta",b:"^\\s*\\[",eB:!0,e:"\\]",eE:!0,c:[{cN:"meta-string",b:/"/,e:/"/}]},{bK:"new return throw await else",r:0},{cN:"function",b:"("+u+"\\s+)+"+e.IR+"\\s*\\(",rB:!0,e:/[{;=]/,eE:!0,k:t,c:[{b:e.IR+"\\s*\\(",rB:!0,c:[e.TM],r:0},{cN:"params",b:/\(/,e:/\)/,eB:!0,eE:!0,k:t,r:0,c:[l,e.CNM,e.CBCM]},e.CLCM,e.CBCM]}]}}),e.registerLanguage("css",function(e){var t="[a-zA-Z-][a-zA-Z0-9_-]*",r={b:/[A-Z\_\.\-]+\s*:/,rB:!0,e:";",eW:!0,c:[{cN:"attribute",b:/\S/,e:":",eE:!0,starts:{eW:!0,eE:!0,c:[{b:/[\w-]+\(/,rB:!0,c:[{cN:"built_in",b:/[\w-]+/},{b:/\(/,e:/\)/,c:[e.ASM,e.QSM]}]},e.CSSNM,e.QSM,e.ASM,e.CBCM,{cN:"number",b:"#[0-9A-Fa-f]+"},{cN:"meta",b:"!important"}]}}]};return{cI:!0,i:/[=\/|'\$]/,c:[e.CBCM,{cN:"selector-id",b:/#[A-Za-z0-9_-]+/},{cN:"selector-class",b:/\.[A-Za-z0-9_-]+/},{cN:"selector-attr",b:/\[/,e:/\]/,i:"$"},{cN:"selector-pseudo",b:/:(:)?[a-zA-Z0-9\_\-\+\(\)"'.]+/},{b:"@(font-face|page)",l:"[a-z-]+",k:"font-face page"},{b:"@",e:"[{;]",i:/:/,c:[{cN:"keyword",b:/\w+/},{b:/\s/,eW:!0,eE:!0,r:0,c:[e.ASM,e.QSM,e.CSSNM]}]},{cN:"selector-tag",b:t,r:0},{b:"{",e:"}",i:/\S/,c:[e.CBCM,r]}]}}),e.registerLanguage("diff",function(e){return{aliases:["patch"],c:[{cN:"meta",r:10,v:[{b:/^@@ +\-\d+,\d+ +\+\d+,\d+ +@@$/},{b:/^\*\*\* +\d+,\d+ +\*\*\*\*$/},{b:/^\-\-\- +\d+,\d+ +\-\-\-\-$/}]},{cN:"comment",v:[{b:/Index: /,e:/$/},{b:/={3,}/,e:/$/},{b:/^\-{3}/,e:/$/},{b:/^\*{3} /,e:/$/},{b:/^\+{3}/,e:/$/},{b:/\*{5}/,e:/\*{5}$/}]},{cN:"addition",b:"^\\+",e:"$"},{cN:"deletion",b:"^\\-",e:"$"},{cN:"addition",b:"^\\!",e:"$"}]}}),e.registerLanguage("http",function(e){var t="HTTP/[0-9\\.]+";return{aliases:["https"],i:"\\S",c:[{b:"^"+t,e:"$",c:[{cN:"number",b:"\\b\\d{3}\\b"}]},{b:"^[A-Z]+ (.*?) "+t+"$",rB:!0,e:"$",c:[{cN:"string",b:" ",e:" ",eB:!0,eE:!0},{b:t},{cN:"keyword",b:"[A-Z]+"}]},{cN:"attribute",b:"^\\w",e:": ",eE:!0,i:"\\n|\\s|=",starts:{e:"$",r:0}},{b:"\\n\\n",starts:{sL:[],eW:!0}}]}}),e.registerLanguage("ini",function(e){var t={cN:"string",c:[e.BE],v:[{b:"'''",e:"'''",r:10},{b:'"""',e:'"""',r:10},{b:'"',e:'"'},{b:"'",e:"'"}]};return{aliases:["toml"],cI:!0,i:/\S/,c:[e.C(";","$"),e.HCM,{cN:"section",b:/^\s*\[+/,e:/\]+/},{b:/^[a-z0-9\[\]_-]+\s*=\s*/,e:"$",rB:!0,c:[{cN:"attr",b:/[a-z0-9\[\]_-]+/},{b:/=/,eW:!0,r:0,c:[{cN:"literal",b:/\bon|off|true|false|yes|no\b/},{cN:"variable",v:[{b:/\$[\w\d"][\w\d_]*/},{b:/\$\{(.*?)}/}]},t,{cN:"number",b:/([\+\-]+)?[\d]+_[\d_]+/},e.NM]}]}]}}),e.registerLanguage("java",function(e){var t="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",r=t+"(<"+t+"(\\s*,\\s*"+t+")*>)?",a="false synchronized int abstract float private char boolean static null if const for true while long strictfp finally protected import native final void enum else break transient catch instanceof byte super volatile case assert short package default double public try this switch continue throws protected public private module requires exports do",n="\\b(0[bB]([01]+[01_]+[01]+|[01]+)|0[xX]([a-fA-F0-9]+[a-fA-F0-9_]+[a-fA-F0-9]+|[a-fA-F0-9]+)|(([\\d]+[\\d_]+[\\d]+|[\\d]+)(\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))?|\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))([eE][-+]?\\d+)?)[lLfF]?",i={cN:"number",b:n,r:0};return{aliases:["jsp"],k:a,i:/<\/|#/,c:[e.C("/\\*\\*","\\*/",{r:0,c:[{b:/\w+@/,r:0},{cN:"doctag",b:"@[A-Za-z]+"}]}),e.CLCM,e.CBCM,e.ASM,e.QSM,{cN:"class",bK:"class interface",e:/[{;=]/,eE:!0,k:"class interface",i:/[:"\[\]]/,c:[{bK:"extends implements"},e.UTM]},{bK:"new throw return else",r:0},{cN:"function",b:"("+r+"\\s+)+"+e.UIR+"\\s*\\(",rB:!0,e:/[{;=]/,eE:!0,k:a,c:[{b:e.UIR+"\\s*\\(",rB:!0,r:0,c:[e.UTM]},{cN:"params",b:/\(/,e:/\)/,k:a,r:0,c:[e.ASM,e.QSM,e.CNM,e.CBCM]},e.CLCM,e.CBCM]},i,{cN:"meta",b:"@[A-Za-z]+"}]}}),e.registerLanguage("javascript",function(e){var t="[A-Za-z$_][0-9A-Za-z$_]*",r={keyword:"in of if for while finally var new function do return void else break catch instanceof with throw case default try this switch continue typeof delete let yield const export super debugger as async await static import from as",literal:"true false null undefined NaN Infinity",built_in:"eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent encodeURI encodeURIComponent escape unescape Object Function Boolean Error EvalError InternalError RangeError ReferenceError StopIteration SyntaxError TypeError URIError Number Math Date String RegExp Array Float32Array Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require module console window document Symbol Set Map WeakSet WeakMap Proxy Reflect Promise"},a={cN:"number",v:[{b:"\\b(0[bB][01]+)"},{b:"\\b(0[oO][0-7]+)"},{b:e.CNR}],r:0},n={cN:"subst",b:"\\$\\{",e:"\\}",k:r,c:[]},i={cN:"string",b:"`",e:"`",c:[e.BE,n]};n.c=[e.ASM,e.QSM,i,a,e.RM];var s=n.c.concat([e.CBCM,e.CLCM]);return{aliases:["js","jsx"],k:r,c:[{cN:"meta",r:10,b:/^\s*['"]use (strict|asm)['"]/},{cN:"meta",b:/^#!/,e:/$/},e.ASM,e.QSM,i,e.CLCM,e.CBCM,a,{b:/[{,]\s*/,r:0,c:[{b:t+"\\s*:",rB:!0,r:0,c:[{cN:"attr",b:t,r:0}]}]},{b:"("+e.RSR+"|\\b(case|return|throw)\\b)\\s*",k:"return throw case",c:[e.CLCM,e.CBCM,e.RM,{cN:"function",b:"(\\(.*?\\)|"+t+")\\s*=>",rB:!0,e:"\\s*=>",c:[{cN:"params",v:[{b:t},{b:/\(\s*\)/},{b:/\(/,e:/\)/,eB:!0,eE:!0,k:r,c:s}]}]},{b:/</,e:/(\/\w+|\w+\/)>/,sL:"xml",c:[{b:/<\w+\s*\/>/,skip:!0},{b:/<\w+/,e:/(\/\w+|\w+\/)>/,skip:!0,c:[{b:/<\w+\s*\/>/,skip:!0},"self"]}]}],r:0},{cN:"function",bK:"function",e:/\{/,eE:!0,c:[e.inherit(e.TM,{b:t}),{cN:"params",b:/\(/,e:/\)/,eB:!0,eE:!0,c:s}],i:/\[|%/},{b:/\$[(.]/},e.METHOD_GUARD,{cN:"class",bK:"class",e:/[{;=]/,eE:!0,i:/[:"\[\]]/,c:[{bK:"extends"},e.UTM]},{bK:"constructor",e:/\{/,eE:!0}],i:/#(?!!)/}}),e.registerLanguage("json",function(e){var t={literal:"true false null"},r=[e.QSM,e.CNM],a={e:",",eW:!0,eE:!0,c:r,k:t},n={b:"{",e:"}",c:[{cN:"attr",b:/"/,e:/"/,c:[e.BE],i:"\\n"},e.inherit(a,{b:/:/})],i:"\\S"},i={b:"\\[",e:"\\]",c:[e.inherit(a)],i:"\\S"};return r.splice(r.length,0,n,i),{c:r,k:t,i:"\\S"}}),e.registerLanguage("makefile",function(e){var t={cN:"variable",v:[{b:"\\$\\("+e.UIR+"\\)",c:[e.BE]},{b:/\$[@%<?\^\+\*]/}]},r={cN:"string",b:/"/,e:/"/,c:[e.BE,t]},a={cN:"variable",b:/\$\([\w-]+\s/,e:/\)/,k:{built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"},c:[t]},n={b:"^"+e.UIR+"\\s*[:+?]?=",i:"\\n",rB:!0,c:[{b:"^"+e.UIR,e:"[:+?]?=",eE:!0}]},i={cN:"meta",b:/^\.PHONY:/,e:/$/,k:{"meta-keyword":".PHONY"},l:/[\.\w]+/},s={cN:"section",b:/^[^\s]+:/,e:/$/,c:[t]};return{aliases:["mk","mak"],k:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath",l:/[\w-]+/,c:[e.HCM,t,r,a,n,i,s]}}),e.registerLanguage("xml",function(e){var t="[A-Za-z0-9\\._:-]+",r={eW:!0,i:/</,r:0,c:[{cN:"attr",b:t,r:0},{b:/=\s*/,r:0,c:[{cN:"string",endsParent:!0,v:[{b:/"/,e:/"/},{b:/'/,e:/'/},{b:/[^\s"'=<>`]+/}]}]}]};return{aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist"],cI:!0,c:[{cN:"meta",b:"<!DOCTYPE",e:">",r:10,c:[{b:"\\[",e:"\\]"}]},e.C("<!--","-->",{r:10}),{b:"<\\!\\[CDATA\\[",e:"\\]\\]>",r:10},{b:/<\?(php)?/,e:/\?>/,sL:"php",c:[{b:"/\\*",e:"\\*/",skip:!0}]},{cN:"tag",b:"<style(?=\\s|>|$)",e:">",k:{name:"style"},c:[r],starts:{e:"</style>",rE:!0,sL:["css","xml"]}},{cN:"tag",b:"<script(?=\\s|>|$)",e:">",k:{name:"script"},c:[r],starts:{e:"</script>",rE:!0,sL:["actionscript","javascript","handlebars","xml"]}},{cN:"meta",v:[{b:/<\?xml/,e:/\?>/,r:10},{b:/<\?\w+/,e:/\?>/}]},{cN:"tag",b:"</?",e:"/?>",c:[{cN:"name",b:/[^\/><\s]+/,r:0},r]}]}}),e.registerLanguage("markdown",function(e){return{aliases:["md","mkdown","mkd"],c:[{cN:"section",v:[{b:"^#{1,6}",e:"$"},{b:"^.+?\\n[=-]{2,}$"}]},{b:"<",e:">",sL:"xml",r:0},{cN:"bullet",b:"^([*+-]|(\\d+\\.))\\s+"},{cN:"strong",b:"[*_]{2}.+?[*_]{2}"},{cN:"emphasis",v:[{b:"\\*.+?\\*"},{b:"_.+?_",r:0}]},{cN:"quote",b:"^>\\s+",e:"$"},{cN:"code",v:[{b:"^```w*s*$",e:"^```s*$"},{b:"`.+?`"},{b:"^( {4}|	)",e:"$",r:0}]},{b:"^[-\\*]{3,}",e:"$"},{b:"\\[.+?\\][\\(\\[].*?[\\)\\]]",rB:!0,c:[{cN:"string",b:"\\[",e:"\\]",eB:!0,rE:!0,r:0},{cN:"link",b:"\\]\\(",e:"\\)",eB:!0,eE:!0},{cN:"symbol",b:"\\]\\[",e:"\\]",eB:!0,eE:!0}],r:10},{b:/^\[[^\n]+\]:/,rB:!0,c:[{cN:"symbol",b:/\[/,e:/\]/,eB:!0,eE:!0},{cN:"link",b:/:\s*/,e:/$/,eB:!0}]}]}}),e.registerLanguage("nginx",function(e){var t={cN:"variable",v:[{b:/\$\d+/},{b:/\$\{/,e:/}/},{b:"[\\$\\@]"+e.UIR}]},r={eW:!0,l:"[a-z/_]+",k:{literal:"on off yes no true false none blocked debug info notice warn error crit select break last permanent redirect kqueue rtsig epoll poll /dev/poll"},r:0,i:"=>",c:[e.HCM,{cN:"string",c:[e.BE,t],v:[{b:/"/,e:/"/},{b:/'/,e:/'/}]},{b:"([a-z]+):/",e:"\\s",eW:!0,eE:!0,c:[t]},{cN:"regexp",c:[e.BE,t],v:[{b:"\\s\\^",e:"\\s|{|;",rE:!0},{b:"~\\*?\\s+",e:"\\s|{|;",rE:!0},{b:"\\*(\\.[a-z\\-]+)+"},{b:"([a-z\\-]+\\.)+\\*"}]},{cN:"number",b:"\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b"},{cN:"number",b:"\\b\\d+[kKmMgGdshdwy]*\\b",r:0},t]};return{aliases:["nginxconf"],c:[e.HCM,{b:e.UIR+"\\s+{",rB:!0,e:"{",c:[{cN:"section",b:e.UIR}],r:0},{b:e.UIR+"\\s",e:";|{",rB:!0,c:[{cN:"attribute",b:e.UIR,starts:r}],r:0}],i:"[^\\s\\}]"}}),e.registerLanguage("objectivec",function(e){var t={cN:"built_in",b:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"},r={keyword:"int float while char export sizeof typedef const struct for union unsigned long volatile static bool mutable if do return goto void enum else break extern asm case short default double register explicit signed typename this switch continue wchar_t inline readonly assign readwrite self @synchronized id typeof nonatomic super unichar IBOutlet IBAction strong weak copy in out inout bycopy byref oneway __strong __weak __block __autoreleasing @private @protected @public @try @property @end @throw @catch @finally @autoreleasepool @synthesize @dynamic @selector @optional @required @encode @package @import @defs @compatibility_alias __bridge __bridge_transfer __bridge_retained __bridge_retain __covariant __contravariant __kindof _Nonnull _Nullable _Null_unspecified __FUNCTION__ __PRETTY_FUNCTION__ __attribute__ getter setter retain unsafe_unretained nonnull nullable null_unspecified null_resettable class instancetype NS_DESIGNATED_INITIALIZER NS_UNAVAILABLE NS_REQUIRES_SUPER NS_RETURNS_INNER_POINTER NS_INLINE NS_AVAILABLE NS_DEPRECATED NS_ENUM NS_OPTIONS NS_SWIFT_UNAVAILABLE NS_ASSUME_NONNULL_BEGIN NS_ASSUME_NONNULL_END NS_REFINED_FOR_SWIFT NS_SWIFT_NAME NS_SWIFT_NOTHROW NS_DURING NS_HANDLER NS_ENDHANDLER NS_VALUERETURN NS_VOIDRETURN",literal:"false true FALSE TRUE nil YES NO NULL",built_in:"BOOL dispatch_once_t dispatch_queue_t dispatch_sync dispatch_async dispatch_once"},a=/[a-zA-Z@][a-zA-Z0-9_]*/,n="@interface @class @protocol @implementation";return{aliases:["mm","objc","obj-c"],k:r,l:a,i:"</",c:[t,e.CLCM,e.CBCM,e.CNM,e.QSM,{cN:"string",v:[{b:'@"',e:'"',i:"\\n",c:[e.BE]},{b:"'",e:"[^\\\\]'",i:"[^\\\\][^']"}]},{cN:"meta",b:"#",e:"$",c:[{cN:"meta-string",v:[{b:'"',e:'"'},{b:"<",e:">"}]}]},{cN:"class",b:"("+n.split(" ").join("|")+")\\b",e:"({|$)",eE:!0,k:n,l:a,c:[e.UTM]},{b:"\\."+e.UIR,r:0}]}}),e.registerLanguage("perl",function(e){var t="getpwent getservent quotemeta msgrcv scalar kill dbmclose undef lc ma syswrite tr send umask sysopen shmwrite vec qx utime local oct semctl localtime readpipe do return format read sprintf dbmopen pop getpgrp not getpwnam rewinddir qqfileno qw endprotoent wait sethostent bless s|0 opendir continue each sleep endgrent shutdown dump chomp connect getsockname die socketpair close flock exists index shmgetsub for endpwent redo lstat msgctl setpgrp abs exit select print ref gethostbyaddr unshift fcntl syscall goto getnetbyaddr join gmtime symlink semget splice x|0 getpeername recv log setsockopt cos last reverse gethostbyname getgrnam study formline endhostent times chop length gethostent getnetent pack getprotoent getservbyname rand mkdir pos chmod y|0 substr endnetent printf next open msgsnd readdir use unlink getsockopt getpriority rindex wantarray hex system getservbyport endservent int chr untie rmdir prototype tell listen fork shmread ucfirst setprotoent else sysseek link getgrgid shmctl waitpid unpack getnetbyname reset chdir grep split require caller lcfirst until warn while values shift telldir getpwuid my getprotobynumber delete and sort uc defined srand accept package seekdir getprotobyname semop our rename seek if q|0 chroot sysread setpwent no crypt getc chown sqrt write setnetent setpriority foreach tie sin msgget map stat getlogin unless elsif truncate exec keys glob tied closedirioctl socket readlink eval xor readline binmode setservent eof ord bind alarm pipe atan2 getgrent exp time push setgrent gt lt or ne m|0 break given say state when",r={cN:"subst",b:"[$@]\\{",e:"\\}",k:t},a={b:"->{",e:"}"},n={v:[{b:/\$\d/},{b:/[\$%@](\^\w\b|#\w+(::\w+)*|{\w+}|\w+(::\w*)*)/},{b:/[\$%@][^\s\w{]/,r:0}]},i=[e.BE,r,n],s=[n,e.HCM,e.C("^\\=\\w","\\=cut",{eW:!0}),a,{cN:"string",c:i,v:[{b:"q[qwxr]?\\s*\\(",e:"\\)",r:5},{b:"q[qwxr]?\\s*\\[",e:"\\]",r:5},{b:"q[qwxr]?\\s*\\{",e:"\\}",r:5},{b:"q[qwxr]?\\s*\\|",e:"\\|",r:5},{b:"q[qwxr]?\\s*\\<",e:"\\>",r:5},{b:"qw\\s+q",e:"q",r:5},{b:"'",e:"'",c:[e.BE]},{b:'"',e:'"'},{b:"`",e:"`",c:[e.BE]},{b:"{\\w+}",c:[],r:0},{b:"-?\\w+\\s*\\=\\>",c:[],r:0}]},{cN:"number",b:"(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",r:0},{b:"(\\/\\/|"+e.RSR+"|\\b(split|return|print|reverse|grep)\\b)\\s*",k:"split return print reverse grep",r:0,c:[e.HCM,{cN:"regexp",b:"(s|tr|y)/(\\\\.|[^/])*/(\\\\.|[^/])*/[a-z]*",r:10},{cN:"regexp",b:"(m|qr)?/",e:"/[a-z]*",c:[e.BE],r:0}]},{cN:"function",bK:"sub",e:"(\\s*\\(.*?\\))?[;{]",eE:!0,r:5,c:[e.TM]},{b:"-\\w\\b",r:0},{b:"^__DATA__$",e:"^__END__$",sL:"mojolicious",c:[{b:"^@@.*",e:"$",cN:"comment"}]}];return r.c=s,a.c=s,{aliases:["pl","pm"],l:/[\w\.]+/,k:t,c:s}}),e.registerLanguage("php",function(e){var t={b:"\\$+[a-zA-Z_-ÿ][a-zA-Z0-9_-ÿ]*"},r={cN:"meta",b:/<\?(php)?|\?>/},a={cN:"string",c:[e.BE,r],v:[{b:'b"',e:'"'},{b:"b'",e:"'"},e.inherit(e.ASM,{i:null}),e.inherit(e.QSM,{i:null})]},n={v:[e.BNM,e.CNM]};return{aliases:["php3","php4","php5","php6"],cI:!0,k:"and include_once list abstract global private echo interface as static endswitch array null if endwhile or const for endforeach self var while isset public protected exit foreach throw elseif include __FILE__ empty require_once do xor return parent clone use __CLASS__ __LINE__ else break print eval new catch __METHOD__ case exception default die require __FUNCTION__ enddeclare final try switch continue endfor endif declare unset true false trait goto instanceof insteadof __DIR__ __NAMESPACE__ yield finally",c:[e.HCM,e.C("//","$",{c:[r]}),e.C("/\\*","\\*/",{c:[{cN:"doctag",b:"@[A-Za-z]+"}]}),e.C("__halt_compiler.+?;",!1,{eW:!0,k:"__halt_compiler",l:e.UIR}),{cN:"string",b:/<<<['"]?\w+['"]?$/,e:/^\w+;?$/,c:[e.BE,{cN:"subst",v:[{b:/\$\w+/},{b:/\{\$/,e:/\}/}]}]},r,{cN:"keyword",b:/\$this\b/},t,{b:/(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/},{cN:"function",bK:"function",e:/[;{]/,eE:!0,i:"\\$|\\[|%",c:[e.UTM,{cN:"params",b:"\\(",e:"\\)",c:["self",t,e.CBCM,a,n]}]},{cN:"class",bK:"class interface",e:"{",eE:!0,i:/[:\(\$"]/,c:[{bK:"extends implements"},e.UTM]},{bK:"namespace",e:";",i:/[\.']/,c:[e.UTM]},{bK:"use",e:";",c:[e.UTM]},{b:"=>"},a,n]}}),e.registerLanguage("python",function(e){var t={keyword:"and elif is global as in if from raise for except finally print import pass return exec else break not with class assert yield try while continue del or def lambda async await nonlocal|10 None True False",built_in:"Ellipsis NotImplemented"},r={cN:"meta",b:/^(>>>|\.\.\.) /},a={cN:"subst",b:/\{/,e:/\}/,k:t,i:/#/},n={cN:"string",c:[e.BE],v:[{b:/(u|b)?r?'''/,e:/'''/,c:[r],r:10},{b:/(u|b)?r?"""/,e:/"""/,c:[r],r:10},{b:/(fr|rf|f)'''/,e:/'''/,c:[r,a]},{b:/(fr|rf|f)"""/,e:/"""/,c:[r,a]},{b:/(u|r|ur)'/,e:/'/,r:10},{b:/(u|r|ur)"/,e:/"/,r:10},{b:/(b|br)'/,e:/'/},{b:/(b|br)"/,e:/"/},{b:/(fr|rf|f)'/,e:/'/,c:[a]},{b:/(fr|rf|f)"/,e:/"/,c:[a]},e.ASM,e.QSM]},i={cN:"number",r:0,v:[{b:e.BNR+"[lLjJ]?"},{b:"\\b(0o[0-7]+)[lLjJ]?"},{b:e.CNR+"[lLjJ]?"}]},s={cN:"params",b:/\(/,e:/\)/,c:["self",r,i,n]};return a.c=[n,i,r],{aliases:["py","gyp"],k:t,i:/(<\/|->|\?)|=>/,c:[r,i,n,e.HCM,{v:[{cN:"function",bK:"def"},{cN:"class",bK:"class"}],e:/:/,i:/[${=;\n,]/,c:[e.UTM,s,{b:/->/,eW:!0,k:"None"}]},{cN:"meta",b:/^[\t ]*@/,e:/$/},{b:/\b(print|exec)\(/}]}}),e.registerLanguage("ruby",function(e){
var t="[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?",r={keyword:"and then defined module in return redo if BEGIN retry end for self when next until do begin unless END rescue else break undef not super class case require yield alias while ensure elsif or include attr_reader attr_writer attr_accessor",literal:"true false nil"},a={cN:"doctag",b:"@[A-Za-z]+"},n={b:"#<",e:">"},i=[e.C("#","$",{c:[a]}),e.C("^\\=begin","^\\=end",{c:[a],r:10}),e.C("^__END__","\\n$")],s={cN:"subst",b:"#\\{",e:"}",k:r},c={cN:"string",c:[e.BE,s],v:[{b:/'/,e:/'/},{b:/"/,e:/"/},{b:/`/,e:/`/},{b:"%[qQwWx]?\\(",e:"\\)"},{b:"%[qQwWx]?\\[",e:"\\]"},{b:"%[qQwWx]?{",e:"}"},{b:"%[qQwWx]?<",e:">"},{b:"%[qQwWx]?/",e:"/"},{b:"%[qQwWx]?%",e:"%"},{b:"%[qQwWx]?-",e:"-"},{b:"%[qQwWx]?\\|",e:"\\|"},{b:/\B\?(\\\d{1,3}|\\x[A-Fa-f0-9]{1,2}|\\u[A-Fa-f0-9]{4}|\\?\S)\b/},{b:/<<(-?)\w+$/,e:/^\s*\w+$/}]},o={cN:"params",b:"\\(",e:"\\)",endsParent:!0,k:r},l=[c,n,{cN:"class",bK:"class module",e:"$|;",i:/=/,c:[e.inherit(e.TM,{b:"[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?"}),{b:"<\\s*",c:[{b:"("+e.IR+"::)?"+e.IR}]}].concat(i)},{cN:"function",bK:"def",e:"$|;",c:[e.inherit(e.TM,{b:t}),o].concat(i)},{b:e.IR+"::"},{cN:"symbol",b:e.UIR+"(\\!|\\?)?:",r:0},{cN:"symbol",b:":(?!\\s)",c:[c,{b:t}],r:0},{cN:"number",b:"(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",r:0},{b:"(\\$\\W)|((\\$|\\@\\@?)(\\w+))"},{cN:"params",b:/\|/,e:/\|/,k:r},{b:"("+e.RSR+"|unless)\\s*",k:"unless",c:[n,{cN:"regexp",c:[e.BE,s],i:/\n/,v:[{b:"/",e:"/[a-z]*"},{b:"%r{",e:"}[a-z]*"},{b:"%r\\(",e:"\\)[a-z]*"},{b:"%r!",e:"![a-z]*"},{b:"%r\\[",e:"\\][a-z]*"}]}].concat(i),r:0}].concat(i);s.c=l,o.c=l;var u="[>?]>",d="[\\w#]+\\(\\w+\\):\\d+:\\d+>",b="(\\w+-)?\\d+\\.\\d+\\.\\d(p\\d+)?[^>]+>",p=[{b:/^\s*=>/,starts:{e:"$",c:l}},{cN:"meta",b:"^("+u+"|"+d+"|"+b+")",starts:{e:"$",c:l}}];return{aliases:["rb","gemspec","podspec","thor","irb"],k:r,i:/\/\*/,c:i.concat(p).concat(l)}}),e.registerLanguage("shell",function(e){return{aliases:["console"],c:[{cN:"meta",b:"^\\s{0,3}[\\w\\d\\[\\]()@-]*[>%$#]",starts:{e:"$",sL:"bash"}}]}}),e.registerLanguage("sql",function(e){var t=e.C("--","$");return{cI:!0,i:/[<>{}*#]/,c:[{bK:"begin end start commit rollback savepoint lock alter create drop rename call delete do handler insert load replace select truncate update set show pragma grant merge describe use explain help declare prepare execute deallocate release unlock purge reset change stop analyze cache flush optimize repair kill install uninstall checksum restore check backup revoke comment",e:/;/,eW:!0,l:/[\w\.]+/,k:{keyword:"abort abs absolute acc acce accep accept access accessed accessible account acos action activate add addtime admin administer advanced advise aes_decrypt aes_encrypt after agent aggregate ali alia alias allocate allow alter always analyze ancillary and any anydata anydataset anyschema anytype apply archive archived archivelog are as asc ascii asin assembly assertion associate asynchronous at atan atn2 attr attri attrib attribu attribut attribute attributes audit authenticated authentication authid authors auto autoallocate autodblink autoextend automatic availability avg backup badfile basicfile before begin beginning benchmark between bfile bfile_base big bigfile bin binary_double binary_float binlog bit_and bit_count bit_length bit_or bit_xor bitmap blob_base block blocksize body both bound buffer_cache buffer_pool build bulk by byte byteordermark bytes cache caching call calling cancel capacity cascade cascaded case cast catalog category ceil ceiling chain change changed char_base char_length character_length characters characterset charindex charset charsetform charsetid check checksum checksum_agg child choose chr chunk class cleanup clear client clob clob_base clone close cluster_id cluster_probability cluster_set clustering coalesce coercibility col collate collation collect colu colum column column_value columns columns_updated comment commit compact compatibility compiled complete composite_limit compound compress compute concat concat_ws concurrent confirm conn connec connect connect_by_iscycle connect_by_isleaf connect_by_root connect_time connection consider consistent constant constraint constraints constructor container content contents context contributors controlfile conv convert convert_tz corr corr_k corr_s corresponding corruption cos cost count count_big counted covar_pop covar_samp cpu_per_call cpu_per_session crc32 create creation critical cross cube cume_dist curdate current current_date current_time current_timestamp current_user cursor curtime customdatum cycle data database databases datafile datafiles datalength date_add date_cache date_format date_sub dateadd datediff datefromparts datename datepart datetime2fromparts day day_to_second dayname dayofmonth dayofweek dayofyear days db_role_change dbtimezone ddl deallocate declare decode decompose decrement decrypt deduplicate def defa defau defaul default defaults deferred defi defin define degrees delayed delegate delete delete_all delimited demand dense_rank depth dequeue des_decrypt des_encrypt des_key_file desc descr descri describ describe descriptor deterministic diagnostics difference dimension direct_load directory disable disable_all disallow disassociate discardfile disconnect diskgroup distinct distinctrow distribute distributed div do document domain dotnet double downgrade drop dumpfile duplicate duration each edition editionable editions element ellipsis else elsif elt empty enable enable_all enclosed encode encoding encrypt end end-exec endian enforced engine engines enqueue enterprise entityescaping eomonth error errors escaped evalname evaluate event eventdata events except exception exceptions exchange exclude excluding execu execut execute exempt exists exit exp expire explain export export_set extended extent external external_1 external_2 externally extract failed failed_login_attempts failover failure far fast feature_set feature_value fetch field fields file file_name_convert filesystem_like_logging final finish first first_value fixed flash_cache flashback floor flush following follows for forall force form forma format found found_rows freelist freelists freepools fresh from from_base64 from_days ftp full function general generated get get_format get_lock getdate getutcdate global global_name globally go goto grant grants greatest group group_concat group_id grouping grouping_id groups gtid_subtract guarantee guard handler hash hashkeys having hea head headi headin heading heap help hex hierarchy high high_priority hosts hour http id ident_current ident_incr ident_seed identified identity idle_time if ifnull ignore iif ilike ilm immediate import in include including increment index indexes indexing indextype indicator indices inet6_aton inet6_ntoa inet_aton inet_ntoa infile initial initialized initially initrans inmemory inner innodb input insert install instance instantiable instr interface interleaved intersect into invalidate invisible is is_free_lock is_ipv4 is_ipv4_compat is_not is_not_null is_used_lock isdate isnull isolation iterate java join json json_exists keep keep_duplicates key keys kill language large last last_day last_insert_id last_value lax lcase lead leading least leaves left len lenght length less level levels library like like2 like4 likec limit lines link list listagg little ln load load_file lob lobs local localtime localtimestamp locate locator lock locked log log10 log2 logfile logfiles logging logical logical_reads_per_call logoff logon logs long loop low low_priority lower lpad lrtrim ltrim main make_set makedate maketime managed management manual map mapping mask master master_pos_wait match matched materialized max maxextents maximize maxinstances maxlen maxlogfiles maxloghistory maxlogmembers maxsize maxtrans md5 measures median medium member memcompress memory merge microsecond mid migration min minextents minimum mining minus minute minvalue missing mod mode model modification modify module monitoring month months mount move movement multiset mutex name name_const names nan national native natural nav nchar nclob nested never new newline next nextval no no_write_to_binlog noarchivelog noaudit nobadfile nocheck nocompress nocopy nocycle nodelay nodiscardfile noentityescaping noguarantee nokeep nologfile nomapping nomaxvalue nominimize nominvalue nomonitoring none noneditionable nonschema noorder nopr nopro noprom nopromp noprompt norely noresetlogs noreverse normal norowdependencies noschemacheck noswitch not nothing notice notrim novalidate now nowait nth_value nullif nulls num numb numbe nvarchar nvarchar2 object ocicoll ocidate ocidatetime ociduration ociinterval ociloblocator ocinumber ociref ocirefcursor ocirowid ocistring ocitype oct octet_length of off offline offset oid oidindex old on online only opaque open operations operator optimal optimize option optionally or oracle oracle_date oradata ord ordaudio orddicom orddoc order ordimage ordinality ordvideo organization orlany orlvary out outer outfile outline output over overflow overriding package pad parallel parallel_enable parameters parent parse partial partition partitions pascal passing password password_grace_time password_lock_time password_reuse_max password_reuse_time password_verify_function patch path patindex pctincrease pctthreshold pctused pctversion percent percent_rank percentile_cont percentile_disc performance period period_add period_diff permanent physical pi pipe pipelined pivot pluggable plugin policy position post_transaction pow power pragma prebuilt precedes preceding precision prediction prediction_cost prediction_details prediction_probability prediction_set prepare present preserve prior priority private private_sga privileges procedural procedure procedure_analyze processlist profiles project prompt protection public publishingservername purge quarter query quick quiesce quota quotename radians raise rand range rank raw read reads readsize rebuild record records recover recovery recursive recycle redo reduced ref reference referenced references referencing refresh regexp_like register regr_avgx regr_avgy regr_count regr_intercept regr_r2 regr_slope regr_sxx regr_sxy reject rekey relational relative relaylog release release_lock relies_on relocate rely rem remainder rename repair repeat replace replicate replication required reset resetlogs resize resource respect restore restricted result result_cache resumable resume retention return returning returns reuse reverse revoke right rlike role roles rollback rolling rollup round row row_count rowdependencies rowid rownum rows rtrim rules safe salt sample save savepoint sb1 sb2 sb4 scan schema schemacheck scn scope scroll sdo_georaster sdo_topo_geometry search sec_to_time second section securefile security seed segment select self sequence sequential serializable server servererror session session_user sessions_per_user set sets settings sha sha1 sha2 share shared shared_pool short show shrink shutdown si_averagecolor si_colorhistogram si_featurelist si_positionalcolor si_stillimage si_texture siblings sid sign sin size size_t sizes skip slave sleep smalldatetimefromparts smallfile snapshot some soname sort soundex source space sparse spfile split sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows sql_small_result sql_variant_property sqlcode sqldata sqlerror sqlname sqlstate sqrt square standalone standby start starting startup statement static statistics stats_binomial_test stats_crosstab stats_ks_test stats_mode stats_mw_test stats_one_way_anova stats_t_test_ stats_t_test_indep stats_t_test_one stats_t_test_paired stats_wsr_test status std stddev stddev_pop stddev_samp stdev stop storage store stored str str_to_date straight_join strcmp strict string struct stuff style subdate subpartition subpartitions substitutable substr substring subtime subtring_index subtype success sum suspend switch switchoffset switchover sync synchronous synonym sys sys_xmlagg sysasm sysaux sysdate sysdatetimeoffset sysdba sysoper system system_user sysutcdatetime table tables tablespace tan tdo template temporary terminated tertiary_weights test than then thread through tier ties time time_format time_zone timediff timefromparts timeout timestamp timestampadd timestampdiff timezone_abbr timezone_minute timezone_region to to_base64 to_date to_days to_seconds todatetimeoffset trace tracking transaction transactional translate translation treat trigger trigger_nestlevel triggers trim truncate try_cast try_convert try_parse type ub1 ub2 ub4 ucase unarchived unbounded uncompress under undo unhex unicode uniform uninstall union unique unix_timestamp unknown unlimited unlock unpivot unrecoverable unsafe unsigned until untrusted unusable unused update updated upgrade upped upper upsert url urowid usable usage use use_stored_outlines user user_data user_resources users using utc_date utc_timestamp uuid uuid_short validate validate_password_strength validation valist value values var var_samp varcharc vari varia variab variabl variable variables variance varp varraw varrawc varray verify version versions view virtual visible void wait wallet warning warnings week weekday weekofyear wellformed when whene whenev wheneve whenever where while whitespace with within without work wrapped xdb xml xmlagg xmlattributes xmlcast xmlcolattval xmlelement xmlexists xmlforest xmlindex xmlnamespaces xmlpi xmlquery xmlroot xmlschema xmlserialize xmltable xmltype xor year year_to_month years yearweek",literal:"true false null",built_in:"array bigint binary bit blob boolean char character date dec decimal float int int8 integer interval number numeric real record serial serial8 smallint text varchar varying void"},c:[{cN:"string",b:"'",e:"'",c:[e.BE,{b:"''"}]},{cN:"string",b:'"',e:'"',c:[e.BE,{b:'""'}]},{cN:"string",b:"`",e:"`",c:[e.BE]},e.CNM,e.CBCM,t]},e.CBCM,t]}}),e});
/*!
 * Fuse.js v3.1.0 - Lightweight fuzzy-search (http://fusejs.io)
 *
 * Copyright (c) 2012-2017 Kirollos Risk (http://kiro.me)
 * All Rights Reserved. Apache Software License 2.0
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 */
(function webpackUniversalModuleDefinition(root, factory) {
    if(typeof exports === 'object' && typeof module === 'object')
        module.exports = factory();
    else if(typeof define === 'function' && define.amd)
        define("Fuse", [], factory);
    else if(typeof exports === 'object')
        exports["Fuse"] = factory();
    else
        root["Fuse"] = factory();
})(this, function() {
    return /******/ (function(modules) { // webpackBootstrap
        /******/ 	// The module cache
        /******/ 	var installedModules = {};
        /******/
        /******/ 	// The require function
        /******/ 	function __webpack_require__(moduleId) {
            /******/
            /******/ 		// Check if module is in cache
            /******/ 		if(installedModules[moduleId]) {
                /******/ 			return installedModules[moduleId].exports;
                /******/ 		}
            /******/ 		// Create a new module (and put it into the cache)
            /******/ 		var module = installedModules[moduleId] = {
                /******/ 			i: moduleId,
                /******/ 			l: false,
                /******/ 			exports: {}
                /******/ 		};
            /******/
            /******/ 		// Execute the module function
            /******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
            /******/
            /******/ 		// Flag the module as loaded
            /******/ 		module.l = true;
            /******/
            /******/ 		// Return the exports of the module
            /******/ 		return module.exports;
            /******/ 	}
        /******/
        /******/
        /******/ 	// expose the modules object (__webpack_modules__)
        /******/ 	__webpack_require__.m = modules;
        /******/
        /******/ 	// expose the module cache
        /******/ 	__webpack_require__.c = installedModules;
        /******/
        /******/ 	// identity function for calling harmony imports with the correct context
        /******/ 	__webpack_require__.i = function(value) { return value; };
        /******/
        /******/ 	// define getter function for harmony exports
        /******/ 	__webpack_require__.d = function(exports, name, getter) {
            /******/ 		if(!__webpack_require__.o(exports, name)) {
                /******/ 			Object.defineProperty(exports, name, {
                    /******/ 				configurable: false,
                    /******/ 				enumerable: true,
                    /******/ 				get: getter
                    /******/ 			});
                /******/ 		}
            /******/ 	};
        /******/
        /******/ 	// getDefaultExport function for compatibility with non-harmony modules
        /******/ 	__webpack_require__.n = function(module) {
            /******/ 		var getter = module && module.__esModule ?
                /******/ 			function getDefault() { return module['default']; } :
                /******/ 			function getModuleExports() { return module; };
            /******/ 		__webpack_require__.d(getter, 'a', getter);
            /******/ 		return getter;
            /******/ 	};
        /******/
        /******/ 	// Object.prototype.hasOwnProperty.call
        /******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
        /******/
        /******/ 	// __webpack_public_path__
        /******/ 	__webpack_require__.p = "";
        /******/
        /******/ 	// Load entry module and return exports
        /******/ 	return __webpack_require__(__webpack_require__.s = 8);
        /******/ })
    /************************************************************************/
    /******/ ([
        /* 0 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (obj) {
                return Object.prototype.toString.call(obj) === '[object Array]';
            };

            /***/ }),
        /* 1 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

            function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

            var bitapRegexSearch = __webpack_require__(5);
            var bitapSearch = __webpack_require__(7);
            var patternAlphabet = __webpack_require__(4);

            var Bitap = function () {
                function Bitap(pattern, _ref) {
                    var _ref$location = _ref.location,
                        location = _ref$location === undefined ? 0 : _ref$location,
                        _ref$distance = _ref.distance,
                        distance = _ref$distance === undefined ? 100 : _ref$distance,
                        _ref$threshold = _ref.threshold,
                        threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                        _ref$maxPatternLength = _ref.maxPatternLength,
                        maxPatternLength = _ref$maxPatternLength === undefined ? 32 : _ref$maxPatternLength,
                        _ref$isCaseSensitive = _ref.isCaseSensitive,
                        isCaseSensitive = _ref$isCaseSensitive === undefined ? false : _ref$isCaseSensitive,
                        _ref$tokenSeparator = _ref.tokenSeparator,
                        tokenSeparator = _ref$tokenSeparator === undefined ? / +/g : _ref$tokenSeparator,
                        _ref$findAllMatches = _ref.findAllMatches,
                        findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                        _ref$minMatchCharLeng = _ref.minMatchCharLength,
                        minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng;

                    _classCallCheck(this, Bitap);

                    this.options = {
                        location: location,
                        distance: distance,
                        threshold: threshold,
                        maxPatternLength: maxPatternLength,
                        isCaseSensitive: isCaseSensitive,
                        tokenSeparator: tokenSeparator,
                        findAllMatches: findAllMatches,
                        minMatchCharLength: minMatchCharLength
                    };

                    this.pattern = this.options.isCaseSensitive ? pattern : pattern.toLowerCase();

                    if (this.pattern.length <= maxPatternLength) {
                        this.patternAlphabet = patternAlphabet(this.pattern);
                    }
                }

                _createClass(Bitap, [{
                    key: 'search',
                    value: function search(text) {
                        if (!this.options.isCaseSensitive) {
                            text = text.toLowerCase();
                        }

                        // Exact match
                        if (this.pattern === text) {
                            return {
                                isMatch: true,
                                score: 0,
                                matchedIndices: [[0, text.length - 1]]
                            };
                        }

                        // When pattern length is greater than the machine word length, just do a a regex comparison
                        var _options = this.options,
                            maxPatternLength = _options.maxPatternLength,
                            tokenSeparator = _options.tokenSeparator;

                        if (this.pattern.length > maxPatternLength) {
                            return bitapRegexSearch(text, this.pattern, tokenSeparator);
                        }

                        // Otherwise, use Bitap algorithm
                        var _options2 = this.options,
                            location = _options2.location,
                            distance = _options2.distance,
                            threshold = _options2.threshold,
                            findAllMatches = _options2.findAllMatches,
                            minMatchCharLength = _options2.minMatchCharLength;

                        return bitapSearch(text, this.pattern, this.patternAlphabet, {
                            location: location,
                            distance: distance,
                            threshold: threshold,
                            findAllMatches: findAllMatches,
                            minMatchCharLength: minMatchCharLength
                        });
                    }
                }]);

                return Bitap;
            }();

// let x = new Bitap("od mn war", {})
// let result = x.search("Old Man's War")
// console.log(result)

            module.exports = Bitap;

            /***/ }),
        /* 2 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var isArray = __webpack_require__(0);

            var deepValue = function deepValue(obj, path, list) {
                if (!path) {
                    // If there's no path left, we've gotten to the object we care about.
                    list.push(obj);
                } else {
                    var dotIndex = path.indexOf('.');
                    var firstSegment = path;
                    var remaining = null;

                    if (dotIndex !== -1) {
                        firstSegment = path.slice(0, dotIndex);
                        remaining = path.slice(dotIndex + 1);
                    }

                    var value = obj[firstSegment];

                    if (value !== null && value !== undefined) {
                        if (!remaining && (typeof value === 'string' || typeof value === 'number')) {
                            list.push(value.toString());
                        } else if (isArray(value)) {
                            // Search each item in the array.
                            for (var i = 0, len = value.length; i < len; i += 1) {
                                deepValue(value[i], remaining, list);
                            }
                        } else if (remaining) {
                            // An object. Recurse further.
                            deepValue(value, remaining, list);
                        }
                    }
                }

                return list;
            };

            module.exports = function (obj, path) {
                return deepValue(obj, path, []);
            };

            /***/ }),
        /* 3 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function () {
                var matchmask = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
                var minMatchCharLength = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;

                var matchedIndices = [];
                var start = -1;
                var end = -1;
                var i = 0;

                for (var len = matchmask.length; i < len; i += 1) {
                    var match = matchmask[i];
                    if (match && start === -1) {
                        start = i;
                    } else if (!match && start !== -1) {
                        end = i - 1;
                        if (end - start + 1 >= minMatchCharLength) {
                            matchedIndices.push([start, end]);
                        }
                        start = -1;
                    }
                }

                // (i-1 - start) + 1 => i - start
                if (matchmask[i - 1] && i - start >= minMatchCharLength) {
                    matchedIndices.push([start, i - 1]);
                }

                return matchedIndices;
            };

            /***/ }),
        /* 4 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (pattern) {
                var mask = {};
                var len = pattern.length;

                for (var i = 0; i < len; i += 1) {
                    mask[pattern.charAt(i)] = 0;
                }

                for (var _i = 0; _i < len; _i += 1) {
                    mask[pattern.charAt(_i)] |= 1 << len - _i - 1;
                }

                return mask;
            };

            /***/ }),
        /* 5 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var SPECIAL_CHARS_REGEX = /[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g;

            module.exports = function (text, pattern) {
                var tokenSeparator = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : / +/g;

                var regex = new RegExp(pattern.replace(SPECIAL_CHARS_REGEX, '\\$&').replace(tokenSeparator, '|'));
                var matches = text.match(regex);
                var isMatch = !!matches;
                var matchedIndices = [];

                if (isMatch) {
                    for (var i = 0, matchesLen = matches.length; i < matchesLen; i += 1) {
                        var match = matches[i];
                        matchedIndices.push([text.indexOf(match), match.length - 1]);
                    }
                }

                return {
                    // TODO: revisit this score
                    score: isMatch ? 0.5 : 1,
                    isMatch: isMatch,
                    matchedIndices: matchedIndices
                };
            };

            /***/ }),
        /* 6 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (pattern, _ref) {
                var _ref$errors = _ref.errors,
                    errors = _ref$errors === undefined ? 0 : _ref$errors,
                    _ref$currentLocation = _ref.currentLocation,
                    currentLocation = _ref$currentLocation === undefined ? 0 : _ref$currentLocation,
                    _ref$expectedLocation = _ref.expectedLocation,
                    expectedLocation = _ref$expectedLocation === undefined ? 0 : _ref$expectedLocation,
                    _ref$distance = _ref.distance,
                    distance = _ref$distance === undefined ? 100 : _ref$distance;

                var accuracy = errors / pattern.length;
                var proximity = Math.abs(expectedLocation - currentLocation);

                if (!distance) {
                    // Dodge divide by zero error.
                    return proximity ? 1.0 : accuracy;
                }

                return accuracy + proximity / distance;
            };

            /***/ }),
        /* 7 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var bitapScore = __webpack_require__(6);
            var matchedIndices = __webpack_require__(3);

            module.exports = function (text, pattern, patternAlphabet, _ref) {
                var _ref$location = _ref.location,
                    location = _ref$location === undefined ? 0 : _ref$location,
                    _ref$distance = _ref.distance,
                    distance = _ref$distance === undefined ? 100 : _ref$distance,
                    _ref$threshold = _ref.threshold,
                    threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                    _ref$findAllMatches = _ref.findAllMatches,
                    findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                    _ref$minMatchCharLeng = _ref.minMatchCharLength,
                    minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng;

                var expectedLocation = location;
                // Set starting location at beginning text and initialize the alphabet.
                var textLen = text.length;
                // Highest score beyond which we give up.
                var currentThreshold = threshold;
                // Is there a nearby exact match? (speedup)
                var bestLocation = text.indexOf(pattern, expectedLocation);

                var patternLen = pattern.length;

                // a mask of the matches
                var matchMask = [];
                for (var i = 0; i < textLen; i += 1) {
                    matchMask[i] = 0;
                }

                if (bestLocation !== -1) {
                    var score = bitapScore(pattern, {
                        errors: 0,
                        currentLocation: bestLocation,
                        expectedLocation: expectedLocation,
                        distance: distance
                    });
                    currentThreshold = Math.min(score, currentThreshold);

                    // What about in the other direction? (speed up)
                    bestLocation = text.lastIndexOf(pattern, expectedLocation + patternLen);

                    if (bestLocation !== -1) {
                        var _score = bitapScore(pattern, {
                            errors: 0,
                            currentLocation: bestLocation,
                            expectedLocation: expectedLocation,
                            distance: distance
                        });
                        currentThreshold = Math.min(_score, currentThreshold);
                    }
                }

                // Reset the best location
                bestLocation = -1;

                var lastBitArr = [];
                var finalScore = 1;
                var binMax = patternLen + textLen;

                var mask = 1 << patternLen - 1;

                for (var _i = 0; _i < patternLen; _i += 1) {
                    // Scan for the best match; each iteration allows for one more error.
                    // Run a binary search to determine how far from the match location we can stray
                    // at this error level.
                    var binMin = 0;
                    var binMid = binMax;

                    while (binMin < binMid) {
                        var _score3 = bitapScore(pattern, {
                            errors: _i,
                            currentLocation: expectedLocation + binMid,
                            expectedLocation: expectedLocation,
                            distance: distance
                        });

                        if (_score3 <= currentThreshold) {
                            binMin = binMid;
                        } else {
                            binMax = binMid;
                        }

                        binMid = Math.floor((binMax - binMin) / 2 + binMin);
                    }

                    // Use the result from this iteration as the maximum for the next.
                    binMax = binMid;

                    var start = Math.max(1, expectedLocation - binMid + 1);
                    var finish = findAllMatches ? textLen : Math.min(expectedLocation + binMid, textLen) + patternLen;

                    // Initialize the bit array
                    var bitArr = Array(finish + 2);

                    bitArr[finish + 1] = (1 << _i) - 1;

                    for (var j = finish; j >= start; j -= 1) {
                        var currentLocation = j - 1;
                        var charMatch = patternAlphabet[text.charAt(currentLocation)];

                        if (charMatch) {
                            matchMask[currentLocation] = 1;
                        }

                        // First pass: exact match
                        bitArr[j] = (bitArr[j + 1] << 1 | 1) & charMatch;

                        // Subsequent passes: fuzzy match
                        if (_i !== 0) {
                            bitArr[j] |= (lastBitArr[j + 1] | lastBitArr[j]) << 1 | 1 | lastBitArr[j + 1];
                        }

                        if (bitArr[j] & mask) {
                            finalScore = bitapScore(pattern, {
                                errors: _i,
                                currentLocation: currentLocation,
                                expectedLocation: expectedLocation,
                                distance: distance
                            });

                            // This match will almost certainly be better than any existing match.
                            // But check anyway.
                            if (finalScore <= currentThreshold) {
                                // Indeed it is
                                currentThreshold = finalScore;
                                bestLocation = currentLocation;

                                // Already passed `loc`, downhill from here on in.
                                if (bestLocation <= expectedLocation) {
                                    break;
                                }

                                // When passing `bestLocation`, don't exceed our current distance from `expectedLocation`.
                                start = Math.max(1, 2 * expectedLocation - bestLocation);
                            }
                        }
                    }

                    // No hope for a (better) match at greater error levels.
                    var _score2 = bitapScore(pattern, {
                        errors: _i + 1,
                        currentLocation: expectedLocation,
                        expectedLocation: expectedLocation,
                        distance: distance
                    });

                    if (_score2 > currentThreshold) {
                        break;
                    }

                    lastBitArr = bitArr;
                }

                // Count exact matches (those with a score of 0) to be "almost" exact
                return {
                    isMatch: bestLocation >= 0,
                    score: finalScore === 0 ? 0.001 : finalScore,
                    matchedIndices: matchedIndices(matchMask, minMatchCharLength)
                };
            };

            /***/ }),
        /* 8 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

            function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

            var Bitap = __webpack_require__(1);
            var deepValue = __webpack_require__(2);
            var isArray = __webpack_require__(0);

            var Fuse = function () {
                function Fuse(list, _ref) {
                    var _ref$location = _ref.location,
                        location = _ref$location === undefined ? 0 : _ref$location,
                        _ref$distance = _ref.distance,
                        distance = _ref$distance === undefined ? 100 : _ref$distance,
                        _ref$threshold = _ref.threshold,
                        threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                        _ref$maxPatternLength = _ref.maxPatternLength,
                        maxPatternLength = _ref$maxPatternLength === undefined ? 32 : _ref$maxPatternLength,
                        _ref$caseSensitive = _ref.caseSensitive,
                        caseSensitive = _ref$caseSensitive === undefined ? false : _ref$caseSensitive,
                        _ref$tokenSeparator = _ref.tokenSeparator,
                        tokenSeparator = _ref$tokenSeparator === undefined ? / +/g : _ref$tokenSeparator,
                        _ref$findAllMatches = _ref.findAllMatches,
                        findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                        _ref$minMatchCharLeng = _ref.minMatchCharLength,
                        minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng,
                        _ref$id = _ref.id,
                        id = _ref$id === undefined ? null : _ref$id,
                        _ref$keys = _ref.keys,
                        keys = _ref$keys === undefined ? [] : _ref$keys,
                        _ref$shouldSort = _ref.shouldSort,
                        shouldSort = _ref$shouldSort === undefined ? true : _ref$shouldSort,
                        _ref$getFn = _ref.getFn,
                        getFn = _ref$getFn === undefined ? deepValue : _ref$getFn,
                        _ref$sortFn = _ref.sortFn,
                        sortFn = _ref$sortFn === undefined ? function (a, b) {
                            return a.score - b.score;
                        } : _ref$sortFn,
                        _ref$tokenize = _ref.tokenize,
                        tokenize = _ref$tokenize === undefined ? false : _ref$tokenize,
                        _ref$matchAllTokens = _ref.matchAllTokens,
                        matchAllTokens = _ref$matchAllTokens === undefined ? false : _ref$matchAllTokens,
                        _ref$includeMatches = _ref.includeMatches,
                        includeMatches = _ref$includeMatches === undefined ? false : _ref$includeMatches,
                        _ref$includeScore = _ref.includeScore,
                        includeScore = _ref$includeScore === undefined ? false : _ref$includeScore,
                        _ref$verbose = _ref.verbose,
                        verbose = _ref$verbose === undefined ? false : _ref$verbose;

                    _classCallCheck(this, Fuse);

                    this.options = {
                        location: location,
                        distance: distance,
                        threshold: threshold,
                        maxPatternLength: maxPatternLength,
                        isCaseSensitive: caseSensitive,
                        tokenSeparator: tokenSeparator,
                        findAllMatches: findAllMatches,
                        minMatchCharLength: minMatchCharLength,
                        id: id,
                        keys: keys,
                        includeMatches: includeMatches,
                        includeScore: includeScore,
                        shouldSort: shouldSort,
                        getFn: getFn,
                        sortFn: sortFn,
                        verbose: verbose,
                        tokenize: tokenize,
                        matchAllTokens: matchAllTokens
                    };

                    this.setCollection(list);
                }

                _createClass(Fuse, [{
                    key: 'setCollection',
                    value: function setCollection(list) {
                        this.list = list;
                        return list;
                    }
                }, {
                    key: 'search',
                    value: function search(pattern) {
                        this._log('---------\nSearch pattern: "' + pattern + '"');

                        var _prepareSearchers2 = this._prepareSearchers(pattern),
                            tokenSearchers = _prepareSearchers2.tokenSearchers,
                            fullSearcher = _prepareSearchers2.fullSearcher;

                        var _search2 = this._search(tokenSearchers, fullSearcher),
                            weights = _search2.weights,
                            results = _search2.results;

                        this._computeScore(weights, results);

                        if (this.options.shouldSort) {
                            this._sort(results);
                        }

                        return this._format(results);
                    }
                }, {
                    key: '_prepareSearchers',
                    value: function _prepareSearchers() {
                        var pattern = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

                        var tokenSearchers = [];

                        if (this.options.tokenize) {
                            // Tokenize on the separator
                            var tokens = pattern.split(this.options.tokenSeparator);
                            for (var i = 0, len = tokens.length; i < len; i += 1) {
                                tokenSearchers.push(new Bitap(tokens[i], this.options));
                            }
                        }

                        var fullSearcher = new Bitap(pattern, this.options);

                        return { tokenSearchers: tokenSearchers, fullSearcher: fullSearcher };
                    }
                }, {
                    key: '_search',
                    value: function _search() {
                        var tokenSearchers = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
                        var fullSearcher = arguments[1];

                        var list = this.list;
                        var resultMap = {};
                        var results = [];

                        // Check the first item in the list, if it's a string, then we assume
                        // that every item in the list is also a string, and thus it's a flattened array.
                        if (typeof list[0] === 'string') {
                            // Iterate over every item
                            for (var i = 0, len = list.length; i < len; i += 1) {
                                this._analyze({
                                    key: '',
                                    value: list[i],
                                    record: i,
                                    index: i
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }

                            return { weights: null, results: results };
                        }

                        // Otherwise, the first item is an Object (hopefully), and thus the searching
                        // is done on the values of the keys of each item.
                        var weights = {};
                        for (var _i = 0, _len = list.length; _i < _len; _i += 1) {
                            var item = list[_i];
                            // Iterate over every key
                            for (var j = 0, keysLen = this.options.keys.length; j < keysLen; j += 1) {
                                var key = this.options.keys[j];
                                if (typeof key !== 'string') {
                                    weights[key.name] = {
                                        weight: 1 - key.weight || 1
                                    };
                                    if (key.weight <= 0 || key.weight > 1) {
                                        throw new Error('Key weight has to be > 0 and <= 1');
                                    }
                                    key = key.name;
                                } else {
                                    weights[key] = {
                                        weight: 1
                                    };
                                }

                                this._analyze({
                                    key: key,
                                    value: this.options.getFn(item, key),
                                    record: item,
                                    index: _i
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }
                        }

                        return { weights: weights, results: results };
                    }
                }, {
                    key: '_analyze',
                    value: function _analyze(_ref2, _ref3) {
                        var key = _ref2.key,
                            _ref2$arrayIndex = _ref2.arrayIndex,
                            arrayIndex = _ref2$arrayIndex === undefined ? -1 : _ref2$arrayIndex,
                            value = _ref2.value,
                            record = _ref2.record,
                            index = _ref2.index;
                        var _ref3$tokenSearchers = _ref3.tokenSearchers,
                            tokenSearchers = _ref3$tokenSearchers === undefined ? [] : _ref3$tokenSearchers,
                            _ref3$fullSearcher = _ref3.fullSearcher,
                            fullSearcher = _ref3$fullSearcher === undefined ? [] : _ref3$fullSearcher,
                            _ref3$resultMap = _ref3.resultMap,
                            resultMap = _ref3$resultMap === undefined ? {} : _ref3$resultMap,
                            _ref3$results = _ref3.results,
                            results = _ref3$results === undefined ? [] : _ref3$results;

                        // Check if the texvaluet can be searched
                        if (value === undefined || value === null) {
                            return;
                        }

                        var exists = false;
                        var averageScore = -1;
                        var numTextMatches = 0;

                        if (typeof value === 'string') {
                            this._log('\nKey: ' + (key === '' ? '-' : key));

                            var mainSearchResult = fullSearcher.search(value);
                            this._log('Full text: "' + value + '", score: ' + mainSearchResult.score);

                            if (this.options.tokenize) {
                                var words = value.split(this.options.tokenSeparator);
                                var scores = [];

                                for (var i = 0; i < tokenSearchers.length; i += 1) {
                                    var tokenSearcher = tokenSearchers[i];

                                    this._log('\nPattern: "' + tokenSearcher.pattern + '"');

                                    // let tokenScores = []
                                    var hasMatchInText = false;

                                    for (var j = 0; j < words.length; j += 1) {
                                        var word = words[j];
                                        var tokenSearchResult = tokenSearcher.search(word);
                                        var obj = {};
                                        if (tokenSearchResult.isMatch) {
                                            obj[word] = tokenSearchResult.score;
                                            exists = true;
                                            hasMatchInText = true;
                                            scores.push(tokenSearchResult.score);
                                        } else {
                                            obj[word] = 1;
                                            if (!this.options.matchAllTokens) {
                                                scores.push(1);
                                            }
                                        }
                                        this._log('Token: "' + word + '", score: ' + obj[word]);
                                        // tokenScores.push(obj)
                                    }

                                    if (hasMatchInText) {
                                        numTextMatches += 1;
                                    }
                                }

                                averageScore = scores[0];
                                var scoresLen = scores.length;
                                for (var _i2 = 1; _i2 < scoresLen; _i2 += 1) {
                                    averageScore += scores[_i2];
                                }
                                averageScore = averageScore / scoresLen;

                                this._log('Token score average:', averageScore);
                            }

                            var finalScore = mainSearchResult.score;
                            if (averageScore > -1) {
                                finalScore = (finalScore + averageScore) / 2;
                            }

                            this._log('Score average:', finalScore);

                            var checkTextMatches = this.options.tokenize && this.options.matchAllTokens ? numTextMatches >= tokenSearchers.length : true;

                            this._log('\nCheck Matches: ' + checkTextMatches);

                            // If a match is found, add the item to <rawResults>, including its score
                            if ((exists || mainSearchResult.isMatch) && checkTextMatches) {
                                // Check if the item already exists in our results
                                var existingResult = resultMap[index];
                                if (existingResult) {
                                    // Use the lowest score
                                    // existingResult.score, bitapResult.score
                                    existingResult.output.push({
                                        key: key,
                                        arrayIndex: arrayIndex,
                                        value: value,
                                        score: finalScore,
                                        matchedIndices: mainSearchResult.matchedIndices
                                    });
                                } else {
                                    // Add it to the raw result list
                                    resultMap[index] = {
                                        item: record,
                                        output: [{
                                            key: key,
                                            arrayIndex: arrayIndex,
                                            value: value,
                                            score: finalScore,
                                            matchedIndices: mainSearchResult.matchedIndices
                                        }]
                                    };

                                    results.push(resultMap[index]);
                                }
                            }
                        } else if (isArray(value)) {
                            for (var _i3 = 0, len = value.length; _i3 < len; _i3 += 1) {
                                this._analyze({
                                    key: key,
                                    arrayIndex: _i3,
                                    value: value[_i3],
                                    record: record,
                                    index: index
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }
                        }
                    }
                }, {
                    key: '_computeScore',
                    value: function _computeScore(weights, results) {
                        this._log('\n\nComputing score:\n');

                        for (var i = 0, len = results.length; i < len; i += 1) {
                            var output = results[i].output;
                            var scoreLen = output.length;

                            var totalScore = 0;
                            var bestScore = 1;

                            for (var j = 0; j < scoreLen; j += 1) {
                                var score = output[j].score;
                                var weight = weights ? weights[output[j].key].weight : 1;
                                var nScore = score * weight;

                                if (weight !== 1) {
                                    bestScore = Math.min(bestScore, nScore);
                                } else {
                                    output[j].nScore = nScore;
                                    totalScore += nScore;
                                }
                            }

                            results[i].score = bestScore === 1 ? totalScore / scoreLen : bestScore;

                            this._log(results[i]);
                        }
                    }
                }, {
                    key: '_sort',
                    value: function _sort(results) {
                        this._log('\n\nSorting....');
                        results.sort(this.options.sortFn);
                    }
                }, {
                    key: '_format',
                    value: function _format(results) {
                        var finalOutput = [];

                        this._log('\n\nOutput:\n\n', JSON.stringify(results));

                        var transformers = [];

                        if (this.options.includeMatches) {
                            transformers.push(function (result, data) {
                                var output = result.output;
                                data.matches = [];

                                for (var i = 0, len = output.length; i < len; i += 1) {
                                    var item = output[i];

                                    if (item.matchedIndices.length === 0) {
                                        continue;
                                    }

                                    var obj = {
                                        indices: item.matchedIndices,
                                        value: item.value
                                    };
                                    if (item.key) {
                                        obj.key = item.key;
                                    }
                                    if (item.hasOwnProperty('arrayIndex') && item.arrayIndex > -1) {
                                        obj.arrayIndex = item.arrayIndex;
                                    }
                                    data.matches.push(obj);
                                }
                            });
                        }

                        if (this.options.includeScore) {
                            transformers.push(function (result, data) {
                                data.score = result.score;
                            });
                        }

                        for (var i = 0, len = results.length; i < len; i += 1) {
                            var result = results[i];

                            if (this.options.id) {
                                result.item = this.options.getFn(result.item, this.options.id)[0];
                            }

                            if (!transformers.length) {
                                finalOutput.push(result.item);
                                continue;
                            }

                            var data = {
                                item: result.item
                            };

                            for (var j = 0, _len2 = transformers.length; j < _len2; j += 1) {
                                transformers[j](result, data);
                            }

                            finalOutput.push(data);
                        }

                        return finalOutput;
                    }
                }, {
                    key: '_log',
                    value: function _log() {
                        if (this.options.verbose) {
                            var _console;

                            (_console = console).log.apply(_console, arguments);
                        }
                    }
                }]);

                return Fuse;
            }();

            module.exports = Fuse;

            /***/ })
        /******/ ]);
});
//# sourceMappingURL=fuse.js.map
var AllInOneMenuTemplate = '<%var chunks = ["<div class=\'cont all-in-one-toc\'><h1 class=\'heading1\'>" + localization.TableOfContents + "</h1>"],    markup;function htmlTreeBuilder(items) {    if (items.length) {        chunks.push("<ul class=\'contents contents_all-in-one\'>");    }    items.forEach(function (item) {        if (!item.hidden) {            chunks.push("<li class=\'contents__item\'>");            chunks.push("<a href=\'");            chunks.push(item.url.match(/([\\w_]+\\.htm[l]?)/i)[1]);            chunks.push("\'>");            chunks.push(item.text);            chunks.push("</a>");            if (item.children) {                htmlTreeBuilder(item.children);            }            chunks.push("</li>");        }    });    if (items.length) {        chunks.push("</ul>");    }}htmlTreeBuilder(menu);chunks.push("</div>");markup = chunks.join("");%><%= markup %>';
var AsideTemplate = '<div class="aside ">    <div class="aside__inner">        <div class="aside__search search hidden-xs hidden-sm">            <div class="search__wrapper">                <input  class="search__field js_search_text" id="serch-text"                        placeholder="<%= localization.SearchLabel %>" type="text" />                <button class="search__btn js_search" id="search-button"></button>                <button class="search__clear is-hidden js_search_clear"></button>            </div>        </div>        <div class="selector-mobile js_selector_mobile_versions"></div>        <div class="selector-mobile js_selector_mobile_langs"></div>        <div class="aside__menu js_tabs_viewport">            <div class="js-menu-content">                <div class="js_menu"></div>            </div><!--            <div id="tab-names" class="b-tab__content js-tab-content">                <div class="b-index js_index_literals"></div>            </div>-->            <div class="js-search-content js_not_default">                <div class="search-results js_search_result_wrapper"></div>            </div>        </div>    </div></div>';
var BottomLinksTemplate = '<div class="bottom-links">    <!--<div class="feedback">        <div class="feedback__heading">Feedback</div>        <div class="feedback__text">            Was this article helpful?        </div>        <div>            <button class="button" type="button">Yes</button>            <button class="button" type="button">No</button>        </div>    </div>-->    <% if ((localization.ArticleIdText && localization.ArticleIdText.trim() && serviceInfo.id) ||            (localization.LastReviewText && localization.LastReviewText.trim() && serviceInfo.reviewDate)) { %>        <div class="bottom-links__service-info">            <% if (serviceInfo.id) { %>                <%= localization.ArticleIdText %> <%= serviceInfo.id %>,            <% } %>            <% if (serviceInfo.reviewDate) { %>                <%= localization.LastReviewText %> <%= serviceInfo.reviewDate %>            <% } %>        </div>    <% } %>    <div class="bottom-links__link">        <%= homeBtnHtml %>    </div></div>';
var ContainerTemplate = '<div class="main js_container">    <header class="js_header_placeholder"></header>    <div class="content js_main">        <div class="container">            <div class="row">                <div class="col-md-4 col-xs-20 menu-box js_aside_placeholder"></div>                <div class="col-md-1 hidden-xs hidden-sm js_prev_btn_placeholder"></div>                <div class="col-md-14 col-xs-20 js_content"></div>                <div class="col-md-1 hidden-xs hidden-sm js_next_btn_placeholder"></div>                <div class="col-md-16 col-xs-20 align-flex-end">                    <footer class="js_footer_placeholder"></footer>                </div>            </div>        </div>    </div>    <aside class="mobile-search-results is-hidden g-scrollable js_scrollable js_mobile_search_result js_mobile_aside"></aside></div><!--<div class="b-modal js_overlay">    <div class="b-modal__window js_modal">        <header class="b-modal__header js_modal_header"></header>        <div class="b-modal__content js_modal_content"></div>        <button href="#" class="b-modal__close-button js_modal_close"></button>    </div></div>--><div class="tooltip js_tooltip" data-id="">    <div class="tooltip__content js_tooltip_content"></div></div>';
var CustomStylesTemplate = '<style>    html {        color: <%= customization.ContentColorMain %>;    }    a {        color: <%= customization.LinkColor %>    }    a:hover {        color: <%= customization.LinkColorHover %>    }    a:visited {        color: <%= customization.LinkColorVisited %>    }    .page-title {        color: <%= customization.TitleColor %>;    }    /*.tablename,    .picturename,    .examplebodytext,    .examplebodytextblue2015,    .bottom-links__service-info,    .search-results__total,    .footer {        color: <%= customization.ContentColorSecondary %>;    }*/    .attentionbody,    .attentionbodytextindent,    .attentioncontinue1,    .attentioncontinue2,    .attentioncontinue3 {        color: <%= customization.AttentionBlockColor %>;    }    .warningbody,    .warningbodytextindent,    .warningcontinue1,    .warningcontinue2,    .warningcontinue3 {        color: <%= customization.WarningBlockColor %>;        border-color: <%= customization.WarningBlockBorder %>;        background: <%= customization.WarningBlockBackground %>;    }    .example-wrapper {        background: <%= customization.ExampleBlockBackground %> !important;    }    .exampleheading,    .examplebodytext,    .exampleheadingblue2015,    .examplebodytextblue2015 {        color: <%= customization.ExampleBlockColor %>;    }    mark {        background: <%= customization.SearchHighlightBackground %>;        color: <%= customization.SearchHighlightColor %>;    }</style>';
var FooterTemplate = '<div class="footer footer_inner">    <!--<div class="container">-->        <div class="row">            <div class="col-xs-20">                <div class="footer__divider"></div>            </div>            <div class="col-md-10 col-xs-20">                <div class="footer__text">                    <%= localization.FooterCopyrightText %>                </div>            </div>            <div class="col-md-10 col-xs-20">                <div class="footer__links">                    <% var hasOldFormatLinks = false %>                    <% if ( localization.FooterPrivacyPolicyLink && localization.FooterPrivacyPolicyLink.trim() &&                            localization.FooterPrivacyPolicyText && localization.FooterPrivacyPolicyText.trim() &&                            (!customization.FooterPrivacyPolicyLink || !customization.FooterPrivacyPolicyLink.hidden)) { %>                        <% hasOldFormatLinks = true %>                        <span class="footer__links-item">                            <% if (customization.FooterPrivacyPolicyLink && customization.FooterPrivacyPolicyLink.disabled) { %>                                <span class="footer__link">                                    <%= localization.FooterPrivacyPolicyText %>                                </span>                            <% } else { %>                                <a class="footer__link" target="blank" href="<%= localization.FooterPrivacyPolicyLink %>">                                    <%= localization.FooterPrivacyPolicyText %>                                </a>                            <% } %>                        </span>                    <% } %>                    <% if ( localization.FooterLegalLink && localization.FooterLegalLink.trim() &&                            localization.FooterLegalText && localization.FooterLegalText.trim() &&                            (!customization.FooterLegalLink || !customization.FooterLegalLink.hidden)) { %>                        <% hasOldFormatLinks = true %>                        <span class="footer__links-item">                            <% if (customization.FooterLegalLink && customization.FooterLegalLink.disabled) { %>                                <span class="footer__link">                                    <%= localization.FooterLegalText %>                                </span>                            <% } else { %>                                <a class="footer__link" target="blank" href="<%= localization.FooterLegalLink %>">                                    <%= localization.FooterLegalText %>                                </a>                            <% } %>                        </span>                    <% } %>                    <% if ( localization.FooterLinks && !hasOldFormatLinks ) { %>                        <% for (var i = 0, link; i < localization.FooterLinks.length; i++ ) { %>                            <% link = localization.FooterLinks[i] %>                            <span class="footer__links-item">                                <a class="footer__link" target="blank" href="<%= link.url %>">                                    <%= link.label %>                                </a>                            </span>                        <% } %>                    <% } %>                </div>            </div>        </div>    <!--</div>--></div>';
var HeaderTemplate = '<div class="header header_inner-help">    <div class="container">        <div class="row">            <div class="col-md-10 col-xs-20">                <button class="header__mobile-menu-btn js_burger" type="button"></button>                <div class="header__title hidden-xs hidden-sm">                    <% if ((!customization.HeaderLogoLink || !customization.HeaderLogoLink.hidden) && localization.HeaderTitle) { %>                        <% if ((customization.HeaderLogoLink && customization.HeaderLogoLink.disabled) || isOffline) { %>                            <span class="header__title-link">                        <% } else { %>                            <a href="<%= localization.HeaderLogoLink %>" class="header__title-link">                        <% } %>                            <% var index = localization.HeaderTitle.indexOf(" ") %>                            <%= localization.HeaderTitle.slice(0, index) %>                            <div class="header__title-big header__title-big_inner-help">                                <%= localization.HeaderTitle.slice(index, localization.HeaderTitle.length) %>                            </div>                        <%= (customization.HeaderLogoLink && customization.HeaderLogoLink.disabled) ? "</span>" : "</a>" %>                    <% } %>                </div>                <div class="header__title header__title_product"><%= titlePreffix %> <%= title %></div>                <div class="header__search">                    <button class="header__search-btn js_mobile_search_button" type="button"></button>                    <input type="search" class="header__search-input is-hidden js_mobile_search_input"                           placeholder="<%= localization.SearchPlaceholder %>" />                    <button class="header__clear-btn is-hidden js_mobile_search_clear" type="button"></button>                </div>            </div>            <div class="col-md-10 hidden-xs hidden-sm">                <div class="header__logo">                    <% if (!customization.FooterLogoLink || !customization.FooterLogoLink.hidden) { %>                        <% if (customization.FooterLogoLink && customization.FooterLogoLink.disabled) { %>                            <span class="logo"></span>                        <% } else { %>                            <a href="<%= localization.FooterLogoLink %>" class="logo"                               title="<%= localization.FooterLogoTitle %>"></a>                        <% } %>                    <% } %>                </div>            </div>        </div>    </div></div><div class="top-bar hidden-xs hidden-sm">    <div class="container">        <div class="row">            <div class="col-md-5">                <div class="top-bar__product-box">                    <div class="top-bar__product js_product_logo"></div>                    <h1 class="top-bar__title js_title">                        <% if (titlePreffix && titlePreffix.trim() ) { %>                            <span class="top-bar__title-small"><%= titlePreffix %></span>                        <% } %>                        <%= title %>                    </h1>                </div>            </div>            <div class="col-md-15">                <div class="top-bar__links-box">                    <div class="top-bar__links">                        <% if ( localization.PrintButtonText && localization.PrintButtonText.trim() ) { %>                            <% if (isAllInOne) { %>                                <a class="top-bar__link top-bar__link_print" href="javascript:print();">                                    <span class="top-bar__icon top-bar__icon_print"></span><%= localization.PrintButtonText %>                                </a>                            <% } else { %>                                <div class="dropdown js_dropdown">                                    <a class="top-bar__link top-bar__link_print js_dropdown_btn" href="#">                                        <span class="top-bar__icon top-bar__icon_print"></span><%= localization.PrintButtonText %>                                        <span class="top-bar__triangle"></span>                                    </a>                                    <ul class="dropdown__list js_dropdown_list">                                        <li class="dropdown__item">                                            <a class="dropdown__link" href="javascript:print();">                                                <%= localization.PrintPageText %>                                            </a>                                        </li>                                        <li class="dropdown__item">                                            <a class="dropdown__link js_print_section" href="">                                                <%= localization.PrintSectionText %>                                            </a>                                        </li>                                        <li class="dropdown__item">                                            <a class="dropdown__link js_print_all" href="all-in-one.htm" target="_blank">                                                <%= localization.PrintAllText %>                                            </a>                                        </li>                                    </ul>                                </div>                            <% } %>                        <% } %>                        <% if ( localization.SupportButtonText && localization.SupportButtonText.trim() &&                                localization.SupportButtonLink && localization.SupportButtonLink.trim() &&                                (!customization.SupportButtonLink || !customization.SupportButtonLink.hidden)) { %>                            <% if (customization.SupportButtonLink && customization.SupportButtonLink.disabled) { %>                                <span class="top-bar__link top-bar__link_support">                                    <span class="top-bar__icon top-bar__icon_support"></span><%= localization.SupportButtonText %>                                </span>                            <% } else { %>                                <a class="top-bar__link top-bar__link_support" href="<%= localization.SupportButtonLink %>" target="blank">                                    <span class="top-bar__icon top-bar__icon_support"></span><%= localization.SupportButtonText %>                                </a>                            <% } %>                        <% } %>                        <% if ( localization.SendLinkButtonText && localization.SendLinkButtonText.trim() &&                                (!customization.SendLinkButton || !customization.SendLinkButton.hidden)) { %>                            <% if (customization.SendLinkButton && customization.SendLinkButton.disabled) { %>                                <span class="top-bar__link top-bar__link_feedback">                                    <span class="top-bar__icon top-bar__icon_feedback"></span><%= localization.SendLinkButtonText %>                                </span>                            <% } else { %>                                <a class="top-bar__link top-bar__link_feedback js_feedback_link" href="">                                    <span class="top-bar__icon top-bar__icon_feedback"></span><%= localization.SendLinkButtonText %>                                </a>                            <% } %>                        <% } %>                    </div>                    <div class="top-bar__langs">                        <span class="top-bar__versions js_header_versions_list"></span>                        <span class="js_header_lang_list"></span>                    </div>                </div>            </div>        </div>    </div></div>';
var IndexLiteralsTemplate = '<ul class="b-index__list"><%    var result,        html = [];    for (var i= 0, item; i < index.length; i++ ) {        item = index[i];        if ( item.nested) {            html.push( "<li class=\'b-index__item js_menu_item b-index__item--nested\'>" );        } else {            html.push( "<li class=\'b-index__item js_menu_item\'>" );        }        if ( item["class"] === "indexlink" ) {            html.push( "<a class=\'b-index__link js_menu_link\' href=\'");            html.push( item.href );            html.push( "\'>" );            html.push( item.text );            html.push( "</a>" )        } else if ( item["class"] === "indexheading" ) {            html.push( "<span class=\'b-index__header\'>" );            html.push( item.text );            html.push( "</span>" )        } else {            html.push( "<span class=\'b-index__subheader\'>" );            html.push( item.text );            html.push( "</span>" )        }        html.push( "</li>" );    }    result = html.join("");%><%= result %></ul>';
var LangListTemplate = '<div class="dropdown dropdown_right js_dropdown">    <a class="dropdown__btn js_dropdown_btn">        <%= currentLang.name %>        <span class="dropdown__arrow"></span>    </a>    <ul class="dropdown__list js_dropdown_list">        <% _.each( langs, function( lang ) {%>            <% var dir = lang.dirname || lang.id %>            <% if (lang.id !== currentLang.id ) { %>                <li class="dropdown__item">                    <% if ( isMac ) { %>                        <a class="dropdown__link js_lang_item" data-lang-id="<%= dir %>" href="../../<%= dir %>/pgs">                            <%= lang.name %>                        </a>                    <% } else { %>                        <a class="dropdown__link js_lang_item" data-lang-id="<%= dir %>" href="../<%= dir %>">                            <%= lang.name %>                        </a>                    <% } %>                </li>            <% } %>        <% }) %>    </ul></div>';
var MenuTemplate = '<%var chunks = [],    isMac = isMacProject,    markup;function htmlTreeBuilder( items, opened ) {    if (items.length) {        chunks.push( "<ul class=\'contents js_contents_level\'" );        chunks.push( !opened ? " style=\'display:none\' ": "" );        chunks.push( ">" );    }    for (var i = 0, item; i < items.length; i++) {        item = items[i];        if ( !item.hidden ) {            if ( item.isActive ) {                chunks.push( "<li class=\'contents__item js_menu_item is-active\'>" );            } else {                chunks.push( "<li class=\'contents__item js_menu_item\'>" );            }            if ( item.children ) {                chunks.push( "<button class=\'contents__toggle js_contents_toggle" );                chunks.push( item.childIsActive || item.isActive ? " is-toggled" : "" );                chunks.push( "\' href=\'#\'></button>" );            }            chunks.push( "<a class=\'contents__item-link js_menu_link\' href=\'" );            chunks.push( (isMac ? "index.htm#" : "") + item.url );            chunks.push( "\'>" );            chunks.push( item.text );            chunks.push( "</a>" );            if ( item.children ) {                /*chunks.push( "<a class=\'contents__item-link-direct js_menu_link_direct\' href=\'" );                chunks.push( item.url );                chunks.push( "\'>" );                chunks.push( "</a>" );*/            }            if ( item.children ) {                htmlTreeBuilder( item.children, item.childIsActive || item.isActive );            }        }    }    if (items.length) {        chunks.push( "</ul>" );    }}htmlTreeBuilder( menu, true );markup = chunks.join("");%><%= markup %>';
var MobileSearchResultsTemplate = '<%if (!isInit){%>    <div class="mobile-search-results__total">        <% if ( resultsCount > 0) { %>            <%= localization.FoundTextBegin %> <%= resultsCount %> <%= localization.FoundTextEnd %>        <% } else { %>            <%= localization.NothingFoundText %>        <%}%>    </div>    <div class="mobile-search-results__content">        <%if ( found ){%>            <ul class="mobile-search-results__list">                <%_.each(results, function( page ){%>                    <li class="mobile-search-result">                        <% var link = isMacProject ? "index.htm#" + page.link : page.link %>                        <a class="mobile-search-result__title" href="<%= link %>"><%= page.title %></a>                        <%_.each( page.texts, function( text ){%>                            <p class="mobile-search-result__content"><%= text %></p>                        <%})%>                    </li>                <%})%>            </ul>        <%}%>    </div><%}%>';
var NextLinkTemplate = '<div class="nav-btn">    <% if (nextPage && nextPage.url) { %>        <% var link = isMacProject ? "index.htm#" + nextPage.url : nextPage.url %>        <a class="nav-btn__link-next js_next_link"           href="<%= link %>"           title="<%= nextPage.text %>"></a>    <% } else { %>        <span class="nav-btn__link-next-inactive"></span>    <% } %></div>';
var PageTitleTemplate = '<div class="page-title">    <div class="page-title__text">        <%= titleHtml %>    </div></div>';
var PrevLinkTemplate = '<div class="nav-btn">    <% if (prevPage && prevPage.url) { %>        <% var link = isMacProject ? "index.htm#" + prevPage.url : prevPage.url %>        <a class="nav-btn__link-prev js_prev_link"           href="<%= link %>"           title="<%= prevPage.text %>"></a>    <% } else { %>        <span class="nav-btn__link-prev-inactive"></span>    <% } %></div>';
var SearchResultsTemplate = '<%if (!isInit){%>    <div class="search-results__header">        <div class="search-results__total">            <%= localization.FoundTextBegin %> <%= resultsCount %> <%= localization.FoundTextEnd %>        </div>    </div>    <%if ( found ){%>        <div class="search-results__content">            <ul class="search-results__list">                <%_.each(results, function( page ){%>                    <li class="search-result">                        <% var link = isMacProject ? "index.htm#" + page.link : page.link %>                        <a class="search-result__title" href="<%= link %>"><%= page.title %></a>                        <%_.each( page.texts, function( text ){%>                            <p class="search-result__content"><%= text %></p>                        <%})%>                    </li>                <%})%>            </ul>        </div>    <%}%><%}%>';
var VersionsTemplate = '<div class="dropdown dropdown_right js_dropdown">    <a class="dropdown__btn js_dropdown_btn">        <%= currentVersion.label %>        <span class="dropdown__arrow"></span>    </a>    <ul class="dropdown__list js_dropdown_list">        <% _.each(versions, function(version)  {%>            <% if (version.url !== currentVersion.url) { %>                <li class="dropdown__item">                    <a class="dropdown__link js_version_item"                       data-version-url="<%= version.url %>" href="../../<%= version.url %>">                        <%= version.label %>                    </a>                </li>            <% } %>        <% }) %>    </ul></div>';
var LangsLocalization = {"en-US":"English","id-ID":"Bahasa Indonesia","cs-CZ":"Čeština &#x202A;(Česká republika)","da-DK":"Dansk &#x202A;(Danmark)","de-DE":"Deutsch","et-EE":"Eesti","es-ES":"Español &#x202A;(España, alfabetización internacional)","es-MX":"Español &#x202A;(México)","fr-FR":"Français","it-IT":"Italiano","lv-LV":"Latviešu","lt-LT":"Lietuvių","hu-HU":"Magyar &#x202A;(Magyarország)","nl-NL":"Nederlands &#x202A;(Nederland)","nb-NO":"Norsk, bokmål &#x202A;(Norge)","pl-PL":"Polski &#x202A;(Polska)","pt-BR":"Português &#x202A;(Brasil)","pt-PT":"Português &#x202A;(Portugal)","ro-RO":"Română &#x202A;(România)","sr-Latn":"Srpski","fi-FI":"Suomi &#x202A;(Suomi)","sv-SE":"Svenska &#x202A;(Sverige)","vi-VN":"Tiếng Việt &#x202A;(Việt Nam)","tr-TR":"Türkçe &#x202A;(Türkiye)","el-GR":"Ελληνικά &#x202A;(Ελλάδα)","bg-BG":"Български","kk-KZ":"Қазақ","ru-RU":"Русский","sr-Cyrl":"Српски","uk-UA":"Українська","ar-AE":"العربية (الإمارات العربية المتحدة&#x202B;)","fa-IR":"فارسى (ایران&#x202B;)","hi-IN":"हिंदी &#x202A;(भारत)","th-TH":"ไทย &#x202A;(ไทย)","ko-KR":"한국어 &#x202A;(대한민국)","ja-JP":"日本語&#x202A;(日本)","zh-Hans":"简体中文","zh-Hant":"繁體中文"};
var Page=new Array();Page[0]=new Array(" ","&nbsp;","&nbsp;","&nbsp;","Dear User, ","Thank you for choosing Kaspersky Lab as your security software provider. We hope that this document helps you to use our product.","Attention! This document is the property of AO Kaspersky Lab (herein also referred to as Kaspersky Lab): all rights to this document are reserved by the copyright laws of the Russian Federation and by international treaties. Illegal reproduction and distribution of this document or parts hereof incur civil, administrative, or criminal liability under applicable law. ","Any type of reproduction or distribution of any materials, including translations, is allowed only with the written permission of Kaspersky Lab.","This document, and graphic images related to it, may be used for informational, non-commercial, and personal purposes only.","Kaspersky Lab reserves the right to amend this document without additional notification.","Kaspersky Lab assumes no liability for the content, quality, relevance, or accuracy of any materials used in this document to which rights are held by third parties, or for any potential harms associated with use of the document.","Document revision date: 01.03.2018","© 2018 AO Kaspersky Lab. All Rights Reserved.","https://www.kaspersky.com<br>https://support.kaspersky.com","Copyright","55937.htm");
Page[1]=new Array("The User's Guide for&nbsp;Kaspersky Endpoint Security 10 Service Pack 1 for&nbsp;Linux (hereinafter referred to&nbsp;as &quot;Kaspersky Endpoint Security&quot;) is&nbsp;intended for&nbsp;professionals who install and administer Kaspersky Endpoint Security, as well as for those who provide technical support to organizations that use Kaspersky Endpoint Security.","You can&nbsp;use the&nbsp;information in&nbsp;this Guide&nbsp;to:","Prepare for&nbsp;installation, install and activate Kaspersky Endpoint Security.","Configure and use Kaspersky Endpoint Security.","This Guide will&nbsp;also help you learn about sources of&nbsp;information on&nbsp;the&nbsp;application and ways to&nbsp;receive technical&nbsp;support.","About this document","161208.htm");
Page[2]=new Array("This Guide contains the&nbsp;following&nbsp;sections:","Sources of&nbsp;information about the&nbsp;application","This section lists the&nbsp;sources of&nbsp;information about the&nbsp;application.","Kaspersky Endpoint Security","This section provides a&nbsp;description of&nbsp;the&nbsp;application's capabilities and brief information about its&nbsp;components. You&nbsp;will&nbsp;learn about the&nbsp;contents of&nbsp;the&nbsp;distribution kit, and which services are&nbsp;available to&nbsp;registered users of&nbsp;the&nbsp;application.","Installing the&nbsp;application","This section contains information on&nbsp;installing Kaspersky Endpoint Security on&nbsp;your computer and completing initial configuration.","Removing the&nbsp;application","This section contains information on&nbsp;removing the&nbsp;application from your&nbsp;computer.","Application licensing","This section covers the&nbsp;main aspects of&nbsp;application&nbsp;licensing.","Starting and stopping the&nbsp;application","This section provides information about how to&nbsp;start, restart, and close the&nbsp;application from the&nbsp;command&nbsp;line.","General settings of Kaspersky Endpoint Security","This section provides information about general application settings.","Managing Kaspersky Endpoint Security tasks using command line","This section contains information about the&nbsp;types of&nbsp;Kaspersky Endpoint Security tasks and instructions on&nbsp;how to&nbsp;manage those&nbsp;tasks using command line.","Real-time protection task (File_Monitoring ID:1)","This section contains information on&nbsp;the&nbsp;real-time protection task, as well as instructions on&nbsp;configuring the&nbsp;settings of&nbsp;this&nbsp;task.","On-demand scan task (Scan_My_Computer ID:2)","This section contains information on&nbsp;the on-demand scan task, as well as instructions on&nbsp;configuring the&nbsp;settings of&nbsp;this&nbsp;task.","Custom scan task (Scan_File ID:3)","This section contains information on&nbsp;the custom scan task, as well as instructions on&nbsp;configuring the&nbsp;settings of&nbsp;this&nbsp;task.","Boot sector scan task (Boot_Scan ID:4)","This section contains information on&nbsp;the boot sectors scan task, as well as instructions on&nbsp;configuring the&nbsp;settings of&nbsp;this&nbsp;task.","Process memory scan task (Memory_Scan ID_5)","This section contains information on&nbsp;the process memory scan task, as well as instructions on&nbsp;configuring the&nbsp;settings of&nbsp;this&nbsp;task.","Update task (Update ID:6)","This section contains information about updating anti-virus databases and application modules (hereinafter collectively referred to&nbsp;as &quot;updates&quot;), and instructions on&nbsp;how to&nbsp;configure update&nbsp;settings.","Update rollback task (Rollback ID:7)","This section contains information on&nbsp;the update rollback task, as well as instructions on&nbsp;how to manage this task.","Update retranslation task (Retranslate ID:8)","This section contains information about anti-virus databases and application updates retranslation, and instructions on&nbsp;how to&nbsp;configure the&nbsp;settings of this task.","License task (License ID:9)","This section contains information on&nbsp;the license task, as well as instructions on&nbsp;how to manage this task.","Storage management task (Backup ID:10)","This section provides instructions on&nbsp;configuring Storage settings, and information about which actions can&nbsp;be&nbsp;performed on&nbsp;objects in&nbsp;Storage.","File Integrity Monitoring task (Integrity_Monitoring ID:11)","This section contains information on&nbsp;the File Integrity Monitoring task, as well as instructions on&nbsp;how to manage this task.","Firewall Manager task (Firewall ID:12)","This section contains information on&nbsp;the Firewall Manager task, as well as instructions on&nbsp;how to manage this task.","Anti-Cryptor task (AntiCryptor ID:13)","This section contains information on&nbsp;the Anti-Cryptor task, as well as instructions on&nbsp;how to manage this task.","Participating in&nbsp;Kaspersky Security Network","This section contains information about participation in Kaspersky Security Network, and instructions on&nbsp;how to&nbsp;enable or disable use of&nbsp;Kaspersky Security&nbsp;Network.","Using Kaspersky Endpoint Security graphical user interface","This section contains information about the application graphical user interface and instructions on how to enable or disable it.","Contacting the Technical Support Service","This section describes the&nbsp;ways to&nbsp;get technical support and the&nbsp;terms on&nbsp;which it is&nbsp;available.","Appendices","This section contains information on&nbsp;the&nbsp;default settings of&nbsp;configuration files and command line return&nbsp;codes. Also this section contains instructions on how to configure Kaspersky Anti-Virus for Linux Mail Server.","AO Kaspersky Lab","This section provides information about Kaspersky&nbsp;Lab.","Information about third-party code","This section provides information about third-party&nbsp;code.","Trademark notices","This section covers trademarks mentioned in&nbsp;the&nbsp;document.","Glossary","This section contains a&nbsp;list of&nbsp;terms mentioned in&nbsp;the&nbsp;document and their respective&nbsp;definitions.","Index","This section allows you to&nbsp;quickly find required information within the&nbsp;document.","In this Guide","161209.htm");
Page[3]=new Array("This document uses the following conventions (see&nbsp;table&nbsp;below).","Document conventions","&nbsp;","Sample text","Description of document convention","Note that...","Warnings are highlighted in red and boxed. Warnings show information about actions that may have unwanted consequences.","We recommended that you use...","Notes are boxed. Notes provide additional and reference information.","Example:","…","Examples are given on a light-blue background under the heading &quot;Example&quot;.","Update means...","The Databases are out of date event occurs.","The following elements are italicized in the text:","New terms","Names of application statuses and events","Press ENTER.","Press ALT+F4.","Names of keyboard keys appear in bold and are capitalized.","Key names joined by a + (plus) sign represent key combinations. Such keys must be pressed simultaneously.","Click the Enable button.","Names of application interface elements, such as entry fields, menu items, and buttons, are set off in bold. ","To configure a task schedule:","Introductory phrases of instructions are italicized and are accompanied by the arrow sign.","In the command line, type help.","The following message then appears:","Specify the date in dd:mm:yy format.","The following types of text content are set off with a special font:","Text in the command line","Text of messages that the application displays on screen","Data to be entered using the keyboard","&lt;User name&gt;","Variables are enclosed in angle brackets. Instead of the variable, insert the corresponding value, not including the angle brackets.","Document conventions","68566.htm");
Page[4]=new Array("Kaspersky Endpoint Security page on the Kaspersky Lab website","On the Kaspersky Endpoint Security page on the Kaspersky Lab website, you can view general information about the application, its functions, and features.","Kaspersky Endpoint Security page in the Knowledge Base","The Knowledge Base is a section on the Kaspersky Lab Technical Support website.","On the Kaspersky Endpoint Security page in the Knowledge Base, you can read articles that provide useful information, recommendations, and answers to frequently asked questions on how to buy, install, and use the application.","Articles in the Knowledge Base may provide answers to questions that relate both to Kaspersky Endpoint Security as well as to other Kaspersky Lab applications. Articles in the Knowledge Base may also contain Technical Support news.","Discuss Kaspersky Lab applications on the Forum","If your question does not require an immediate answer, you can discuss it with Kaspersky Lab experts and other users on our forum.","On the forum you can view existing topics, leave your comments, and create new discussion topics.","An Internet connection is required to access website resources.","If you can't find a solution to your problem, contact Technical Support.","Sources of information about the application","80831.htm");
Page[5]=new Array("You can use the following sources of information about Kaspersky Endpoint Security to research on your own:","Kaspersky Endpoint Security page on the Kaspersky Lab website","Kaspersky Endpoint Security page on the Technical Support website (Knowledge Base)","Help materials included with the application","If you cannot find the solution to an issue on your own, we recommend that you contact Technical Support.","An Internet connection is required for access to website resources.","Kaspersky Endpoint Security page on the Kaspersky Lab website","On the Kaspersky Endpoint Security page you can view general information about the application and its functions and features.","The Kaspersky Endpoint Security page contains a link to the online store, where you can buy or renew your license for the application.","Kaspersky Endpoint Security page in the Knowledge Base","The Knowledge Base&nbsp;is a section on the Kaspersky Lab Technical Support website.","On the Kaspersky Endpoint Security page in the Knowledge Base you can read articles that provide useful information, recommendations, and answers to frequently asked questions on how to purchase, install, and use the application.","Articles in the Knowledge Base may provide answers to questions that relate both to Kaspersky Endpoint Security as well as to other Kaspersky Lab applications. Articles in the Knowledge Base may also contain news from Technical Support.","Help materials included with the application","The application includes full help and context help.","Full help provides information on how to configure and use Kaspersky Endpoint Security.","Context help provides information about Kaspersky Endpoint Security windows, describes Kaspersky Endpoint Security settings and contains links to task descriptions where those settings are used.","Help can be included in the distribution kit or located on the Kaspersky Lab website. If online help is available, a browser window is opened when online help is accessed. An Internet connection is required for viewing online help.","Documentation","The application user guide provides information about how to install, activate, and configure the application, as well as about use of the application. The document also describes the application interface and ways of performing the most typical user tasks.","Sources of information for independent research","166041.htm");
Page[6]=new Array("If your question does not require an immediate answer, you can discuss it with Kaspersky Lab experts and other users on our forum.","On the forum you can view existing topics, leave your comments, and create new discussion topics.","Discussing Kaspersky Lab applications on the Forum","35700.htm");
Page[7]=new Array("This section describes the&nbsp;functions, components, and distribution kit of&nbsp;Kaspersky Endpoint Security, and provides a&nbsp;list of&nbsp;hardware and software requirements of&nbsp;Kaspersky Endpoint Security.","Kaspersky Endpoint Security 10 Service Pack 1 for Linux","161213.htm");
Page[8]=new Array("Kaspersky Endpoint Security protects computers running Linux operating systems against&nbsp;malware. Threats&nbsp;can&nbsp;infiltrate the&nbsp;system via&nbsp;network data transfer channels or from removable&nbsp;drives.","The application lets&nbsp;you:","Scan file system objects located on&nbsp;the&nbsp;computer's local drives, as well as mounted and shared resources accessed via&nbsp;the&nbsp;SMB and NFS&nbsp;protocols.","Scan file system objects both in&nbsp;real time using real-time protection tasks and on&nbsp;demand using on-demand scan&nbsp;tasks.","Scan boot sectors.","Scan process memory.","Detect infected&nbsp;objects. If an&nbsp;object is&nbsp;found to&nbsp;contain code from a&nbsp;known virus, Kaspersky Endpoint Security considers the&nbsp;object as&nbsp;infected.","Neutralize threats detected in&nbsp;files.","Automatically choose what&nbsp;action to&nbsp;perform to&nbsp;neutralize the&nbsp;threat.","Save backup copies of&nbsp;files before disinfection or deletion and restore files from backup&nbsp;copies.","Manage tasks and configure their&nbsp;settings.","Manage the&nbsp;real-time protection task, on-demand scan task, boot sector scan task, process memory scan task, update task, update rollback task, and update retranslation&nbsp;task.","Add keys and activate the&nbsp;application using activation codes.","Notify the&nbsp;administrator about events occurring during the&nbsp;operation of&nbsp;Kaspersky Endpoint Security.","Update Kaspersky Endpoint Security databases from Kaspersky Lab update servers, via&nbsp;the&nbsp;Administration Server, or from a&nbsp;user-specified source by&nbsp;schedule or on&nbsp;demand.","Use anti-virus databases to&nbsp;detect and disinfect infected&nbsp;files. Kaspersky Endpoint Security analyzes each file for&nbsp;threats during the&nbsp;scan&nbsp;process: file code is&nbsp;matched against code that resembles a&nbsp;particular&nbsp;threat.","Monitor the integrity of the specified files and report changes. File integrity monitoring can be performed in a constant monitoring mode, and in on-demand scan mode.","Manage an operating system firewall and, if necessary, restore a set of the firewall rules that was changed.","Protect your files in the local directories with network access by SMB / NFS protocols from remote malicious encrypting.","Allow non-root users manage basic application functions using the graphical user interface.","Update the application using update packages.","Manage Kaspersky Endpoint Security using the&nbsp;following&nbsp;methods:","From the&nbsp;command line using the&nbsp;application control&nbsp;commands.","Using graphical user interface.","Via Kaspersky Security Center.","About Kaspersky Endpoint Security","161214.htm");
Page[9]=new Array("Kaspersky Endpoint Security 10 Service Pack 1 for Linux offers the following features and improvements:","File Integrity Monitoring","Monitors the integrity of the specified files and report changes. File integrity monitoring can be performed in real-time monitoring mode, and in on-demand scan mode.","Firewall management","Allows you to manage an operating system firewall and, if necessary, restore a set of the firewall rules that was changed.","Anti-Cryptor","Protects your files in local directories with network access by SMB / NFS protocols from remote malicious encryption.","Graphical user interface","Allows non-root users to manage basic application functions by using the localized graphical user interface (GUI).","Application updates","You can update the application by using update packages.","The kesl-control utility is now located in the /usr/bin system directory.","What's new","162018.htm");
Page[10]=new Array("The distribution kit includes the&nbsp;Kaspersky Endpoint Security installation package containing the&nbsp;following&nbsp;files:","kesl-10.1.0-&lt;build number&gt;.i386.rpm, kesl_10.1.0-&lt;build number&gt;_i386.deb","Contains the&nbsp;main files of&nbsp;Kaspersky Endpoint Security. Packages&nbsp;can&nbsp;be&nbsp;installed to&nbsp;32-bit operating systems based on&nbsp;the&nbsp;type of&nbsp;package&nbsp;manager.","kesl-10.1.0-&lt;build number&gt;.x86_64.rpm, kesl_10.1.0-&lt;build number&gt;_amd64.deb","Contains the&nbsp;main files of&nbsp;Kaspersky Endpoint Security. Packages&nbsp;can&nbsp;be&nbsp;installed to&nbsp;64-bit operating systems based on&nbsp;the&nbsp;type of&nbsp;package&nbsp;manager.","kesl.zip","Contains the&nbsp;files used in&nbsp;the&nbsp;procedure for&nbsp;remotely installing Kaspersky Endpoint Security using Kaspersky Security Center.","klnagent-&lt;build number&gt;.i386.rpm, klnagent_&lt;build number&gt;_i386.deb, klnagent64-&lt;build number&gt;.x86_64.rpm, klnagent64_&lt;build number&gt;_amd64.deb","Contains Network Agent (a&nbsp;utility that connects Kaspersky Endpoint Security to&nbsp;Kaspersky Security Center).","klnagent-rpm.tar.gz,&nbsp;klnagent-deb.tar.gz","Contain the&nbsp;files&nbsp;klnagent.kpd and&nbsp;akinstall.sh used in&nbsp;the&nbsp;remote installation procedure for&nbsp;Administration Console using Kaspersky Security Center.","The ksn_license.&lt;language ID&gt; file, which you can&nbsp;use to&nbsp;view the&nbsp;terms of&nbsp;participation in&nbsp;Kaspersky Security&nbsp;Network.","The&nbsp;license.&lt;language ID&gt; file, which you can&nbsp;use to&nbsp;view the&nbsp;End User License&nbsp;Agreement. The&nbsp;End User License Agreement specifies the&nbsp;terms of&nbsp;use of&nbsp;the&nbsp;application.","Distribution kit","161216.htm");
Page[11]=new Array("To ensure proper operation of&nbsp;Kaspersky Endpoint Security, your computer must&nbsp;meet the&nbsp;following&nbsp;requirements:","Minimum general&nbsp;requirements:","Core 2 Duo&nbsp;1.86 GHz or higher&nbsp;processor","1 GB of&nbsp;RAM for&nbsp;32-bit operating&nbsp;systems","2 GB of&nbsp;RAM for&nbsp;64-bit operating&nbsp;systems","Swap partition of&nbsp;at&nbsp;least 1&nbsp;GB","1 GB of&nbsp;free disk space on&nbsp;the&nbsp;hard&nbsp;drive","Software&nbsp;requirements:","Supported 32-bit operating&nbsp;systems:","Red Hat Enterprise Linux&nbsp;6.9","CentOS-6.9","Ubuntu Server&nbsp;14.04.5&nbsp;LTS","Ubuntu Server&nbsp;16.04.5&nbsp;LTS","Ubuntu Server&nbsp;17.10.1&nbsp;LTS","Debian GNU/Linux&nbsp;7, all editions (graphical user interface is not supported)","Debian GNU/Linux&nbsp;8.10","Debian GNU/Linux&nbsp;9.3","Supported 64-bit operating&nbsp;systems:","Red Hat Enterprise Linux&nbsp;6.9","Red Hat Enterprise Linux&nbsp;7.4","CentOS-6.9","CentOS-7.4","Ubuntu Server&nbsp;14.04.5&nbsp;LTS","Ubuntu Server&nbsp;16.04.5&nbsp;LTS","Ubuntu Server&nbsp;17.10.1&nbsp;LTS","Debian GNU/Linux&nbsp;7, all editions (graphical user interface is not supported)","Debian GNU/Linux&nbsp;8.10","Debian GNU/Linux&nbsp;9.3","openSUSE&nbsp;42.3","SUSE Linux Enterprise Server 12.3","Novell OES2015, all editions (graphical user interface is not supported)","Oracle Linux&nbsp;7.4","Perl&nbsp;interpreter: version&nbsp;5.10 or&nbsp;higher","Installed Which&nbsp;utility","Installed packages for&nbsp;compiling applications (gcc, binutils, glibc, glibc-devel, make, ld),","source code for&nbsp;the&nbsp;operating system kernel&nbsp;&#8211; for&nbsp;compiling modules of&nbsp;Kaspersky Endpoint Security on&nbsp;operating systems that do&nbsp;not&nbsp;support fanotify&nbsp;technology.","Kaspersky Endpoint Security 10 for&nbsp;Linux is&nbsp;compatible with&nbsp;Kaspersky Security Center 10 SP1 and Kaspersky Security Center 10&nbsp;SP2.","To ensure proper functioning of&nbsp;the&nbsp;Kaspersky Endpoint Security administration plug-in, Microsoft Visual C++ 2015 Redistributable Update 3 RC must&nbsp;be&nbsp;installed.","Prior to&nbsp;installing Network Agent, the&nbsp;following modules must&nbsp;be&nbsp;installed:","The libc6-i386 module must&nbsp;be&nbsp;installed to&nbsp;64-bit versions of&nbsp;Debian and&nbsp;Ubuntu.","The&nbsp;glibc.i686 module must&nbsp;be&nbsp;installed to&nbsp;Red Hat Enterprise Linux 7 or later, CentOS 6 or later, and Oracle Linux 7 or later,&nbsp;Novel.","glibc-32bit module must be installed on openSUSE 42.2, CentOS 6 or later, Novel.","Hardware and software requirements","161217.htm");
Page[12]=new Array("This section contains instructions on&nbsp;how to&nbsp;install the&nbsp;installer package (hereinafter referred to&nbsp;as the&nbsp;&quot;package&quot;) for&nbsp;Kaspersky Endpoint Security and Network&nbsp;Agent.","Installing the application","161219.htm");
Page[13]=new Array("Kaspersky Endpoint Security is&nbsp;distributed in&nbsp;packages in&nbsp;the&nbsp;DEB and RPM&nbsp;formats.","To work with&nbsp;Kaspersky Endpoint Security, you must&nbsp;perform the&nbsp;following:","Install the&nbsp;Kaspersky Endpoint Security&nbsp;package.","Run the&nbsp;settings update&nbsp;script.","Install the Network Agent package and the Kaspersky Endpoint Security administration plug-in if you are&nbsp;planning to&nbsp;manage Kaspersky Endpoint Security using Kaspersky Security Center.","Root rights are required to access the application files and directories during the installation and application update downloading and applying.","About installing Kaspersky Endpoint Security","161220.htm");
Page[14]=new Array("Kaspersky Endpoint Security is&nbsp;distributed in&nbsp;packages in&nbsp;the&nbsp;DEB and RPM&nbsp;formats.","To install Kaspersky Endpoint Security from an&nbsp;RPM package to&nbsp;a&nbsp;32-bit operating system, execute the&nbsp;following&nbsp;command:","# rpm -i&nbsp;kesl-10.1.0-&lt;build number&gt;.i386.rpm","To install Kaspersky Endpoint Security from an&nbsp;RPM package to&nbsp;a&nbsp;64-bit operating system, execute the&nbsp;following&nbsp;command:","# rpm -i&nbsp;kesl-10.1.0-&lt;build number&gt;.x86_64.rpm","To install Kaspersky Endpoint Security from a&nbsp;DEB package to&nbsp;a&nbsp;32-bit operating system, execute the&nbsp;following&nbsp;command:","# dpkg -i&nbsp;kesl-10.1.0-&lt;build number&gt;_i386.deb","To install Kaspersky Endpoint Security from a&nbsp;DEB package to&nbsp;a&nbsp;64-bit operating system, execute the&nbsp;following&nbsp;command:","# dpkg -i kesl_10.1.0-&lt;build number&gt;_amd64.deb","Installing the Kaspersky Endpoint Security package","161221.htm");
Page[15]=new Array("After installing Kaspersky Endpoint Security, you must run the script for post-installation configuration of Kaspersky Endpoint Security. The post-installation configuration script for Kaspersky Endpoint Security is included in the&nbsp;Kaspersky Endpoint Security&nbsp;package.","If you have&nbsp;not&nbsp;complete the&nbsp;procedure for&nbsp;initial configuration of&nbsp;Kaspersky Endpoint Security, the&nbsp;computer's anti-virus protection will&nbsp;not&nbsp;work.","To start the&nbsp;Kaspersky Endpoint Security post-installation configuration script, execute the&nbsp;following&nbsp;command:","# /opt/kaspersky/kesl/bin/kesl-setup.pl","The post-installation configuration script requests Kaspersky Endpoint Security parameter values&nbsp;step-by-step.","The post-installation configuration script must be run with root privileges after installation of the Kaspersky Endpoint Security package is&nbsp;complete.","You can upgrade Kaspersky Endpoint Security 10 for&nbsp;Linux to Kaspersky Endpoint Security 10 Service Pack 1 for&nbsp;Linux. ","Kaspersky Anti-Virus 8.0 for Linux File Server cannot be upgraded to Kaspersky Endpoint Security 10 Service Pack 1 for&nbsp;Linux. You&nbsp;must&nbsp;uninstall the&nbsp;previous version of&nbsp;the&nbsp;application before installing Kaspersky Endpoint Security 10 Service Pack 1 for&nbsp;Linux.","Initial configuration of Kaspersky Endpoint Security settings","161222.htm");
Page[16]=new Array("At this step, you must&nbsp;assign the&nbsp;locale that will&nbsp;be&nbsp;used during operation of&nbsp;Kaspersky Endpoint Security.","You can&nbsp;assign the&nbsp;locale in&nbsp;the&nbsp;format defined in&nbsp;RFC&nbsp;3066.","To receive a&nbsp;full list of&nbsp;locale values, execute the&nbsp;following&nbsp;command:","# locale&nbsp;-a","By default, the&nbsp;application suggests using the&nbsp;locale that is&nbsp;set for&nbsp;root.","Step 1. Selecting the locale","161223.htm");
Page[17]=new Array("At this step, you must&nbsp;either agree or decline the&nbsp;terms of&nbsp;the&nbsp;End User License&nbsp;Agreement.","You can&nbsp;view the&nbsp;text by&nbsp;using the&nbsp;less&nbsp;utility. To&nbsp;navigate through the&nbsp;text, use the&nbsp;arrow keys or the&nbsp;B (to&nbsp;move back one screen) and F (to&nbsp;move forward one screen)&nbsp;keys. To&nbsp;obtain help, use the&nbsp;H&nbsp;key. To&nbsp;finish your review, use the&nbsp;Q&nbsp;key.","After exiting viewing mode, enter one of&nbsp;the&nbsp;following&nbsp;values:","yes (or y), if you accept the&nbsp;terms of&nbsp;the&nbsp;End User License&nbsp;Agreement.","no (or n), if you do&nbsp;not&nbsp;accept the&nbsp;terms of&nbsp;the&nbsp;End User License&nbsp;Agreement.","If you do not agree to the terms of the End User License Agreement, the&nbsp;application terminates the Kaspersky Endpoint Security configuration&nbsp;process.","Step 2. Accepting the End User License Agreement","161224.htm");
Page[18]=new Array("At this step, you must&nbsp;either agree or decline the&nbsp;terms of&nbsp;the&nbsp;Privacy Policy.","You can&nbsp;view the&nbsp;text by&nbsp;using the&nbsp;less&nbsp;utility. To&nbsp;navigate through the&nbsp;text, use the&nbsp;arrow keys or the&nbsp;B (to&nbsp;move back one screen) and F (to&nbsp;move forward one screen)&nbsp;keys. To&nbsp;obtain help, use the&nbsp;H&nbsp;key. To&nbsp;finish your review, use the&nbsp;Q&nbsp;key.","After exiting viewing mode, enter one of&nbsp;the&nbsp;following&nbsp;values:","yes (or y), if you accept the&nbsp;Privacy Policy.","no (or n), if you do&nbsp;not&nbsp;accept the&nbsp;Privacy Policy.","If you do not agree to the Privacy Policy, the&nbsp;application terminates the Kaspersky Endpoint Security configuration&nbsp;process.","Step 3. Accepting the Privacy Policy","166206.htm");
Page[19]=new Array("At this step, you must either accept or decline the terms of the Kaspersky Security Network Statement. The file containing the text of the Kaspersky Security Network Statement is&nbsp;located in the directory /opt/kaspersky/kesl/doc/ksn_license.&lt;language ID&gt;.","Enter one of&nbsp;the&nbsp;following&nbsp;values:","yes (or y), if you agree to&nbsp;the&nbsp;terms of&nbsp;the&nbsp;Kaspersky Security Network&nbsp;Statement. The extended mode of Kaspersky Security Network will be enabled. ","no (or n), if you do&nbsp;not&nbsp;agree to&nbsp;the&nbsp;terms of&nbsp;the&nbsp;Kaspersky Security Network&nbsp;Statement.","Refusal to&nbsp;participate in Kaspersky Security Network does not interrupt the&nbsp;Kaspersky Endpoint Security installation process. You&nbsp;can&nbsp;enable, disable, or change the&nbsp;Kaspersky Security Network mode at&nbsp;any&nbsp;time.","Step 4. Participating in Kaspersky Security Network","161225.htm");
Page[20]=new Array("At this step, the&nbsp;type of&nbsp;file operation interceptor for&nbsp;the&nbsp;utilized operating system is&nbsp;determined. For&nbsp;operating systems that do&nbsp;not&nbsp;support fanotify technology, kernel module compilation is&nbsp;started. The&nbsp;kernel module is&nbsp;required for&nbsp;operation of&nbsp;the&nbsp;real-time protection&nbsp;task.","To compile the&nbsp;kernel module, the&nbsp;System.map-&lt;kernel version&gt; file must&nbsp;be&nbsp;present in&nbsp;the&nbsp;/boot/&nbsp;directory.","If the&nbsp;script finds the&nbsp;operating system's Module kernel source code in&nbsp;the&nbsp;default directory, the&nbsp;application will&nbsp;use the&nbsp;path to&nbsp;this&nbsp;directory. Otherwise, you will&nbsp;have&nbsp;to&nbsp;specify the&nbsp;path to&nbsp;the&nbsp;Module kernel source&nbsp;code.","If the necessary packages are not detected during the Module kernel compilation process, Kaspersky Endpoint Security attempts to download them on its own. If&nbsp;it fails to&nbsp;download the packages, an error message is&nbsp;displayed.","You can&nbsp;compile the&nbsp;kernel module later after&nbsp;initial configuration of&nbsp;Kaspersky Endpoint Security is&nbsp;complete.","Step 5. Determining the type of file operation interceptor","161226.htm");
Page[21]=new Array("At this step, you can download Kaspersky Endpoint Security anti-virus databases to&nbsp;your&nbsp;computer. Anti-virus databases contain descriptions of&nbsp;threat signatures and methods of countering them. Kaspersky Endpoint Security uses these records when searching for threats and neutralizing them. Kaspersky Lab virus analysts regularly add new records about new&nbsp;threats.","To download Kaspersky Endpoint Security anti-virus databases to&nbsp;your computer, you must&nbsp;enter yes as your&nbsp;answer.","Enter no&nbsp;if you do&nbsp;not&nbsp;want to&nbsp;immediately download anti-virus&nbsp;databases.","The default answer is&nbsp;yes.","The application will provide anti-virus protection for the computer only after downloading the Kaspersky Endpoint Security anti-virus&nbsp;databases.","You can&nbsp;start Update task without using the&nbsp;initial configuration&nbsp;script.","Step 6. Downloading Kaspersky Endpoint Security anti-virus databases","161228.htm");
Page[22]=new Array("At this step, you must&nbsp;specify the&nbsp;proxy server settings if you are&nbsp;using a&nbsp;proxy server to&nbsp;access the&nbsp;Internet. An&nbsp;Internet connection is&nbsp;required for&nbsp;downloading Kaspersky Endpoint Security anti-virus databases from the&nbsp;update servers.","To configure proxy server settings, perform one of&nbsp;the&nbsp;following&nbsp;actions:","If you use a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;Internet, specify the&nbsp;address of&nbsp;the&nbsp;proxy server using one of&nbsp;the&nbsp;following&nbsp;formats:","proxy_server_IP:port_number, if no&nbsp;authentication is&nbsp;required to&nbsp;connect to&nbsp;the&nbsp;proxy&nbsp;server;","user_name:password@proxy_server_IP_address:port_number, if authentication is&nbsp;required when connecting to&nbsp;the&nbsp;proxy&nbsp;server.","If you do&nbsp;not&nbsp;use a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;Internet, enter no&nbsp;as your&nbsp;answer.","By default, the&nbsp;application suggests the&nbsp;answer&nbsp;no.","You can&nbsp;configure the&nbsp;proxy server settings without using the&nbsp;initial configuration&nbsp;script.","Step 7. Configuring proxy server settings","161227.htm");
Page[23]=new Array("At this step, you can&nbsp;enable automatic updates of&nbsp;anti-virus&nbsp;databases.","Enter yes to&nbsp;enable automatic update of&nbsp;anti-virus&nbsp;databases. By&nbsp;default, Kaspersky Endpoint Security checks for&nbsp;available anti-virus database updates every&nbsp;60&nbsp;minutes. If&nbsp;updates are&nbsp;available, Kaspersky Endpoint Security downloads the&nbsp;updated anti-virus&nbsp;databases.","Enter no&nbsp;if you do&nbsp;not&nbsp;want Kaspersky Endpoint Security to&nbsp;automatically update the&nbsp;anti-virus&nbsp;databases.","You can&nbsp;enable automatic updates of&nbsp;anti-virus databases without using the&nbsp;initial configuration script by&nbsp;managing the&nbsp;update task schedule.","Step 8. Enabling automatic update of anti-virus databases","161229.htm");
Page[24]=new Array("At this step, you must&nbsp;activate the&nbsp;application with&nbsp;an&nbsp;activation code or a&nbsp;key&nbsp;file.","To activate the&nbsp;application with&nbsp;an&nbsp;activation code, you must&nbsp;enter the&nbsp;activation&nbsp;code.","To activate the&nbsp;application using a&nbsp;key file, you must&nbsp;specify the&nbsp;full path to&nbsp;the&nbsp;key&nbsp;file.","If no&nbsp;activation code or key file is&nbsp;specified, the&nbsp;application will&nbsp;be&nbsp;activated using a&nbsp;trial key for&nbsp;one&nbsp;month.","You can&nbsp;install a&nbsp;key file without using the&nbsp;initial configuration script.","Step 9. Activating the application","161230.htm");
Page[25]=new Array("At this step, you can enable the use of the graphical user interface (GUI).","Enter one of the following values:","yes (or y), if you want to enable the use of the graphical user interface. Kaspersky Endpoint Security will check all required libraries, and, if necessary, try to install the missing ones.","no (or n), if you do not want to enable the use of the graphical user interface.","You&nbsp;can&nbsp;enable or disable the&nbsp;use of&nbsp;the graphical user interface at&nbsp;any&nbsp;time.","Step 10. Configuring graphical user interface","161231.htm");
Page[26]=new Array("You can perform automatic initial configuration of Kaspersky Endpoint Security. The&nbsp;application sets the values of settings as specified in&nbsp;the&nbsp;initial setup configuration&nbsp;file.","To start automatic initial configuration of&nbsp;Kaspersky Endpoint Security, execute the&nbsp;following&nbsp;command:","kesl-setup.pl --autoinstall=&lt;full path to&nbsp;the&nbsp;initial configuration file&gt;","Automatic initial configuration of Kaspersky Endpoint Security","161232.htm");
Page[27]=new Array("The Kaspersky Endpoint Security initial setup configuration file contains the&nbsp;settings presented in&nbsp;the&nbsp;table&nbsp;below.","Settings of&nbsp;the&nbsp;Kaspersky Endpoint Security initial setup configuration&nbsp;file","Setting","Description","Available values","EULA_AGREED","Required&nbsp;setting","Acceptance of&nbsp;the&nbsp;terms of&nbsp;the&nbsp;End User License Agreement","yes&#8212;You must&nbsp;accept the&nbsp;terms of&nbsp;the&nbsp;End User License Agreement to&nbsp;continue the&nbsp;application installation&nbsp;procedure","no&#8212;Do not accept the End User License Agreement. The application installation will be interrupted","PRIVACY_POLICY_AGREED","Required setting","Acceptance of&nbsp;the&nbsp;Privacy Policy","yes&#8212;You must accept the Privacy Policy to to&nbsp;continue the&nbsp;application installation&nbsp;procedure","no&#8212;Do not accept the Privacy Policy. The application installation will be interrupted","USE_KSN","Acceptance of&nbsp;the&nbsp;Kaspersky Security Network Statement","yes&#8212;Accept the&nbsp;Kaspersky Security Network&nbsp;Statement","no&#8212;Do&nbsp;not&nbsp;accept the&nbsp;Kaspersky Security Network&nbsp;Statement","SERVICE_LOCALE","Optional setting","Locale used during operation of &nbsp;Kaspersky Endpoint Security","The locale in the format specified by RFC 3066.","If the SERVICE_LOCALE setting is not specified, the system locale is set by default.","INSTALL_LICENSE","Activation code or key file","&#8212;","UPDATER_SOURCE","Updates source","SCServer&#8212;Use the&nbsp;Kaspersky Security Center Administration Server as the&nbsp;update&nbsp;source","KLServers&#8212;Use the&nbsp;Kaspersky Lab servers as the&nbsp;update&nbsp;source","update source address","PROXY_SERVER","Address of&nbsp;the&nbsp;proxy server used to&nbsp;connect to&nbsp;the&nbsp;Internet","proxy server&nbsp;address","no&#8212;Do not&nbsp;use a&nbsp;proxy&nbsp;server","UPDATE_EXECUTE","Start database update task during setup","yes&#8212;Start update&nbsp;task","no&#8212;Do not&nbsp;start update&nbsp;task","KERNEL_SRCS_INSTALL","Automatic start of&nbsp;kernel module compilation","yes&#8212;Compile kernel&nbsp;module","no&#8212;Do not&nbsp;compile kernel&nbsp;module","USE_GUI","Enable the use of the graphical user interface","yes&#8212;Enable the use of the graphical user interface","no&#8212;Disable the use of the graphical user interface","IMPORT_SETTINGS","Use application settings from a configuration file ","yes&#8212;Use application settings from a configuration file","no&#8212;Do not use application settings from a configuration file","If you want to&nbsp;change the&nbsp;settings in&nbsp;the&nbsp;initial setup configuration file for&nbsp;Kaspersky Endpoint Security, enter the&nbsp;values of&nbsp;settings in&nbsp;the&nbsp;format parameter_name=parameter_value (the&nbsp;application does&nbsp;not&nbsp;process spaces between a&nbsp;parameter name and its value).","Settings of the Kaspersky Endpoint Security initial setup configuration file","161233.htm");
Page[28]=new Array("You can&nbsp;install Kaspersky Endpoint Security to&nbsp;a&nbsp;computer via&nbsp;Kaspersky Security Center.","More details about this type of&nbsp;application installation can&nbsp;be&nbsp;found in&nbsp;the&nbsp;Kaspersky Security Center documentation.","Installing Kaspersky Endpoint Security via Kaspersky Security Center","161234.htm");
Page[29]=new Array("Installation of Network Agent is required if you are&nbsp;planning on managing Kaspersky Endpoint Security via Kaspersky Security Center.","The Network Agent installation process must&nbsp;be&nbsp;started with&nbsp;root&nbsp;privileges.","To install Network Agent from an&nbsp;RPM package to&nbsp;a&nbsp;32-bit operating system, execute the&nbsp;following&nbsp;command:","# rpm -i klnagent-&lt;build number&gt;.i386.rpm","To install Network Agent from an&nbsp;RPM package to&nbsp;a&nbsp;64-bit operating system, execute the&nbsp;following&nbsp;command:","# rpm -i klnagent64-&lt;build number&gt;.x86_64.rpm","To install Network Agent from a&nbsp;DEB package to&nbsp;a&nbsp;32-bit operating system, execute the&nbsp;following&nbsp;command:","# dpkg -i klnagent_&lt;build number&gt;_i386.deb","To install Network Agent from a&nbsp;DEB package to&nbsp;a&nbsp;64-bit operating system, execute the&nbsp;following&nbsp;command:","# dpkg -i klnagent64_&lt;build number&gt;_amd64.deb","After installing the&nbsp;package, start the&nbsp;Kaspersky Endpoint Security post-installation configuration script by&nbsp;executing the&nbsp;following&nbsp;command:","for a&nbsp;32-bit operating system:","/opt/kaspersky/klnagent/lib/bin/setup/postinstall.pl","for a&nbsp;64-bit operating system:","/opt/kaspersky/klnagent64/lib/bin/setup/postinstall.pl","Installing Network Agent","161235.htm");
Page[30]=new Array("If you plan to&nbsp;manage Kaspersky Endpoint Security via&nbsp;Kaspersky Security Center, you must&nbsp;configure the&nbsp;Network Agent&nbsp;settings.","To configure the&nbsp;Network Agent&nbsp;settings:","Execute the&nbsp;command:","for a&nbsp;32-bit operating system:","# /opt/kaspersky/klnagent/lib/bin/setup/postinstall.pl","for a&nbsp;64-bit operating system:","# /opt/kaspersky/klnagent64/lib/bin/setup/postinstall.pl","Specify the&nbsp;DNS name or IP address of&nbsp;the&nbsp;Administration&nbsp;Server.","Specify the&nbsp;port number of&nbsp;the&nbsp;Administration&nbsp;Server.","Port 14000 is&nbsp;used by&nbsp;default.","If you want to&nbsp;use an&nbsp;SSL connection, specify the&nbsp;SSL port number of&nbsp;the&nbsp;Administration&nbsp;Server.","Port 13000 is&nbsp;used by&nbsp;default.","Do one of the following:","Enter yes if you want to&nbsp;use an&nbsp;SSL&nbsp;connection.","Enter no&nbsp;if you do&nbsp;not&nbsp;want to&nbsp;use an&nbsp;SSL&nbsp;connection.","By default, SSL connection is&nbsp;enabled.","If necessary, specify the connection gateway mode:","0&#8212;Do not use connection gateway.","1&#8212;Use this Network Agent as connection gateway.","2&#8212;Connect to Administration Server through connection gateway.","For more detailed information about configuring Network Agent, please refer to the Kaspersky Security Center documentation.","Initial configuration of Network Agent settings","161236.htm");
Page[31]=new Array("You can upgrade Kaspersky Endpoint Security 10 for Linux to Kaspersky Endpoint Security 10 Service Pack 1 for Linux. ","You can upgrade the old version of the application as follows:","Locally&#8212;From the command line","Remotely&#8212;Using the Kaspersky Security Center software suite (see the Kaspersky Security Center documentation)","When upgrading a previous version of the application to Kaspersky Endpoint Security 10 Service Pack 1 for Linux, you do not have to remove the previous version of the application. We recommend quitting all active applications before upgrading a previous application version.","Upgrading an old application version","161237.htm");
Page[32]=new Array("You can upgrade Kaspersky Endpoint Security 10 for Linux to Kaspersky Endpoint Security 10 Service Pack 1 for Linux locally by performing the procedure below.","A restart of the operating system or application may be required after the upgrade procedure is complete.","To upgrade the application:","Run the required Kaspersky Endpoint Security 10 Service Pack 1 for Linux package installation.","Kaspersky Endpoint Security 10 for Linux is stopped, and the application settings and event log are exported.","Run the post-installation configuration script.","The post-installation configuration script requests Kaspersky Endpoint Security parameter values step-by-step.","Accepting the End User License Agreement (EULA) and the Privacy Policy is mandatory.","The application settings and event log are transferred to the upgraded application version; new settings are set to the default values. When the application settings are transferred, the application stops.","If necessary, restart the operating system or the application.","If an error occurred during the application upgrade procedure, the application cannot be automatically restored to the previous version. An error message is displayed.","If the transfer of application settings fails for any reason, the application is set to the default values.","Upgrading the application from the command line","165607.htm");
Page[33]=new Array("You can remotely upgrade Kaspersky Endpoint Security 10 for Linux to Kaspersky Endpoint Security 10 Service Pack 1 for Linux using Kaspersky Security Center by performing the following procedure.","To upgrade the application managed by the Kaspersky Security Center policy:","Upgrade Network Agent.","If Network Agent is not upgraded, the application cannot be managed through Kaspersky Security Center.","The application functions correctly during a Network Agent upgrade.","Remotely install Kaspersky Endpoint Security 10 Service Pack 1 for Linux.","More details about this type of application upgrade can be found in the Kaspersky Security Center documentation.","Upgrading the application using Kaspersky Security Center","165608.htm");
Page[34]=new Array("To create an&nbsp;SELinux module with&nbsp;rules required for&nbsp;operation of&nbsp;Kaspersky Endpoint Security:","Switch SELinux to&nbsp;permissive&nbsp;mode:","If SELinux has&nbsp;been activated, execute the&nbsp;following&nbsp;command:","# setenforce&nbsp;Permissive","If SELinux was&nbsp;disabled, in&nbsp;the&nbsp;configuration file /etc/selinux/config specify the&nbsp;SELINUX=permissive parameter value and restart the&nbsp;operating&nbsp;system.","Run the&nbsp;following&nbsp;tasks:","real-time protection&nbsp;task:","kesl-control --start-t&nbsp;1","process memory scan&nbsp;task:","kesl-control --start-t 4&nbsp;-W","boot sector scan&nbsp;task:","kesl-control --start-t 5&nbsp;-W","Create a&nbsp;rules module on&nbsp;the&nbsp;basis of&nbsp;blocking&nbsp;records:","grep kesl /var/log/audit/audit.log | audit2allow -M&nbsp;kesl","Ensure that the&nbsp;generated list contains only rules related to&nbsp;Kaspersky Endpoint Security.","Load the&nbsp;new rules&nbsp;module:","# semodule -i&nbsp;kesl.pp","Switch SELinux to&nbsp;enforcing&nbsp;mode:","# setenforce&nbsp;Enforcing","If new audit messages related to&nbsp;Kaspersky Endpoint Security appear, the&nbsp;rules module file needs to&nbsp;be&nbsp;updated.","For additional information, please refer to&nbsp;the&nbsp;documentation on&nbsp;the&nbsp;relevant operating&nbsp;system.","Configuring permissions in the SELinux system","161238.htm");
Page[35]=new Array("To update the&nbsp;AppArmor profiles required to&nbsp;run Kaspersky Endpoint Security:","Make sure that the&nbsp;AppArmor module is&nbsp;loaded by&nbsp;using one of&nbsp;the&nbsp;following&nbsp;methods:","systemctl status&nbsp;apparmor","/etc/init.d/apparmor&nbsp;status","Create a&nbsp;Kaspersky Endpoint Security&nbsp;profile:","In the&nbsp;first console, execute the&nbsp;following&nbsp;commands:","cd /etc/apparmor.d","aa-genprof /opt/kaspersky/kesl/libexec/kesl","In the&nbsp;second console, run the&nbsp;following&nbsp;tasks:","real-time protection&nbsp;task:","kesl-control --start-t&nbsp;1","process memory scan&nbsp;task:","kesl-control --start-t 4&nbsp;-W","boot sector scan&nbsp;task:","kesl-control --start-t 5&nbsp;-W","update&nbsp;task:","kesl-control --start-t 6&nbsp;-W","In the&nbsp;first console, press&nbsp;S. After&nbsp;event scanning completes, press&nbsp;F.","Switch the&nbsp;created Kaspersky Endpoint Security profile to&nbsp;message display&nbsp;mode:","aa-complain&nbsp;opt.kaspersky.kesl.libexec.kesl","After the&nbsp;application has&nbsp;run for&nbsp;several days, update the&nbsp;profile by&nbsp;running the&nbsp;following&nbsp;command:","aa-logprof","Specify the&nbsp;Allow or Glob permissions for&nbsp;all files that Kaspersky Endpoint Security used during this&nbsp;period.","Switch the&nbsp;Kaspersky Endpoint Security profile to&nbsp;blocking&nbsp;mode:","aa-enforce&nbsp;opt.kaspersky.kesl.libexec.kesl","If new audit messages related to&nbsp;Kaspersky Endpoint Security appear, the&nbsp;rules module file needs to&nbsp;be&nbsp;updated.","For additional information, please refer to&nbsp;the&nbsp;documentation on&nbsp;the&nbsp;relevant operating&nbsp;system.","Configuring permissions in the AppArmor system","161239.htm");
Page[36]=new Array("This section contains instructions on how to remove Kaspersky Endpoint Security locally or via Kaspersky Security Center.","Removing the application","161240.htm");
Page[37]=new Array("While the&nbsp;application is&nbsp;being removed, all tasks of&nbsp;Kaspersky Endpoint Security will&nbsp;be&nbsp;stopped.","To uninstall Kaspersky Endpoint Security that was&nbsp;installed from an&nbsp;RPM package, execute the&nbsp;following&nbsp;command:","# rpm -e&nbsp;kesl","To uninstall Kaspersky Endpoint Security that was&nbsp;installed from a&nbsp;DEB package, execute the&nbsp;following&nbsp;command:","# dpkg -r&nbsp;kesl","To remove Network Agent that was&nbsp;installed from an&nbsp;RPM package, execute the&nbsp;following&nbsp;command:","# rpm -e&nbsp;klnagent","To remove Network Agent that was&nbsp;installed from a&nbsp;DEB package, execute the&nbsp;following&nbsp;command:","# dpkg -r&nbsp;klnagent","The application automatically performs the&nbsp;removal&nbsp;procedure. When&nbsp;completed, the&nbsp;application displays a&nbsp;message containing the&nbsp;results of&nbsp;removal.","After Kaspersky Endpoint Security removal, the license database remains, which can be used when installing the application again.","Local removal of Kaspersky Endpoint Security","161241.htm");
Page[38]=new Array("You can&nbsp;remove Kaspersky Endpoint Security via&nbsp;Kaspersky Security Center. To&nbsp;do&nbsp;so, you must&nbsp;create and start a&nbsp;removal task for&nbsp;Kaspersky Endpoint Security.","For more details about creating and starting a&nbsp;Kaspersky Endpoint Security removal task, please refer to&nbsp;the&nbsp;Kaspersky Security Center documentation.","Removing Kaspersky Endpoint Security via Kaspersky Security Center","161242.htm");
Page[39]=new Array("This section covers the&nbsp;main aspects of&nbsp;application&nbsp;licensing.","Application licensing","161243.htm");
Page[40]=new Array("The End User License Agreement&nbsp;is&nbsp;a&nbsp;binding agreement between you and AO Kaspersky Lab, stipulating the&nbsp;terms on&nbsp;which you may use the&nbsp;application.","Read through the&nbsp;terms of&nbsp;the&nbsp;License Agreement carefully before you start using the&nbsp;application.","You can&nbsp;view the&nbsp;terms of&nbsp;the&nbsp;License Agreement in&nbsp;the&nbsp;following&nbsp;ways:","During installation of&nbsp;Kaspersky Endpoint Security.","By reading the&nbsp;license.&lt;language ID&gt;&nbsp;file. This&nbsp;file is&nbsp;included in&nbsp;the&nbsp;application's distribution&nbsp;kit.","By confirming that you agree with&nbsp;the&nbsp;End User License Agreement when installing the application, you signify your acceptance of the terms of the End User License Agreement. If you do not accept the terms of the End User License Agreement, you must abort application installation and must&nbsp;not&nbsp;use the&nbsp;application.","About the End User License Agreement","161244.htm");
Page[41]=new Array("A license&nbsp;is&nbsp;a&nbsp;time-limited right to&nbsp;use the&nbsp;application, granted under&nbsp;the&nbsp;End User License&nbsp;Agreement.","A current license entitles you to&nbsp;the&nbsp;following kinds of&nbsp;services:","Use of&nbsp;the&nbsp;application in&nbsp;accordance with&nbsp;the&nbsp;terms of&nbsp;the&nbsp;End User License&nbsp;Agreement","Getting technical&nbsp;support","The scope of&nbsp;services and application usage term depend on&nbsp;the&nbsp;type of&nbsp;license under&nbsp;which the&nbsp;application is&nbsp;activated.","The following license types are&nbsp;provided:","Trial&#8212;Free license intended for&nbsp;trying out the&nbsp;application.","A trial license is&nbsp;usually of&nbsp;limited&nbsp;duration. When&nbsp;the&nbsp;trial license expires, all Kaspersky Endpoint Security features become&nbsp;disabled. To&nbsp;continue using the&nbsp;application, you need to&nbsp;purchase a&nbsp;commercial&nbsp;license.","You can&nbsp;activate the&nbsp;application under&nbsp;a&nbsp;trial license only&nbsp;once.","Commercial&#8212;Paid license offered upon purchase of&nbsp;the&nbsp;application.","When the&nbsp;commercial license expires, the&nbsp;application continues running with&nbsp;limited functionality (for&nbsp;example, Kaspersky Endpoint Security database updates are&nbsp;not&nbsp;available). To&nbsp;continue using Kaspersky Endpoint Security in&nbsp;fully functional mode, you must&nbsp;renew your commercial&nbsp;license.","We recommend renewing the&nbsp;license before its expiration to&nbsp;ensure maximum protection of&nbsp;your computer against security&nbsp;threats.","About the license","161245.htm");
Page[42]=new Array("License Certificate&#8212;Document provided with&nbsp;the&nbsp;key file or activation&nbsp;code.","The License Certificate contains the&nbsp;following license&nbsp;information:","Order&nbsp;number","Details of&nbsp;the&nbsp;license&nbsp;holder","Information about the&nbsp;application that can&nbsp;be&nbsp;activated using the&nbsp;license","Limitation on&nbsp;the&nbsp;number of&nbsp;licensing units (devices on&nbsp;which the&nbsp;application can&nbsp;be&nbsp;used under&nbsp;the&nbsp;license)","License start&nbsp;date","License expiration date or license validity&nbsp;period","License&nbsp;type","About the license certificate","161246.htm");
Page[43]=new Array("Activation code&#8212;Unique sequence of&nbsp;twenty Latin letters and&nbsp;numerals. You&nbsp;have&nbsp;to&nbsp;enter an&nbsp;activation code in&nbsp;order to&nbsp;add a&nbsp;key that activates Kaspersky Endpoint Security. You receive the activation code at the email address that you provided when you bought Kaspersky Endpoint Security or ordered the&nbsp;trial version of&nbsp;Kaspersky Endpoint Security.","To activate the application using the&nbsp;activation code, Internet access is&nbsp;required to&nbsp;connect to Kaspersky Lab's activation&nbsp;servers.","If the activation code has&nbsp;been lost after activation of the application, you can restore the activation code. You may need the activation code to&nbsp;register a&nbsp;Kaspersky CompanyAccount, for&nbsp;example. To restore an activation code, you must&nbsp;contact Kaspersky Lab Technical Support.","About the activation code","161247.htm");
Page[44]=new Array("Key&#8212;Sequence of&nbsp;bits with&nbsp;which you can&nbsp;activate and subsequently use the&nbsp;application in&nbsp;accordance with&nbsp;the&nbsp;terms of&nbsp;the&nbsp;End User License&nbsp;Agreement. A&nbsp;key is&nbsp;generated by&nbsp;Kaspersky&nbsp;Lab.","You can&nbsp;add a&nbsp;key to&nbsp;the&nbsp;application in&nbsp;one of&nbsp;the&nbsp;following&nbsp;ways: apply a&nbsp;key file or enter an&nbsp;activation&nbsp;code. After&nbsp;you add a&nbsp;key to&nbsp;the&nbsp;application, the&nbsp;key is&nbsp;displayed in&nbsp;the&nbsp;application interface as a&nbsp;unique alphanumeric&nbsp;sequence.","Kaspersky Lab can&nbsp;black-list a&nbsp;key over&nbsp;violations of&nbsp;the&nbsp;End User License&nbsp;Agreement. If&nbsp;the&nbsp;key has&nbsp;been black-listed, you have&nbsp;to&nbsp;add a&nbsp;different key to&nbsp;continue using the&nbsp;application.","There are&nbsp;two types of&nbsp;keys: active and&nbsp;additional.","Active key&#8212;Key that is&nbsp;currently used by&nbsp;the&nbsp;application. A&nbsp;trial or commercial license key can&nbsp;be&nbsp;added as the&nbsp;active&nbsp;key. The&nbsp;application cannot have&nbsp;more than one active&nbsp;key.","Additional key&#8212;Key that certifies the&nbsp;right to&nbsp;use the&nbsp;application but is&nbsp;not&nbsp;currently being&nbsp;used. An&nbsp;additional key automatically becomes active when the&nbsp;license associated with&nbsp;the&nbsp;current active key&nbsp;expires. An&nbsp;additional key can&nbsp;be&nbsp;added only if the&nbsp;active key is&nbsp;available.","A key for&nbsp;a&nbsp;trial license can&nbsp;be&nbsp;added only as the&nbsp;active&nbsp;key. A&nbsp;key for&nbsp;a&nbsp;trial license cannot be&nbsp;added as an&nbsp;additional&nbsp;key.","About the key","161248.htm");
Page[45]=new Array("A key file&nbsp;is&nbsp;a&nbsp;file with&nbsp;the&nbsp;.key extension that you receive from Kaspersky&nbsp;Lab. Key&nbsp;files are&nbsp;designed to&nbsp;activate the&nbsp;application by&nbsp;adding a&nbsp;key.","You receive a&nbsp;key file at&nbsp;the&nbsp;email address that you provided when you bought Kaspersky Endpoint Security or ordered the&nbsp;trial version of&nbsp;Kaspersky Endpoint Security.","You do&nbsp;not&nbsp;need to&nbsp;connect to&nbsp;Kaspersky Lab activation servers in&nbsp;order to&nbsp;activate the&nbsp;application with&nbsp;a&nbsp;key&nbsp;file.","You can&nbsp;recover a key file if it is&nbsp;accidentally&nbsp;deleted. You&nbsp;may need a&nbsp;key file to&nbsp;register with Kaspersky&nbsp;CompanyAccount.","To recover a&nbsp;key file, do&nbsp;one of&nbsp;the&nbsp;following:","Contact Technical Support (http://support.kaspersky.com).","Receive a&nbsp;key file through Kaspersky Lab website (https://activation.kaspersky.com) by&nbsp;using your available activation&nbsp;code.","About the key file","161249.htm");
Page[46]=new Array("Subscription for&nbsp;Kaspersky Endpoint Security is&nbsp;a&nbsp;purchase order for&nbsp;the&nbsp;application with&nbsp;specific parameters (subscription expiry date, number of&nbsp;devices protected). You&nbsp;can&nbsp;order a&nbsp;subscription for&nbsp;Kaspersky Endpoint Security from your service provider (such as your ISP). A&nbsp;subscription can&nbsp;be&nbsp;renewed manually or automatically, or you may cancel your&nbsp;subscription. You&nbsp;can&nbsp;manage your subscription on&nbsp;the&nbsp;website of&nbsp;the&nbsp;service&nbsp;provider.","Subscription can&nbsp;be&nbsp;limited (for&nbsp;one year, for&nbsp;example) or unlimited (without an&nbsp;expiry date). To&nbsp;keep Kaspersky Endpoint Security working after&nbsp;expiry of&nbsp;the&nbsp;limited subscription term, you have&nbsp;to&nbsp;renew your&nbsp;subscription. Unlimited&nbsp;subscription is&nbsp;renewed automatically if the&nbsp;vendor's services have&nbsp;been prepaid on&nbsp;time.","In the&nbsp;case of&nbsp;limited subscription, upon its expiry you may be&nbsp;offered a&nbsp;grace period for&nbsp;renewing subscription, during which time the&nbsp;application will&nbsp;retain its&nbsp;functionality. The&nbsp;service provider decides whether or not&nbsp;to&nbsp;grant a&nbsp;grace period and, if so, determines the&nbsp;duration of&nbsp;the&nbsp;grace&nbsp;period.","To use Kaspersky Endpoint Security under&nbsp;subscription, you have&nbsp;to&nbsp;apply the&nbsp;activation code received from the&nbsp;service&nbsp;provider. After&nbsp;the&nbsp;activation code is&nbsp;applied, the&nbsp;active key is&nbsp;installed. The&nbsp;active key defines the&nbsp;license for&nbsp;using the&nbsp;application under&nbsp;subscription. An&nbsp;additional key can&nbsp;be&nbsp;installed only using an&nbsp;activation code and cannot be&nbsp;installed using a&nbsp;key file or under&nbsp;subscription.","The application functionality available by&nbsp;subscription can&nbsp;correspond to&nbsp;the&nbsp;application functionality for&nbsp;the&nbsp;following types of&nbsp;commercial&nbsp;license: Standard,&nbsp;Kaspersky Business Space Security,&nbsp;Kaspersky Enterprise Space&nbsp;Security. Licenses&nbsp;of&nbsp;these types are&nbsp;designed for&nbsp;protecting file servers, workstations, and mobile devices, and support the&nbsp;use of&nbsp;control components on&nbsp;workstations and mobile&nbsp;devices.","The possible subscription management options may vary with&nbsp;each service&nbsp;provider. The&nbsp;service provider may not&nbsp;offer a&nbsp;grace period for&nbsp;renewing subscription, during which time the&nbsp;application will&nbsp;retain its&nbsp;functionality.","Activation codes purchased under&nbsp;subscription may not&nbsp;be&nbsp;used to&nbsp;activate previous versions of&nbsp;Kaspersky Endpoint Security.","About subscription","161250.htm");
Page[47]=new Array("In accepting the End User License Agreement, you agree to automatically transfer information on your use of the product, as well as the type, version and localization of the program installed, the unique identifier of the program installer and type of installation, and data on active and additional keys (including license type, validity period, date of program activation and date the license expires, the number of the license, the current state of the license, the activation server interaction protocol version).","By accepting the terms of the Kaspersky Security Network Statement, you also agree to automatically transmit the following information:","ID and version of the Kaspersky Security Network Statement, that you accepted or rejected.","Information about acceptance or rejection of the Kaspersky Security Network Statement.","Date and time when the Kaspersky Security Network Statement was accepted or rejected.","Information about the Kaspersky Security Network without statistics option selection.","Information about the Kaspersky Security Network with statistics option selection.","Unique IDs of a computer and user, full application version, and application type.","Should the program be activated with an activation code, in order to receive statistical information on the distribution and use of the License Holder's products, you agree to automatically provide the version of the program being utilized (including information on installed program updates, the program installation identifier, and information on licenses), the version of the operating system, and program component identifiers active at the time the information is provided.","Kaspersky Lab protects any information thus received in accordance with law and applicable Kaspersky Lab rules.","Kaspersky Lab uses any received information in anonymized form and as general statistics only. Aggregate statistics are automatically generated from the source information received, and do not contain any personal or other confidential data. The original information received is destroyed as new information is accumulated (once a year). Aggregate statistics are stored indefinitely.","Read the End User License Agreement and visit the Kaspersky Lab website to learn more about how we collect, process, store, and destroy information about application usage after you accept the End User License Agreement and concur with the KSN Statement. The license.&lt;language ID&gt; and ksn_license.&lt;language ID&gt; files contain the End User License Agreement and Kaspersky Security Network Statement and are part of the program distribution package.","About data provision","161251.htm");
Page[48]=new Array("By default, Kaspersky Endpoint Security starts automatically when the&nbsp;operating system is&nbsp;booted (at&nbsp;the&nbsp;default level of&nbsp;execution for&nbsp;each operating system). Kaspersky Endpoint Security starts all service tasks as well as custom tasks whose schedule settings is set to PS.","If you stop Kaspersky Endpoint Security, all running tasks will&nbsp;be&nbsp;interrupted. After&nbsp;restarting Kaspersky Endpoint Security, the&nbsp;interrupted custom tasks will&nbsp;not&nbsp;be&nbsp;automatically&nbsp;resumed. Only&nbsp;those custom tasks whose schedule settings is set to PS, will&nbsp;be&nbsp;restarted.","To start Kaspersky Endpoint Security, execute the&nbsp;following&nbsp;command:","/etc/init.d/kesl-supervisor&nbsp;start","To stop Kaspersky Endpoint Security, execute the&nbsp;following&nbsp;command:","/etc/init.d/kesl-supervisor&nbsp;stop","To restart Kaspersky Endpoint Security, execute the&nbsp;following&nbsp;command:","/etc/init.d/kesl-supervisor&nbsp;restart","To display the&nbsp;status of&nbsp;Kaspersky Endpoint Security, execute the&nbsp;following&nbsp;command:","/etc/init.d/kesl-supervisor&nbsp;status","To start Kaspersky Endpoint Security in&nbsp;the&nbsp;systemd system, execute the&nbsp;following&nbsp;command:","systemctl start&nbsp;kesl-supervisor","To stop Kaspersky Endpoint Security in&nbsp;the&nbsp;systemd system, execute the&nbsp;following&nbsp;command:","systemctl stop&nbsp;kesl-supervisor","To restart Kaspersky Endpoint Security in&nbsp;the&nbsp;systemd system, execute the&nbsp;following&nbsp;command:","systemctl restart&nbsp;kesl-supervisor","To display the&nbsp;status of&nbsp;Kaspersky Endpoint Security in&nbsp;the&nbsp;systemd system, execute the&nbsp;following&nbsp;command:","systemctl status&nbsp;kesl-supervisor","Application state monitoring","The application state is monitored by the watchdog service. The watchdog service is automatically started on the application start.","In case of the application crash, a dump file is generated, and the application is restarted automatically. The /var/opt/kaspersky/kesl directory, excluding dump files, is backed up.","Starting and stopping the application","161252.htm");
Page[49]=new Array("This section describes general settings of Kaspersky Endpoint Security.","After modifying the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security, restart the&nbsp;application.","General settings of&nbsp;the&nbsp;configuration file have&nbsp;the&nbsp;following&nbsp;values:","SambaConfigPath","Directory that stores the&nbsp;Samba configuration&nbsp;file. The&nbsp;Samba configuration file is&nbsp;needed to&nbsp;ensure that the&nbsp;AllShared or&nbsp;Shared:SMB values are&nbsp;applied for&nbsp;the&nbsp;Path&nbsp;option.","The standard directory of&nbsp;the&nbsp;SAMBA configuration file on&nbsp;the&nbsp;computer is&nbsp;specified by&nbsp;default.","Default value:&nbsp;/etc/samba/smb.conf","NfsExportPath","Directory storing the&nbsp;NFS configuration&nbsp;file. The&nbsp;NFS configuration file is&nbsp;needed to&nbsp;ensure that the&nbsp;AllShared or&nbsp;Shared:NFS values are&nbsp;applied for&nbsp;the&nbsp;Path&nbsp;option.","The standard directory of&nbsp;the&nbsp;NFS configuration file on&nbsp;the&nbsp;computer is&nbsp;specified by&nbsp;default.","Default value:&nbsp;/etc/exports","TraceFolder","Directory in&nbsp;which Kaspersky Endpoint Security stores trace log&nbsp;files.","If you specify a&nbsp;different directory, make sure that the&nbsp;account under&nbsp;which Kaspersky Endpoint Security is&nbsp;running has&nbsp;read/write permissions for&nbsp;this&nbsp;directory.","Default value:&nbsp;/var/log/kaspersky/kesl","TraceLevel","Trace log level of&nbsp;detail.","Available&nbsp;values:","Detailed&#8212;Most&nbsp;detailed trace&nbsp;log.","NotDetailed&#8212;The&nbsp;trace log contains error&nbsp;notifications.","None&#8212;Does&nbsp;not&nbsp;create a&nbsp;trace&nbsp;log.","Default value:&nbsp;None.","BlockFilesGreaterMaxFileNamePath","Blocks access to&nbsp;files for&nbsp;which the&nbsp;full path length exceeds the&nbsp;defined parameter value specified in&nbsp;bytes.","If the&nbsp;complete path to&nbsp;the&nbsp;file being scanned exceeds the&nbsp;value of&nbsp;this setting, on-demand scan tasks skip this file during&nbsp;scanning.","Available&nbsp;values: 4096 &#8211;&nbsp;33554432.","Default value:&nbsp;16384.","DetectOtherObjects","Enables&nbsp;/&nbsp;disables the&nbsp;detection of&nbsp;legitimate software that could be&nbsp;used by&nbsp;hackers to&nbsp;harm computers or data of&nbsp;users.","Available&nbsp;values:","Yes&#8212;Enable&nbsp;the&nbsp;detection of&nbsp;legitimate software that could be&nbsp;used by&nbsp;hackers to&nbsp;harm computers or data of&nbsp;users.","No&#8212;Disable&nbsp;the&nbsp;detection of&nbsp;legitimate software that could be&nbsp;used by&nbsp;hackers to&nbsp;harm computers or data of&nbsp;users.","Default value:&nbsp;No.","UseKSN","Enables / disables participation in&nbsp;Kaspersky Security&nbsp;Network.","Available&nbsp;values:","No&#8212;Disable&nbsp;participation in&nbsp;Kaspersky Security&nbsp;Network.","Basic&#8212;Enable participation in Kaspersky Security Network without sending statistics.","Extended&#8212;Enable participation in Kaspersky Security Network with sending statistics.","Default value:&nbsp;No.","UseProxy","Enables / disables use of&nbsp;a&nbsp;proxy for&nbsp;Kaspersky Security Network, activation of&nbsp;the&nbsp;application, and&nbsp;updates.","Available&nbsp;values:","Yes&#8212;Enable&nbsp;use of&nbsp;a&nbsp;proxy.","No&#8212;Disable&nbsp;use of&nbsp;a&nbsp;proxy.","Default value:&nbsp;No.","ProxyServer","Proxy server settings in&nbsp;the&nbsp;format [user[:password]@]host[:port].","MaxEventsNumber","Maximum number of&nbsp;events that will&nbsp;be&nbsp;stored by&nbsp;Kaspersky Endpoint Security. When&nbsp;the&nbsp;specified number of&nbsp;events is&nbsp;exceeded, Kaspersky Endpoint Security deletes the&nbsp;oldest&nbsp;events.","Default value:&nbsp;500000.","LimitNumberOfScanFileTasks","Maximum number of&nbsp;Scan_File tasks that a&nbsp;non-privileged user can&nbsp;simultaneously start on&nbsp;a&nbsp;computer. This&nbsp;parameter does&nbsp;not&nbsp;limit the&nbsp;number of&nbsp;tasks that a&nbsp;user with&nbsp;root privileges can&nbsp;start. If&nbsp;the&nbsp;value 0 is&nbsp;defined, a&nbsp;non-privileged user cannot start Scan_File&nbsp;tasks.","Available&nbsp;values: 0 &#8211;&nbsp;4294967295.","Default value:&nbsp;0.","If the USE_GUI setting was set to yes during the application installation, the default value for the LimitNumberOfScanFileTasks is 5.","UseSysLog","Enables / disables the&nbsp;logging of&nbsp;information about events to&nbsp;syslog. In certain cases, the application cannot generate and save an event. Then information is saved to syslog.","Yes&#8212;Enable&nbsp;the&nbsp;logging of&nbsp;information about events to&nbsp;syslog.","No&#8212;Disable&nbsp;the&nbsp;logging of&nbsp;information about events to&nbsp;syslog.","Default value:&nbsp;No.","UIReportsForRootOnly","Enables / disables viewing reports for users from graphical user interface.","Yes&#8212;Allow only root user to view reports in GUI.","No&#8212;Allow unprivileged users to view reports in GUI. Also, unprivileged users will be able to create and start up to 5 custom scan tasks.","Default value: No.","EventsStoragePath","Database file in&nbsp;which Kaspersky Endpoint Security saves information about&nbsp;events.","Default value:&nbsp;/var/opt/kaspersky/kesl/events.db","General settings of Kaspersky Endpoint Security","161254.htm");
Page[50]=new Array("This section provides information about the commands used to manage Kaspersky Endpoint Security settings and tasks.","Commands for managing Kaspersky Endpoint Security settings and tasks","161255.htm");
Page[51]=new Array("The command --get-app-settings displays the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security. Using&nbsp;this command, you can&nbsp;also receive the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security that were&nbsp;assigned using the&nbsp;command&nbsp;keys.","You can&nbsp;use this command to&nbsp;edit the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security installed on&nbsp;the&nbsp;computer:","Save the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security in&nbsp;the&nbsp;configuration file using the&nbsp;option&nbsp;--get-app-settings.","Open the&nbsp;created configuration file, edit the&nbsp;necessary settings and save the&nbsp;changes.","Import the&nbsp;settings from the&nbsp;configuration file to&nbsp;Kaspersky Endpoint Security using the&nbsp;option&nbsp;--set-app-settings. Kaspersky Endpoint Security will&nbsp;apply the&nbsp;new values of&nbsp;the&nbsp;settings after&nbsp;you stop and restart Kaspersky Endpoint Security.","You can&nbsp;use the&nbsp;created configuration file to&nbsp;import the&nbsp;settings to&nbsp;Kaspersky Endpoint Security installed on&nbsp;another&nbsp;computer.","Command&nbsp;syntax","kesl-control [-T] --get-app-settings [--file &lt;configuration file name&gt;]","kesl-control [-T] --get-app-settings","Arguments and&nbsp;keys","--file &lt;name of&nbsp;configuration file&gt;","Name of&nbsp;the&nbsp;configuration file in&nbsp;which Kaspersky Endpoint Security settings will&nbsp;be&nbsp;saved. If&nbsp;you specify the&nbsp;name of&nbsp;a&nbsp;file without specifying its path, the&nbsp;file will&nbsp;be&nbsp;created in&nbsp;the&nbsp;current&nbsp;directory. If&nbsp;a&nbsp;file with&nbsp;the&nbsp;specified name already exists in&nbsp;the&nbsp;specified path, it will&nbsp;be&nbsp;overwritten. If&nbsp;the&nbsp;specified directory cannot be&nbsp;found on&nbsp;the&nbsp;disk, the&nbsp;configuration file will&nbsp;not&nbsp;be&nbsp;created.","Example:","Export the general settings of Kaspersky Endpoint Security to a file named kesl_сonfig.ini. Save the created file in the current directory:","kesl-control --get-app-settings --file kesl_config.ini","Receiving the general settings of Kaspersky Endpoint Security","161256.htm");
Page[52]=new Array("The command --set-app-settings sets the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security using the&nbsp;command keys or imports the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security from the&nbsp;specified configuration&nbsp;file.","You can&nbsp;use this command to&nbsp;edit the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security:","Save the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security in&nbsp;the&nbsp;configuration file using the&nbsp;option&nbsp;--get-app-settings.","Open the&nbsp;created configuration file, edit the&nbsp;necessary settings and save the&nbsp;changes.","Import the&nbsp;settings from the&nbsp;configuration file to&nbsp;Kaspersky Endpoint Security using the&nbsp;option&nbsp;--set-app-settings. Kaspersky Endpoint Security will&nbsp;apply the&nbsp;new values of&nbsp;the&nbsp;settings after&nbsp;you stop and restart Kaspersky Endpoint Security using the&nbsp;options --stop-app and --start-app or using the&nbsp;option&nbsp;--restart-app.","Command&nbsp;syntax","kesl-control [-T] --set-app-settings --file &lt;configuration file name&gt;","kesl-control [-T] --set-app-settings &lt;parameter name&gt;=&lt;parameter value&gt; &lt;parameter name&gt;=&lt;parameter value&gt;","Arguments and&nbsp;keys","--file &lt;name of&nbsp;configuration file&gt;","Name of&nbsp;the&nbsp;configuration file whose settings will&nbsp;be&nbsp;imported into Kaspersky Endpoint Security; includes the&nbsp;full path to&nbsp;the&nbsp;file.","Example:","Import the general settings from the configuration file named /home/test/kav_сonfig.ini to Kaspersky Endpoint Security:","kesl-control --set-app-settings --file /home/test/kav_сonfig.ini","Set the low detalization level for the trace log:","kesl-control --set-app-settings TraceLevel=NotDetailed","Editing the general settings of Kaspersky Endpoint Security","161257.htm");
Page[53]=new Array("The command kesl-control with&nbsp;the&nbsp;key --help &lt;set of&nbsp;Kaspersky Endpoint Security commands&gt; returns Help on&nbsp;Kaspersky Endpoint Security&nbsp;commands.","Command&nbsp;syntax","kesl-control --help [&lt;set of&nbsp;commands of&nbsp;Kaspersky Endpoint Security&gt;]","&lt;set of&nbsp;commands of&nbsp;Kaspersky Endpoint Security&gt;","Available&nbsp;values:","[-T]&#8212;Commands for&nbsp;managing the&nbsp;tasks and general settings of&nbsp;Kaspersky Endpoint Security.","[-L]&#8212;Key management&nbsp;commands.","[-B]&#8212;Storage management&nbsp;commands.","[-E]&#8212;Commands for&nbsp;managing Kaspersky Endpoint Security&nbsp;events.","[-F]&#8212;Commands for managing the Firewall task.","[-H]&#8212;Commands for managing the Anti-Cryptor task.","[-S]&#8212;Statistical commands.","-W&#8212;Event monitoring.","Displaying Kaspersky Endpoint Security command Help","161258.htm");
Page[54]=new Array("The command -W enables the&nbsp;display of&nbsp;Kaspersky Endpoint Security&nbsp;events. You&nbsp;can&nbsp;use this command either separately to&nbsp;display all Kaspersky Endpoint Security events or together with&nbsp;the&nbsp;--start-task command to&nbsp;display only events associated with&nbsp;the&nbsp;running&nbsp;task. You&nbsp;can&nbsp;use --query with&nbsp;the&nbsp;-W flag to&nbsp;display only specific&nbsp;events.","The command returns the&nbsp;name of&nbsp;the&nbsp;event and additional information about the&nbsp;event.","Command&nbsp;syntax","kesl-control -W","Example:","Enable the display of Kaspersky Endpoint Security events:","kesl-control -W","Enabling the display of events","161259.htm");
Page[55]=new Array("The command --app-info displays information about Kaspersky Endpoint Security.","Command&nbsp;syntax","kesl-control [-S]&nbsp;--app-info","Result of&nbsp;command&nbsp;execution","Name","Application name.","Version","Current application version.","Key&nbsp;status","Status of&nbsp;the&nbsp;key.","Subscription status","Status of the subscription. This field is displayed if the application is run under subscription.","License expiration&nbsp;date","License expiration&nbsp;date.","Storage&nbsp;state","State of the Storage. Displays information about time or size limitations.","Storage space usage","Size of&nbsp;Storage.","Last run date of the Scan_My_Computer task","Time at&nbsp;which the&nbsp;last Scan_My_Computer task was&nbsp;run.","Last release date of databases","Time when the&nbsp;databases were&nbsp;last&nbsp;released.","Anti-virus databases&nbsp;loaded","Displays whether or not&nbsp;anti-virus databases have&nbsp;been&nbsp;downloaded.","Anti-virus databases&nbsp;records","Number of&nbsp;records in&nbsp;anti-virus&nbsp;databases.","KSN&nbsp;state","Participating in&nbsp;Kaspersky Security&nbsp;Network state.","File monitoring","State of file monitoring component.","Integrity monitoring","State of File Integrity Monitoring component.","Firewall","State of the Firewall manager component.","Anti-Cryptor","State of the Anti-Cryptor component.","Application update state","Displays the application updates availability.","Viewing information about the application","161260.htm");
Page[56]=new Array("You can&nbsp;modify the&nbsp;values of&nbsp;Kaspersky Endpoint Security&nbsp;settings.","The&nbsp;following are the rules for using Kaspersky Endpoint Security&nbsp;commands:","Be&nbsp;case-sensitive.","Separate keys with&nbsp;a&nbsp;space&nbsp;character.","When using the&nbsp;full name of&nbsp;a&nbsp;command or key, enter the&nbsp;value after&nbsp;an&nbsp;equal (=)&nbsp;character.","Example:","Specify the URL parameter value for the custom update source of the update task (ID=6) from the command line:","kesl-control --set-settings 6","SourceType=Custom CustomSources.item_0000.URL=http://site.domain/path CustomSources.item_0000.Enabled=Yes","Displaying Kaspersky Endpoint Security command&nbsp;Help","--help","Displays Help for&nbsp;Kaspersky Endpoint Security&nbsp;commands.","Display Kaspersky Endpoint Security&nbsp;events","-W","Enables the&nbsp;display of&nbsp;Kaspersky Endpoint Security&nbsp;events.","Commands for&nbsp;managing Kaspersky Endpoint Security settings and&nbsp;tasks","-T","Prefix indicating that the&nbsp;command belongs to&nbsp;the&nbsp;group of&nbsp;commands used for&nbsp;managing Kaspersky Endpoint Security settings / managing tasks (optional).","[-S]&nbsp;--app-info","Displays general information about Kaspersky Endpoint Security.","[-Т] --get-app-settings --file &lt;file name and directory&gt;","Returns the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security.","[-T] --set-app-settings --file &lt;file name and directory&gt;","Sets the&nbsp;general settings of&nbsp;Kaspersky Endpoint Security.","[-T]&nbsp;--get-task-list","Returns the&nbsp;list of&nbsp;existing Kaspersky Endpoint Security&nbsp;tasks.","[-T] --get-task-state &lt;task ID&gt;|&lt;task name&gt;","Displays the&nbsp;status of&nbsp;the&nbsp;specified&nbsp;task.","[-T] --create-task &lt;task name&gt; --type &lt;task type&gt; --file &lt;file name and directory&gt;","Creates a&nbsp;task of&nbsp;the&nbsp;specified&nbsp;type; imports the&nbsp;settings from the&nbsp;specified configuration file into the&nbsp;task.","[-T] --delete-task &lt;task ID&gt;|&lt;task name&gt;","Deletes the&nbsp;task.","[-T] --start-task &lt;task ID&gt;|&lt;task name&gt; [-W] [--progress] [--file &lt;file name and directory&gt;]","Starts the&nbsp;task.","[-T] --stop-task &lt;task ID&gt;|&lt;task name&gt;","Stops the&nbsp;task.","[-T] --suspend-task &lt;task ID&gt;|&lt;task name&gt;","Suspends the&nbsp;task.","[-T] --resume-task &lt;task ID&gt;|&lt;task name&gt;","Resumes the&nbsp;task.","[-T] --get-settings &lt;task ID&gt;|&lt;task name&gt; --file &lt;file_name_and_directory&gt;","Returns task&nbsp;settings.","[-T] --set-settings &lt;task ID&gt;|&lt;task name&gt; [&lt;parameters&gt;] [--file &lt;file name and directory&gt;] [--add-path &lt;path&gt;] [--del-path &lt;path&gt;] [--add-exclusion &lt;exclusion&gt;] [--del-exclusion &lt;exclusion&gt;]","Sets task&nbsp;settings.","[-T] --scan-file &lt;path&gt; [--action &lt;action&gt;]","Creates and starts a&nbsp;temporary Scan_File&nbsp;task.","[-T] --import-settings &lt;--file file&gt;","Imports the application setting to the configuration file.","[-T] --update-application","Updates the application.","[-S] --omsinfo --file &lt;path&gt;","Creates a file in JSON format for integration with Microsoft Operations Management Suite.","Key management&nbsp;commands","-L","Prefix indicating that the&nbsp;command belongs to&nbsp;the&nbsp;group of&nbsp;commands used to&nbsp;manage&nbsp;keys.","[-L] --install-active-key &lt;activation code&gt;|&lt;key file&gt;","Adds the&nbsp;active&nbsp;key.","[-L] --install-additional-key &lt;activation code&gt;|&lt;key file&gt;","Adds the&nbsp;additional&nbsp;key.","[-L]&nbsp;--revoke-active-key","Removes the&nbsp;active&nbsp;key.","[-L]&nbsp;--revoke-additional-key","Removes the&nbsp;additional&nbsp;key.","[-L]&nbsp;--query","Displays information about the&nbsp;key.","Commands for Firewall Manager task","[-F] --add-rule [--name &lt;string&gt;] [--action &lt;action&gt;] [--protocol &lt;protocol&gt;] [--direction &lt;directory&gt;] [--remote &lt;remote&gt;] [--local &lt;local&gt;] [--at &lt;index&gt;]","Adds a new rule.","[-F] --del-rule [--name &lt;string&gt;] [--index &lt;index&gt;]","Deletes a rule.","[-F] --move-rule [--name &lt;string&gt;] [--index &lt;index&gt;] [--at &lt;index&gt;]","Changes the rule priority.","[-F] --add-zone [--zone &lt;zone&gt;] [--address &lt;address&gt;]","Adds an IP address to the zone.","[-F] --del-zone [--zone &lt;zone&gt;] [--address &lt;address&gt;] [--index &lt;index&gt;]","Deletes an IP address from the zone.","-F --query","Displays information.","Commands for Anti-Cryptor task","[-H] --get-blocked-hosts","Displays a list of blocked hosts.","[-H] --allow-hosts","Unblocks untrusted hosts.","Commands for&nbsp;managing&nbsp;Storage","-B","Prefix indicating that the&nbsp;command belongs to&nbsp;the&nbsp;group of&nbsp;commands used to&nbsp;manage&nbsp;Storage.","[-B] --mass-remove&nbsp;--query","Clears the&nbsp;Storage, fully or&nbsp;selectively.","[-B] --query --limit&nbsp;--offset","Displays information about objects in&nbsp;Storage:","--limit","Maximum number of&nbsp;objects for&nbsp;which information is&nbsp;displayed.","--offset","Number of&nbsp;records by&nbsp;which to&nbsp;offset from the&nbsp;start of&nbsp;the&nbsp;sample.","[-B] --restore &lt;object ID&gt; --file &lt;file name and directory&gt;","Restores an&nbsp;object from&nbsp;Storage.","Commands used to&nbsp;manage the&nbsp;event&nbsp;log","-E","Prefix indicating that the&nbsp;command belongs to&nbsp;the&nbsp;group of&nbsp;commands used to&nbsp;manage the&nbsp;event&nbsp;log.","[-E] --query --limit --offset --file &lt;file name and directory&gt;&nbsp;--db &lt;db file&gt;","Maximum number of&nbsp;events for&nbsp;which information is&nbsp;displayed.","--query","Returns information about the&nbsp;filtered events from the&nbsp;event log or the&nbsp;specified log rotation&nbsp;file.","--offset","Number of&nbsp;records by&nbsp;which to&nbsp;offset from the&nbsp;start of&nbsp;the&nbsp;sample.","--db","Database file&nbsp;name.","Task schedule management&nbsp;commands","[-T] --set-schedule &lt;task ID&gt;|&lt;task name&gt; --file &lt;file name and directory&gt;","Sets the&nbsp;task schedule settings / imports them from the&nbsp;configuration file into the&nbsp;task.","[-T] --get-schedule &lt;task ID&gt;|&lt;task name&gt; --file &lt;file name and directory&gt;","Returns the&nbsp;task schedule&nbsp;settings.","RuleType=Once|Monthly|Weekly|Daily|Hourly|Minutely|Manual|PS|BR","Task launch&nbsp;schedule.","PS&#8212;Start the&nbsp;task after&nbsp;starting Kaspersky Endpoint Security.","BR&#8212;Start the&nbsp;task after&nbsp;anti-virus databases are&nbsp;updated.","StartTime=[year/month/month_day] [hh]:[mm]:[ss]; [&lt;month_day&gt;|&lt;week_day&gt;]; [&lt;period&gt;]","Task start&nbsp;time.","RandomInterval=&lt;min.&gt;","Task run interval, if several tasks are&nbsp;running at&nbsp;the&nbsp;same time (in&nbsp;minutes).","ExecuteTimeLimit=&lt;min.&gt;","Limit the&nbsp;duration of&nbsp;task execution (in&nbsp;minutes).","RunMissedStartRules","Enables / disables the&nbsp;start of&nbsp;a&nbsp;skipped task after&nbsp;Kaspersky Endpoint Security is&nbsp;started.","Kaspersky Endpoint Security commands","161262.htm");
Page[57]=new Array("Kaspersky Endpoint Security allows you to export and import all application settings for troubleshooting, verifying settings, or for easier application configuring on other computers.","When exporting settings, all application and task settings are saved to a configuration file. This configuration file is used for importing settings to configure the application.","Kaspersky Endpoint Security must be started when you import or export settings. After importing settings, the application must be restarted. ","If the application is managed via Kaspersky Security Center, settings importing is not available. ","When importing or exporting settings from the older application version, new settings are set to default values. When matching configuration files of new and older application versions, the return code will be 1.","Importing settings to an older application version is unavailable.","When importing application settings, the UseKSN setting is set to No. To start or resume participating in Kaspersky Security Network, you need to specify UseKSN=Basic or UseKSN=Extended.","After importing application settings, internal task IDs can be changed. We recommend to use task names to manage them.","To export application settings to a configuration file, execute the following command:","kesl-control --export-settings [--file full path to configuration file] ","To configure the application using settings from a configuration file (import settings), execute the following command:","kesl-control --import-settings --file full path to configuration file","Exporting and importing application settings","162401.htm");
Page[58]=new Array("This section contains information about the&nbsp;types of&nbsp;Kaspersky Endpoint Security tasks and instructions on&nbsp;how to&nbsp;manage those&nbsp;tasks.","Managing Kaspersky Endpoint Security tasks using command line","161263.htm");
Page[59]=new Array("You can&nbsp;manage the&nbsp;operation of&nbsp;Kaspersky Endpoint Security using tasks locally on&nbsp;computers (using the&nbsp;command line or configuration files), as well as centrally via&nbsp;Kaspersky Security Center.","There are&nbsp;two types of&nbsp;tasks for&nbsp;working with&nbsp;Kaspersky Endpoint Security:","Predefined task&#8212;Task that is&nbsp;created during installation of&nbsp;the&nbsp;application. You&nbsp;cannot create or delete predefined tasks, but you can&nbsp;modify the&nbsp;settings of&nbsp;these&nbsp;tasks.","Custom task&#8212;Task that you can&nbsp;create or delete on&nbsp;your&nbsp;own.","You can&nbsp;manage the&nbsp;following&nbsp;tasks:","File_Monitoring is a real-time protection task (ID=1, type&#8212;OAS).","Scan_My_Computer&nbsp;is a on-demand scan task (ID=2, type&#8212;ODS).","Scan_File&nbsp;is a custom scan task (ID=3, type&#8212;ODS) By default, the&nbsp;settings of&nbsp;this task match the&nbsp;settings of&nbsp;the&nbsp;Scan_My_Computer&nbsp;task.","Boot_Scan&nbsp;is a Boot sector scan task (ID=4, type&#8212;BootScan).","Memory_Scan&nbsp;is a Memory scan task (ID=5, type&#8212;MemoryScan).","Update&nbsp;is an Update task (ID=6, type&#8212;Update).","Rollback&nbsp;is an Update rollback task (ID=7, type&#8212;Rollback). This task has&nbsp;no&nbsp;settings. You&nbsp;can&nbsp;only start and stop this&nbsp;task.","Retranslate&nbsp;is an Update distribution task (ID=8, type&#8212;Retranslate).","License&nbsp;is a license server implementation task (ID=9, type&#8212;License).","Backup&nbsp;is a Storage management task (ID=10, type&#8212;Backup).","Integrity_Monitoring is a File Integrity Monitoring task (ID=11, type&#8212;OAFIM).","Firewall is a system firewall management task (ID=12, type&#8212;Firewall).","Anti-Cryptor is an Anti-Cryptor task (ID=13, type&#8212;AntiCryptor).","ID&#8212;Number that Kaspersky Endpoint Security assigns to&nbsp;the&nbsp;task when it is&nbsp;created.","You can&nbsp;perform the&nbsp;following actions with&nbsp;tasks:","Start and stop&nbsp;tasks.","Create and delete tasks (only for&nbsp;custom tasks).","Edit task&nbsp;settings.","About Kaspersky Endpoint Security tasks","161264.htm");
Page[60]=new Array("To view a&nbsp;list of&nbsp;Kaspersky Endpoint Security tasks, execute the&nbsp;following&nbsp;command:","kesl-control [-T]&nbsp;--get-task-list","A list of Kaspersky Endpoint Security tasks is displayed.","The following information is displayed for each task:","Name. Task name.","ID. Task ID.","Type. Task type.","State. Current task state.","If a user is prohibited to view and edit task settings, information about Scan_File, Backup,  License, File_Monitoring, Integrity_Monitor, and Anti_Cryptor tasks is displayed. Information about other tasks is not available.","If your license does not cover the Anti-Cryptor and File Integrity Monitoring functionality, information on the corresponding tasks will not be displayed.","For more information, see About Kaspersky Endpoint Security tasks section.","Viewing a list of Kaspersky Endpoint Security tasks","161267.htm");
Page[61]=new Array("You can&nbsp;create&nbsp;tasks with default settings or with settings specified in a configuration task.","Tasks of OAS, Firewall, OAFIM, License, Backup, and AntiCryptor types cannot be created.","To create a&nbsp;task with default settings, execute the&nbsp;following&nbsp;command:","kesl-control [-T] --create-task &lt;task name&gt; --type &lt;task type&gt;","Here:","&lt;task name&gt; is a name you specify for a new task","&lt;task type&gt; is a predefined task type","A task of the specified type is created with default settings.","To create a task with settings specified in a configuration file, execute the following command:","kesl-control [-T] --create-task &lt;task name&gt; --type &lt;task type&gt; --file &lt;full path to the configuration file&gt;","Here:","&lt;task name&gt; is a name you specify for a new task","&lt;task type&gt; is a predefined task type","&lt;full path to the configuration file&gt; is the full path to the configuration file","A task of the specified type is created with settings specified in a configuration file.","Creating a task","161268.htm");
Page[62]=new Array("To edit a task settings by changing the configuration file:","Save a task settings to the configuration file:","kesl-control --get-settings &lt;task name&gt;|&lt;task ID&gt; --file &lt;full path to file&gt;","Open the created configuration file for editing.","Edit the required settings in the configuration file.","Save the changes in the configuration file.","Import the settings from the configuration file into the task:","kesl-control --set-settings &lt;task name&gt;|&lt;task ID&gt; --file &lt;full path to file&gt;","As a result, the task is running with updated settings.","Editing task settings using configuration file","162022.htm");
Page[63]=new Array("To edit a task settings using command line:","Specify the required setting value:","kesl-control --set-settings &lt;task name or ID&gt; setting=value [setting=value]","Kaspersky Endpoint Security changes the specified setting.","Make sure the setting value is changed in a task configuration file:","kesl-control --get-settings &lt;task name or ID&gt;","If you add a new scan scope or exclusion scope not specifying all settings, a scope with default settings is added to a configuration file.","Example:","To specify a new scan scope, execute the following command:","--set-settings 100 ScanScope.item_0001.UseScanArea=Yes ScanScope.item_0001.Path=/home","A new section describing a scan scope is added to the configuration file for the task with ID=100:","[ScanScope.item_0001]","AreaDesc=","UseScanArea=Yes","Path=/home","AreaMask.item_0000=*","Editing task settings using command line","162393.htm");
Page[64]=new Array("You cannot start or stop Backup and License&nbsp;tasks.","To start the&nbsp;task, execute the&nbsp;following&nbsp;command:","kesl-control --start-task &lt;task ID&gt;|&lt;task name&gt;","To stop the&nbsp;task, execute the&nbsp;following&nbsp;command:","kesl-control --stop-task &lt;task ID&gt;|&lt;task name&gt;","Starting and stopping a task","161269.htm");
Page[65]=new Array("You can add or delete a scan scope with specified Path for OAS, ODS, OAFIM, ODFIM, and Anti-Cryptor tasks from command line.","To add a new scan scope, execute the following command:","kesl-control --set-settings &lt;task ID or name&gt; --add-path &lt;path&gt;","A new [ScanScope.item_#] section is added to a task configuration file. Kaspersky Endpoint Security scans objects located in the directory specified by the Path parameter. ","If a [ScanScope.item_#] section for the specified Path already exists, a duplicate section is not added to the configuration file. If the UseScanArea settings was set to No, after executing this command, the value becomes Yes, and objects located in this directory are scanned.","To delete a scan scope, execute the following command:","kesl-control --set-settings &lt;task ID or name&gt; --del-path &lt;path&gt;","A [ScanScope.item_#] section that contains the specified path is deleted from a task configuration file. Kaspersky Endpoint Security does not scan objects located in the directory specified by the Path parameter. ","Managing scan scopes from command line","162407.htm");
Page[66]=new Array("You can add or delete an exclusion scope with specified Path for OAS, ODS, OAFIM, ODFIM, and Anti-Cryptor tasks from command line.","To add a new exclusion scope, execute the following command:","kesl-control --set-settings &lt;task ID or name&gt; --add-exclusion &lt;path&gt;","A new [ExcludedFromScanScope.item_#] section is added to a task configuration file. Kaspersky Endpoint Security excludes objects located in the directory specified by the Path parameter. ","If a [ExcludedFromScanScope.item_#] section for the specified Path already exists, a duplicate section is not added to the configuration file. If the UseScanArea settings was set to No, after executing this command, the value becomes Yes, and objects located in this directory are excluded from scan.","To delete an exclusion scope, execute the following command:","kesl-control --set-settings &lt;task ID or name&gt; --del-exclusion &lt;path&gt;","A [ExcludedFromScanScope.item_#] section that contains the specified path is deleted from a task configuration file. Kaspersky Endpoint Security does not exclude objects located in the directory specified by the Path parameter. ","Managing exclusion scopes from command line","162408.htm");
Page[67]=new Array("You can&nbsp;view a&nbsp;task state.","To view a&nbsp;task state, execute the&nbsp;following&nbsp;command:","kesl-control --get-task-state &lt;task ID&gt;|&lt;task name&gt;","Here:","&lt;task ID&gt; is a task ID that Kaspersky Endpoint Security assigned to the task on creation.","&lt;task name&gt; is a name you specify for a new task.","Kaspersky Endpoint Security tasks can&nbsp;be in one of&nbsp;the&nbsp;following&nbsp;states:","Started&#8212;Task is&nbsp;running.","Starting&#8212;Task is being&nbsp;launched.","Stopped&#8212;Task is&nbsp;stopped.","Stopping&#8212;Task is&nbsp;stopping.","Suspended&#8212;Task is&nbsp;suspended.","Suspending&#8212;Task is&nbsp;being&nbsp;suspended.","Resumed&#8212;Task is&nbsp;resumed.","Resuming&#8212;Task is&nbsp;being&nbsp;resumed.","Viewing a task state","161277.htm");
Page[68]=new Array("You can&nbsp;pause and resume the&nbsp;following types of&nbsp;tasks: ODS, BootScan, MemoryScan, Rollback, Retranslate and&nbsp;Update.","To suspend a&nbsp;task, execute the&nbsp;following&nbsp;command:","kesl-control --suspend-task &lt;task ID&gt;|&lt;task name&gt;","The task is&nbsp;paused after&nbsp;the&nbsp;command has&nbsp;been&nbsp;executed.","To resume a&nbsp;task, execute the&nbsp;following&nbsp;command:","kesl-control --resume-task &lt;task ID&gt;|&lt;task name&gt;","The task is&nbsp;resumed after&nbsp;the&nbsp;command has&nbsp;been&nbsp;executed.","Pausing and resuming a task","161271.htm");
Page[69]=new Array("To configure a&nbsp;task&nbsp;schedule:","Save task schedule settings to&nbsp;a&nbsp;configuration file executing the&nbsp;following&nbsp;command:","kesl-control --get-schedule &lt;task ID&gt;|&lt;task name&gt;","Open the&nbsp;configuration file for&nbsp;editing.","Specify the&nbsp;schedule&nbsp;settings.","Save the&nbsp;changes in&nbsp;the&nbsp;configuration&nbsp;file.","Import the&nbsp;schedule settings into the&nbsp;task executing the&nbsp;following&nbsp;command:","kesl-control --set-schedule &lt;task ID&gt;|&lt;task name&gt; --file &lt;full path to&nbsp;file&gt;","Scheduling a task","161272.htm");
Page[70]=new Array("The command --get-schedule returns the&nbsp;task schedule&nbsp;settings. Using&nbsp;this command, you can&nbsp;also receive the&nbsp;task schedule settings that were&nbsp;assigned using the&nbsp;command&nbsp;keys.","You can&nbsp;use this command to&nbsp;edit the&nbsp;task&nbsp;schedule:","Save the&nbsp;schedule settings in&nbsp;the&nbsp;configuration file using the&nbsp;command&nbsp;--get-schedule.","Open the&nbsp;created configuration file, edit the&nbsp;necessary settings and save the&nbsp;changes.","Import the&nbsp;settings from the&nbsp;configuration file to&nbsp;Kaspersky Endpoint Security using the&nbsp;command&nbsp;--set-schedule. Kaspersky Endpoint Security will&nbsp;immediately apply the&nbsp;new values for&nbsp;the&nbsp;schedule&nbsp;settings.","Command&nbsp;syntax","kesl-control [-T] --get-schedule &lt;task ID&gt;|&lt;task name&gt; [--file &lt;configuration file name&gt;]","kesl-control [-T] --get-schedule &lt;task ID&gt;|&lt;task name&gt; &lt;parameter name&gt;","Arguments and&nbsp;keys","&lt;task ID&gt;","Identification number of&nbsp;the&nbsp;task in&nbsp;Kaspersky Endpoint Security.","&lt;task name&gt;","Task&nbsp;name.","--file &lt;name of&nbsp;configuration file&gt;","Name of&nbsp;the&nbsp;configuration file in&nbsp;which the&nbsp;schedule settings will&nbsp;be&nbsp;saved. If&nbsp;you specify the&nbsp;name of&nbsp;a&nbsp;file without specifying its path, the&nbsp;file will&nbsp;be&nbsp;created in&nbsp;the&nbsp;current&nbsp;directory. If&nbsp;a&nbsp;file with&nbsp;the&nbsp;specified name already exists in&nbsp;the&nbsp;specified path, it will&nbsp;be&nbsp;overwritten. If&nbsp;the&nbsp;specified directory cannot be&nbsp;found on&nbsp;the&nbsp;disk, the&nbsp;configuration file will&nbsp;not&nbsp;be&nbsp;created.","Example:","Save Kaspersky Endpoint Security settings to a file named update_schedule.ini. Save the created file in the current directory:","kesl-control --get-schedule 6 --file update_schedule.ini","Return the Update task schedule:","kesl-control --get-schedule 6","Receiving task schedule settings","161274.htm");
Page[71]=new Array("The command --set-schedule sets the&nbsp;task schedule settings using the&nbsp;command keys or imports the&nbsp;task schedule settings from the&nbsp;specified configuration&nbsp;file.","You can&nbsp;use this command to&nbsp;edit the&nbsp;settings of&nbsp;Kaspersky Endpoint Security:","Save the&nbsp;schedule settings in&nbsp;the&nbsp;configuration file executing the&nbsp;command&nbsp;--get-schedule.","Open the&nbsp;created configuration file, edit the&nbsp;necessary settings and save the&nbsp;changes.","Import the&nbsp;settings from the&nbsp;configuration file to&nbsp;Kaspersky Endpoint Security executing the&nbsp;command -T&nbsp;--set-schedule. Kaspersky Endpoint Security will&nbsp;immediately apply the&nbsp;new values for&nbsp;the&nbsp;schedule&nbsp;settings.","Command&nbsp;syntaxs","kesl-control --set-schedule &lt;task ID&gt;|&lt;task name&gt; --file &lt;configuration file name&gt;","kesl-control --set-schedule &lt;task ID&gt;|&lt;task name&gt; &lt;parameter name&gt;=&lt;parameter value&gt; &lt;parameter name&gt;=&lt;parameter value&gt;","Arguments and&nbsp;keys","&lt;task ID&gt;","Identification number of&nbsp;the&nbsp;task in&nbsp;Kaspersky Endpoint Security.","&lt;task name&gt;","Task&nbsp;name.","--file &lt;name of&nbsp;configuration file&gt;","Name of&nbsp;the&nbsp;configuration file whose schedule settings will&nbsp;be&nbsp;imported into the&nbsp;task; includes the&nbsp;full path to&nbsp;the&nbsp;file.","Example:","Import the schedule settings from the configuration file named /home/test/on_demand_schedule.ini into the task with ID=2:","kesl-control --set-schedule 2 --file /home/test/on_demand_schedule.ini","Editing task schedule settings","161275.htm");
Page[72]=new Array("You can&nbsp;delete tasks that you have&nbsp;created (custom tasks).","To delete a&nbsp;task, execute the&nbsp;following&nbsp;command:","kesl-control --delete-task &lt;task ID&gt;|&lt;task name&gt;","Deleting a task","161270.htm");
Page[73]=new Array("This section contains information about the&nbsp;real-time protection&nbsp;task.","Real-time protection task (File_Monitoring ID:1)","161279.htm");
Page[74]=new Array("Real-time protection prevents infection of&nbsp;the&nbsp;file system of&nbsp;the&nbsp;computer. A&nbsp;real-time protection task is&nbsp;created with&nbsp;the&nbsp;default settings when Kaspersky Endpoint Security is&nbsp;installed to&nbsp;the&nbsp;computer. By&nbsp;default, the&nbsp;real-time protection task starts automatically when Kaspersky Endpoint Security&nbsp;starts. The&nbsp;task resides in&nbsp;the&nbsp;computer's RAM and scans all opened, saved, and active&nbsp;files. You&nbsp;can&nbsp;stop and start the&nbsp;task.","You cannot create custom real-time protection&nbsp;tasks. You&nbsp;can&nbsp;modify the&nbsp;settings of&nbsp;the&nbsp;predefined real-time protection&nbsp;task.","Real-time protection settings are&nbsp;contained in&nbsp;the&nbsp;configuration file used by&nbsp;the&nbsp;real-time protection&nbsp;task. ","About real-time protection","161280.htm");
Page[75]=new Array("Kaspersky Endpoint Security uses anti-virus databases when scanning&nbsp;files. These&nbsp;databases contain files with&nbsp;fragments of&nbsp;malicious code and the&nbsp;algorithms used for&nbsp;disinfecting objects that contain such&nbsp;threats. Anti-virus&nbsp;databases enable detection of&nbsp;known threats in&nbsp;the&nbsp;files being&nbsp;scanned.","If a&nbsp;file contains code that fully matches the&nbsp;code of&nbsp;a&nbsp;known threat, Kaspersky Endpoint Security assigns the&nbsp;status of&nbsp;Infected to&nbsp;the&nbsp;file.","About infected files","161281.htm");
Page[76]=new Array("Kaspersky Endpoint Security lets you scan symbolic links and hard links to&nbsp;files.","Scanning symbolic&nbsp;links","Kaspersky Endpoint Security scans symbolic links only if the&nbsp;file referenced by&nbsp;the&nbsp;symbolic link is&nbsp;within the&nbsp;protection scope of&nbsp;the&nbsp;real-time protection task or within the&nbsp;scan scope of&nbsp;the&nbsp;on-demand scan&nbsp;task.","If the&nbsp;file referenced by&nbsp;the&nbsp;symbolic link is&nbsp;not&nbsp;within the&nbsp;protection scope or scan scope of&nbsp;the&nbsp;task, the&nbsp;application does&nbsp;not&nbsp;scan this&nbsp;file. However, if the&nbsp;file contains malicious code, the&nbsp;security of&nbsp;the&nbsp;computer is&nbsp;at&nbsp;risk.","Scanning hard&nbsp;links","When Kaspersky Endpoint Security processes a&nbsp;file that has&nbsp;more than one hard link, the&nbsp;application selects an&nbsp;action based on&nbsp;the&nbsp;assigned action to&nbsp;take on&nbsp;objects:","If Perform recommended action is&nbsp;selected, Kaspersky Endpoint Security automatically selects and performs an&nbsp;action on&nbsp;an&nbsp;object based on&nbsp;data about the&nbsp;danger of&nbsp;the&nbsp;threat detected in&nbsp;the&nbsp;object and the&nbsp;capability to&nbsp;disinfect&nbsp;it.","If Remove action is&nbsp;selected, Kaspersky Endpoint Security removes the&nbsp;hard link being&nbsp;processed.  The remaining hard links to&nbsp;this file will&nbsp;not&nbsp;be&nbsp;processed.","If Cure action is&nbsp;selected, Kaspersky Endpoint Security disinfects the&nbsp;source&nbsp;file. If&nbsp;disinfection fails, the&nbsp;application deletes the&nbsp;hard link and creates in&nbsp;its place a&nbsp;copy of&nbsp;the&nbsp;source file with&nbsp;the&nbsp;name of&nbsp;the&nbsp;deleted hard&nbsp;link.","When you restore a&nbsp;file with&nbsp;a&nbsp;hard link from Storage, Kaspersky Endpoint Security creates a copy of the source file with the name of the hard link that was moved to Storage. Connections with the&nbsp;remaining hard links to&nbsp;the&nbsp;source file will&nbsp;not&nbsp;be&nbsp;restored.","Special considerations for scanning symbolic links and hard links","161283.htm");
Page[77]=new Array("This section provides information about the settings you can specify for the real-time protection task.","All available values and default values for each setting are described.","ScanArchived","Enables / disables scanning of&nbsp;archives (including SFX self-extracting archives). Kaspersky Endpoint Security detects threats in&nbsp;archives but does&nbsp;not&nbsp;disinfect&nbsp;them. The following archive types are supported: .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Available&nbsp;values:","Yes&#8212;Scan&nbsp;archives.","No&#8212;Do not&nbsp;scan&nbsp;archives.","Default value: No.","ScanSfxArchived","Enables / disables scanning of&nbsp;self-extracting archives only (archives that contain an&nbsp;executable extraction module).","Available&nbsp;values:","Yes&#8212;Scan self-extracting&nbsp;archives.","No&#8212;Do not&nbsp;scan self-extracting&nbsp;archives.","Default value: No.","ScanMailBases","Enables / disables scanning of&nbsp;email databases of&nbsp;Microsoft Outlook, Outlook Express, The&nbsp;Bat! and&nbsp;other mail&nbsp;clients.","Available&nbsp;values:","Yes&#8212;Scan files of&nbsp;email&nbsp;databases.","No&#8212;Do not&nbsp;scan files of&nbsp;email&nbsp;databases.","Default value:&nbsp;No.","ScanPlainMail","Enables / disables scanning of&nbsp;plain text email&nbsp;messages.","Available&nbsp;values:","Yes&#8212;Scan plain text email&nbsp;messages.","No&#8212;Do not&nbsp;scan plain text email&nbsp;messages.","Default value:&nbsp;No.","SizeLimit","Specifies the&nbsp;maximum size of&nbsp;an&nbsp;object to&nbsp;be&nbsp;scanned (in&nbsp;megabytes). If&nbsp;an&nbsp;object to&nbsp;be&nbsp;scanned is&nbsp;larger than the&nbsp;specified value, Kaspersky Endpoint Security skips the&nbsp;object.","This setting is&nbsp;used together with&nbsp;the&nbsp;UseSizeLimit&nbsp;setting.","Available&nbsp;values:","0&nbsp;&#8211; 999,999.","0&#8212;Kaspersky Endpoint Security scans objects of&nbsp;any&nbsp;size.","Default value:&nbsp;0.","TimeLimit","Specifies maximum duration for&nbsp;the&nbsp;object scan (in&nbsp;seconds). Kaspersky Endpoint Security stops scanning an&nbsp;object if it takes longer than the&nbsp;number of&nbsp;seconds specified by&nbsp;this&nbsp;parameter.","This setting is&nbsp;used together with&nbsp;the&nbsp;UseTimeLimit&nbsp;setting.","Available&nbsp;values:","0 &#8211;&nbsp;9999.","0&#8212;The&nbsp;object scan duration is&nbsp;unlimited.","Default value:&nbsp;60.","FirstAction","Selection of&nbsp;the&nbsp;first action to&nbsp;be&nbsp;performed by&nbsp;Kaspersky Endpoint Security on&nbsp;infected&nbsp;objects.","In real-time protection tasks, before performing the&nbsp;action specified by&nbsp;you on&nbsp;an&nbsp;object, Kaspersky Endpoint Security blocks access to&nbsp;the&nbsp;object by&nbsp;applications that attempt to&nbsp;access&nbsp;it.","Available&nbsp;values:","Cure (disinfect)&#8212;Kaspersky Endpoint Security attempts to&nbsp;disinfect an&nbsp;object by&nbsp;saving a&nbsp;copy of&nbsp;it in&nbsp;Storage. If&nbsp;disinfection fails (for&nbsp;example, if the&nbsp;type of&nbsp;object or the&nbsp;type of&nbsp;threat in&nbsp;the&nbsp;object cannot be&nbsp;disinfected) Kaspersky Endpoint Security leaves the&nbsp;object&nbsp;unchanged. If&nbsp;the&nbsp;first action is&nbsp;set to&nbsp;Cure, it is&nbsp;recommended to&nbsp;specify the&nbsp;second action using the&nbsp;SecondAction&nbsp;setting.","Remove&#8212;Kaspersky Endpoint Security removes the&nbsp;infected object after&nbsp;first creating a&nbsp;backup copy of&nbsp;it.","Recommended (perform recommended action)&#8212;Kaspersky Endpoint Security automatically selects and performs an&nbsp;action on&nbsp;the&nbsp;object based on&nbsp;information about the&nbsp;threat detected in&nbsp;the&nbsp;object. For&nbsp;example, Kaspersky Endpoint Security immediately removes Trojans since they do&nbsp;not&nbsp;incorporate themselves into other files and therefore they do&nbsp;not&nbsp;need to&nbsp;be&nbsp;disinfected.","Block&#8212;Kaspersky Endpoint Security blocks access to&nbsp;the&nbsp;infected&nbsp;object. Information&nbsp;about the&nbsp;infected object is&nbsp;logged.","Default value:&nbsp;Recommended.","SecondAction","Selection of&nbsp;the&nbsp;second action to&nbsp;be&nbsp;performed by&nbsp;Kaspersky Endpoint Security on&nbsp;infected&nbsp;objects. Kaspersky Endpoint Security performs the&nbsp;second action if the&nbsp;first action&nbsp;fails.","The values of&nbsp;the&nbsp;SecondAction setting are&nbsp;the&nbsp;same as the&nbsp;values of&nbsp;the&nbsp;FirstAction&nbsp;setting.","If Block or Remove is&nbsp;selected as the&nbsp;first action, a&nbsp;second action does&nbsp;not&nbsp;need to&nbsp;be&nbsp;specified. It&nbsp;is&nbsp;recommended to&nbsp;specify two actions in&nbsp;other&nbsp;cases. If&nbsp;you have&nbsp;not&nbsp;specified a&nbsp;second action, Kaspersky Endpoint Security applies Block as the&nbsp;second&nbsp;action.","Default value:&nbsp;Block.","UseExcludeMasks","Enables / disables the&nbsp;scan exclusion of&nbsp;objects specified using the&nbsp;ExcludeMasks&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude objects specified by&nbsp;the&nbsp;ExcludeMasks&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude objects specified by&nbsp;the&nbsp;ExcludeMasks&nbsp;setting.","Default value:&nbsp;No.","ExcludeMasks","Excludes objects from scanning by&nbsp;name or&nbsp;mask. You&nbsp;can&nbsp;use this setting to&nbsp;exclude an&nbsp;individual file from the&nbsp;specified scan scope by&nbsp;name or exclude several files at&nbsp;once using masks in&nbsp;command shell&nbsp;format.","The default value is&nbsp;not defined.","Example:","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Enables or disables the&nbsp;scan exclusion of&nbsp;objects with&nbsp;threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Default value:&nbsp;No.","ExcludeThreats","Excludes objects from scanning by&nbsp;the&nbsp;name of&nbsp;the&nbsp;threats detected in&nbsp;them. Before&nbsp;specifying a&nbsp;value for&nbsp;this setting, make sure that the&nbsp;UseExcludeThreats setting is&nbsp;enabled.","In order to&nbsp;exclude a&nbsp;single object from scanning, specify the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;this object&nbsp;&#8211; the&nbsp;Kaspersky Endpoint Security string with&nbsp;the&nbsp;verdict that the&nbsp;object is&nbsp;infected.","E.g., you may be&nbsp;using a&nbsp;utility to&nbsp;collect information about your&nbsp;network. To&nbsp;keep Kaspersky Endpoint Security from blocking it, add the&nbsp;full name of&nbsp;the&nbsp;threat contained in&nbsp;it to&nbsp;the&nbsp;list of&nbsp;threats excluded from&nbsp;scanning.","You can&nbsp;find the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;the&nbsp;object in&nbsp;the&nbsp;Kaspersky Endpoint Security&nbsp;log. You&nbsp;can&nbsp;also find the&nbsp;full name of&nbsp;the&nbsp;threat on&nbsp;the&nbsp;website of&nbsp;the&nbsp;Virus Encyclopedia (http://www.securelist.com). To&nbsp;find the&nbsp;name of&nbsp;a&nbsp;threat, enter the&nbsp;application name in&nbsp;the&nbsp;Search&nbsp;field.","The setting value is&nbsp;case-sensitive.","The default value is&nbsp;not defined.","Example:","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Enables / disables logging of&nbsp;information about scanned objects that Kaspersky Endpoint Security has&nbsp;deemed&nbsp;non-infected.","You can&nbsp;enable this setting, for&nbsp;example, to&nbsp;make sure that a&nbsp;particular object has&nbsp;been scanned by&nbsp;Kaspersky Endpoint Security.","Available&nbsp;values:","Yes&#8212;Log information about non-infected&nbsp;objects.","No&#8212;Do not&nbsp;log information about non-infected&nbsp;objects.","Default value:&nbsp;No.","ReportPackedObjects","Enables / disables logging of&nbsp;information about scanned objects that are&nbsp;part of&nbsp;compound&nbsp;objects.","You can&nbsp;enable this setting, for&nbsp;example, to&nbsp;make sure that an&nbsp;object within an&nbsp;archive has&nbsp;been scanned by&nbsp;Kaspersky Endpoint Security.","Available&nbsp;values:","Yes&#8212;Log information about scanning objects within&nbsp;archives.","No&#8212;Do not&nbsp;log information about scanning objects within&nbsp;archives.","Default value:&nbsp;No.","ReportUnprocessedObjects","Enables / disables the&nbsp;logging of&nbsp;information about unscanned&nbsp;objects.","Available&nbsp;values:","Yes&#8212;Log information about unscanned&nbsp;objects.","No&#8212;Do not&nbsp;log information about unscanned&nbsp;objects.","Default value:&nbsp;No.","UseAnalyzer","Enables / disables Heuristic&nbsp;Analyzer.","Heuristic analysis enables the application to detect new threats even before they become known to virus analysts. ","Available&nbsp;values:","Yes&#8212;Enable Heuristic&nbsp;Analyzer.","No&#8212;disable Heuristic&nbsp;Analyzer.","Default value:&nbsp;Yes.","HeuristicLevel","Heuristic analysis&nbsp;level.","You can specify the heuristic analysis level. The heuristic analysis level sets the balance between the thoroughness of searches for threats, the load on the operating system's resources, and the scan duration. The higher the heuristic analysis level, the more resources and time are required for scanning.","Available&nbsp;values:","Light&#8212;The least thorough scan with&nbsp;minimal load on&nbsp;the&nbsp;system.","Medium&#8212;Medium heuristic analysis level with&nbsp;a&nbsp;balanced load on&nbsp;the&nbsp;operating&nbsp;system.","Deep&#8212;The most thorough scan with&nbsp;maximal load on&nbsp;the&nbsp;operating&nbsp;system.","Recommended&#8212;recommended&nbsp;value.","Default value:&nbsp;Recommended.","UseIChecker","Enables&nbsp;/&nbsp;disables the&nbsp;use of&nbsp;iChecker&nbsp;technology.","Available&nbsp;values:","Yes&#8212;Enable use of&nbsp;iChecker&nbsp;technology.","No&#8212;Disable use of&nbsp;iChecker&nbsp;technology.","Default value:&nbsp;Yes.","ScanByAccessType","You can&nbsp;use this setting to&nbsp;specify the&nbsp;real-time protection&nbsp;mode. The&nbsp;ScanByAccessType setting is&nbsp;applied only in&nbsp;real-time protection&nbsp;tasks.","Available&nbsp;values:","SmartCheck&#8212;Scan a&nbsp;file when there is&nbsp;an&nbsp;attempt to&nbsp;open it, and scan it again when there is&nbsp;an&nbsp;attempt to&nbsp;close it if the&nbsp;file has&nbsp;been&nbsp;modified. If&nbsp;a&nbsp;process accesses an&nbsp;object multiple times in&nbsp;the&nbsp;course of&nbsp;its operation and modifies it, the&nbsp;application scans the&nbsp;object again only when the&nbsp;process closes it for&nbsp;the&nbsp;last&nbsp;time.","OpenAndModify&#8212;Scan a&nbsp;file when there is&nbsp;an&nbsp;attempt to&nbsp;open it, and scan it again when there is&nbsp;an&nbsp;attempt to&nbsp;close it if the&nbsp;file has&nbsp;been&nbsp;modified.","Open&#8212;Scan the&nbsp;file when an&nbsp;attempt is&nbsp;made to&nbsp;open it for&nbsp;reading or for&nbsp;execution or&nbsp;modification.","Default value:&nbsp;SmartCheck.","The [ScanScope.item_#] section contains the&nbsp;following&nbsp;settings:","AreaDesc","Description of&nbsp;the&nbsp;scan scope, which contains additional information about the&nbsp;scan&nbsp;scope. The&nbsp;maximum length of&nbsp;the&nbsp;string specified using this setting is&nbsp;4096&nbsp;characters.","Default value:&nbsp;All&nbsp;objects.","Example:","AreaDesc=&quot;Scan mail databases&quot;","UseScanArea","This setting enables / disables scanning of&nbsp;the&nbsp;specified&nbsp;scope. To&nbsp;run the&nbsp;task, you must&nbsp;include at&nbsp;least one area to&nbsp;scan.","Available&nbsp;values:","Yes&#8212;Scan the&nbsp;specified&nbsp;scope.","No&#8212;Do&nbsp;not&nbsp;scan the&nbsp;specified&nbsp;scope.","Default value:&nbsp;Yes.","AreaMask","You can&nbsp;use this setting to&nbsp;restrict the&nbsp;scan&nbsp;scope.","In the&nbsp;scan scope, Kaspersky Endpoint Security scans only the&nbsp;files that are&nbsp;indicated using command shell&nbsp;masks.","If this setting is&nbsp;not&nbsp;specified, Kaspersky Endpoint Security scans all objects in&nbsp;the&nbsp;scan&nbsp;scope. You&nbsp;can&nbsp;specify several values for&nbsp;this&nbsp;setting.","Default value:&nbsp;* (scan all objects).","Example:","AreaMask=*doc","Path","You can&nbsp;use this setting to&nbsp;specify the&nbsp;path to&nbsp;objects to&nbsp;scan.","The value of&nbsp;the&nbsp;Path setting consists of&nbsp;two&nbsp;elements: &lt;file system type&gt;:&lt;access protocol&gt;. It&nbsp;may also contain the&nbsp;path to&nbsp;the&nbsp;directory in&nbsp;the&nbsp;local file&nbsp;system.","Available&nbsp;values:","&lt;path to&nbsp;local directory&gt;&#8212;Scan objects in&nbsp;the&nbsp;specified&nbsp;directory.","Shared:NFS&#8212;Scan the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;NFS&nbsp;protocol.","Shared:SMB&#8212;Scan the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;SMB&nbsp;protocol.","AllRemoteMounted&#8212;Scan all remote directories mounted on&nbsp;the&nbsp;computer using the&nbsp;SMB and NFS&nbsp;protocols.","AllShared&#8212;Scan all of&nbsp;the&nbsp;computer's file system resources shared via&nbsp;the&nbsp;SMB and NFS&nbsp;protocols.","The [ExcludedFromScanScope.item_#] section contains the&nbsp;following&nbsp;settings:","AreaDesc","Description of&nbsp;the&nbsp;scan exclusion&nbsp;scope. Contains&nbsp;additional information about the&nbsp;exclusion&nbsp;scope.","The default value is&nbsp;not defined.","Example:","AreaDesc=&quot;Exclude separate SAMBA&quot;","UseScanArea","This setting enables&nbsp;/&nbsp;disables scanning of&nbsp;the&nbsp;specified&nbsp;scope.","Available&nbsp;values:","Yes&#8212;Excludes the&nbsp;specified&nbsp;scope.","No&#8212;Does&nbsp;not&nbsp;exclude the&nbsp;specified&nbsp;scope.","Default value:&nbsp;Yes.","Path","You can&nbsp;use this setting to&nbsp;specify the&nbsp;path to&nbsp;objects excluded from&nbsp;scanning.","The value of&nbsp;the&nbsp;Path setting consists of&nbsp;two&nbsp;elements: &lt;file system type&gt;:&lt;access protocol&gt;. It&nbsp;may also contain the&nbsp;path to&nbsp;the&nbsp;directory in&nbsp;the&nbsp;local file&nbsp;system.","Available&nbsp;values:","&lt;path to&nbsp;local directory&gt;&#8212;Exclude objects in&nbsp;the&nbsp;specified directory from&nbsp;scanning.","Shared:NFS&#8212;Exclude the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;NFS&nbsp;protocol.","Shared:SMB&#8212;Exclude the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;Samba&nbsp;protocol.","AllRemoteMounted&#8212;Exclude all remote directories mounted on&nbsp;the&nbsp;computer using the&nbsp;SMB and NFS&nbsp;protocols.","AllShared&#8212;Exclude all of the computer file system resources shared via the SMB and NFS protocols.","Real-time protection task settings","161284.htm");
Page[78]=new Array("You can specify a global exclusion scope for the real-time protection task. Files in the global exclusion scope are excluded from the real-time protection scopes.","To create a global exclusion scope,","Save the real-time protection task settings to a file using the following command:","kesl-control --get-settings &lt;task name or task ID&gt; --file &lt;full path to the configuration file&gt;","Add [ExcludedFromScanScope.item_#] sections to the created file. Each [ExcludedFromScanScope.item_#] section includes the following settings:","AreaMask-specifies file name masks for files to be excluded from the protection scope.","AreaDesc-specifies the unique name of the exclusion scope.","Path-specifies the path to the files to be excluded from the protection scope. ","Import settings from the configuration file to the real-time protection task using the following command:","kesl-control --set-settings &lt;task name or task ID&gt; --file &lt;full path to the configuration file&gt;","Specifying global exclusion scope","162099.htm");
Page[79]=new Array("This section contains information about the&nbsp;on-demand scan task.","On-demand scan task (Scan_My_Computer ID:2)","161286.htm");
Page[80]=new Array("An on-demand scan is&nbsp;a&nbsp;one-time full or custom scan of&nbsp;files on&nbsp;a&nbsp;computer performed by&nbsp;Kaspersky Endpoint Security. Kaspersky Endpoint Security can&nbsp;perform multiple on-demand scan tasks at&nbsp;the&nbsp;same&nbsp;time.","By default, Kaspersky Endpoint Security creates one predefined on-demand scan task&nbsp;&#8211; full&nbsp;scan. The&nbsp;application scans all objects located on&nbsp;local drives of&nbsp;the&nbsp;computer, as well as all mounted and shared objects that are&nbsp;accessed via&nbsp;the&nbsp;Samba and NFS protocols with&nbsp;the&nbsp;recommended security&nbsp;settings.","Users can&nbsp;create custom on-demand scan&nbsp;tasks.","By default, Kaspersky Endpoint Security also creates a&nbsp;predefined custom scan&nbsp;task.","If the application was restarted by the watchdog or manually by a user during an on-demand scan run, a task is interrupted. The application logs the OnDemandTaskInterrupted event.","About on-demand scan","161287.htm");
Page[81]=new Array("This section provides information about the settings you can specify for the on-demand scan task.","All available values and default values for each setting are described.","ScanArchived ","Enables / disables scanning of&nbsp;archives (including SFX self-extracting archives). Kaspersky Endpoint Security detects threats in&nbsp;archives but does&nbsp;not&nbsp;disinfect&nbsp;them. The following archive types are supported: .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Available&nbsp;values:","Yes&#8212;Scan&nbsp;archives.","No&#8212;Do not&nbsp;scan&nbsp;archives.","Default value: Yes.","ScanSfxArchived","Enables / disables scanning of&nbsp;self-extracting archives only (archives that contain an&nbsp;executable extraction module).","Available&nbsp;values:","Yes&#8212;Scan self-extracting&nbsp;archives.","No&#8212;Do not&nbsp;scan self-extracting&nbsp;archives.","Default value: Yes.","ScanMailBases","Enables / disables scanning of&nbsp;email databases of&nbsp;Microsoft Outlook, Outlook Express, The&nbsp;Bat! and&nbsp;other mail&nbsp;clients.","Available&nbsp;values:","Yes&#8212;Scan files of&nbsp;email&nbsp;databases.","No&#8212;Do not&nbsp;scan files of&nbsp;email&nbsp;databases.","Default value:&nbsp;No.","ScanPlainMail","Enables / disables scanning of&nbsp;plain text email&nbsp;messages.","Available&nbsp;values:","Yes&#8212;Scan plain text email&nbsp;messages.","No&#8212;Do not&nbsp;scan plain text email&nbsp;messages.","Default value:&nbsp;No.","UseSizeLimit","Enables / disables use of&nbsp;the&nbsp;SizeLimit setting (maximum size of&nbsp;an&nbsp;object to&nbsp;be&nbsp;scanned).","Available&nbsp;values:","Yes&#8212;Apply the&nbsp;SizeLimit&nbsp;parameter.","No&#8212;Do not&nbsp;apply the&nbsp;SizeLimit&nbsp;parameter.","Default value:&nbsp;No.","SizeLimit","Specifies the&nbsp;maximum size of&nbsp;an&nbsp;object to&nbsp;be&nbsp;scanned (in&nbsp;megabytes). If&nbsp;an&nbsp;object to&nbsp;be&nbsp;scanned is&nbsp;larger than the&nbsp;specified value, Kaspersky Endpoint Security skips the&nbsp;object.","This setting is&nbsp;used together with&nbsp;the&nbsp;UseSizeLimit&nbsp;setting.","Available&nbsp;values:","0&nbsp;&#8211; 999,999.","0&#8212;Kaspersky Endpoint Security scans objects of&nbsp;any&nbsp;size.","Default value:&nbsp;0.","UseTimeLimit","Enables / disables use of&nbsp;the&nbsp;TimeLimit setting (maximum duration of&nbsp;an&nbsp;object scan).","Available&nbsp;values:","Yes&#8212;Apply the&nbsp;TimeLimit&nbsp;parameter.","No&#8212;Do&nbsp;not&nbsp;apply the&nbsp;TimeLimit&nbsp;parameter.","Default value: No.","TimeLimit","Specifies maximum duration for&nbsp;the&nbsp;object scan (in&nbsp;seconds). Kaspersky Endpoint Security stops scanning an&nbsp;object if it takes longer than the&nbsp;number of&nbsp;seconds specified by&nbsp;this&nbsp;parameter.","This setting is&nbsp;used together with&nbsp;the&nbsp;UseTimeLimit&nbsp;setting.","Available&nbsp;values:","0 &#8211;&nbsp;9999.","0&#8212;The&nbsp;object scan duration is&nbsp;unlimited.","Default value:&nbsp;0.","FirstAction","Selection of&nbsp;the&nbsp;first action to&nbsp;be&nbsp;performed by&nbsp;Kaspersky Endpoint Security on&nbsp;infected&nbsp;objects.","Available&nbsp;values:","Cure (disinfect)&#8212;Kaspersky Endpoint Security attempts to&nbsp;disinfect an&nbsp;object by&nbsp;saving a&nbsp;copy of&nbsp;it in&nbsp;Storage. If&nbsp;disinfection fails (for&nbsp;example, if the&nbsp;type of&nbsp;object or the&nbsp;type of&nbsp;threat in&nbsp;the&nbsp;object cannot be&nbsp;disinfected) Kaspersky Endpoint Security leaves the&nbsp;object&nbsp;unchanged. If&nbsp;the&nbsp;first action is&nbsp;set to&nbsp;Cure, it is&nbsp;recommended to&nbsp;specify the&nbsp;second action using the&nbsp;SecondAction&nbsp;setting.","Remove&#8212;Kaspersky Endpoint Security removes the&nbsp;infected object after&nbsp;first creating a&nbsp;backup copy of&nbsp;it.","Recommended (perform recommended action)&#8212;Kaspersky Endpoint Security automatically selects and performs an&nbsp;action on&nbsp;the&nbsp;object based on&nbsp;information about the&nbsp;threat detected in&nbsp;the&nbsp;object. For&nbsp;example, Kaspersky Endpoint Security immediately removes Trojans since they do&nbsp;not&nbsp;incorporate themselves into other files and therefore they do&nbsp;not&nbsp;need to&nbsp;be&nbsp;disinfected.","Skip&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;attempt to&nbsp;disinfect or delete an&nbsp;infected&nbsp;object. Information&nbsp;about the&nbsp;infected object is&nbsp;logged.","Default value:&nbsp;Recommended.","SecondAction","Selection of&nbsp;the&nbsp;second action to&nbsp;be&nbsp;performed by&nbsp;Kaspersky Endpoint Security on&nbsp;infected&nbsp;objects. Kaspersky Endpoint Security performs the&nbsp;second action if the&nbsp;first action&nbsp;fails.","The values of&nbsp;the&nbsp;SecondAction setting are&nbsp;the&nbsp;same as the&nbsp;values of&nbsp;the&nbsp;FirstAction&nbsp;setting.","If Skip or Remove is&nbsp;selected as the&nbsp;first action, a&nbsp;second action does&nbsp;not&nbsp;need to&nbsp;be&nbsp;specified. It&nbsp;is&nbsp;recommended to&nbsp;specify two actions in&nbsp;other&nbsp;cases. If&nbsp;you have&nbsp;not&nbsp;specified a&nbsp;second action, Kaspersky Endpoint Security applies Skip as the&nbsp;second&nbsp;action.","Default value:&nbsp;Skip.","UseExcludeMasks","Enables / disables the&nbsp;scan exclusion of&nbsp;objects specified using the&nbsp;ExcludeMasks&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude objects specified by&nbsp;the&nbsp;ExcludeMasks&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude objects specified by&nbsp;the&nbsp;ExcludeMasks&nbsp;setting.","Default value:&nbsp;No.","ExcludeMasks","Excludes objects from scanning by&nbsp;name or&nbsp;mask. You&nbsp;can&nbsp;use this setting to&nbsp;exclude an&nbsp;individual file from the&nbsp;specified scan scope by&nbsp;name or exclude several files at&nbsp;once using masks in&nbsp;command shell&nbsp;format.","The default value is&nbsp;not defined.","Example:","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Enables or disables the&nbsp;scan exclusion of&nbsp;objects with&nbsp;threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Default value:&nbsp;No.","ExcludeThreats","Excludes objects from scanning by&nbsp;the&nbsp;name of&nbsp;the&nbsp;threats detected in&nbsp;them. Before&nbsp;specifying a&nbsp;value for&nbsp;this setting, make sure that the&nbsp;UseExcludeThreats setting is&nbsp;enabled.","In order to&nbsp;exclude a&nbsp;single object from scanning, specify the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;this object&nbsp;&#8211; the&nbsp;Kaspersky Endpoint Security string with&nbsp;the&nbsp;verdict that the&nbsp;object is&nbsp;infected.","E.g., you may be&nbsp;using a&nbsp;utility to&nbsp;collect information about your&nbsp;network. To&nbsp;keep Kaspersky Endpoint Security from blocking it, add the&nbsp;full name of&nbsp;the&nbsp;threat contained in&nbsp;it to&nbsp;the&nbsp;list of&nbsp;threats excluded from&nbsp;scanning.","You can&nbsp;find the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;the&nbsp;object in&nbsp;the&nbsp;Kaspersky Endpoint Security&nbsp;log. You&nbsp;can&nbsp;also find the&nbsp;full name of&nbsp;the&nbsp;threat on&nbsp;the&nbsp;website of&nbsp;the&nbsp;Virus Encyclopedia (http://www.securelist.com). To&nbsp;find the&nbsp;name of&nbsp;a&nbsp;threat, enter the&nbsp;application name in&nbsp;the&nbsp;Search&nbsp;field.","The setting value is&nbsp;case-sensitive.","The default value is&nbsp;not defined.","Example:","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Enables / disables logging of&nbsp;information about scanned objects that Kaspersky Endpoint Security has&nbsp;deemed&nbsp;non-infected.","You can&nbsp;enable this setting, for&nbsp;example, to&nbsp;make sure that a&nbsp;particular object has&nbsp;been scanned by&nbsp;Kaspersky Endpoint Security.","Available&nbsp;values:","Yes&#8212;Log information about non-infected&nbsp;objects.","No&#8212;Do not&nbsp;log information about non-infected&nbsp;objects.","Default value:&nbsp;No.","ReportPackedObjects","Enables / disables logging of&nbsp;information about scanned objects that are&nbsp;part of&nbsp;compound&nbsp;objects.","You can&nbsp;enable this setting, for&nbsp;example, to&nbsp;make sure that an&nbsp;object within an&nbsp;archive has&nbsp;been scanned by&nbsp;Kaspersky Endpoint Security.","Available&nbsp;values:","Yes&#8212;Log information about scanning objects within&nbsp;archives.","No&#8212;Do not&nbsp;log information about scanning objects within&nbsp;archives.","Default value:&nbsp;No.","ReportUnprocessedObjects","Enables / disables the&nbsp;logging of&nbsp;information about unscanned&nbsp;objects.","Available&nbsp;values:","Yes&#8212;Log information about unscanned&nbsp;objects.","No&#8212;Do not&nbsp;log information about unscanned&nbsp;objects.","Default value:&nbsp;No.","UseAnalyzer","Enables / disables Heuristic&nbsp;Analyzer.","Heuristic analysis enables the application to detect new threats even before they become known to virus analysts.","Available&nbsp;values:","Yes&#8212;Enable Heuristic&nbsp;Analyzer.","No&#8212;Disable Heuristic&nbsp;Analyzer.","Default value:&nbsp;Yes.","HeuristicLevel","Heuristic analysis&nbsp;level.","You can specify the heuristic analysis level. The heuristic analysis level sets the balance between the thoroughness of searches for threats, the load on the operating system's resources, and the scan duration. The higher the heuristic analysis level, the more resources and time are required for scanning.","Available&nbsp;values:","Light&#8212;The least thorough scan with&nbsp;minimal load on&nbsp;the&nbsp;system.","Medium&#8212;Medium heuristic analysis level with&nbsp;a&nbsp;balanced load on&nbsp;the&nbsp;operating&nbsp;system.","Deep&#8212;The most thorough scan with&nbsp;maximal load on&nbsp;the&nbsp;operating&nbsp;system.","Recommended&#8212;Recommended&nbsp;value.","Default value:&nbsp;Recommended.","UseIChecker","Enables&nbsp;/&nbsp;disables the&nbsp;use of&nbsp;iChecker&nbsp;technology.","Available&nbsp;values:","Yes&#8212;Enable use of&nbsp;iChecker&nbsp;technology.","No&#8212;Disable use of&nbsp;iChecker&nbsp;technology.","Default value:&nbsp;Yes.","ScanByAccessType","You can&nbsp;use this setting to&nbsp;specify the&nbsp;real-time protection&nbsp;mode. The&nbsp;ScanByAccessType setting is&nbsp;applied only in&nbsp;real-time protection&nbsp;tasks.","Available&nbsp;values:","SmartCheck&#8212;Scan a&nbsp;file when there is&nbsp;an&nbsp;attempt to&nbsp;open it, and scan it again when there is&nbsp;an&nbsp;attempt to&nbsp;close it if the&nbsp;file has&nbsp;been&nbsp;modified. If&nbsp;a&nbsp;process accesses an&nbsp;object multiple times in&nbsp;the&nbsp;course of&nbsp;its operation and modifies it, the&nbsp;application scans the&nbsp;object again only when the&nbsp;process closes it for&nbsp;the&nbsp;last&nbsp;time.","OpenAndModify&#8212;Scan a&nbsp;file when there is&nbsp;an&nbsp;attempt to&nbsp;open it, and scan it again when there is&nbsp;an&nbsp;attempt to&nbsp;close it if the&nbsp;file has&nbsp;been&nbsp;modified.","Open&#8212;Scan the&nbsp;file when an&nbsp;attempt is&nbsp;made to&nbsp;open it for&nbsp;reading or for&nbsp;execution or&nbsp;modification.","Default value:&nbsp;SmartCheck.","The [ScanScope.item_#] section contains the&nbsp;following&nbsp;settings:","AreaDesc","Description of&nbsp;the&nbsp;scan scope, which contains additional information about the&nbsp;scan&nbsp;scope. The&nbsp;maximum length of&nbsp;the&nbsp;string specified using this setting is&nbsp;4096&nbsp;characters.","The default value:&nbsp;All&nbsp;objects.","Example:","AreaDesc=&quot;Scan mail databases&quot;","UseScanArea","This setting enables / disables scanning of&nbsp;the&nbsp;specified&nbsp;scope. To&nbsp;run the&nbsp;task, you must&nbsp;include at&nbsp;least one area to&nbsp;scan.","Available&nbsp;values:","Yes&#8212;Scan the&nbsp;specified&nbsp;scope.","No&#8212;Do&nbsp;not&nbsp;scan the&nbsp;specified&nbsp;scope.","The default value:&nbsp;Yes.","AreaMask","You can&nbsp;use this setting to&nbsp;restrict the&nbsp;scan&nbsp;scope.","In the&nbsp;scan scope, Kaspersky Endpoint Security scans only the&nbsp;files that are&nbsp;indicated using command shell&nbsp;masks.","If this setting is&nbsp;not&nbsp;specified, Kaspersky Endpoint Security scans all objects in&nbsp;the&nbsp;scan&nbsp;scope. You&nbsp;can&nbsp;specify several values for&nbsp;this&nbsp;setting.","The default value:&nbsp;* (scan all objects).","Example:","AreaMask=*doc","Path","You can&nbsp;use this setting to&nbsp;specify the&nbsp;path to&nbsp;objects to&nbsp;scan.","The value of&nbsp;the&nbsp;Path setting consists of&nbsp;two&nbsp;elements: &lt;file system type&gt;:&lt;access protocol&gt;. It&nbsp;may also contain the&nbsp;path to&nbsp;the&nbsp;directory in&nbsp;the&nbsp;local file&nbsp;system.","Available&nbsp;values:","&lt;path to&nbsp;local directory&gt;&#8212;Scan objects in&nbsp;the&nbsp;specified&nbsp;directory.","Shared:NFS&#8212;Scan the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;NFS&nbsp;protocol.","Shared:SMB&#8212;Scan the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;SMB&nbsp;protocol.","AllRemoteMounted&#8212;Scan all remote directories mounted on&nbsp;the&nbsp;computer using the&nbsp;SMB and NFS&nbsp;protocols.","AllShared&#8212;Scan all of&nbsp;the&nbsp;computer's file system resources shared via&nbsp;the&nbsp;SMB and NFS&nbsp;protocols.","The [ExcludedFromScanScope.item_#] section contains the&nbsp;following&nbsp;settings:","AreaDesc","Description of&nbsp;the&nbsp;scan exclusion&nbsp;scope. Contains&nbsp;additional information about the&nbsp;exclusion&nbsp;scope.","The default value is&nbsp;not defined.","Example:","AreaDesc=&quot;Exclude separate SAMBA&quot;","UseScanArea","This setting enables&nbsp;/&nbsp;disables scanning of&nbsp;the&nbsp;specified&nbsp;scope.","Available&nbsp;values:","Yes&#8212;Excludes the&nbsp;specified&nbsp;scope.","No&#8212;Does&nbsp;not&nbsp;exclude the&nbsp;specified&nbsp;scope.","Default value:&nbsp;Yes.","Path","You can&nbsp;use this setting to&nbsp;specify the&nbsp;path to&nbsp;objects excluded from&nbsp;scanning.","The value of&nbsp;the&nbsp;Path setting consists of&nbsp;two&nbsp;elements: &lt;file system type&gt;:&lt;access protocol&gt;. It&nbsp;may also contain the&nbsp;path to&nbsp;the&nbsp;directory in&nbsp;the&nbsp;local file&nbsp;system.","Available&nbsp;values:","&lt;path to&nbsp;local directory&gt;&#8212;Exclude objects in&nbsp;the&nbsp;specified directory from&nbsp;scanning.","Shared:NFS&#8212;Exclude the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;NFS&nbsp;protocol.","Shared:SMB&#8212;Exclude the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;Samba&nbsp;protocol.","AllRemoteMounted&#8212;Exclude all remote directories mounted on&nbsp;the&nbsp;computer using the&nbsp;SMB and NFS&nbsp;protocols.","AllShared&#8212;Exclude all of the computer's file system resources shared via the SMB and NFS protocols.","On-demand scan task settings","161288.htm");
Page[82]=new Array("This section contains information about the&nbsp;custom scan task.","Custom scan task (Scan_File ID:3)","161290.htm");
Page[83]=new Array("A custom scan task uses settings that are applied by --scan-file command.","You can scan a file or a directory using the following command:","--scan-file &lt;file path&gt;","The application creates a temporary on-demand scan (ODS) task with settings from the Scan_File task. After scan completion, the temporary task is deleted automatically.","You can change scan parameters for the temporary Scan_File task from the command line.","About custom scan task","161291.htm");
Page[84]=new Array("This section provides information about the settings you can specify for the custom scan task.","All available values and default values for each setting are described.","ScanArchived","Enables / disables scanning of&nbsp;archives (including SFX self-extracting archives). Kaspersky Endpoint Security detects threats in&nbsp;archives but does&nbsp;not&nbsp;disinfect&nbsp;them. the following archive types are supported: .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Available&nbsp;values:","Yes&#8212;Scan&nbsp;archives.","No&#8212;Do not&nbsp;scan&nbsp;archives.","Default value: Yes.","ScanSfxArchived","Enables / disables scanning of&nbsp;self-extracting archives only (archives that contain an&nbsp;executable extraction module).","Available&nbsp;values:","Yes&#8212;Scan self-extracting&nbsp;archives.","No&#8212;Do not&nbsp;scan self-extracting&nbsp;archives.","Default value: Yes.","ScanMailBases","Enables / disables scanning of&nbsp;email databases of&nbsp;Microsoft Outlook, Outlook Express, The&nbsp;Bat! and&nbsp;other mail&nbsp;clients.","Available&nbsp;values:","Yes&#8212;Scan files of&nbsp;email&nbsp;databases.","No&#8212;Do not&nbsp;scan files of&nbsp;email&nbsp;databases.","Default value:&nbsp;No.","ScanPlainMail","Enables / disables scanning of&nbsp;plain text email&nbsp;messages.","Available&nbsp;values:","Yes&#8212;Scan plain text email&nbsp;messages.","No&#8212;Do not&nbsp;scan plain text email&nbsp;messages.","Default value:&nbsp;No.","UseSizeLimit","Enables / disables use of&nbsp;the&nbsp;SizeLimit setting (maximum size of&nbsp;an&nbsp;object to&nbsp;be&nbsp;scanned).","Available&nbsp;values:","Yes&#8212;Apply the&nbsp;SizeLimit&nbsp;parameter.","No&#8212;Do not&nbsp;apply the&nbsp;SizeLimit&nbsp;parameter.","Default value:&nbsp;No.","SizeLimit","Specifies the&nbsp;maximum size of&nbsp;an&nbsp;object to&nbsp;be&nbsp;scanned (in&nbsp;megabytes). If&nbsp;an&nbsp;object to&nbsp;be&nbsp;scanned is&nbsp;larger than the&nbsp;specified value, Kaspersky Endpoint Security skips the&nbsp;object.","This setting is&nbsp;used together with&nbsp;the&nbsp;UseSizeLimit&nbsp;setting.","Available&nbsp;values:","0&nbsp;&#8211; 999,999.","0&#8212;Kaspersky Endpoint Security scans objects of&nbsp;any&nbsp;size.","Default value:&nbsp;0.","UseTimeLimit","Enables / disables use of&nbsp;the&nbsp;TimeLimit setting (maximum duration of&nbsp;an&nbsp;object scan).","Available&nbsp;values:","Yes&#8212;Аpply the&nbsp;TimeLimit&nbsp;parameter.","No&#8212;Do&nbsp;not&nbsp;apply the&nbsp;TimeLimit&nbsp;parameter.","Default value: No.","TimeLimit","Specifies maximum duration for&nbsp;the&nbsp;object scan (in&nbsp;seconds). Kaspersky Endpoint Security stops scanning an&nbsp;object if it takes longer than the&nbsp;number of&nbsp;seconds specified by&nbsp;this&nbsp;parameter.","This setting is&nbsp;used together with&nbsp;the&nbsp;UseTimeLimit&nbsp;setting.","Available&nbsp;values:","0-9999.","0&#8212;The&nbsp;object scan duration is&nbsp;unlimited.","Default value:&nbsp;0.","FirstAction","Selection of&nbsp;the&nbsp;first action to&nbsp;be&nbsp;performed by&nbsp;Kaspersky Endpoint Security on&nbsp;infected&nbsp;objects.","Available&nbsp;values:","Cure (disinfect)&#8212;Kaspersky Endpoint Security attempts to&nbsp;disinfect an&nbsp;object by&nbsp;saving a&nbsp;copy of&nbsp;it in&nbsp;Storage. If&nbsp;disinfection fails (for&nbsp;example, if the&nbsp;type of&nbsp;object or the&nbsp;type of&nbsp;threat in&nbsp;the&nbsp;object cannot be&nbsp;disinfected) Kaspersky Endpoint Security leaves the&nbsp;object&nbsp;unchanged. If&nbsp;the&nbsp;first action is&nbsp;set to&nbsp;Cure, it is&nbsp;recommended to&nbsp;specify the&nbsp;second action using the&nbsp;SecondAction&nbsp;setting.","Remove&#8212;Kaspersky Endpoint Security removes the&nbsp;infected object after&nbsp;first creating a&nbsp;backup copy of&nbsp;it.","Recommended (perform recommended action)&#8212;Kaspersky Endpoint Security automatically selects and performs an&nbsp;action on&nbsp;the&nbsp;object based on&nbsp;information about the&nbsp;threat detected in&nbsp;the&nbsp;object. For&nbsp;example, Kaspersky Endpoint Security immediately removes Trojans since they do&nbsp;not&nbsp;incorporate themselves into other files and therefore they do&nbsp;not&nbsp;need to&nbsp;be&nbsp;disinfected.","Skip&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;attempt to&nbsp;disinfect or delete an&nbsp;infected&nbsp;object. Information&nbsp;about the&nbsp;infected object is&nbsp;logged.","Default value:&nbsp;Recommended.","SecondAction","Selection of&nbsp;the&nbsp;second action to&nbsp;be&nbsp;performed by&nbsp;Kaspersky Endpoint Security on&nbsp;infected&nbsp;objects. Kaspersky Endpoint Security performs the&nbsp;second action if the&nbsp;first action&nbsp;fails.","The values of&nbsp;the&nbsp;SecondAction setting are&nbsp;the&nbsp;same as the&nbsp;values of&nbsp;the&nbsp;FirstAction&nbsp;setting.","If Skip or Remove is&nbsp;selected as the&nbsp;first action, a&nbsp;second action does&nbsp;not&nbsp;need to&nbsp;be&nbsp;specified. It&nbsp;is&nbsp;recommended to&nbsp;specify two actions in&nbsp;other&nbsp;cases. If&nbsp;you have&nbsp;not&nbsp;specified a&nbsp;second action, Kaspersky Endpoint Security applies Skip as the&nbsp;second&nbsp;action.","Default value:&nbsp;Skip.","UseExcludeMasks","Enables / disables the&nbsp;scan exclusion of&nbsp;objects specified using the&nbsp;ExcludeMasks&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude objects specified by&nbsp;the&nbsp;ExcludeMasks&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude objects specified by&nbsp;the&nbsp;ExcludeMasks&nbsp;setting.","Default value:&nbsp;No.","ExcludeMasks","Excludes objects from scanning by&nbsp;name or&nbsp;mask. You&nbsp;can&nbsp;use this setting to&nbsp;exclude an&nbsp;individual file from the&nbsp;specified scan scope by&nbsp;name or exclude several files at&nbsp;once using masks in&nbsp;command shell&nbsp;format.","The default value is&nbsp;not&nbsp;defined.","Example:","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Enables or disables the&nbsp;scan exclusion of&nbsp;objects with&nbsp;threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Default value:&nbsp;No.","ExcludeThreats","Excludes objects from scanning by&nbsp;the&nbsp;name of&nbsp;the&nbsp;threats detected in&nbsp;them. Before&nbsp;specifying a&nbsp;value for&nbsp;this setting, make sure that the&nbsp;UseExcludeThreats setting is&nbsp;enabled.","In order to&nbsp;exclude a&nbsp;single object from scanning, specify the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;this object&nbsp;&#8211; the&nbsp;Kaspersky Endpoint Security string with&nbsp;the&nbsp;verdict that the&nbsp;object is&nbsp;infected.","E.g., you may be&nbsp;using a&nbsp;utility to&nbsp;collect information about your&nbsp;network. To&nbsp;keep Kaspersky Endpoint Security from blocking it, add the&nbsp;full name of&nbsp;the&nbsp;threat contained in&nbsp;it to&nbsp;the&nbsp;list of&nbsp;threats excluded from&nbsp;scanning.","You can&nbsp;find the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;the&nbsp;object in&nbsp;the&nbsp;Kaspersky Endpoint Security&nbsp;log. You&nbsp;can&nbsp;also find the&nbsp;full name of&nbsp;the&nbsp;threat on&nbsp;the&nbsp;website of&nbsp;the&nbsp;Virus Encyclopedia (http://www.securelist.com). To&nbsp;find the&nbsp;name of&nbsp;a&nbsp;threat, enter the&nbsp;application name in&nbsp;the&nbsp;Search&nbsp;field.","The setting value is&nbsp;case-sensitive.","The default value is&nbsp;not&nbsp;defined.","Example:","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Enables / disables logging of&nbsp;information about scanned objects that Kaspersky Endpoint Security has&nbsp;deemed&nbsp;non-infected.","You can&nbsp;enable this setting, for&nbsp;example, to&nbsp;make sure that a&nbsp;particular object has&nbsp;been scanned by&nbsp;Kaspersky Endpoint Security.","Available&nbsp;values:","Yes&#8212;Log information about non-infected&nbsp;objects.","No&#8212;Do not&nbsp;log information about non-infected&nbsp;objects.","Default value:&nbsp;No.","ReportPackedObjects","Enables / disables logging of&nbsp;information about scanned objects that are&nbsp;part of&nbsp;compound&nbsp;objects.","You can&nbsp;enable this setting, for&nbsp;example, to&nbsp;make sure that an&nbsp;object within an&nbsp;archive has&nbsp;been scanned by&nbsp;Kaspersky Endpoint Security.","Available&nbsp;values:","Yes&#8212;Log information about scanning objects within&nbsp;archives.","No&#8212;Do not&nbsp;log information about scanning objects within&nbsp;archives.","Default value:&nbsp;No.","ReportUnprocessedObjects","Enables / disables the&nbsp;logging of&nbsp;information about unscanned&nbsp;objects.","Available&nbsp;values:","Yes&#8212;Log information about unscanned&nbsp;objects.","No&#8212;Do not&nbsp;log information about unscanned&nbsp;objects.","Default value:&nbsp;No.","UseAnalyzer","Enables / disables Heuristic&nbsp;Analyzer. Heuristic analysis enables the application to detect new threats even before they become known to virus analysts. ","Available&nbsp;values:","Yes&#8212;Enable Heuristic&nbsp;Analyzer.","No&#8212;Disable Heuristic&nbsp;Analyzer.","Default value:&nbsp;Yes.","HeuristicLevel","Heuristic analysis&nbsp;level.","You can specify the heuristic analysis level. The heuristic analysis level sets the balance between the thoroughness of searches for threats, the load on the operating system's resources, and the scan duration. The higher the heuristic analysis level, the more resources and time are required for scanning.","Available&nbsp;values:","Light&#8212;The least thorough scan with&nbsp;minimal load on&nbsp;the&nbsp;system.","Medium&#8212;Medium heuristic analysis level with&nbsp;a&nbsp;balanced load on&nbsp;the&nbsp;operating&nbsp;system.","Deep&#8212;The most thorough scan with&nbsp;maximal load on&nbsp;the&nbsp;operating&nbsp;system.","Recommended&#8212;Recommended&nbsp;value.","Default value:&nbsp;Recommended.","UseIChecker","Enables&nbsp;/&nbsp;disables the&nbsp;use of&nbsp;iChecker&nbsp;technology.","Available&nbsp;values:","Yes&#8212;Enable use of&nbsp;iChecker&nbsp;technology.","No&#8212;Disable use of&nbsp;iChecker&nbsp;technology.","Default value:&nbsp;Yes.","ScanByAccessType","You can&nbsp;use this setting to&nbsp;specify the&nbsp;real-time protection&nbsp;mode. The&nbsp;ScanByAccessType setting is&nbsp;applied only in&nbsp;real-time protection&nbsp;tasks.","Available&nbsp;values:","SmartCheck&#8212;Scan a&nbsp;file when there is&nbsp;an&nbsp;attempt to&nbsp;open it, and scan it again when there is&nbsp;an&nbsp;attempt to&nbsp;close it if the&nbsp;file has&nbsp;been&nbsp;modified. If&nbsp;a&nbsp;process accesses an&nbsp;object multiple times in&nbsp;the&nbsp;course of&nbsp;its operation and modifies it, the&nbsp;application scans the&nbsp;object again only when the&nbsp;process closes it for&nbsp;the&nbsp;last&nbsp;time.","OpenAndModify&#8212;Scan a&nbsp;file when there is&nbsp;an&nbsp;attempt to&nbsp;open it, and scan it again when there is&nbsp;an&nbsp;attempt to&nbsp;close it if the&nbsp;file has&nbsp;been&nbsp;modified.","Open&#8212;Scan the&nbsp;file when an&nbsp;attempt is&nbsp;made to&nbsp;open it for&nbsp;reading or for&nbsp;execution or&nbsp;modification.","Default value:&nbsp;SmartCheck.","The [ScanScope.item_#] section contains the&nbsp;following&nbsp;settings:","AreaDesc","Description of&nbsp;the&nbsp;scan scope, which contains additional information about the&nbsp;scan&nbsp;scope. The&nbsp;maximum length of&nbsp;the&nbsp;string specified using this setting is&nbsp;4096&nbsp;characters.","Default value:&nbsp;All&nbsp;objects.","Example:","AreaDesc=&quot;Scan mail databases&quot;","UseScanArea","This setting enables / disables scanning of&nbsp;the&nbsp;specified&nbsp;scope. To&nbsp;run the&nbsp;task, you must&nbsp;include at&nbsp;least one area to&nbsp;scan.","Available&nbsp;values:","Yes&#8212;Scan the&nbsp;specified&nbsp;scope.","No&#8212;Do&nbsp;not&nbsp;scan the&nbsp;specified&nbsp;scope.","Default value:&nbsp;Yes.","AreaMask","You can&nbsp;use this setting to&nbsp;restrict the&nbsp;scan&nbsp;scope.","In the&nbsp;scan scope, Kaspersky Endpoint Security scans only the&nbsp;files that are&nbsp;indicated using command shell&nbsp;masks.","If this setting is&nbsp;not&nbsp;specified, Kaspersky Endpoint Security scans all objects in&nbsp;the&nbsp;scan&nbsp;scope. You&nbsp;can&nbsp;specify several values for&nbsp;this&nbsp;setting.","Default value:&nbsp;* (scan all objects).","Example:","AreaMask=*doc","Path","You can&nbsp;use this setting to&nbsp;specify the&nbsp;path to&nbsp;objects to&nbsp;scan.","The value of&nbsp;the&nbsp;Path setting consists of&nbsp;two&nbsp;elements: &lt;file system type&gt;:&lt;access protocol&gt;. It&nbsp;may also contain the&nbsp;path to&nbsp;the&nbsp;directory in&nbsp;the&nbsp;local file&nbsp;system.","Available&nbsp;values:","&lt;path to&nbsp;local directory&gt;&#8212;Scan objects in&nbsp;the&nbsp;specified&nbsp;directory.","Shared:NFS&#8212;Scan the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;NFS&nbsp;protocol.","Shared:SMB&#8212;Scan the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;SMB&nbsp;protocol.","AllRemoteMounted&#8212;Scan all remote directories mounted on&nbsp;the&nbsp;computer using the&nbsp;SMB and NFS&nbsp;protocols.","AllShared&#8212;Scan all of&nbsp;the&nbsp;computer's file system resources shared via&nbsp;the&nbsp;SMB and NFS&nbsp;protocols.","The [ExcludedFromScanScope.item_#] section contains the&nbsp;following&nbsp;settings:","AreaDesc","Description of&nbsp;the&nbsp;scan exclusion&nbsp;scope. Contains&nbsp;additional information about the&nbsp;exclusion&nbsp;scope.","The default value is&nbsp;not defined.","Example:","AreaDesc=&quot;Exclude separate SAMBA&quot;","UseScanArea","This setting enables&nbsp;/&nbsp;disables scanning of&nbsp;the&nbsp;specified&nbsp;scope.","Available&nbsp;values:","Yes&#8212;Excludes the&nbsp;specified&nbsp;scope.","No&#8212;Does&nbsp;not&nbsp;exclude the&nbsp;specified&nbsp;scope.","Default value:&nbsp;Yes.","Path","You can&nbsp;use this setting to&nbsp;specify the&nbsp;path to&nbsp;objects excluded from&nbsp;scanning.","The value of&nbsp;the&nbsp;Path setting consists of&nbsp;two&nbsp;elements: &lt;file system type&gt;:&lt;access protocol&gt;. It&nbsp;may also contain the&nbsp;path to&nbsp;the&nbsp;directory in&nbsp;the&nbsp;local file&nbsp;system.","Available&nbsp;values:","&lt;path to&nbsp;local directory&gt;&#8212;Exclude objects in&nbsp;the&nbsp;specified directory from&nbsp;scanning.","Shared:NFS&#8212;Exclude the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;NFS&nbsp;protocol.","Shared:SMB&#8212;Exclude the&nbsp;computer's file system resources that are&nbsp;accessible via&nbsp;the&nbsp;Samba&nbsp;protocol.","AllRemoteMounted&#8212;Exclude all remote directories mounted on&nbsp;the&nbsp;computer using the&nbsp;SMB and NFS&nbsp;protocols.","AllShared&#8212;Exclude all of the computer's file system resources shared via the SMB and NFS protocols.","Custom scan task settings","161292.htm");
Page[85]=new Array("This section contains information about the&nbsp;boot sector scan task.","Boot sector scan task (Boot_Scan ID:4)","161294.htm");
Page[86]=new Array("Boot sector scan task lets you scan boot sectors not specifying a scan scope.","About boot sector scan task","161295.htm");
Page[87]=new Array("This section provides information about the settings you can specify for the boot sector scan task.","All available values and default values for each setting are described.","UseExcludeMasks ","Enables / disables the&nbsp;scan exclusion of&nbsp;objects specified using the&nbsp;ExcludeMasks&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude objects specified by&nbsp;the&nbsp;ExcludeMasks&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude objects specified by&nbsp;the&nbsp;ExcludeMasks&nbsp;setting.","Default value:&nbsp;No.","ExcludeMasks","Excludes objects from scanning by&nbsp;name or&nbsp;mask. You&nbsp;can&nbsp;use this setting to&nbsp;exclude an&nbsp;individual file from the&nbsp;specified scan scope by&nbsp;name or exclude several files at&nbsp;once using masks in&nbsp;command shell&nbsp;format.","The default value is&nbsp;not defined.","UseExcludeThreats","Enables or disables the&nbsp;scan exclusion of&nbsp;objects with&nbsp;threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Default value: No.","ExcludeThreats","Excludes objects from scanning by&nbsp;the&nbsp;name of&nbsp;the&nbsp;threats detected in&nbsp;them. Before&nbsp;specifying a&nbsp;value for&nbsp;this setting, make sure that the&nbsp;UseExcludeThreats setting is&nbsp;enabled.","In order to&nbsp;exclude a&nbsp;single object from scanning, specify the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;this object&nbsp;&#8211; the&nbsp;Kaspersky Endpoint Security string with&nbsp;the&nbsp;verdict that the&nbsp;object is&nbsp;infected.","E.g., you may be&nbsp;using a&nbsp;utility to&nbsp;collect information about your&nbsp;network. To&nbsp;keep Kaspersky Endpoint Security from blocking it, add the&nbsp;full name of&nbsp;the&nbsp;threat contained in&nbsp;it to&nbsp;the&nbsp;list of&nbsp;threats excluded from&nbsp;scanning.","You can&nbsp;find the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;the&nbsp;object in&nbsp;the&nbsp;Kaspersky Endpoint Security&nbsp;log. You&nbsp;can&nbsp;also find the&nbsp;full name of&nbsp;the&nbsp;threat on&nbsp;the&nbsp;website of&nbsp;the&nbsp;Virus Encyclopedia (http://www.securelist.com). To&nbsp;find the&nbsp;name of&nbsp;a&nbsp;threat, enter the&nbsp;application name in&nbsp;the&nbsp;Search&nbsp;field.","The setting value is&nbsp;case-sensitive.","The default value is&nbsp;not defined.","ReportCleanObjects","Enables / disables logging of&nbsp;information about scanned objects that Kaspersky Endpoint Security has&nbsp;deemed&nbsp;non-infected.","You can&nbsp;enable this setting, for&nbsp;example, to&nbsp;make sure that a&nbsp;particular object has&nbsp;been scanned by&nbsp;Kaspersky Endpoint Security.","Available&nbsp;values:","Yes&#8212;Log information about non-infected&nbsp;objects.","No&#8212;Do not&nbsp;log information about non-infected&nbsp;objects.","Default value:&nbsp;No.","ReportUnprocessedObjects","Enables / disables logging of information about files that have not been processed for some reason.","Available values:","Yes&#8212;Log the information about unprocessed objects. Setting this parameter value to Yes for a long period is not recommended, since logging a large amount of information may reduce the application performance","No&#8212;Do not log the information about unprocessed objects","Default value: No","UseAnalyzer","Enables / disables Heuristic&nbsp;Analyzer. Heuristic analysis enables the application to detect new threats even before they become known to virus analysts.","Available&nbsp;values:","Yes&#8212;Enable Heuristic&nbsp;Analyzer.","No&#8212;Disable Heuristic&nbsp;Analyzer.","Default value:&nbsp;Yes.","HeuristicLevel","Heuristic analysis&nbsp;level.","You can specify the heuristic analysis level. The heuristic analysis level sets the balance between the thoroughness of searches for threats, the load on the operating system's resources, and the scan duration. The higher the heuristic analysis level, the more resources and time are required for scanning.","Available&nbsp;values:","Light&#8212;The least thorough scan with&nbsp;minimal load on&nbsp;the&nbsp;system.","Medium&#8212;Medium heuristic analysis&nbsp;level; balanced load on&nbsp;the&nbsp;system.","Deep&#8212;The most thorough scan with&nbsp;maximal load on&nbsp;the&nbsp;operating&nbsp;system.","Recommended&#8212;Recommended&nbsp;value.","Default value:&nbsp;Recommended.","Action","Selection of&nbsp;the&nbsp;action to&nbsp;be&nbsp;performed by&nbsp;Kaspersky Endpoint Security on&nbsp;infected&nbsp;objects.","Available&nbsp;values:","Cure (disinfect)&#8212;Kaspersky Endpoint Security attempts to&nbsp;disinfect an&nbsp;object by&nbsp;saving a&nbsp;copy of&nbsp;it in&nbsp;Storage. If&nbsp;disinfection fails (for&nbsp;example, if the&nbsp;type of&nbsp;object or the&nbsp;type of&nbsp;threat in&nbsp;the&nbsp;object cannot be&nbsp;disinfected) Kaspersky Endpoint Security leaves the&nbsp;object&nbsp;unchanged.","Skip&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;attempt to&nbsp;disinfect or delete an&nbsp;infected&nbsp;object. Information&nbsp;about the&nbsp;infected object is&nbsp;logged.","Default value:&nbsp;Cure.","Boot sector scan task settings","161296.htm");
Page[88]=new Array("This section contains information about the&nbsp;process memory scan task.","Process memory scan task (Memory_Scan ID:5)","161297.htm");
Page[89]=new Array("Process memory scan task lets you scan the process memory not specifying a scan scope.","About process memory scan task","161298.htm");
Page[90]=new Array("This section provides information about the settings you can specify for the process memory scan task.","All available values and default values for each setting are described.","UseExcludeThreats","Enables or disables the&nbsp;scan exclusion of&nbsp;objects with&nbsp;threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Available&nbsp;values:","Yes&#8212;Exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","No&#8212;Do&nbsp;not&nbsp;exclude from scanning the&nbsp;objects containing threats specified using the&nbsp;ExcludeThreats&nbsp;setting.","Default value:&nbsp;No.","ExcludeThreats","Excludes objects from scanning by&nbsp;the&nbsp;name of&nbsp;the&nbsp;threats detected in&nbsp;them. Before&nbsp;specifying a&nbsp;value for&nbsp;this setting, make sure that the&nbsp;UseExcludeThreats setting is&nbsp;enabled.","In order to&nbsp;exclude a&nbsp;single object from scanning, specify the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;this object&#8212;the&nbsp;Kaspersky Endpoint Security string with&nbsp;the&nbsp;verdict that the&nbsp;object is&nbsp;infected.","E.g., you may be&nbsp;using a&nbsp;utility to&nbsp;collect information about your&nbsp;network. To&nbsp;keep Kaspersky Endpoint Security from blocking it, add the&nbsp;full name of&nbsp;the&nbsp;threat contained in&nbsp;it to&nbsp;the&nbsp;list of&nbsp;threats excluded from&nbsp;scanning.","You can&nbsp;find the&nbsp;full name of&nbsp;the&nbsp;threat detected in&nbsp;the&nbsp;object in&nbsp;the&nbsp;Kaspersky Endpoint Security&nbsp;log. You&nbsp;can&nbsp;also find the&nbsp;full name of&nbsp;the&nbsp;threat on&nbsp;the&nbsp;website of&nbsp;the&nbsp;Virus Encyclopedia (http://www.securelist.com). To&nbsp;find the&nbsp;name of&nbsp;a&nbsp;threat, enter the&nbsp;application name in&nbsp;the&nbsp;Search&nbsp;field.","The setting value is&nbsp;case-sensitive.","The default value is&nbsp;not defined.","ReportCleanObjects","Enables / disables logging of&nbsp;information about scanned objects that Kaspersky Endpoint Security has&nbsp;deemed&nbsp;non-infected.","You can&nbsp;enable this setting, for&nbsp;example, to&nbsp;make sure that a&nbsp;particular object has&nbsp;been scanned by&nbsp;Kaspersky Endpoint Security.","Available&nbsp;values:","Yes&#8212;Log information about non-infected&nbsp;objects.","No&#8212;Do not&nbsp;log information about non-infected&nbsp;objects.","Default value:&nbsp;No.","ReportUnprocessedObjects","Enables / disables logging of information about files that have not been processed for some reason.","Available values:","Yes&#8212;Log the information about unprocessed objects. Setting this parameter value to Yes for a long period is not recommended, since logging a large amount of information may reduce the application performance","No&#8212;Do not log the information about unprocessed objects","Default value: No","Action","Selection of&nbsp;the&nbsp;action to&nbsp;be&nbsp;performed by&nbsp;Kaspersky Endpoint Security on&nbsp;infected&nbsp;objects.","Available&nbsp;values:","Cure (disinfect)&#8212;Kaspersky Endpoint Security attempts to&nbsp;disinfect an&nbsp;object by&nbsp;saving a&nbsp;copy of&nbsp;it in&nbsp;Storage. If&nbsp;disinfection fails (for&nbsp;example, if the&nbsp;type of&nbsp;object or the&nbsp;type of&nbsp;threat in&nbsp;the&nbsp;object cannot be&nbsp;disinfected) Kaspersky Endpoint Security leaves the&nbsp;object&nbsp;unchanged.","Skip&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;attempt to&nbsp;disinfect or delete an&nbsp;infected&nbsp;object. Information&nbsp;about the&nbsp;infected object is&nbsp;logged.","Default value:&nbsp;Cure.","Process memory scan task settings","161299.htm");
Page[91]=new Array("This section contains information about the Update task.","Update task (Update ID:6)","161300.htm");
Page[92]=new Array("Updating the databases and application modules of Kaspersky Endpoint Security ensures up-to-date protection on your computer. New viruses and other types of malware appear worldwide on a daily basis. Kaspersky Endpoint Security databases contain information about threats and ways of neutralizing them. To detect threats quickly, you are urged to regularly update the databases and application modules.","Regular updates require a license in effect. If there is no current license, you will be able to perform an update only once.","The main update source for Kaspersky Endpoint Security is Kaspersky Lab update servers.","Your computer must be connected to the Internet to successfully download the update package from Kaspersky Lab update servers. By default, the Internet connection settings are determined automatically. If you use a proxy server, you need to adjust the connection settings.","While performing an update, the following objects are downloaded and installed on your computer:","Kaspersky Endpoint Security databases. During installation, Kaspersky Endpoint Security downloads the&nbsp;latest databases from one of&nbsp;the&nbsp;Kaspersky Lab HTTP update&nbsp;servers. If&nbsp;the&nbsp;predefined task with&nbsp;default settings (ID=6) is&nbsp;used for&nbsp;updating, Kaspersky Endpoint Security updates the&nbsp;databases once every&nbsp;60&nbsp;minutes. You&nbsp;can&nbsp;edit the&nbsp;settings of&nbsp;the&nbsp;predefined task for&nbsp;database and application module updates and create custom update&nbsp;tasks.","Kaspersky Endpoint Security continues to&nbsp;use the&nbsp;previously installed database version if the&nbsp;database update download is&nbsp;interrupted or ends with&nbsp;an&nbsp;error.","By default, the&nbsp;application logs the&nbsp;Databases are&nbsp;out of&nbsp;date event (AVBasesAreOutOfDate) if the&nbsp;last installed database updates were&nbsp;published on&nbsp;the&nbsp;Kaspersky Lab server more than a&nbsp;day, but less than seven days&nbsp;ago. If&nbsp;the&nbsp;databases have&nbsp;not&nbsp;been updated for seven days, Kaspersky Endpoint Security logs the&nbsp;event Databases are&nbsp;obsolete (AVBasesAreTotallyOutOfDate). The database is actual if it was downloaded less that 24 hours ago.","Application updates. In addition to the databases of Kaspersky Endpoint Security, you can also update the application. Updating the application fixes vulnerabilities in Kaspersky Endpoint Security or enhances existing functions.","The application update can be installed regardless the state of the application (started or stopped, managed by a Kaspersky Security Center policy) and update scheduling.","Kaspersky Endpoint Security continues protecting your computer during the application update procedure.","Kaspersky Endpoint Security migrates the application settings and even log automatically. The settings form the previous application version are exportedon the start of the updated version.","In case Kaspersky Endpoint Security functions incorrectly after the application update installation, the application is automatically rolled back to the previous version. A message about the application update rollback is displayed. We recommend contacting Kaspersky Lab Technical Support.","While updating, the application and databases on your computer are compared against the up-to-date version at the update source. If your current databases and application modules differ from their respective up-to-date versions, the missing portion of the updates is installed on your computer.","If the databases are obsolete, the update package may be large, which may cause additional Internet traffic (up to several dozen MB).","About database and application module updates","161301.htm");
Page[93]=new Array("An update source&nbsp;is&nbsp;a&nbsp;resource that contains updates for&nbsp;databases and application modules of&nbsp;Kaspersky Endpoint Security. Update&nbsp;sources include FTP or HTTP servers (such as Kaspersky Security Center and Kaspersky Lab update servers) and local or network directories mounted by&nbsp;the&nbsp;user.","In the&nbsp;predefined update task, the&nbsp;default source of&nbsp;updates are&nbsp;the&nbsp;Kaspersky Lab update&nbsp;servers. The&nbsp;update servers contain updates for&nbsp;databases and application modules for&nbsp;many Kaspersky Lab&nbsp;applications. Updates&nbsp;are&nbsp;downloaded via&nbsp;HTTP&nbsp;protocols.","If, for&nbsp;some reason, you are&nbsp;not&nbsp;able to&nbsp;use the&nbsp;Kaspersky Lab update servers as the&nbsp;update source, you can&nbsp;receive updates from a&nbsp;custom update source such as a&nbsp;local or network directory (SMB / NFS) mounted by&nbsp;the&nbsp;user, or an&nbsp;FTP or HTTP server specified by you. You can&nbsp;specify a&nbsp;custom update source in&nbsp;the&nbsp;configuration file of&nbsp;the&nbsp;update&nbsp;task.","About update sources","161302.htm");
Page[94]=new Array("This section provides information about the settings you can specify for the Update task.","All available values and default values for each setting are described.","SourceType","This setting lets you select the&nbsp;source from which Kaspersky Endpoint Security will&nbsp;receive&nbsp;updates.","Available&nbsp;values:","KLServers&#8212;Kaspersky Endpoint Security receives updates from one of&nbsp;the&nbsp;Kaspersky Lab update&nbsp;servers. Updates&nbsp;are&nbsp;downloaded via&nbsp;the&nbsp;HTTP&nbsp;protocol.","SCServer&#8212;Kaspersky Endpoint Security downloads updates to&nbsp;the&nbsp;protected computer from Kaspersky Security Center Administration Server installed on&nbsp;the&nbsp;local&nbsp;network. You&nbsp;can&nbsp;select this update source if you use the&nbsp;Kaspersky Security Center application for&nbsp;centralized administration of&nbsp;anti-virus protection of&nbsp;computers in&nbsp;your&nbsp;organization.","Custom&#8212;Kaspersky Endpoint Security downloads updates from the&nbsp;custom source specified in&nbsp;the [CommonSettings:CustomSources] section. You&nbsp;can&nbsp;specify directories on&nbsp;HTTP servers or directories on&nbsp;any&nbsp;device mounted on&nbsp;the&nbsp;protected computer, including directories on&nbsp;remote computers mounted via&nbsp;the&nbsp;Samba or NFS&nbsp;protocols.","Default value:&nbsp;KLServers.","UseKLServersWhenUnavailable","You can&nbsp;use this setting to&nbsp;configure Kaspersky Endpoint Security to&nbsp;access the&nbsp;Kaspersky Lab update servers if all custom update sources are&nbsp;unavailable.","Available&nbsp;values:","Yes&#8212;Kaspersky Endpoint Security connects to&nbsp;Kaspersky Lab update servers if all custom update sources are&nbsp;unavailable.","No&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;connect to&nbsp;Kaspersky Lab update servers if all custom update sources are&nbsp;unavailable.","Default value:&nbsp;Yes.","IgnoreProxySettingsForKLServers","This setting lets you configure the&nbsp;use of&nbsp;a&nbsp;proxy server for&nbsp;connecting to&nbsp;Kaspersky Lab update&nbsp;servers.","Available&nbsp;values:","Yes&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;use a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;Kaspersky Lab update&nbsp;servers.","No&#8212;Kaspersky Endpoint Security uses a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;Kaspersky Lab update&nbsp;servers.","Default value:&nbsp;No.","IgnoreProxySettingsForCustomSources","This setting lets you configure the&nbsp;use of&nbsp;a&nbsp;proxy server for&nbsp;connecting to&nbsp;custom sources of&nbsp;updates. You&nbsp;need to&nbsp;enable this setting if you require access to&nbsp;a&nbsp;proxy server in&nbsp;order to&nbsp;connect to&nbsp;any&nbsp;of&nbsp;the&nbsp;custom HTTP update&nbsp;servers.","Available&nbsp;values:","Yes&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;use a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;custom update&nbsp;sources.","No&#8212;Kaspersky Endpoint Security uses a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;custom update&nbsp;sources.","Default value:&nbsp;No.","ApplicationUpdateMode","Specifies the application updates downloading and installation mode.","Available values:","Disable&#8212;Do not download and install the application updates","DownloadOnly&#8212;Download the application updates, but do not install them","DownloadAndInstall&#8212;Automatically download and install the application updates","Default value: DownloadOnly","ConnectionTimeout","You can&nbsp;use this setting to&nbsp;specify the&nbsp;time to&nbsp;wait (in&nbsp;seconds) for&nbsp;a&nbsp;response from an&nbsp;update source such as an&nbsp;HTTP server while attempting to&nbsp;connect to&nbsp;it. If&nbsp;an&nbsp;update source does&nbsp;not&nbsp;respond within the&nbsp;specified time interval, Kaspersky Endpoint Security contacts the&nbsp;next update source on&nbsp;the&nbsp;list.","You can&nbsp;use only integers within the&nbsp;range from 0 to&nbsp;120.","Default value:&nbsp;10.","The [CustomSources.item_#] section contains the&nbsp;following&nbsp;settings:","URL","This section lets you specify the&nbsp;address of&nbsp;the&nbsp;custom source of&nbsp;updates in&nbsp;the&nbsp;local area network or on&nbsp;the&nbsp;Internet.","The default value is&nbsp;not defined.","Example:","URL=http://example.com/bases/ &#8211; address of the HTTP server with the directory containing the updates.","URL=/home/bases/ &#8211; directory on the protected computer containing the application databases.","Enabled","This setting lets you enable or disable use of&nbsp;the&nbsp;update source specified in&nbsp;the&nbsp;URL&nbsp;setting. Use&nbsp;of&nbsp;at&nbsp;least one update source must&nbsp;be&nbsp;enabled before the&nbsp;task can&nbsp;run.","Available&nbsp;values:","Yes&#8212;Kaspersky Endpoint Security uses the&nbsp;update&nbsp;source.","No&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;use the&nbsp;update&nbsp;source.","The default value is&nbsp;not&nbsp;defined.","Example:","Enabled=Yes","Update task settings","161303.htm");
Page[95]=new Array("You can manually install the application update from the command line. Kaspersky Endpoint Security must be installed on your computer to install the application update.","To install Kaspersky Endpoint Security update from an&nbsp;RPM package, execute the&nbsp;following&nbsp;command:","# rpm &#8211;U &lt;rpm package name&gt;.rpm","To install Kaspersky Endpoint Security update from a&nbsp;DEB package, execute the&nbsp;following&nbsp;command:","# dpkg -i &lt;deb package name&gt;.deb","The application update process is started.","The application or operating system restart may be required. The corresponding message is displayed. After the application or operating system restart, the updated version of Kaspersky Endpoint Security is started.","After the application update, accepting the End User License Agreement and / or Kaspersky Security Network Statement may be required. ","To accept the End User License Agreement,","Read the text of the End User License Agreement.","If you are agree with the text of the End User License Agreement, specify the environment variable:","# KESL_EULA_AGREED=Yes rpm -U &lt;rpm package name&gt;.rpm for a rpm package.","# KESL_EULA_AGREED=Yes dpkg -i &lt;deb package name&gt;.deb for a deb package.","To accept the Kaspersky Security Network Statement,","Read the text of the Kaspersky Security Network Statement.","If you are agree with the text of the Kaspersky Security Network Statement, specify the environment variable:","# KESL_USE_KSN=Yes rpm -U &lt;rpm package name&gt;.rpm for a rpm package.","# KESL_ USE_KSN=Yes dpkg -i &lt;deb package name&gt;.deb for a deb package.","Installing application update manually","162013.htm");
Page[96]=new Array("This section contains information about the update rollback task.","The update rollback task is run to roll back the last successful databases update.","This task does not have any settings.","For more information on managing the update rollback task, see section &quot;Managing Kaspersky Endpoint Security tasks using command line&quot;.","Update rollback task (Rollback ID:7)","161304.htm");
Page[97]=new Array("This section contains information about the update retranslation task.","Update retranslation task (Retranslate ID:8)","161306.htm");
Page[98]=new Array("The update retranslation task allows you to download databases and application updates to the selected directory. The updates will not be installed.","Retranslated update databases can be used only by the application with the same build number.","About Update retranslation task","161307.htm");
Page[99]=new Array("This section provides information about the settings you can specify for the update retranslation task.","All available values and default values for each setting are described.","SourceType ","This setting lets you select the&nbsp;source from which Kaspersky Endpoint Security will&nbsp;receive&nbsp;updates.","Available&nbsp;values:","KLServers&#8212;Kaspersky Endpoint Security receives updates from one of&nbsp;the&nbsp;Kaspersky Lab update&nbsp;servers. Updates&nbsp;are&nbsp;downloaded via&nbsp;the&nbsp;HTTP&nbsp;protocol.","SCServer&#8212;Kaspersky Endpoint Security downloads updates to&nbsp;the&nbsp;protected computer from Kaspersky Security Center Administration Server installed on&nbsp;the&nbsp;local&nbsp;network. You&nbsp;can&nbsp;select this update source if you use the&nbsp;Kaspersky Security Center application for&nbsp;centralized administration of&nbsp;anti-virus protection of&nbsp;computers in&nbsp;your&nbsp;organization.","Custom&#8212;Kaspersky Endpoint Security downloads updates from the&nbsp;custom source specified in&nbsp;the [CommonSettings:CustomSources] section. You&nbsp;can&nbsp;specify directories on&nbsp;HTTP servers or directories on&nbsp;any&nbsp;device mounted on&nbsp;the&nbsp;protected computer, including directories on&nbsp;remote computers mounted via&nbsp;the&nbsp;Samba or NFS&nbsp;protocols.","Default value:&nbsp;KLServers.","UseKLServersWhenUnavailable","You can&nbsp;use this setting to&nbsp;configure Kaspersky Endpoint Security to&nbsp;access the&nbsp;Kaspersky Lab update servers if all custom update sources are&nbsp;unavailable.","Available&nbsp;values:","Yes&#8212;Kaspersky Endpoint Security connects to&nbsp;Kaspersky Lab update servers if all custom update sources are&nbsp;unavailable.","No&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;connect to&nbsp;Kaspersky Lab update servers if all custom update sources are&nbsp;unavailable.","Default value:&nbsp;Yes.","IgnoreProxySettingsForKLServers","This setting lets you configure the&nbsp;use of&nbsp;a&nbsp;proxy server for&nbsp;connecting to&nbsp;Kaspersky Lab update&nbsp;servers.","Available&nbsp;values:","Yes&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;use a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;Kaspersky Lab update&nbsp;servers.","No&#8212;Kaspersky Endpoint Security uses a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;Kaspersky Lab update&nbsp;servers.","Default value:&nbsp;No.","IgnoreProxySettingsForCustomSources","This setting lets you configure the&nbsp;use of&nbsp;a&nbsp;proxy server for&nbsp;connecting to&nbsp;custom sources of&nbsp;updates. You&nbsp;need to&nbsp;enable this setting if you require access to&nbsp;a&nbsp;proxy server in&nbsp;order to&nbsp;connect to&nbsp;any&nbsp;of&nbsp;the&nbsp;custom HTTP update&nbsp;servers.","Available&nbsp;values:","Yes&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;use a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;custom update&nbsp;sources.","No&#8212;Kaspersky Endpoint Security uses a&nbsp;proxy server to&nbsp;connect to&nbsp;the&nbsp;custom update&nbsp;sources.","Default value:&nbsp;No.","ConnectionTimeout","You can&nbsp;use this setting to&nbsp;specify the&nbsp;time to&nbsp;wait (in&nbsp;seconds) for&nbsp;a&nbsp;response from an&nbsp;update source such as an&nbsp;HTTP server while attempting to&nbsp;connect to&nbsp;it. If&nbsp;an&nbsp;update source does&nbsp;not&nbsp;respond within the&nbsp;specified time interval, Kaspersky Endpoint Security contacts the&nbsp;next update source on&nbsp;the&nbsp;list.","You can&nbsp;use only integers within the&nbsp;range from 0 to&nbsp;120.","Default value:&nbsp;10.","RetranslationFolder","You can&nbsp;use this setting to&nbsp;specify the&nbsp;directory to&nbsp;which updates will&nbsp;be&nbsp;copied. If&nbsp;the&nbsp;specified directory does&nbsp;not&nbsp;exist, Kaspersky Endpoint Security creates it while running the&nbsp;update retranslation&nbsp;task.","The [CustomSources.item_#] section contains the&nbsp;following&nbsp;settings:","URL","This section lets you specify the&nbsp;address of&nbsp;the&nbsp;custom source of&nbsp;updates in&nbsp;the&nbsp;local area network or on&nbsp;the&nbsp;Internet.","The default value is&nbsp;not&nbsp;defined.","Example:","URL=http://example.com/bases/ &#8211; address of the HTTP server with the directory containing the updates.","URL=/home/bases/ &#8211; directory on the protected computer containing the application databases.","Enabled","This setting lets you enable or disable use of&nbsp;the&nbsp;update source specified in&nbsp;the&nbsp;URL&nbsp;setting. Use&nbsp;of&nbsp;at&nbsp;least one update source must&nbsp;be&nbsp;enabled before the&nbsp;task can&nbsp;run.","Available&nbsp;values:","Yes&#8212;Kaspersky Endpoint Security uses the&nbsp;update&nbsp;source.","No&#8212;Kaspersky Endpoint Security does&nbsp;not&nbsp;use the&nbsp;update&nbsp;source.","The default value is&nbsp;not&nbsp;defined.","AutoPatchDownload","Enables / disables the automatic application updates downloading.","Available values: ","Yes&#8212;Automatically download application updates","No&#8212;Do not download application updates automatically","Default value: Yes","Update retranslation task settings","161308.htm");
Page[100]=new Array("This section contains information about the License task.","License task (License ID:9)","161309.htm");
Page[101]=new Array("The License task allows you to manage Kaspersky Endpoint Security keys and activation codes.","About License task","161310.htm");
Page[102]=new Array("The command --install-active-key adds an&nbsp;active&nbsp;key. For&nbsp;details about keys, please refer to&nbsp;the&nbsp;section &quot;About the key&quot;.","Command&nbsp;syntax","kesl-control [-L] --install-active-key &lt;path to&nbsp;key file&gt;|&lt;activation code&gt;","Arguments and&nbsp;keys","&lt;path to&nbsp;the&nbsp;key file&gt;","The path to&nbsp;the&nbsp;key&nbsp;file; if the&nbsp;key file is&nbsp;located in&nbsp;the&nbsp;current directory, it is&nbsp;sufficient to&nbsp;specify only the&nbsp;file&nbsp;name.","Example:","Add the key from file /home/test/00000001.key as the active key:","kesl-control --install-active-key /home/test/00000001.keу","Adding an active key","161311.htm");
Page[103]=new Array("The command --install-additional-key adds an&nbsp;additional&nbsp;key. For&nbsp;details about keys, please refer to&nbsp;the&nbsp;section &quot;About the key&quot;.","If an&nbsp;active key is&nbsp;not&nbsp;installed, the&nbsp;additional key will&nbsp;be&nbsp;installed as the&nbsp;primary&nbsp;key.","Command&nbsp;syntax","kesl-control [-L] --install-additional-key &lt;path to&nbsp;key file&gt;","Arguments and&nbsp;keys","&lt;path to&nbsp;the&nbsp;key file&gt;","The path to&nbsp;the&nbsp;key&nbsp;file; if the&nbsp;key file is&nbsp;located in&nbsp;the&nbsp;current directory, it is&nbsp;sufficient to&nbsp;specify only the&nbsp;file&nbsp;name.","Example:","Install an additional key from the file /home/test/00000002.key:","kesl-control --install-additional-key /home/test/00000002.key","Adding an additional key","161312.htm");
Page[104]=new Array("The command --revoke-active-key removes the&nbsp;active&nbsp;key.","Command&nbsp;syntax","kesl-control [-L]&nbsp;--revoke-active-key","Removing the active key","161313.htm");
Page[105]=new Array("The command --revoke-additional-key removes the&nbsp;additional&nbsp;key.","Command&nbsp;syntax","kesl-control [-L]&nbsp;--revoke-additional-key","Removing the additional key","161314.htm");
Page[106]=new Array("The command --install-additional-key enters the&nbsp;additional activation&nbsp;code. For&nbsp;more details on&nbsp;activation codes, see section &quot;About the&nbsp;activation code&quot;.","Command&nbsp;syntax","kesl-control [-L] --install-additional-key &lt;activation code&gt;","Entering an additional activation code","161315.htm");
Page[107]=new Array("This section contains information about the Storage management task.","Storage management task (Backup ID:10)","161316.htm");
Page[108]=new Array("Storage is&nbsp;a&nbsp;list of&nbsp;backup copies of&nbsp;files that have&nbsp;been deleted or modified during the&nbsp;disinfection&nbsp;process. Backup&nbsp;copy is&nbsp;a&nbsp;file copy created at&nbsp;the&nbsp;first attempt to&nbsp;disinfect or delete this&nbsp;file. Backup&nbsp;copies of&nbsp;files are&nbsp;stored in&nbsp;a&nbsp;special format and do&nbsp;not&nbsp;pose a&nbsp;threat.","Sometimes it is&nbsp;not&nbsp;possible to&nbsp;maintain the&nbsp;integrity of&nbsp;files during&nbsp;disinfection. If&nbsp;you partially or completely lose access to&nbsp;important information in&nbsp;a&nbsp;disinfected file after&nbsp;disinfection, you can&nbsp;attempt to&nbsp;restore the&nbsp;disinfected copy of&nbsp;the&nbsp;file to&nbsp;its original&nbsp;directory.","About Storage","161317.htm");
Page[109]=new Array("This section provides information about the settings you can specify for the Storage management task.","All available values and default values for each setting are described.","DaysToLive","Time period for&nbsp;storing objects in&nbsp;Storage (in&nbsp;days).","To remove the&nbsp;time limit for&nbsp;storing objects in&nbsp;Storage, specify the&nbsp;value&nbsp;0.","Default value:&nbsp;90.","BackupSizeLimit","Maximum size of&nbsp;Storage.","When the&nbsp;maximum Storage size is&nbsp;reached, Kaspersky Endpoint Security deletes the&nbsp;oldest&nbsp;objects.","Available&nbsp;values:","0&nbsp;&#8211; 999,999 (in&nbsp;megabytes).","To remove the&nbsp;Storage size limit, specify the&nbsp;value&nbsp;0.","Default value:&nbsp;0.","BackupFolder","Path to&nbsp;the&nbsp;Storage&nbsp;directory. You&nbsp;can&nbsp;specify a&nbsp;custom Storage directory that is&nbsp;different from the&nbsp;default&nbsp;directory.","You can&nbsp;use directories on&nbsp;any&nbsp;computer devices to&nbsp;serve as&nbsp;Storage. It&nbsp;is&nbsp;not&nbsp;recommended to&nbsp;assign directories that are&nbsp;located on&nbsp;remote computers, such as those mounted via&nbsp;the&nbsp;Samba and NFS&nbsp;protocols.","Kaspersky Endpoint Security starts to&nbsp;place objects into the&nbsp;specified directory after&nbsp;you import the&nbsp;settings from the&nbsp;file into the&nbsp;Storage task and restart Kaspersky Endpoint Security.","If the&nbsp;specified directory does&nbsp;not&nbsp;exist or is&nbsp;unavailable, Kaspersky Endpoint Security uses the&nbsp;default Storage&nbsp;directory.","Default value&nbsp;is: /var/opt/kaspersky/kesl/objects-backup/","Storage management task settings","161318.htm");
Page[110]=new Array("When an&nbsp;object is&nbsp;placed in&nbsp;Storage, Kaspersky Endpoint Security assigns a&nbsp;numeric ID to&nbsp;it. The&nbsp;ID is&nbsp;used to&nbsp;perform actions on&nbsp;the&nbsp;object, such as restoring or removing the&nbsp;object from&nbsp;Storage.","To view the&nbsp;IDs of&nbsp;objects in&nbsp;Storage,","execute the&nbsp;command: kesl-control -B&nbsp;--query","The object ID is&nbsp;displayed in&nbsp;the&nbsp;ObjectId&nbsp;string.","Viewing IDs of objects in Storage","161319.htm");
Page[111]=new Array("Kaspersky Endpoint Security stores files in&nbsp;Storage in&nbsp;encrypted form to&nbsp;keep the&nbsp;protected server safe from their potential harmful&nbsp;effects.","You can&nbsp;restore objects from&nbsp;Storage. You&nbsp;may need to&nbsp;restore objects from Storage in&nbsp;the&nbsp;following&nbsp;cases:","While disinfecting an&nbsp;infected file, Kaspersky Endpoint Security failed to&nbsp;preserve its integrity, which made the&nbsp;information in&nbsp;the&nbsp;file&nbsp;inaccessible.","If you consider the&nbsp;object to&nbsp;be&nbsp;safe for&nbsp;the&nbsp;server and wish to&nbsp;use it, you can&nbsp;exclude the&nbsp;object from scanning so the&nbsp;application will&nbsp;not&nbsp;detect it during subsequent&nbsp;scans. To&nbsp;do&nbsp;so, you have&nbsp;to&nbsp;exclude the&nbsp;object by&nbsp;its name or by&nbsp;the&nbsp;name of&nbsp;the&nbsp;threat detected during the&nbsp;real-time protection task and also by&nbsp;the&nbsp;object name and the&nbsp;name of&nbsp;the&nbsp;threat detected during the&nbsp;on-demand scan&nbsp;task.","Restoring infected objects may lead to&nbsp;computer&nbsp;infection.","You can&nbsp;save the&nbsp;object under&nbsp;a&nbsp;new name when restoring it from&nbsp;Storage.","About restoring objects from the Storage","161320.htm");
Page[112]=new Array("To restore an&nbsp;object from Storage, do&nbsp;one of&nbsp;the&nbsp;following:","To restore an&nbsp;object under&nbsp;its original name to&nbsp;its original location, execute the&nbsp;following&nbsp;command:","kesl-control --restore &lt;object ID&gt;","where object ID is&nbsp;the&nbsp;ID of&nbsp;the&nbsp;object in&nbsp;Storage.","To restore an&nbsp;object under&nbsp;a&nbsp;new name to&nbsp;the&nbsp;specified directory, execute the&nbsp;following&nbsp;command:","kesl-control --restore &lt;object ID&gt; --file &lt;file name and path&gt;","If the&nbsp;specified directory does&nbsp;not&nbsp;exist, Kaspersky Endpoint Security creates&nbsp;it.","Restoring objects from the Storage","161321.htm");
Page[113]=new Array("To remove an&nbsp;object from Storage, execute the&nbsp;following&nbsp;command:","kesl-control -B --mass-remove --query &quot;ObjectId == 'object ID&gt;'&quot;","To remove several objects from Storage, execute the&nbsp;following&nbsp;command:","kesl-control -B --mass-remove --query &quot;&lt;field&gt;&lt;comparison operator&gt; '&lt;value&gt;' [and &lt;field&gt; &lt;comparison operator&gt;'&lt;value&gt;' ]* ]","To remove all objects from Storage, execute one of&nbsp;the&nbsp;following&nbsp;commands:","kesl-control -B&nbsp;--mass-remove","or","kesl-control -B --mass-remove&nbsp;--query","Removing objects from Storage","161322.htm");
Page[114]=new Array("This section contains information about the File Integrity Monitoring task.","File Integrity Monitoring task (Integrity_Monitoring ID:11)","161323.htm");
Page[115]=new Array("The File Integrity Monitoring task is designed to track actions performed with the files and directories in the monitoring scopes specified in the task settings. You can use the task to find file changes that may indicate a security breach on the protected server. You can also configure file changes to be tracked during periods when monitoring is interrupted.","To use File Integrity Monitoring functionality, you must purchase an extended license that covers this functionality. File Integrity Monitoring is disabled by default.","File integrity monitoring can be performed in real-time mode by running the On-access File Integrity Monitoring (OAFIM) task. Also, On-demand File Integrity Monitoring (ODFIM) tasks can be created and run.","Both OAFIM and ODFIM tasks send notifications about changes to an object access control list. For the OAFIM task, details about what exactly was changed are not reported. For the ODFIM task, information is reported about attribute changes and file / directory moves are reported.","About File Integrity Monitoring","161324.htm");
Page[116]=new Array("While the OAFIM task is running, each object change is determined trough real-time interception of file operations in real-time mode. When an object changes, Kaspersky Endpoint Security sends an event to the Kaspersky Security Center administration server. A file checksum is not calculated during the task run. The OAFIM task does not monitor changes in files (attributes and content) with hard links, that are not located in a monitoring scope.","Kaspersky Endpoint Security monitors file operations on specific files or in scopes specified in the parameters of the task.","Monitoring scopes","Monitoring scopes for File Integrity Monitoring tasks must always be specified. The administrator can change scanning and monitoring scopes in real-time mode. If no monitoring scope is specified, task settings cannot be saved in the configuration file. When a monitoring scope or exclusion scope is added, the application does not check whether the specified directory exists.","You can specify several monitoring scopes.","Monitoring exclusion scopes","You can create exclusions for the monitoring scope. Exclusions are specified for individual scopes, and work only for the indicated monitoring scope. You can specify several exclusion scopes.","Exclusions have a higher priority than the monitoring scope and are not monitored by a task, even if a specific directory or file is in the monitoring scope. If the settings for one of the rules specify a monitoring scope that is at a lower level than a directory specified in exclusions, the monitoring scope is not considered when the task is run.","To specify exclusions, you can use the same command line shell masks that are used to specify monitoring scopes.","Monitored parameters","Changes to the following parameters are monitored during the File Integrity Monitoring task run:","Content (write (), truncate (), etc.)","Metadata (possession rights (chmod / chown))","Time stamps (utimensat)","Extended attributes ((setxattr) and others)","The technical limitations of the Linux operating system prevent the File Integrity Monitoring component from detecting which administrator or process has made a change to a file.","On-access File Integrity Monitoring (OAFIM)","161948.htm");
Page[117]=new Array("While the ODFIM task is running, each object change is determined by comparing the current state of the monitored objects with the original state, which was previously established as a baseline.","You can create several ODFIM tasks.","Baseline","The baseline is established during the first run of the ODFIM task on the computer. For each ODFIM task, a separate baseline is created. The task is performed only if the baseline corresponds to the monitoring scope. If the baseline does not match the monitoring scope, Kaspersky Endpoint Security generates an event about file integrity violation.","You can rebuild a baseline for a task using the corresponding parameter. The baseline is rebuilt after an ODFIM task has finished.","Also, a baseline is rebuilt when the parameters of a task change, for example, if a new monitoring scope is added. The baseline will be rebuilt during the next task run.","The ODFIM task creates storage for baselines on a computer that has the File integrity Monitoring component installed.","You can delete a baseline only if you delete the corresponding ODFIM task. ","On-demand File Integrity Monitoring (ODFIM)","161949.htm");
Page[118]=new Array("This section describes the settings you can specify for the on-access File Integrity Monitoring task.","All available values and default values for each setting are described below.","UseExcludeMasks","Enables or disables exclusion, from the monitoring scope, of objects that are specified by the ExcludeMasks setting.","The UseExcludeMasks setting works only if the ExcludeMasks setting is specified.","Available values:","Yes&#8212;Exclude objects specified by the ExcludeMasks setting from the monitoring scope","No&#8212;Do not exclude objects specified by the ExcludeMasks setting from the monitoring scope","Default value: No","ExcludeMasks","Specifies a list of masks that define objects to be excluded from the monitoring scope.","Before specifying this setting, make sure that the UseExcludeMasks setting value is set to Yes.","Masks are specified in command shell format. ","If you want to specify several masks, each mask must be specified on a new line with the new index specified (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Default value: not defined","Section [ScanScope.item_#]","The [ScanScope.item_#] sections specify scopes to be monitored by the File Integrity Monitoring task. At least one monitoring scope must be specified for the task.","You can define several [ScanScope.item_#] sections in a configuration file in any order. Kaspersky Endpoint Security will process scopes by item index, in ascending order.","Each [ScanScope.item_#] section contains the following settings:","AreaDesc","Specifies the name of the monitoring scope.","UseScanArea","Enables or disables monitoring of the specified scope.","Available values:","Yes&#8212;Monitor a specified scope","No&#8212;Do not monitor a specified scope","Default value: Yes","Path","Specifies the full path to the object or directories to be monitored.","Default value: /opt/kaspersky/kesl/","AreaMask.item_#","Specifies a command line shell mask that defines the objects to be monitored.","You can specify several AreaMask.item_# items in any order. Kaspersky Endpoint Security will process items by indexes, in ascending order.","Default value: * (all objects will be processed)","Section [ExcludedFromScanScope.item_#]","The [ExcludedFromScanScope.item_#] sections specify the objects to be excluded from all [ScanScope.item_#] sections.","All objects that match the rules of any [ExcludedFromScanScope.item_#] section will be excluded from monitoring. An [ExcludedFromScanScope.item_#] section format is similar to the format of a [ScanScope.item_#] section.","You can define several [ExcludedFromScanScope.item_#] sections in a configuration file in any order. Kaspersky Endpoint Security will process scopes by item index, in ascending order.","Each [ScanScope.item_#] section contains the following settings:","AreaDesc","Specifies the name of the scope to be excluded from monitoring.","UseScanArea","Specifies whether the specified scope will be excluded from monitoring.","Available values:","Yes&#8212;Exclude a specified scope from the monitoring","No&#8212;Do not exclude the specified scope from the monitoring","Default value: Yes","Path","Specifies the path to the objects or directories to be excluded from monitoring.","AreaMask.item_#","Specifies a command line shell mask that defines the objects to be excluded from monitoring.","You can specify several AreaMask.item_# items in any order. Kaspersky Endpoint Security will process items by indexes, in ascending order.","Default value: * (all objects will be monitored)","On-access File Integrity Monitoring task settings","161325.htm");
Page[119]=new Array("This section describes the settings that you can specify for the on-demand File Integrity Monitoring task.","All available values and default values for each setting are described.","RebuildBaseline","Enables or disables rebuilding a baseline after an ODFIM task has finished.","Available values:","Yes&#8212;Rebuild a baseline after an ODFIM task has finished","No&#8212;Do not rebuild a baseline after an ODFIM task has finished","Default value: No","CheckFileHash","Enables or disables a hash (SHA-256) check.","Available values:","Yes&#8212;Enable a hash check","No&#8212;Disable a hash check","Default value: No","TrackDirectoryChanges","Enables or disables monitoring of directories.","Available values:","Yes&#8212;Monitor directories","No&#8212;Do not monitor directories","Default value: No","TrackLastAccessTime","Enables or disables checking of the last time the file was accessed. (In Linux operating systems this is the noatime parameter.)","Available values:","Yes&#8212;Check the last time the file was accessed","No&#8212;Do not check the last time the file was accessed","Default value: No","UseExcludeMasks","Enables or disables exclusion from the monitoring scope of objects specified by the ExcludeMasks setting.","This setting works only with the ExcludeMasks setting specified.","Available values:","Yes&#8212;Exclude objects specified by the ExcludeMasks setting from the monitoring scope","No&#8212; Do not exclude objects specified by the ExcludeMasks setting from the monitoring scope","Default value: No","ExcludeMasks","Specifies a list of masks that define objects to be excluded from the monitoring scope.","Before specifying this setting, make sure that the UseExcludeMasks setting value is set to Yes.","Masks are specified in command shell format. ","If you want to specify several masks, each mask must be specified on a new line with new index specified (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Default value: not defined","Section [ScanScope.item_#]","The [ScanScope.item_#] sections specify scopes to be monitored by the File Integrity Monitoring task. At least one monitoring scope must be specified for the task.","You can define several [ScanScope.item_#] sections in a configuration file in any order. Kaspersky Endpoint Security will process scopes by item index, in ascending order.","Each [ScanScope.item_#] section contains the following settings:","AreaDesc","Specifies the name of the monitoring scope.","UseScanArea","Enables or disables monitoring of the specified scope.","Available values:","Yes&#8212;Monitor a specified scope","No&#8212;Do not monitor a specified scope","Default value: Yes","Path","Specifies the full path to the object or directories to be monitored.","Default value: /opt/kaspersky/kesl/","AreaMask.item_#","Specifies a command line shell mask that defines the objects to be monitored.","You can specify several AreaMask.item_# items in any order. Kaspersky Endpoint Security will process items by indexes, in ascending order.","Default value: * (all objects will be processed)","Section [ExcludedFromScanScope.item_#]","The [ExcludedFromScanScope.item_#] sections specify the objects to be excluded from all [ScanScope.item_#] sections.","All objects that match the rules of any [ExcludedFromScanScope.item_#] section will be excluded from monitoring. An [ExcludedFromScanScope.item_#] section format is similar to the format of a [ScanScope.item_#] section.","You can define several [ExcludedFromScanScope.item_#] sections in a configuration file in any order. Kaspersky Endpoint Security will process scopes by item index, in ascending order.","Each [ScanScope.item_#] section contains the following settings:","AreaDesc","Specifies the name of the scope to be excluded from monitoring.","UseScanArea","Specifies whether the specified scope will be excluded from monitoring.","Available values:","Yes&#8212;Exclude a specified scope from monitoring","No&#8212;Do not exclude the specified scope from monitoring","Default value: Yes","Path","Specifies the path to the objects or directories to be excluded from monitoring.","AreaMask.item_#","Specifies a command line shell mask that defines the objects to be excluded from monitoring.","You can specify several AreaMask.item_# items in any order. Kaspersky Endpoint Security will process items by indexes, in ascending order.","Default value: * (all objects will be monitored)","On-demand File Integrity Monitoring settings","165474.htm");
Page[120]=new Array("This section contains information about the Firewall Manager task.","Firewall Manager task (Firewall ID:12)","161326.htm");
Page[121]=new Array("During use on local area networks (LANs) and the Internet, a computer is exposed to viruses, other malware, and a variety of attacks that exploit vulnerabilities in operating systems and software.","The operating system firewall protects personal data that is stored on the user's computer. The firewall blocks most potential threats to the operating system when the computer is connected to the Internet or a LAN. Firewall Manager detects all network connections of the user's computer and provides a list of IP addresses, as well as an indication of the status of the default network connection.","The Firewall Manager component filters all network activity according to network packet rules. Configuring network packet rules lets you specify the desired level of computer protection, from blocking Internet access for all applications to allowing unlimited access.","While the Firewall Manager task is running, Kaspersky Endpoint Security manages the parameters and rules of the operating system firewall. The application blocks any configuration of the operating system firewall parameters when, for example, a program or tool adds or deletes a rule. Kaspersky Endpoint Security checks the operating system firewall every 60 seconds and, if necessary, restores a set of the firewall rules. The checking period cannot be changed.","Checking of the operating system firewall continues when the Firewall Manager task is stopped. This allows the application to restore dynamic rules.","When the Firewall Manager task is stopped (when the component deleted, or the application is stopped or uninstalled), Kaspersky Endpoint Security does not change the operating system firewall rules, and does not control changes to its settings.","All outbound connections are allowed by default (default action setting), unless the corresponding blocking rules for the Firewall Manager task are specified. The default action is performed with the lowest priority: if no other network packet rule has been triggered or if no network packet rules have been specified, the connection is allowed.","Before the Firewall Manager task is enabled, we recommend that you disable other OS firewall management tools.","About Firewall Manager","161327.htm");
Page[122]=new Array("Network packet rules are allowed or blocked actions that are performed by Firewall Manager when it detects a network connection attempt.","Network packet rules impose restrictions on network packets regardless of the program. Such rules restrict inbound and outbound network traffic through specific ports of the selected data protocol. ","Firewall Manager specifies certain network packet rules by default. You can create your own network packet rules, and specify an execution priority for each network packet rule.","About network packet rules","161953.htm");
Page[123]=new Array("Kaspersky Endpoint Security components can add and delete dynamic rules to the firewall that are required for correct functioning. For example, Network Agent adds dynamic rules that allow connections to Kaspersky Security Center initiated both by the application and by Kaspersky Security Center.","The Firewall Manager task does not control dynamic rules and does not block access to network resources for the application components. Dynamic rules do not depend on the Firewall Manager task state (started / stopped) or its settings changes. An execution priority of the dynamic rules is higher than a priority of the network packet rules. Kaspersky Endpoint Security restores a set of dynamic rules if any of them were deleted, for example, using the iptables utility.","You can view a set of dynamic rules (using the kesl-control &#8211;F &#8211;query command) but you cannot change the settings for dynamic rules. ","About dynamic rules","161954.htm");
Page[124]=new Array("The Firewall controls all network connections on the user's computer. You can add a network address to one of the following predefined zones:","Public","Local","Trusted","About the predefined network zone names","161955.htm");
Page[125]=new Array("This section provides information about the settings that you can specify for the Firewall Manager task.","All available values and default values for each setting are described.","DefaultIncomingAction","The default action to perform on an inbound connection if no network rules can be applied to this kind of the connection.","Available values:","Allow&#8212;Allow inbound connection","Block&#8212;Block inbound connection","Default value: Allow","DefaultIncomingPacketAction","The default action to perform on an incoming packet if no network packet rules can be applied to this kind of the connection.","Available values:","Allow&#8212;Allow incoming packet","Block&#8212;Block incoming packet","Default value: Allow","Section [PacketRules.item_xxxx]","The [PacketRules.item_#] sections specify network packet rules for the Firewall Manager task.","You can define several [PacketRules.item_#] sections in a configuration file in any order. Kaspersky Endpoint Security will process scopes by an item index, in ascending order.","Each [PacketRules.item_#] section contains the following settings:","Name","A network packet rule name.","Default value: Network rule #&lt;n&gt;; where, n is an index.","FirewallAction","Action to be performed on connections specified in this network packet rule.","Available values:","Allow&#8212;Allow network connection","Block&#8212;Block network connection","Default value: Allow","Protocol","Type of protocol for which network activity is to be monitored.","Available values:","Any&#8212;The Firewall Manager monitors all network activity","TCP","UDP","ICMP","ICMPv6","IGMP","GRE","Default value: Any","RemotePorts","Port numbers of the remote computers between which the connection is to be monitored.","This setting can be specified only if the Protocol setting value was set to TCP or UDP.","Integer or interval can be specified for this setting.","Available values:","Any&#8212;All remote ports are monitored","0-65535","Default value: Any","LocalPorts","Port numbers of the local computers between which the connection is to be monitored.","This setting can be specified only if the Protocol setting value was set to TCP or UDP.","Integer or interval can be specified for this setting.","Available values:","Any&#8212;All local ports are monitored","0-65535","Default value: Any","ICMPType","ICMP packet type.","This setting can be specified only if the Protocol setting value was set to ICMP or ICMPv6.","Available values:","Any&#8212;All ICMP packet types are monitored","Integer according to a data transfer protocol specification","Default value: Any","ICMPCode","ICMP packet code.","This setting can be specified only if the Protocol setting value was set to ICMP or ICMPv6.","Available values:","Any&#8212;All ICMP packet codes are monitored","Integer according to a data transfer protocol specification","Default value: Any","Direction","Direction of the monitored network activity.","Available values:","IncomingOutgoing&#8212;Monitor both inbound and outbound connections","Incoming&#8212;Monitor inbound connections","Outgoing&#8212;Monitor outbound connections","IncomingPacket&#8212;Monitor incoming packets","OutgoingPacket&#8212;Monitor outgoing packets","IncomingOutgoingPacket&#8212;Monitor both incoming and outgoing connections","Default value: IncomingOutgoing","RemoteAddress","The network addresses of remote computers that can send and / or receive network packets.","Available values:","Any&#8212;Monitor network packets sent and/or received by remote computers with any IP address","Trusted&#8212;All Trusted networks","Local&#8212;All Local networks","Public&#8212;All Public networks","d.d.d.d&#8212;IPv4 address; where, d is a decimal number 0-255","d.d.d.d/p&#8212;Subnet of IPv4 addresses; where, p is a number 0-32","x:x:x:x:x:x:x:x&#8212;IPv6 address; where, x is a hexadecimal number 0-ffffff","x:x:x:x::0/p&#8212;Subnet of IPv6 addresses; where, p is a number 0-64","Default value: Any","LocalAddress","Network addresses of computers that have Kaspersky Endpoint Security installed and can send and / or receive network packets.","Available values:","Any&#8212;Monitor network packets sent and/or received by remote computers with any IP address","d.d.d.d&#8212;IPv4 address; where, d is a decimal number 0-255","d.d.d.d/p&#8212;Subnet of IPv4 addresses; where, p is a number 0-32","x:x:x:x:x:x:x:x&#8212;IPv6 address; where, x is a hexadecimal number 0-ffffff","x:x:x:x::0/p&#8212;Subnet of IPv6 addresses; where, p is a number 0-64","Default value: Any","LogAttempts","Specify whether you want the actions of the network rule to be included in the report.","Available values:","Yes&#8212;Report actions","No&#8212;Do not report actions","Default value: No","Section [NetworkZonesPublic]","The [NetworkZonesPublic] section specifies network addresses associated with Public networks.","You can specify several IP addresses or subnets of IP addresses.","Address.item_xxxx","Available values:","d.d.d.d&#8212;IPv4 address; where, d is a decimal number 0-255","d.d.d.d/p&#8212;Subnet of IPv4 addresses; where, p is a number 0-32","x:x:x:x:x:x:x:x&#8212;IPv6 address; where, x is a hexadecimal number 0-ffffff","x:x:x:x::0/p&#8212;Subnet of IPv6 addresses; where, p is a number 0-64","Default value: &#8220;&#8221; (no network addresses in this zone)","Section [NetworkZonesLocal]","The [NetworkZonesLocal] section specifies network addresses associated with Local networks.","You can specify several IP addresses or subnets of IP addresses.","Address.item_xxxx","Available values:","d.d.d.d&#8212;IPv4 address; where, d is a decimal number 0-255","d.d.d.d/p&#8212;Subnet of IPv4 addresses; where, p is a number 0-32","x:x:x:x:x:x:x:x&#8212;IPv6 address; where, x is a hexadecimal number 0-ffffff","x:x:x:x::0/p&#8212;Subnet of IPv6 addresses; where, p is a number 0-64","Default value: &#8220;&#8221; (no network addresses in this zone)","Section [NetworkZonesTrusted]","The [NetworkZonesTrusted] section specifies network addresses associated with Trusted networks.","You can specify several IP addresses or subnets of IP addresses.","Address.item_xxxx","Available values:","d.d.d.d&#8212;IPv4 address; where, d is a decimal number 0-255","d.d.d.d/p&#8212;Subnet of IPv4 addresses; where, p is a number 0-32","x:x:x:x:x:x:x:x&#8212;IPv6 address; where, x is a hexadecimal number 0-ffffff","x:x:x:x::0/p&#8212;Subnet of IPv6 addresses; where, p is a number 0-64","Default value: &#8220;&#8221; (no network addresses in this zone)","Firewall Manager task settings","161328.htm");
Page[126]=new Array("You can manually add a network packet rule.","You can add only one network packet rule at a time.","To add a network packet rule, execute the following command:","kesl-control -F --add-rule --name &lt;rule name&gt; --action &lt;action&gt; --protocol &lt;protocol&gt; --direction &lt;direction&gt; --remote &lt;remote address&gt; --local &lt;local address&gt; --at &lt;index in a list of network packet rules&gt;","A section containing new network packet rule settings is added to the Firewall Manager task configuration file. If you did not specify a certain parameter in the command, the default value is set.","The &#8211;at option lets you specify the index of the rule being created, in the list of network packet rules. If the &#8211;at option is not specified, or its value is larger than the number of rules in the list, the new rule is added into the end of the list.","Adding network packet rule","161956.htm");
Page[127]=new Array("You can manually delete a network packet rule.","You can delete only one network packet rule at a time.","To delete a network packet rule, execute one of the following commands:","kesl-control -F --del-rule --name &lt;name&gt;","A network packet rule is deleted by its name. If a list of network packet rules contains several rules with the same name, Kaspersky Endpoint Security does not delete any of them.","kesl-control -F &#8211;del-rule --index &lt;index&gt;","A network packet rule is deleted by its index in the network packet rules list.","A section with network packet rules settings is deleted from the configuration file of the Firewall Manager task.","If the list of network packet rules does not contain a rule with a specified name or index, an error occurs.","Deleting network packet rule","161958.htm");
Page[128]=new Array("You can manually change an execution priority for a network packet rule.","To change an execution priority for a network packet rule, execute the following command:","kesl-control -F --move-rule [--name &lt;name&gt;|--index &lt;index&gt;] --at &lt;index&gt;","The network packet rule priority is changed to the specified index.","Changing execution priority of network packet rule","161960.htm");
Page[129]=new Array("You can manually add network addresses associated with a certain type of network to the configuration file of the Firewall Manager task.","To add a network address to the zone, execute the following command:","kesl-control -F --add-zone &lt;Public|Local|Trusted&gt; --address &lt;address&gt;","A network address is added to the specified zone section in the task configuration file.","Adding network address to zone section","161959.htm");
Page[130]=new Array("You can manually delete network addresses associated with a certain type of network from the configuration file of the Firewall Manager task.","To delete a network address from the zone in a configuration task, execute the following command:","kesl_control -F --del-zone &lt;zone&gt; [--address &lt;address&gt;| --index &lt;address index in the zone&gt;]","The specified network address is deleted from the specified zone section in a configuration file.","If a zone contains several items with the same network address, the command &#8211;del-zone will not be executed.","If the specified network address or index does not exist, an error occurs.","Deleting network address from zone section","161961.htm");
Page[131]=new Array("This section contains information about the Anti-Cryptor task.","Anti-Cryptor task (AntiCryptor ID:13)","161329.htm");
Page[132]=new Array("The Anti-Cryptor task allows you to protect your files in the local directories with network access by SMB / NFS protocols from remote malicious encrypting.","While the Anti-Cryptor task is running, Kaspersky Endpoint Security scans remote computers' calls to access files located in the shared network directories of the protected device. If the application considers a remote computer's actions on network file resources to be malicious encrypting, then this computer is added to a list of untrusted hosts and loses access to the shared network directories.","Kaspersky Endpoint Security does not consider activity to be malicious encrypting if the detected encryption activity takes place in directories excluded from the scope of the Anti-Cryptor task.","By default, Kaspersky Endpoint Security blocks untrusted hosts' access to network file resources for 30 minutes.","The Anti-Cryptor task runs correctly with SMB1, SMB2, SMB3, NFS3, TCP / UDP, and IP / IPv6 protocols. Working with NFS2 and NFS4 protocols is not supported. We recommend to configure your server settings so that NFS2 and NFS4 protocols could not be used to mount resources.","The Anti-Cryptor task does not block access to network file resources until the host's activity is identified as malicious. So at least one file will be encrypted before the application detects a malicious activity. ","About Anti-Cryptor task","161330.htm");
Page[133]=new Array("When a malicious encryption activity is detected, Kaspersky Endpoint Security creates and enables a rule for the operating system firewall, that blocks a network traffic from a compromised host. A compromised host is added to the list of untrusted hosts. Kaspersky Endpoint Security blocks access to shared network directories for all remote hosts in the list of untrusted hosts. Information about blocked hosts from a protected server is sent to the Kaspersky Security Center.","Firewall rules created by the Anti-Cryptor cannot be deleted by using the iptables utility: Kaspersky Endpoint Security restores the set of rules once per minute. Use the --allow-hosts option to unblock a host.","By default Kaspersky Endpoint Security removes untrusted computers from the list in 30 minutes since they were added to the list. Computers' access to network file resources is restored automatically after they are deleted from the list of untrusted hosts. You can modify the list of blocked hosts and specify the time after which blocked computers are automatically unblocked.","About untrusted hosts blocking","161331.htm");
Page[134]=new Array("This section provides information about the settings you can specify for the Anti-Cryptor task.","All available values and default values for each setting are described.","UseHostBlocker","Enables or disables blocking of untrusted hosts.","If blocking of untrusted hosts is disabled, Kaspersky Endpoint Security still scans remote computers actions on network file resources for malicious encrypting when the Anti-Cryptor task is running. In case of malicious activity detection, the EncryptionDetected event is created, but an attacking host is not be blocked. ","Available values:","Yes&#8212;Enable blocking of untrusted hosts","No&#8212;Disable blocking of untrusted hosts","Default value: Yes","BlockTime","Specifies the time to block an untrusted host (in minutes).","If a compromised host is blocked, and you change a value for the BlockTime setting, the blocking time for this host will not change. The blocking time is not a dynamic value, and is calculated at the moment of blocking.","Available values:","Integer from 1 to 4294967295","Default value: 30","UseExcludeMasks","Enables or disables the exclusion from protection scope of objects specified by the ExcludeMasks setting.","This setting works only with the ExcludeMasks setting specified.","Available values:","Yes&#8212;Exclude objects specified by the ExcludeMasks setting from the protection scope","No&#8212;Do not exclude objects specified by the ExcludeMasks setting from the protection scope","Default value: No","ExcludeMasks","Specifies a list of masks that define objects to be excluded from the protection scope.","Before specifying this parameter, make sure the UseExcludeMasks setting&#8217;s value is set to Yes.","Masks are specified in command shell format. ","If you want to specify several masks, each mask must be specified on a new line with new index specified (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Default value: not defined","Section [ScanScope.item_#]","[ScanScope.item_#] sections specify scopes to be protected by Kaspersky Endpoint Security. At least one protection scope must be specified for the Anti-Cryptor task.","For the Anti-Cryptor task only shared directories can be specified.","You can define several [ScanScope.item_#] sections in a configuration file in any order. Kaspersky Endpoint Security will process scopes by an item index in ascending order.","Each [ScanScope.item_#] section contains the following settings:","AreaDesc","Specifies the name of the protection scope.","Default value: AllSharedFolders","UseScanArea","Enables or disables protection of the specified scope.","Available values:","Yes&#8212;Protect a specified scope","No&#8212;Do not protect a specified scope","Default value: Yes","Path","Specifies the path to the objects to be protected.","Available values:","absolute path available via SMB / NFS (for example, Path=/tmp)","AllShared&#8212;Protect all resources shared via SMB / NFS","Shared:SMB &lt;path&gt;&#8212;Protect resources shared via SMB","Shared:NFS &lt;path&gt;&#8212;Protect resources shared via NFS","Default value: AllShared","AreaMask.item_#","Specifies a command line shell mask that defines the objects to be protected.","You can specify several AreaMask.item_# items in any order. Kaspersky Endpoint Security will process items by indexes in ascending order.","Default value: * (all objects will be processed)","Section [ExcludedFromScanScope.item_#]","[ExcludedFromScanScope.item_#] sections specify the objects to be excluded from all [ScanScope.item_#] sections.","All objects that match the rules of any [ExcludedFromScanScope.item_#] section will not be scanned. A [ExcludedFromScanScope.item_#] section format is similar to the format of a [ScanScope.item_#] section.","You can define several [ExcludedFromScanScope.item_#] sections in a configuration file in any order. Kaspersky Endpoint Security will process scopes by an item index in ascending order","Each [ScanScope.item_#] section contains the following settings:","AreaDesc","Specifies the name of the scope to be excluded from scanning.","Default value: All objects","UseScanArea","Specifies whether the specifies scope will be excluded from the protection.","Available values:","Yes&#8212;Exclude a specified scope from the protection","No&#8212;Do not exclude the specified scope from the protection","Default value: Yes","Path","Specifies the path to the objects to be excluded from the protection.","You can specify only an absolute path to a local directory (for example, /root /tmp/123) that will not be protected by the Anti-Cryptor.","Default value: not defined","AreaMask.item_#","Specifies a command line shell mask that defines the objects to be excluded from the protection.","You can specify several AreaMask.item_# items in any order. Kaspersky Endpoint Security will process items by indexes in ascending order.","Default value: * (all objects will be processed)","Anti-Cryptor task settings","161332.htm");
Page[135]=new Array("You can view a list of untrusted hosts blocked by the Anti-Cryptor task.","To view a list of blocked hosts, execute the following command:","kesl-control -H --get-blocked-hosts","Hosts blocked by the anti-Cryptor task will be displayed.","Viewing list of blocked hosts","161333.htm");
Page[136]=new Array("You can manually unblock hosts that were blocked by the Anti-Cryptor task, and restore the network access for them.","To unblock hosts, execute the following command:","kesl-control [-H] --allow-hosts &lt;host&gt;","where &lt;host&gt; can be a list of valid IPv4 / IPv6 addresses (including addresses in short form) or / and a subnet. Also, you can specify hosts as a list.","Specified hosts are unblocked.","Examples:","IPv4 addresses:","dec - 192.168.0.1","dec - 192.168.0.0/24","IPv6 addresses:","hex - FEDC:BA98:7654:3210:FEDC:BA98:7654:3210","hex - FEDC:BA98:7654:3210:FEDC:BA98:7654:3210%1","hex - 2001:db8::ae21:ad12","hex - ::ffff:255.255.255.254","hex - ::","Allowing blocked hosts","161334.htm");
Page[137]=new Array("This section contains information about participation in&nbsp;Kaspersky Security Network and instructions on&nbsp;how to&nbsp;enable or disable use of&nbsp;Kaspersky Security&nbsp;Network.","Participating in Kaspersky Security Network","161355.htm");
Page[138]=new Array("To protect your computer more effectively, Kaspersky Endpoint Security uses data that is&nbsp;gathered from users around the&nbsp;globe. Kaspersky&nbsp;Security Network is&nbsp;designed to&nbsp;collect such&nbsp;data.","Kaspersky Security Network (KSN)&nbsp;is&nbsp;an&nbsp;infrastructure of&nbsp;cloud services providing access to&nbsp;Kaspersky Lab's online knowledge base with&nbsp;information about the&nbsp;reputation of&nbsp;files, web resources, and&nbsp;software. The&nbsp;use of&nbsp;data from Kaspersky Security Network ensures faster responses by&nbsp;Kaspersky Endpoint Security to&nbsp;new threats, improves the&nbsp;performance of&nbsp;some protection components, and reduces the&nbsp;likelihood of&nbsp;false&nbsp;positives.","Depending on&nbsp;the&nbsp;location of&nbsp;the&nbsp;infrastructure, there is&nbsp;a&nbsp;Global KSN service (the&nbsp;infrastructure is&nbsp;hosted by&nbsp;Kaspersky Lab servers) and a&nbsp;Private KSN service (the&nbsp;infrastructure is&nbsp;hosted by&nbsp;third-party servers, for&nbsp;example on&nbsp;the&nbsp;network of&nbsp;the&nbsp;Internet service provider).","After changing the&nbsp;license, submit the&nbsp;details of&nbsp;the&nbsp;new key to&nbsp;the&nbsp;service provider in&nbsp;order to&nbsp;be&nbsp;able to&nbsp;use Private&nbsp;KSN. Otherwise, data exchange with&nbsp;Private KSN will&nbsp;be&nbsp;impossible due to&nbsp;an&nbsp;authentication&nbsp;error.","Thanks to&nbsp;users who participate in&nbsp;KSN, Kaspersky Lab is&nbsp;able to&nbsp;promptly gather information about types and sources of&nbsp;threats, develop solutions for&nbsp;neutralizing them, and minimize the&nbsp;number of&nbsp;false alarms displayed by&nbsp;application&nbsp;components.","There are two ways to participate in KSN:","Kaspersky Security Network with statistics&#8212;You can obtain information from the knowledge base. The application automatically sends statistics generated during operation of the application to KSN. The application can also send to Kaspersky Lab for additional scanning certain files (or parts of files) that intruders can use to harm the computer or data.","Kaspersky Security Network without statistics&#8212;You can obtain information from the knowledge base, but the application does not send anonymous statistics and information about the types and sources of new threats.","No personal data is&nbsp;collected, processed, or&nbsp;stored. More&nbsp;detailed information about submission of&nbsp;statistical information generated during participation in&nbsp;KSN, storage and destruction of&nbsp;such information is&nbsp;available in&nbsp;the&nbsp;Kaspersky Security Network Statement and on&nbsp;the&nbsp;Kaspersky Lab website at&nbsp;(http://www.kaspersky.com/privacy). The&nbsp;file with&nbsp;the&nbsp;text of&nbsp;the&nbsp;Kaspersky Security Network Statement is&nbsp;included in&nbsp;the&nbsp;application distribution&nbsp;kit.","User computers managed by&nbsp;Kaspersky Security Center Administration Server can&nbsp;interact with&nbsp;KSN via&nbsp;the&nbsp;KSN Proxy&nbsp;service.","The KSN Proxy service provides the&nbsp;following&nbsp;capabilities:","The user's computer can&nbsp;query KSN and submit information to&nbsp;KSN, even without direct access to&nbsp;the&nbsp;Internet.","KSN Proxy caches processed data, thereby reducing the&nbsp;load on&nbsp;the&nbsp;external network connection and speeding up receipt of&nbsp;the&nbsp;information that is&nbsp;requested by&nbsp;the&nbsp;user's&nbsp;computer.","More details about the&nbsp;KSN Proxy service can&nbsp;be&nbsp;found in&nbsp;the&nbsp;Kaspersky Security Center documentation.","KSN Proxy settings can&nbsp;be&nbsp;configured in&nbsp;the&nbsp;properties of&nbsp;the&nbsp;of&nbsp;Kaspersky Security Center policy.","Participation in&nbsp;Kaspersky Security Network is&nbsp;voluntary. The&nbsp;application offers the&nbsp;user to&nbsp;participate in&nbsp;KSN during&nbsp;installation. Users&nbsp;can&nbsp;begin or discontinue participation in&nbsp;KSN at&nbsp;any&nbsp;time.","About participation in Kaspersky Security Network","161356.htm");
Page[139]=new Array("To enable use of&nbsp;Kaspersky Security Network, execute one the&nbsp;following&nbsp;commands:","To enable use of Kaspersky Security Network with statistics,","kesl-control --set-app-settings UseKSN=Extended","To enable use of Kaspersky Security Network without statistics,","kesl-control --set-app-settings UseKSN=Basic","To disable use of&nbsp;Kaspersky Security Network, execute the&nbsp;following&nbsp;command:","kesl-control --set-app-settings UseKSN=No","To enable or disable use of&nbsp;Kaspersky Security Network with&nbsp;a&nbsp;configuration file, execute the&nbsp;following&nbsp;command:","kesl-control --set-app-settings --file &lt;configuration file name&gt;","If Kaspersky Endpoint Security installed on a computer runs under a policy that was&nbsp;assigned in&nbsp;Kaspersky Security Center, the&nbsp;value of the&nbsp;UseKSN parameter can&nbsp;only be&nbsp;changed by&nbsp;using Kaspersky Security Center.","If Kaspersky Endpoint Security installed on&nbsp;a&nbsp;computer stops running a&nbsp;policy, the&nbsp;UseKSN=No parameter value is&nbsp;set.","The file containing the text of the Kaspersky Security Network Statement is&nbsp;located in&nbsp;the&nbsp;directory /opt/kaspersky/kesl/doc/ksn_license.&lt;language ID&gt;.","Enabling and disabling use of Kaspersky Security Network","161357.htm");
Page[140]=new Array("To check the&nbsp;connection to&nbsp;Kaspersky Security Network, run the&nbsp;following&nbsp;command:","kesl-control&nbsp;--app-info","The KSN state string displays the&nbsp;status of&nbsp;the&nbsp;connection to&nbsp;Kaspersky Security&nbsp;Network:","If the&nbsp;Extended status is&nbsp;displayed, Kaspersky Endpoint Security is&nbsp;connected to&nbsp;Kaspersky Security&nbsp;Network, information from knowledge base can be obtained, anonymous statistics and information about the types and sources of new threats is sent.","If the&nbsp;Basic status is&nbsp;displayed, Kaspersky Endpoint Security is&nbsp;connected to&nbsp;Kaspersky Security&nbsp;Network, information from knowledge base can be obtained, but anonymous statistics and information about the types and sources of new threats is not sent.","If the&nbsp;No status is&nbsp;displayed, Kaspersky Endpoint Security is&nbsp;not&nbsp;connected to&nbsp;Kaspersky Security&nbsp;Network.","A connection to&nbsp;Kaspersky Security Network may be&nbsp;absent for&nbsp;the&nbsp;following&nbsp;reasons:","The computer is&nbsp;not&nbsp;connected to&nbsp;the&nbsp;Internet.","You are&nbsp;not&nbsp;a&nbsp;participant in&nbsp;Kaspersky Security&nbsp;Network.","The application has&nbsp;not&nbsp;been activated or the&nbsp;license has&nbsp;expired.","Key-related problems have&nbsp;been&nbsp;detected. For&nbsp;example, the&nbsp;key has&nbsp;been&nbsp;black-listed.","Checking the connection to Kaspersky Security Network","161358.htm");
Page[141]=new Array("Kaspersky Lab offers an&nbsp;extra layer of&nbsp;protection to&nbsp;users through the&nbsp;Kaspersky Security&nbsp;Network. This&nbsp;protection method is&nbsp;designed to&nbsp;combat advanced persistent threats and zero-day&nbsp;attacks. Integrated&nbsp;cloud technologies and the&nbsp;expertise of&nbsp;Kaspersky Lab virus analysts make Kaspersky Endpoint Security the&nbsp;unsurpassed choice for&nbsp;protection against the&nbsp;most sophisticated network&nbsp;threats.","Details on&nbsp;enhanced protection in&nbsp;Kaspersky Endpoint Security are&nbsp;available on&nbsp;the&nbsp;Kaspersky Lab&nbsp;website.","Enhanced protection with Kaspersky Security Network","161359.htm");
Page[142]=new Array("This section describes working with Kaspersky Endpoint Security by using the graphical user interface (GUI).","Using Kaspersky Endpoint Security graphical user interface","161978.htm");
Page[143]=new Array("You can enable or disable the Kaspersky Endpoint Security graphical user interface (GUI) locally from the command line.","Root privileges are required to enable or disable the GUI.","To enable or disable the GUI:","Run the application configuration script:","/opt/kaspersky/kesl/bin/kesl-setup.pl &#8211;G","In the command line, do one of the following:","If you want to enable graphical user interface, press the Y key.","If you enable the GUI, users without root privileges will be able to run on-demand scan tasks.","If a user is logged in, a GUI will be launched for this user if all necessary libraries are available. The application icon appears in the notification area of the taskbar and shortcuts are created.","If you want to disable the GUI, press the N key.","The application blocks users from starting the GUI. The application icon and shortcuts are removed.","Enabling and disabling graphical user interface locally","161980.htm");
Page[144]=new Array("This section describes the primary elements of the application graphical user interface (GUI).","Application interface","161988.htm");
Page[145]=new Array("After the Kaspersky Endpoint Security graphical user interface is enabled, the application icon appears in the notification area on the right side of the taskbar.","The icon acts as a shortcut to the context menu and main window of the application.","The context menu of the application icon contains the following items:","Kaspersky Endpoint Security 10 SP1 for Linux. Opens the main application window. The main application window lets you view the protection status of your computer and the state of the On-demand scan task and Update task. Also, you can navigate to the Reports, Storage, Settings, and Support windows.","Exit. Quits the Kaspersky Endpoint Security GUI. ","You can open the context menu of the application icon by right-clicking  the application icon in the notification area.","Application icon in the notification area","161990.htm");
Page[146]=new Array("The main window of Kaspersky Endpoint Security contains interface elements that provide access to the application functions.","The main application window is divided into several parts:","The central part of the window displays the protection status of your computer. Clicking this part of the main window takes you to the Protection center window.","The Scan tab displays the on-demand scan task state and the number of detected threats. Clicking this tab takes you to the Scan window. In this window, you can start or stop on-demand scan, boot sector scan, and memory scan tasks. Also, you can view reports for these tasks.","The Update tab displays the state of the Update task and anti-virus databases. Clicking this tab takes you to the Update window. In this window, you can start or stop the Update and Update distribution tasks. Also, you can view reports for these tasks.","The lower part of the mail application window contains the following elements:","Reports button. Clicking this button takes you to the Reports window, where you can view tasks statistics and various reports.","Storage button. Clicking this button takes you to the Storage window, which contains information about objects in the Storage.","Settings button. Clicking this button takes you to the Settings window, where you can enable or disable participation in Kaspersky Security Network, Real-time protection, Firewall, Anti-Cryptor, and File Integrity Monitoring tasks.","Support button. Clicking this button takes you to the Support window, which contains information about the current version of Kaspersky Endpoint Security, about licenses, key status, databases state, operating system, and links to Kaspersky Lab information resources.","To open the main window of Kaspersky Endpoint Security, perform one of the following actions:","Double-click or right-click the application icon in the notification area of the taskbar.","Right-click the application and select Kaspersky Endpoint Security 10 SP 1 for Linux.","Main application window","161987.htm");
Page[147]=new Array("By default, the Kaspersky Endpoint Security graphical user interface (GUI) allows you to start and stop the following tasks:","Full scan task (Scan_My_Computer)","On-demand scan tasks (Scan_File, Boot_Scan, Memory_Scan)","Update tasks (Update, Rollback, Retranslate)","The Kaspersky Endpoint Security GUI also allows you to enable and disable the following components:","Real-time protection","Firewall","Anti-Cryptor","File Integrity Monitoring","Also, you can manage your participation in Kaspersky Security Network.","Managing tasks and components","165423.htm");
Page[148]=new Array("You can start and stop Full scan, On-demand scan, Boot sector scan, and Memory scan tasks by using the Kaspersky Endpoint Security GUI.","To start or stop a scan task,","Open the main application window.","In the main application window, click the Scan button to open the Scan window.","Do one of the following:","If you want to start a task, click the Start button under the scan task that you want to start.","The progress of the running task is displayed.","If you want to stop a task, click the Stop button under the scan task that you want to stop.","The scan task stops, and information about scanned objects and detected threats is displayed.","If necessary, you can click the Show report button to view the task report.","The Reports window is available for non-root users only when the general application setting UIReportsForRootOnly is set to No. Otherwise, the Reports window is available only for a root user.","Starting and stopping scan tasks","161997.htm");
Page[149]=new Array("You can start and stop Update, Update rollback, and Update distribution tasks by using the Kaspersky Endpoint Security graphical user interface.","To start or stop an Update task or Update distribution task:","Open the main application window.","In the main application window, click the Update button to open the Update window.","Do one of the following:","If you want to start a task, click the Start button under the task that you want to start.","The progress of the running task is displayed. ","If the Update task finishes successfully, the Rollback update link becomes available, and you can roll back the last update.","If you want to stop a task, click the Stop button under the task that you want to stop.","The task stops.","If necessary, you can click the Show report button to view the task report.","The Reports window is available for non-root users only when the general application setting UIReportsForRootOnly is set to No. Otherwise, the Reports window is available only for a root user.","To run an update rollback task:","Open the main application window.","In the main application window, click the Update button to open the Update window.","In the Update section, click the Rollback update link to roll back the last successful database update.","Starting and stopping update tasks","165426.htm");
Page[150]=new Array("You can enable and disable the Real-time protection, Firewall Manager, Anti-Cryptor, and File Integrity Monitoring components using the Kaspersky Endpoint Security graphical user interface at any time. .","If a component is enabled, the Disable button is available. By default, only Real-time protection is enabled.","If a component is disabled, the Enable button is available.","To enable or disable a component:","Open the main application window.","In the lower part of the main application window, click the Settings button.","The Settings window opens.","In the Settings window, perform the following actions for the required component:","If you want to enable a component, click the Enable button.","If you want to disable a component, click the Disable button.","Enabling and disabling application components","162000.htm");
Page[151]=new Array("You can manage your participation in Kaspersky Security Network at any time.","To enable Kaspersky Security Network:","Open the main application window.","In the lower part of the main application window, click the Settings button.","The Settings window opens.","In the Settings window, select one of the following options:","Kaspersky Security Network with statistics&#8212;To enable Kaspersky Security Network, obtain information from the knowledge base, and send anonymous statistics and information about the types and sources of new threats.","Kaspersky Security Network without statistics&#8212;To obtain information from the knowledge base, but not to send anonymous statistics and information about the types and sources of new threats.","Click the Enable button.","In the Participation in Kaspersky Security Network window, carefully read the Kaspersky Security Network Statement, and select one of the following options:","I confirm I have fully read, understood, and accept the terms and conditions of this KSN Statement&#8212;To enable Kaspersky Security Network.","I do not accept the terms and conditions of this KSN Statement&#8212;To disable using Kaspersky Security Network.","Click OK.","The OK button is unavailable, if the Not selected option is selected.","To disable Kaspersky Security Network:","Open the main application window.","In the lower part of the main application window, click the Settings button.","The Settings window opens.","In the Settings window, click the Disable button.","In the window that opens, do one of the following:","Click Yes to confirm disabling Kaspersky Security Network.","Click Cancel to continue participating in Kaspersky Security Network.","Managing participation in Kaspersky Security Network","165428.htm");
Page[152]=new Array("This section describes how you can view reports in the Kaspersky Endpoint Security graphical user interface.","Reporting","161993.htm");
Page[153]=new Array("The Reports window is available for non-root users only when the general application setting UIReportsForRootOnly is set to No. Otherwise, the Reports window is available only for a root user.","Information about the performance of Kaspersky Endpoint Security tasks is recorded in reports.","Report data is presented in a table that contains a list of events. Each line in the table contains information about a separate event. Event attributes are located in the table columns. Events logged during the performance of various tasks have different sets of attributes.","The following reports, listed in a menu on the left, are available:","Statistic. Contains statistical information about the Real-time protection task and on-demand scan tasks. You can update the displayed report by clicking the Reload button.","A reset of statistics for the Real-time protection task occurs when the task is stopped. No reset of statistics for On-demand scan tasks occurs; instead, there is incrementation of the statistics while the application is installed on the computer.","System audit. This report contains information about events that occur during interaction the user with the application. It also contains information about events that occur during general operation of the application.","Threat protection. These reports contain information about events that are logged while the following Kaspersky Endpoint Security components are running:","Anti-Cryptor","File Integrity Monitoring","Firewall","File Anti-Virus","On-demand tasks. These reports contain information about events that are logged while the following Kaspersky Endpoint Security tasks are running:","Scan tasks","Update","Integrity check","Reports use the following event importance levels:","Informational events. Formal events that normally do not contain important information.","Important events. Events that require attention because they reflect important situations in the operation of Kaspersky Endpoint Security.","Critical events. Events of critical importance that indicate problems in the operation of Kaspersky Endpoint Security or vulnerabilities in the protection of the user's computer.","For convenient processing of reports, you can modify the presentation of data on the screen in the following ways:","Filter the event list by the period of time.","Use the search function to find a specific event.","View the selected event in a separate section.","Principles of managing reports","161992.htm");
Page[154]=new Array("The Reports window is available for non-root users only when the general application setting UIReportsForRootOnly is set to No. Otherwise, the Reports window is available only for a root user.","To view reports:","Open the main application window.","In the lower part of the main application window, click the Reports button.","The Reports window opens.","To view a specific report, in the left part of the Reports window, in the list of tasks, select the required task.","A report is displayed in the right part of the window and contains a list of events in the operation of the selected Kaspersky Endpoint Security task.","By default, events are sorted, in ascending order, by the values in the Date column. You can choose a different order by clicking the required column header.","To view a detailed summary of each event in a report, select the relevant event in the report.","The event summary is displayed in the lower part of the window.","Viewing reports","161994.htm");
Page[155]=new Array("To view objects that Kaspersky Endpoint Security moved to the Storage:","Open the main application window.","Click the Storage button.","In the window that opens, information about objects in Storage is displayed.","You can view the following information about objects in Storage:","Threat name.","Full path to an object.","Date when an object was moved to Storage.","Date when an object will be removed from Storage. This field is displayed if the DaysToLive setting was specified.","Object size.","You can restore objects from Storage to their original directories. You can also delete objects from Storage. Deleted objects cannot be restored in the future. Information about these actions is recorded in the event log. ","Viewing objects in Storage","161999.htm");
Page[156]=new Array("To create a trace file:","Open the main application window.","Click the Support button.","In the Support window, click the Tracing link.","In the Level drop-down list, select the trace level.","You are advised to clarify the required trace level with a Technical Support specialist. By default, the trace level is set to Diagnostic (300).","To start the tracing process, click the Enable button.","To stop the tracing process, click the Disable button.","Created trace files are stored in /var/log/kaspersky/kesl/ directory.","Creating a trace file","166209.htm");
Page[157]=new Array("This section describes how to get technical support and the terms on which it is available.","Contact Technical Support","70331.htm");
Page[158]=new Array("If you do not find a solution to your problem in the application documentation or in one of the sources of information about the application, we recommend that you contact Kaspersky Lab Technical Support. Technical Support specialists will answer any of your questions about installing and using the application.","Before contacting Technical Support, please read the support rules.","You can contact Technical Support in one of the following ways:","By telephone. This method allows you to consult with specialists from our Russian-language or international Technical Support.","Send request from My Kaspersky portal. This method allows you to contact our specialists using the query form.","Technical support is available only to users who have purchased a license for use of the application. No technical support is provided to users of trial versions.","How to get technical support","85903.htm");
Page[159]=new Array("You can call Technical Support specialists from most regions worldwide. You can find information about how to obtain technical support in your region and contact information for Technical Support on the Kaspersky Lab Technical Support website.","Before contacting Technical Support, please read the support rules.","Get technical support by phone","70152.htm");
Page[160]=new Array("Kaspersky CompanyAccount is a portal for companies that use Kaspersky Lab applications. The Kaspersky CompanyAccount portal is designed to facilitate interaction between users and Kaspersky Lab specialists through online requests. You can use Kaspersky CompanyAccount to track the status of your online requests and store a history of them as well.","You can register all of your organization's employees under a single account on Kaspersky CompanyAccount. A single account lets you centrally manage electronic requests from registered employees to Kaspersky Lab and also manage the privileges of these employees via Kaspersky CompanyAccount.","The Kaspersky CompanyAccount portal is available in the following languages:","English","Spanish","Italian","German","Polish","Portuguese","Russian","French","Japanese","To learn more about Kaspersky CompanyAccount, visit the Technical Support website.","Technical Support via Kaspersky CompanyAccount","68417.htm");
Page[161]=new Array("After you report a problem to Kaspersky Lab Technical Support specialists, they may ask you to generate a report with information about the operation of Kaspersky Endpoint Security and send it to Kaspersky Lab Technical Support. Technical Support specialists may also ask you to create a trace file. The trace file makes it possible to perform a step-by-step examination of the execution of application commands and determine when errors occur.","After Technical Support specialists analyze the data that you have sent, they can create an AVZ script and send it to you. By running AVZ scripts, it is&nbsp;possible&nbsp;to analyze active processes for threats, scan the computer for threats, disinfect or delete infected files, and create system scan reports.","Using a trace file and AVZ script","73375.htm");
Page[162]=new Array("This section provides information that complements the&nbsp;primary text of&nbsp;the&nbsp;document.","Appendices","161364.htm");
Page[163]=new Array("This section contains the default configuration files for Kaspersky Endpoint Security tasks.","You can change configuration files at any time. Also, you can change setting values from the command line.","Default task configuration files","161365.htm");
Page[164]=new Array("When editing a&nbsp;configuration file, adhere to&nbsp;the&nbsp;following&nbsp;rules:","You must&nbsp;specify all mandatory settings in&nbsp;the&nbsp;configuration&nbsp;file. You&nbsp;can&nbsp;specify individual task settings without a&nbsp;file by&nbsp;using the&nbsp;command&nbsp;line.","If a&nbsp;parameter belongs to&nbsp;a&nbsp;certain section, place it only in&nbsp;that&nbsp;section. Within&nbsp;the&nbsp;confines of&nbsp;one section, you can&nbsp;place the&nbsp;settings in&nbsp;any&nbsp;order.","Enclose the&nbsp;names of&nbsp;sections in&nbsp;square brackets [ ].","Enter the&nbsp;values of&nbsp;parameters in&nbsp;the&nbsp;format parameter name=value (spaces between the&nbsp;parameter name and its value are&nbsp;not&nbsp;processed).","Example:","[ScanScope.item_0000]","AreaDesc=Home","AreaMask.item_0000=*doc","Path=/home","Space and tab characters are&nbsp;ignored before the&nbsp;first quotation mark and after&nbsp;the&nbsp;last quotation mark of&nbsp;a&nbsp;string value, and at&nbsp;the&nbsp;beginning and end of&nbsp;a&nbsp;string value that is&nbsp;not&nbsp;enclosed in&nbsp;quotation&nbsp;marks.","If you need to&nbsp;specify several values for&nbsp;a&nbsp;parameter, repeat the&nbsp;parameter the&nbsp;same number of&nbsp;times as the&nbsp;number of&nbsp;values that you want to&nbsp;specify.","Example:","AreaMask.item_0000=*xml","AreaMask.item_0001=*doc","Be case-sensitive when entering values for&nbsp;the&nbsp;following types of&nbsp;parameters:","Names (masks) of&nbsp;scanned objects and excluded&nbsp;objects.","Names (masks) of&nbsp;threats.","The remaining parameter values are&nbsp;not&nbsp;case-sensitive.","Specify Boolean parameter values as&nbsp;follows: Yes&nbsp;&#8211;&nbsp;No.","Use quotation marks to&nbsp;enclose string values containing a&nbsp;space character (for&nbsp;example, names of&nbsp;files and directories and their paths, expressions containing the&nbsp;date and time in&nbsp;the&nbsp;format &quot;YYYY-MM-DD&nbsp;HH:MM:SS&quot;).","You can&nbsp;enter the&nbsp;remaining values with&nbsp;or without quotation&nbsp;marks.","Example:","AreaDesc=&quot;Scan mail databases&quot;","A single quotation mark in&nbsp;the&nbsp;beginning or end of&nbsp;a&nbsp;string is&nbsp;considered an&nbsp;error.","Rules for editing configuration files of Kaspersky Endpoint Security","161266.htm");
Page[165]=new Array("ScanArchived=No","ScanSfxArchived=No","ScanMailBases=No","ScanPlainMail=No","TimeLimit=60","SizeLimit=0","FirstAction=Recommended","SecondAction=Block","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","ScanByAccessType=SmartCheck","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*","Real-time protection task configuration file","161366.htm");
Page[166]=new Array("ScanArchived=Yes","ScanSfxArchived=Yes","ScanMailBases=No","ScanPlainMail=No","TimeLimit=0","SizeLimit=0","FirstAction=Recommended","SecondAction=Skip","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*","On-demand scan task configuration file","161367.htm");
Page[167]=new Array("ScanArchived=Yes","ScanSfxArchived=Yes","ScanMailBases=No","ScanPlainMail=No","TimeLimit=0","SizeLimit=0","FirstAction=Recommended","SecondAction=Skip","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*","Custom scan task configuration file","161368.htm");
Page[168]=new Array("UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","Action=Cure","Boot sectors scan task configuration file","161369.htm");
Page[169]=new Array("UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportUnprocessedObjects=No","Action=Cure","Memory scan task configuration file","161370.htm");
Page[170]=new Array("SourceType=&quot;KLServers&quot;","UseKLServersWhenUnavailable=Yes","IgnoreProxySettingsForKLServers=No","IgnoreProxySettingsForCustomSources=No","ApplicationUpdateMode=DownloadOnly","ConnectionTimeout=10","Update task configuration file","161371.htm");
Page[171]=new Array("SourceType=KLServers","UseKLServersWhenUnavailable=Yes","ConnectionTimeout=10","ApplicationUpdateMode=DownloadOnly","Update retranslation task configuration file","161372.htm");
Page[172]=new Array("DaysToLive=90","BackupSizeLimit=0","BackupFolder=/var/opt/kaspersky/kesl/common/objects-backup/","Managing Storage task configuration file","161373.htm");
Page[173]=new Array("DefaultIncomingAction=Allow","DefaultIncomingPacketAction=Allow","[NetworkZonesTrusted]","[NetworkZonesLocal]","[NetworkZonesPublic]","Firewall Manager task configuration file","161374.htm");
Page[174]=new Array("UseExcludeMasks=No","[ScanScope.item_0000]","AreaDesc=Kaspersky internal objects","UseScanArea=Yes","Path=/opt/kaspersky/kesl/","AreaMask.item_0000=*","File integrity monitoring task configuration file","161375.htm");
Page[175]=new Array("UseHostBlocker=yes","BlockTime=30","UseExcludeMasks=no","[ScanScope.item_0000]","AreaDesc=AllSharedFolders","UseScanArea=yes","Path=AllShared","AreaMask.item_0000=*","Anti-Cryptor task configuration file","161376.htm");
Page[176]=new Array("To configure the&nbsp;joint operation of&nbsp;Kaspersky Endpoint Security 10 and Kaspersky Anti-Virus for&nbsp;Linux Mail&nbsp;Server:","Save the&nbsp;real-time protection task settings in&nbsp;the&nbsp;configuration file using the&nbsp;following&nbsp;command:","kesl-control --get-settings 1 --file &lt;full path to&nbsp;file&gt;","Open the&nbsp;created configuration file for&nbsp;editing.","Add the&nbsp;following section to&nbsp;the&nbsp;created&nbsp;file:","[ExcludedFromScanScope.item_#]","Path=&lt;/var/opt/kaspersky/klms&gt;","Repeat the&nbsp;section specified above for&nbsp;all mail agents integrated with&nbsp;Kaspersky Anti-Virus for&nbsp;Linux Mail&nbsp;Server.","To exclude the&nbsp;temporary directory of&nbsp;filters and services of&nbsp;Kaspersky Anti-Virus for&nbsp;Linux Mail Server from scanning, add the&nbsp;following section to&nbsp;the&nbsp;created&nbsp;file:","[ExcludedFromScanScope.item_#]","Path=/tmp/klmstmp","Save the&nbsp;changes in&nbsp;the&nbsp;configuration&nbsp;file.","Import settings from the&nbsp;configuration file to&nbsp;the&nbsp;real-time protection task by&nbsp;using the&nbsp;following&nbsp;command:","kesl-control --set-settings 1 --file &lt;full path to&nbsp;file&gt;","Configuring collaboration: Kaspersky Anti-Virus for Linux Mail Server","161377.htm");
Page[177]=new Array("This section contains a&nbsp;description of&nbsp;return codes from the&nbsp;command&nbsp;line.","0&nbsp;&#8211; command / task completed&nbsp;successfully.","1&nbsp;&#8211; general error in&nbsp;command&nbsp;arguments.","2&nbsp;&#8211; error in&nbsp;passed application&nbsp;settings.","64&nbsp;&#8211; Kaspersky Endpoint Security is&nbsp;not&nbsp;running.","66&nbsp;&#8211; anti-virus databases have&nbsp;not&nbsp;been downloaded (used only for&nbsp;the&nbsp;command --app-info).","67&nbsp;&#8211; activation&nbsp;2.0 ended with&nbsp;an&nbsp;error due to&nbsp;network&nbsp;problems.","68&nbsp;&#8211; the&nbsp;command cannot be&nbsp;executed because the&nbsp;application is&nbsp;running under&nbsp;a&nbsp;policy.","128&nbsp;&#8211; unknown&nbsp;error.","65&nbsp;&#8211; all other&nbsp;errors.","Command line return codes","161378.htm");
Page[178]=new Array("Kaspersky Lab&nbsp;is a world-renowned vendor of systems protecting computers against digital threats, including viruses and other malware, unsolicited email (spam), and network and hacking attacks.","In 2008, Kaspersky Lab was rated among the world&#8217;s top four leading vendors of information security software solutions for end users (IDC Worldwide Endpoint Security Revenue by Vendor). Kaspersky&nbsp;Lab is the preferred vendor of computer protection systems for home users in Russia (IDC Endpoint Tracker 2014).","Kaspersky Lab was founded in Russia in 1997. It has&nbsp;since grown into an international group of companies with 38 offices in 33 countries. The company employs more than 3,000 skilled professionals.","Products. Kaspersky Lab products provide protection for all systems, from home computers to large corporate networks.","The personal product range includes security applications for desktop, laptop, and tablet computers, smartphones and other mobile devices.","The company offers protection and control solutions and technologies for workstations and mobile devices, virtual machines, file and web servers, mail gateways, and firewalls. The company's portfolio also features specialized products providing protection against DDoS attacks, protection for industrial control systems, and prevention of financial fraud. Used in conjunction with centralized management tools, these solutions ensure effective automated protection for companies and organizations of any size against computer threats. Kaspersky Lab products are certified by major test laboratories, compatible with software from diverse vendors, and optimized to run on many hardware platforms.","Kaspersky Lab virus analysts work around the clock. Every day they uncover hundreds of thousands of new computer threats, create tools to detect and disinfect them, and include their signatures in databases used by Kaspersky Lab applications.","Technologies. Many technologies that are now part and parcel of modern anti-virus tools were originally developed by Kaspersky&nbsp;Lab. It is no coincidence that many other developers use the Kaspersky&nbsp;Anti-Virus engine in their products, including: Alcatel-Lucent, Alt-N, Asus, BAE Systems, Blue Coat, Check Point, Cisco Meraki, Clearswift, D-Link, Facebook, General Dynamics, H3C, Juniper Networks, Lenovo, Microsoft, NETGEAR, Openwave Messaging, Parallels, Qualcomm, Samsung, Stormshield, Toshiba, Trustwave, Vertu, and ZyXEL. Many of the company&#8217;s innovative technologies are patented.","Achievements. Over the years, Kaspersky Lab has won hundreds of awards for its services in combating computer threats. Following tests and research conducted by the reputed Austrian test laboratory AV-Comparatives in 2014, Kaspersky Lab ranked among the top two vendors by the number of Advanced+ certificates earned and was ultimately awarded the Top Rated certificate. But Kaspersky Lab's main&nbsp;achievement is the loyalty of its users worldwide. The company&#8217;s products and technologies protect more than 400 million users, and its corporate clients number more than 270,000.","&nbsp;","Kaspersky Lab website:","https://www.kaspersky.com ","Virus encyclopedia:","https://securelist.com ","Virus Lab:","https://virusdesk.kaspersky.com (for analyzing suspicious files and websites)","Kaspersky Lab&#8217;s web forum:","https://forum.kaspersky.com ","&nbsp;","AO Kaspersky Lab","34744.htm");
Page[179]=new Array("Information about third-party code is&nbsp;contained in&nbsp;the&nbsp;file legal_notices.txt located in&nbsp;the&nbsp;application installation&nbsp;directory.","Information about third-party code","161380.htm");
Page[180]=new Array("Registered trademarks and service marks are the property of their respective owners.","Core is a trademark of Intel Corporation in the U.S. and/or other countries.","Linux is the registered trademark of Linus Torvalds in the U.S. and other countries.","Microsoft, Outlook, Outlook Express, and Windows are registered trademarks of Microsoft Corporation in the United States and other countries.","Novell is a registered trademark of Novell Inc. in the United States and other countries.","Oracle is a registered trademark of Oracle and/or its affiliates.","Red Hat, Red Hat Enterprise Linux, and CentOS are registered trademarks of Red Hat Inc. in the United States and other countries.","Debian is a registered trademark of Software in the Public Interest, Inc.","SUSE is a registered trademark of SUSE LLC in the United States and other countries.","Trademark notices","161381.htm");
Page[181]=new Array("A code that you receive when purchasing a license for Kaspersky Endpoint Security. This code is required for activation of the application.","The activation code is a unique sequence of twenty letters and numbers in the format xxxxx-xxxxx-xxxxx-xxxxx.","Activation code","95897.htm#o112627");
Page[182]=new Array("A key that is currently used by the application.","Active key","95897.htm#o111595");
Page[183]=new Array("A key that certifies the right to use the application but is not currently being used.","Additional key","95897.htm#o111599");
Page[184]=new Array("A set of computers that share common functions and a set of Kaspersky Lab applications installed on them. Computers are grouped so that they can be managed conveniently as a single unit. A group may include other groups. It is possible to create group policies and group tasks for each installed application in the group.","Administration group","95897.htm#o112575");
Page[185]=new Array("A component of Kaspersky Security Center that centrally stores information about all Kaspersky Lab applications that are installed within the corporate network. It can also be used to manage these applications.","Administration Server","95897.htm#o112576");
Page[186]=new Array("Databases that contain information about computer security threats known to Kaspersky Lab as of when the anti-virus databases are released. Entries in anti-virus databases allow malicious code to be detected in scanned objects. Anti-virus databases are created by Kaspersky Lab specialists and updated hourly.","Anti-virus databases","95897.htm#o111582");
Page[187]=new Array("A specialized component that provides the interface for application management through Administration Console. Each application has its own plug-in. It is included in all Kaspersky Lab applications that can be managed by using Kaspersky Endpoint Security.","Application administration plug-in","95897.htm#o112588");
Page[188]=new Array("A special storage for backup copies of files, which are created before disinfection or deletion is attempted.","Backup","95897.htm#o112592");
Page[189]=new Array("A method of processing infected objects that results in full or partial recovery of data. Not all infected objects can be disinfected.","Disinfection","95897.htm#o112629");
Page[190]=new Array("An Exclusion is&nbsp;an object excluded from the scan by a Kaspersky Lab application. You can exclude from the scan files of certain formats, file masks, a certain area (for example, a folder or a program), application processes, or objects by threat type, according to the Virus Encyclopedia classification. Each task can be assigned a set of exclusions.","Exclusion","95897.htm#o112624");
Page[191]=new Array("A situation when a Kaspersky Lab application considers a non-infected object to be infected because the object's code is similar to that of a virus.","False positive","95897.htm#o112631");
Page[192]=new Array("Representation of a file name using wildcards. The standard wildcards used in file masks are * and ?, where * represents any number of any characters and ? stands for any single character.","File mask","95897.htm#o111603");
Page[193]=new Array("A task defined for an administration group and executed on all the client computers included in that administration group.","Group task","95897.htm#o112572");
Page[194]=new Array("An object which, due to its structure or format, can be used by intruders as a &quot;container&quot; to store and spread malicious code. As a rule, these are executable files, with such file extensions as .com, .exe, and .dll. The risk of penetration of malicious code into such files is quite high.","Infectable object","95897.htm#o112644");
Page[195]=new Array("An object of which a portion of code completely matches part of the code of known malware. Kaspersky Lab does not recommend accessing such objects.","Infected object","95897.htm#o112621");
Page[196]=new Array("A list of Kaspersky Lab's HTTP and FTP servers from which the application downloads database updates to mobile devices.","Kaspersky Lab update servers","95897.htm#o112658");
Page[197]=new Array("A time-limited right to use the app, granted under the End User License Agreement.","License","95897.htm#o135751");
Page[198]=new Array("A document provided to you by Kaspersky Lab together with a key file or an activation code. This document contains information about the license provided.","License certificate","95897.htm#o166042");
Page[199]=new Array("A policy determines the settings of an application and manages the access to configuration of an application installed on computers within an administration group. An individual policy must be created for each application. You can create an unlimited number of various policies for applications installed on computers in each administration group, but only one policy can be applied to each application at a time within an administration group.","Policy","95897.htm#o111585");
Page[200]=new Array("Application settings that are common to all types of tasks and govern the overall operation of the application, such as application performance settings, report settings, and backup settings.","Program settings","95897.htm#o112587");
Page[201]=new Array("A computer network service which allows users to make indirect requests to other network services. First, a user connects to a proxy server and requests a resource (e.g., a file) located on another server. Then the proxy server either connects to the specified server and obtains the resource from it or returns the resource from its own cache (if the proxy has its own cache). In some cases, a user's request or a server's response can be modified by the proxy server for certain purposes.","Proxy-server","95897.htm#o112649");
Page[202]=new Array("The application's operating mode under which objects are scanned for the presence of malicious code in real time.","The application intercepts all attempts to open any object (read, write, or execute) and scans the object for threats. Uninfected objects are passed on to the user; objects containing threats or probably infected objects are processed according to the task settings (disinfected, deleted or quarantined).","Real-time protection","95897.htm#o112643");
Page[203]=new Array("Enables use of the application within the selected parameters (expiration date and number of devices). You can pause or resume your subscription, renew it automatically, or cancel it.","Subscription","95897.htm#o142586");
Page[204]=new Array("Functions performed by the Kaspersky Lab application are implemented as tasks, such as: Real-time file protection, Full computer scan, and Database update.","Task","95897.htm#o112579");
Page[205]=new Array("A task assigned for a set of client computers from arbitrary administration groups and performed on those hosts.","Task for specific computers","95897.htm#o112571");
Page[206]=new Array("Application settings that are specific for each task type.","Task settings","95897.htm#o112586");
Page[207]=new Array("A function performed by a Kaspersky Lab application that enables it to keep computer protection up-to-date. During the update, an application downloads updates for its databases and modules from Kaspersky Lab update servers and automatically installs and applies them.","Update","95897.htm#o111604");
var PageCount=208;
var parsedMainTitle = 'Kaspersky Endpoint Security 10 Service Pack 1 for Linux ';
(function () {
    var maxTextLength = 0;
    var fakeDiv = $('<div/>');
    var text;
    var pageSearch = _.map(Page, function (page) {
        return {
            link: page[page.length - 1],
            title: page[page.length - 2],
            text: _.map(page.slice(0, page.length - 2), function(item) {
                text = fakeDiv.html(item).text();
                maxTextLength = Math.max(maxTextLength, text.length);

                return text;
            })
        };
    });

    fakeDiv.remove();

    window.search = function (searchWord, searchWordMinLength) {
        //console.time('search');
        var result = {
            found: false,
            isInit: false,
            results: [],
            resultsCount: 0
        };

        if (searchWord !== '') {
            result.searchWord = searchWord;

            var searchLength = searchWord.length > 5 ? searchWord.length - 2 : searchWordMinLength;

            var fuseOptions = {
                //verbose: true,
                shouldSort: true,
                includeScore: true,
                includeMatches: true,
                minMatchCharLength: searchLength,
                tokenize: true,
                matchAllTokens: true,
                findAllMatches: true,
                threshold: 0.2,
                location: 0,
                distance: maxTextLength,
                keys: ['text', 'title']
            };

            var fuse = new Fuse(pageSearch, fuseOptions);
            var currentResults = fuse.search(searchWord);
            var searchRegExp = new RegExp(searchWord, 'gi');

            if (currentResults.length) {
                result.found = true;
                result.results = _.chain(currentResults)
                    // .filter(function(result) {
                    //     return result.matches.length;
                    // })
                    .map(function (result) {
                        var item = result.item;

                        return {
                            title: item.title.replace(searchRegExp, '<mark>$&</mark>'),
                            link: item.link,
                            texts: _.reduce(result.matches, function(previous, searchResult) {
                                if (searchResult.key === 'text') {
                                    previous.push(searchResult.value.replace(searchRegExp, '<mark>$&</mark>'));
                                }

                                return previous;
                            }, [])
                        }
                    })
                    .value();

                result.resultsCount = result.results.length;
            }
        }

        //console.timeEnd('search');
        return result;
    };

    /*
    #    result = {
    #        found: true
    #        isInit: false
    #        results: {
    #            "12345.htm": {
    #                {
    #                    title: 'Страница 1'
    #                    texts: [
    #                               "В этом тексте было найдено <mark>#{searchWord}</mark>",
    #                               "В этом тексте тоже было найдено <mark>#{searchWord}</mark>"
    #                           ]
    #                    link: '#'
    #                }
    #                {
    #                    title: 'Страница 8962'
    #                    texts: [
    #                               "Здесь текст, а в нём встречается <mark>#{searchWord}</mark>",
    #                               "Здесь тоже текст, и в нём тоже встречается <mark>#{searchWord}</mark>"
    #                           ]
    #                    link: '#'
    #                }
    #            }
    #        }
    #    }
    */
})();

if (typeof String.prototype.trim !== 'function') {
    String.prototype.trim = function () {
        return this.replace(/^\s+|\s+$/g, '');
    };
}

window.loadParent = function () {};

// hide content to avoid blink
window.document.documentElement.style.display = 'none';

$(function () {
    var $aside, $container, $content, $header, $modalContent, $modalHeader, $overlay, $pageTitle,
        $tooltip, $tooltipContent, tooltipButton;

    $.support.cors = true;
    $.fx.speeds._default = 200;

    var options = {
        helpers: {
            media_hv_min: 568,
            media_hv_middle: 874,
            media_mobile: 768
        },
        isMac: Boolean(window['IsMacVersion']),
        isMacProject: Boolean(window['isMacProject']),
        isIE7: Boolean(navigator.appVersion.match('MSIE 7.')),
        isIE8: Boolean(navigator.appVersion.match('MSIE 8.')),
        isIE9: Boolean(navigator.appVersion.match('MSIE 9.')),
        isIE10: Boolean(navigator.appVersion.match('MSIE 10.')),
        isOperaMini: Object.prototype.toString.call(window["operamini"]) === "[object OperaMini]",
        isFileProtocol: window.location.protocol === 'file:',
        isAllInOne: window.location.pathname.match(/(all-in-one\.htm)[l]?$/),
        searchWord: getParam('searchWord', true),
        searchWordMinLength: 3
    };

    if (window.Customization) {
        _.each(window.Localization, function(item, key) {
            if (_.isObject(window.Customization[key])) {
                window.Localization[key] = window.Customization[key].value;
            }
        });
    }

    setParam('searchWord', null, true);

    var HELP = window.HELP = $.extend(true, window.HELP, options);
    var $window = $(window);
    var html = document.documentElement;
    var $html = $(html);
    var $head = $(document.head);
    var $body = $(document.body);
    var title = $html.find('title').text();

    $body.removeClass("no-js");

    var ContainerTemplateFunction = _.template(ContainerTemplate);
    var HeaderTemplateFunction = _.template(HeaderTemplate);
    var FooterTemplateFunction = _.template(FooterTemplate);
    var AsideTemplateFunction = _.template(AsideTemplate);
    var SearchResultsTemplateFunction = _.template(SearchResultsTemplate);
    var MobileSearchResultsTemplateFunction = _.template(MobileSearchResultsTemplate);
    var LangListTemplateFunction = _.template(LangListTemplate);
    var VersionsTemplateFunction = _.template(VersionsTemplate);
    var IndexLiteralsTemplateFunction = _.template(IndexLiteralsTemplate);
    var MenuTemplateFunction = _.template(MenuTemplate);
    var AllInOneMenuTemplateFunction = _.template(AllInOneMenuTemplate);
    var CustomStylesTemplateFunction = _.template(CustomStylesTemplate);

    window.parsedMainTitle = window.parsedMainTitle || "Kaspersky Online Help";
    window.toggleBlock = toggleBlock;
    window.showAll = showAll;
    window.hideAll = hideAll;
    window.togglePopup = togglePopup;
    window.showPopup = showTooltip;
    window.hidePopup = hideTooltip;

    function getParam(param, inSession) {
        if (localStorageChecker()) {
            if (inSession && window.sessionStorage) {
                return window.sessionStorage.getItem(param);
            }

            return store(param);
        }

        return null;
    }

    function setParam(param, value, inSession) {
        if (localStorageChecker()) {
            if (value === void 0) {
                value = null;
            }

            if (inSession && window.sessionStorage) {
                if (value === null) {
                    window.sessionStorage.removeItem(param);
                } else {
                    window.sessionStorage.setItem(param, value);
                }
            } else {
                store(param, value);
            }
        }
    }

    function toggleBlock(id) {
        if (!HELP.isAllInOne) {
            var $block = $('#d' + id);
            var $toggler = $('#h' + id);

            if ($block.length > 0 && $toggler.length > 0) {
                $block.slideToggle();
                $toggler.toggleClass('is-expanded');
                $window.resize();
            }
        }
    }

    function showAll() {
        $('.expandingblock').slideDown();
        $('.expandingblocktemplate').addClass('is-expanded');
        $window.resize();
    }

    function hideAll() {
        $('.expandingblock').slideUp();
        $('.expandingblocktemplate').removeClass('is-expanded');
        $window.resize();
    }

    function togglePopup(id, legacyblockname, show) {
        switch (show) {
            case true:
                showTooltip(id, legacyblockname);
                break;
            case false:
                hideTooltip();
                break;
            default:
                toggleTooltip(id, legacyblockname);
        }
    }

    function calcTooltipPosition() {
        if (tooltipButton) {
            var body = document.body;
            var delta = 30;
            var offset = 10;

            if (options.isIE7 || options.isIE8) {
                offset = 0;
            }

            var bodyHeight = body.clientHeight;
            var bodyWidth = body.clientWidth;
            var linkRect = tooltipButton.getBoundingClientRect();
            var tooltip = $tooltip[0];
            var isToTop = linkRect.top > bodyHeight - linkRect.bottom;
            var isToLeft = linkRect.left > bodyWidth - linkRect.right;
            var coords = {
                top: isToTop ? "" : linkRect.bottom + offset,
                bottom: isToTop ? bodyHeight - linkRect.top + offset : "",
                left: isToLeft ? "" : linkRect.left - delta,
                right: isToLeft ? bodyWidth - linkRect.right - delta : ""
            };

            $tooltip.toggleClass("is-to-top", isToTop).toggleClass("is-to-left", isToLeft).css(coords);

            var tooltipRect = tooltip.getBoundingClientRect();
            coords = {};

            var isOverlapLeft = tooltipRect.left < delta;
            var isOverlapRight = tooltipRect.right > bodyWidth - delta;

            if (isOverlapLeft) {
                coords.left = delta;
            }

            if (isOverlapRight) {
                coords.right = delta;
            }

            if (isOverlapLeft || isOverlapRight) {
                coords.width = "auto";
            } else {
                coords.width = "";
            }

            $tooltip.css(coords);
            tooltipRect = tooltip.getBoundingClientRect();
            coords = {};

            var isOverlapTop = tooltipRect.top < delta;
            var isOverlapBottom = tooltipRect.bottom > bodyHeight - delta;

            if (isOverlapTop) {
                coords.top = delta;
            }

            if (isOverlapBottom) {
                coords.bottom = delta;
            }

            $tooltip.css(coords);
            if (options.isIE7 || options.isIE8) {
                return $tooltip.height(Math.min($tooltipContent[0] != null ? $tooltipContent[0].scrollHeight : void 0, 200));
            }
        }
    }

    function calcHomeBtnVisibility($viewport) {
        return setTimeout(function () {
            var $homeBtn = $viewport.find('.bt-home');

            var calcHeight;
            if ($homeBtn.hasClass('is-shown')) {
                var btn = $homeBtn[0];
                var style = btn.currentStyle || window.getComputedStyle(btn);
                calcHeight = btn.offsetHeight + parseInt(style.marginTop) + parseInt(style.marginBottom);
            } else {
                calcHeight = 0;
            }

            var showBtn = $viewport[0].offsetHeight < $viewport[0].scrollHeight - calcHeight;

            $homeBtn.toggleClass('is-shown', showBtn);
        }, 400);
    }

    function verifyMenuVisiblity($asidePlaceholder) {
        if (window.matchMedia) {
            var mq = window.matchMedia('screen and (max-width: 767px)');

            if (!mq.matches) {
                //$asidePlaceholder.removeClass('is-hidden');
            } else {
                $('.js-tab-link').eq(0).click();
            }
        }
    }

    function showTooltip(id, btnId) {
        if ($tooltip.data("id") !== id) {
            var content = document.getElementById("d" + id).innerHTML;
            $tooltip.data("id", id);
            $tooltipContent.html(content);
        }

        tooltipButton = document.getElementById(btnId);
        $tooltip.show();

        calcTooltipPosition();
    }

    function hideTooltip() {
        return $tooltip.hide();
    }

    function toggleTooltip(id, btnId) {
        if ($tooltip.data("id") !== id || $tooltip.css("display") === "none") {
            showTooltip(id, btnId);
        } else {
            hideTooltip();
        }
    }

    function bindEvents() {
        var $asidePlaceholder = $('.js_aside_placeholder');
        var $menuItems = $('.js_menu_item');
        var $mobileSearch = $('.js_mobile_search_result');
        var $viewport = $('.js_main');
        var mobileMenuToggle = function (button) {
            if (!$mobileSearch.hasClass('is-hidden')) {
                $mobileSearch.addClass('is-hidden');
            }

            $asidePlaceholder.toggleClass('is-active');
            $(button).toggleClass('is-active');
        };

        $('.js_burger').on('click', function (event) {
            event.preventDefault();
            mobileMenuToggle(this);
        });

        $body.on('click', '.js_mobile_menu_deeper', function (event) {
            event.preventDefault();
            mobileMenuShowItem($(this).data('id'));
        });

        $body.on('click', '.bt-home', function (event) {
            event.preventDefault();

            $(".js_content, .js_main").animate({
                scrollTop: 0
            }, '500', 'swing');
        });

        $body.on('click', '.js-tab-link', function () {
            if (!$(this).hasClass('js_search_tab')) {
                delete HELP.searchWord;
                setParam('searchWord', null, true);
            }
        });

        $window.on('resize', function () {
            calcTooltipPosition();
            calcHomeBtnVisibility($('.js_main'));
            verifyMenuVisiblity($asidePlaceholder);
            calcAsideWidth($asidePlaceholder);
        });

        $viewport.on("scroll", calcTooltipPosition);

        $body.on('click', 'a', function (event) {
            var $self = $(this);
            var url = $self.attr('href');

            if (HELP.isAllInOne) {
                if (url) {
                    var hash = url.match( /(.*)\.html?$/ );
                    if (hash && hash[1]) {
                        scrollToHash(hash[1]);

                        if (window.history && window.history.pushState) {
                            window.history.pushState({
                                url: url,
                                hash: hash[1]
                            }, document.title, location.pathname + '#' + hash[1]);
                        }

                        event.stopPropagation();
                        event.preventDefault();

                        trackPage();

                        return;
                    }
                }
            }

            if (window.matchMedia) {
                var mq = window.matchMedia('screen and (max-width: 767px)');
                if (mq.matches) {
                    var toggleSiblings = $self.siblings('.js_contents_toggle');
                    if (toggleSiblings.length > 0 && !$self.hasClass('js_menu_link_direct')) {
                        toggleSiblings.trigger('click');
                        event.preventDefault();
                        return;
                    }
                }
            }

            if (url && url !== '#') {
                var localUrlRegExp = /([\w_]+\.htm)[l]?(#[\w]+(.htm))?/i;
                var urlMatches = url.match(localUrlRegExp);
                var isLocalUrl = Boolean(urlMatches && urlMatches[2] && urlMatches[3]);
                var isLocalAnchor = urlMatches && urlMatches[2] && !urlMatches[3];

                if ($self.closest('.js_search_result_wrapper')) {
                    setParam('searchWord', HELP.searchWord, true);
                }

                if (localStorageChecker()) {
                    var $view = $('.js_tabs_viewport');

                    if ($view.length) {
                        window['localStorage']['asideScrollPosition'] = $view[0].scrollTop;
                    }

                    var $opened_menus = $('.js_contents_toggle.is-toggled+.js_menu_link');

                    if ($opened_menus.length) {
                        window['localStorage']['openedMenus'] = _.map($opened_menus, function (a) {
                            return $(a).attr('href');
                        });
                    }
                }

                if (isLocalUrl) {
                    if ($tooltip) {
                        $tooltip.hide();
                    }

                    var targetUrl = url;
                    var titlePageMatch = location.pathname.match(/(title\.htm)[l]?$/);

                    //if (titlePageMatch && titlePageMatch[1] === "title.htm") {
                    if (HELP.isMacProject) {
                        targetUrl = "./pgs/" + urlMatches[2].slice(1);
                        if (HELP.isFileProtocol) {
                            $self.attr('href', targetUrl);
                        }
                    }

                    if (!HELP.isFileProtocol) {
                        event.preventDefault();

                        setNavigation(HELP.isMacProject ? urlMatches[2].slice(1) : url);

                        loadContent(targetUrl, true, null, url);

                        if (window.matchMedia && mq && mq.matches) {
                            $('.js_aside_placeholder').removeClass('is-active');
                            $('.js_burger').removeClass('is-active');
                            $('.js_mobile_aside').addClass('is-hidden');
                        }

                        $('.js_home').toggleClass('is-active', HELP.nav.home.url === HELP.nav.currentPage.url);
                    }
                } else if (isLocalAnchor) {
                    if (window.matchMedia && mq && mq.matches) {
                        $('.js_aside_placeholder').removeClass('is-active');
                        $('.js_burger').removeClass('is-active');
                        $('.js_mobile_aside').addClass('is-hidden');
                    }
                } else if ($self.hasClass('hyperlinktemplate') && url.indexOf('mailto') !== 0) {
                    if (window.confirm(HELP.localization.ExternalLinkText)) {
                        return;
                    }

                    event.preventDefault();
                }
            } else {
                event.preventDefault();
            }
        });

        $body.on('click', '.js_menu_link, .js_menu_link_direct', function () {
            var $self = $(this);
            delete HELP.searchWord;
            setParam('searchWord', null, true);

            if (!$self.prev().hasClass('js_contents_toggle')) {
                $menuItems.removeClass('is-active');
            }

            $self.children('.js_contents_toggle').addClass('is-toggled').siblings('.js_contents_level').slideDown();
            $self.closest('.js_menu_item').addClass('is-active');

            var href = $self.attr('href');
            var topicRegExp = /[\w_]+\.htm/;
            var hashRegExp = /#([\w_]+)/;

            if (href.indexOf('#') > -1) {
                var locationMatch = location.pathname.match(topicRegExp);
                var hrefMatch = href.match(topicRegExp);
                var hash = href.match(hashRegExp)[1];
                event.preventDefault();

                if (!(locationMatch.length && hrefMatch.length && locationMatch[0] === hrefMatch[0])) {
                    loadContent(href, true, function() {
                        if (hash) {
                            scrollToHash(hash);
                        }
                    });
                }

                if (hash) {
                    scrollToHash(hash);

                    if (!HELP.isMacProject && window.history && window.history.pushState) {
                        window.history.pushState({
                            url: href,
                            hash: hash
                        }, document.title, href);
                    }
                }
            }
        });

        $body.on('click', '.js_home_link', function () {
            $('.js-tab-link').eq(0).trigger('click');
        });

        $(window).on('popstate', function (event) {
            var state = event.originalEvent.state;

            if (state && state.url) {
                if (!HELP.isAllInOne) {
                    loadContent(state.url, false, scroll, state.originalUrl);
                    setNavigation(state.url);
                } else {
                    scroll();
                    trackPage();
                }
            }

            function scroll() {
                if (state.hash) {
                    $(".js_menu_item").removeClass('is-active');
                    var $menuItem = $(".js_menu_link[href='" + state.hash + ".htm']").closest('.js_menu_item');
                    autoScrollContents($menuItem);

                    scrollToHash(state.hash);
                }
            }
        });

        $body.on('click', '.js_modal_close', function () {
            $overlay.removeClass('is-visible');
        }).on('click', '.js_overlay', function (event) {
            if (!$(event.target).closest('.js_modal').length) {
                $overlay.removeClass('is-visible');
            }
        });

        $body.on('click', '.js_print_section', function() {
            var currentUrl = window.location.pathname.match(/\/(\w+\.\w+)$/)[1];
            //window.location.href = 'all-in-one.htm?sectionUrl=' + currentUrl;
            window.open('all-in-one.htm?sectionUrl=' + currentUrl);
        });

        if (!HELP.isAllInOne) {
            var xStart = null;
            var yStart = null;

            $body.on('touchstart', '.js_content', function(event) {

                var tableInTopic = $(event.target).closest('.tableintopic');
                if (tableInTopic.length && tableInTopic.width() > tableInTopic.parent().width()) {
                    return;
                }

                var touch = event.originalEvent.touches[0];
                if (touch) {
                    xStart = touch.clientX;
                    yStart = touch.clientY;
                }
            });

            $body.on('touchmove', '.js_content', function(event) {
                if (!xStart || !yStart) {
                    return;
                }

                var touch = event.originalEvent.touches[0];
                var xEnd = touch.clientX;
                var yEnd = touch.clientY;
                var xDiff = xStart - xEnd ;
                var yDiff = yStart - yEnd;

                if (Math.abs(xDiff) > Math.abs(yDiff) && Math.abs(xDiff) > 50) {
                    if (xDiff > 0 && HELP.nav.nextPage) {
                        $('.js_container').addClass('is-loading');
                        $('.js_main').addClass('swipe-left');
                        setTimeout(function () {
                            $('.js_next_link').click();
                        }, 350);
                    } else if(xDiff < 0 && HELP.nav.prevPage) {
                        $('.js_container').addClass('is-loading');
                        $('.js_main').addClass('swipe-right');
                        setTimeout(function () {
                            $('.js_prev_link').click();
                        }, 350);
                    }

                    xStart = null;
                    yStart = null;
                }
            });
        }
    }

    /*
    #* Языки в хэдере --------------------------------------------------------------------------------------------------
     */
    function loadLangs() {
        if (!window.Langs) {
            $('.js_selector_mobile_langs').remove();
            return;
        }

        var currentId = 'no id';
        var currentName = 'no name';
        var locLangs = window.LangsLocalization;

        window.Langs.forEach(function(item) {
            if (locLangs && locLangs[item.id]) {
                item.name = locLangs[item.id];
            }

            if (item.id === document.documentElement.lang) {
                HELP.currentLangId = currentId = item.id;
                HELP.currentLangCode = currentName = item.name;

                if (~['ja-JP', 'ko-KR', 'zh-Hans', 'zh-Hant'].indexOf(HELP.currentLangId)) {
                    HELP.searchWordMinLength = 2;
                }
            }
        });

        if (window.Langs.length < 2) {
            $('.js_selector_mobile_langs').remove();
            return;
        }

        var isMac = Boolean(window.location.pathname.match(/pgs\/[\w_\.]+/));
        var isMacTitle = Boolean(window.location.pathname.match(/title\.html?$/));
        var LangListHtml = LangListTemplateFunction({
            langs: window.Langs,
            currentLang: {
                name: currentName,
                id: currentId
            },
            localization: HELP.localization,
            isMac: isMac,
            isMacTitle: isMacTitle
        });

        $header.find('.js_header_lang_list').html(LangListHtml);
        $('.js_selector_mobile_langs').html(LangListHtml).find('.js_dropdown').addClass('dropdown_large');

        $body.on('click', '.js_lang_item', function (event) {
            event.preventDefault();

            var $element = $(this);
            var langId = $element.data('lang-id');
            var path = window.location.pathname;
            var currentFolder = window.location.pathname.match(/([\w]+|[\w\.-]+)(\/pgs)?\/[\w_]+.html?/)[1];

            window.location.href  = path.replace("/" + currentFolder + "/", "/" + langId + "/");
        });
    }

    function triggerSearch() {
        if (HELP.helpers.searchTimeout) {
            clearTimeout(HELP.helpers.searchTimeout);
        }

        HELP.helpers.searchTimeout = setTimeout(function () {
            var searchWord = $('.js_search_text').val().trim();

            if (searchWord.length < HELP.searchWordMinLength) {
                delete HELP.searchWord;
                setParam('searchWord', null, true);

                searchWord = null;

                $('.js-menu-content, .js_search').show();
                $('.js-search-content, .js_search_clear').hide();
            } else {
                HELP.searchWord = searchWord;
                setParam('searchWord', searchWord, true);

                var resultObj = search(searchWord, HELP.searchWordMinLength);
                resultObj.localization = HELP.localization;
                resultObj.isMacProject = HELP.isMacProject;

                var searchResultsHtml = SearchResultsTemplateFunction(resultObj);

                $('.js-menu-content, .js_search').hide();
                $('.js-search-content, .js_search_clear').show();
                //$('.js_search_tab').trigger('click');

                $('.js_search_result_wrapper').html(searchResultsHtml);
            }
        }, 300);
    }

    /*
    #* Левое меню ------------------------------------------------------------------------------------------------------
     */
    function loadMenu(menu) {
        if (!window['Toc']) {
            return;
        }

        var flatMenu = [];
        var currentUrl = HELP.isAllInOne || HELP.isMacProject ?
            /#([\w_]+)/.exec(location.hash) : /\/([\w_]+\.\w+$)/.exec(location.pathname);
        var currentPage = {};
        var currentLevel, parentPage;

        if (currentUrl && currentUrl[1]) {
            currentUrl = currentUrl[1];
        }

        function buildMenu(menu, level, parentId) {
            var isCurrentMenuLevelActive;
            level = level || 0;

            _.each(menu, function (item) {
                item.level = level;
                if (item.url && item.url.match(/#|(title\.html?)/)) {
                    return;
                }

                if (item.hidden) {
                    return;
                }

                flatMenu.push(item);

                if (item.url === currentUrl || item.url === currentUrl + '.htm') {
                    item.isActive = true;
                    currentPage = item;
                    currentLevel = level;
                }

                if (item.children) {
                    item.childIsActive = buildMenu(item.children, level + 1, item.id);
                }

                if (item.isActive || item.childIsActive) {
                    isCurrentMenuLevelActive = true;
                }

                if (level > 0 && parentId) {
                    return item.parentId = parentId;
                }
            });

            return isCurrentMenuLevelActive;
        }

        buildMenu(menu);

        var i, j, ref, item, prevSection, nextSection;
        for (i = j = 0, ref = flatMenu.length - 1; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
            item = flatMenu[i];
            if (item.url === currentUrl || item.url === currentUrl + '.htm') {
                if (i > 0) {
                    prevSection = flatMenu[i - 1];
                }

                if (i !== flatMenu.length - 1) {
                    nextSection = flatMenu[i + 1];
                }
            }
        }

        if (!currentPage.url) {
            nextSection = flatMenu[0];
        }

        window.HELP = $.extend(true, window.HELP, {
            nav: {
                menu: menu,
                flatMenu: flatMenu,
                home: flatMenu[0],
                currentPage: currentPage,
                currentLevel: currentLevel,
                parentPage: parentPage,
                prevPage: prevSection,
                nextPage: nextSection
            }
        });

        var $homeBtn = $body.find('.js_home');
        var $homeBtnLink = $homeBtn.find('.js_home_link');

        if (HELP.nav.home) {
            $homeBtnLink.attr('href', HELP.nav.home.url);
        }

        if (HELP.isAllInOne) {
            $(window).on('load', function() {
                setTimeout(function() {
                    scrollToHash(currentUrl);
                });
            });
        }

        buildLinks($container);

        var MenuHtml = MenuTemplateFunction({
            menu: menu,
            localization: HELP.localization,
            isMacProject: HELP.isMacProject
        });

        $aside.find('.js_menu').html(MenuHtml);

        $('.js_search_text').on('keyup', function (event) {
            if (event.keyCode === 27) {
                $('.js-tab-link').eq(0).click();
                $(this).val('');
            } else {

            }
            triggerSearch();
        });

        $('.js_search_clear').on('click', function () {
            $('.js_search_text').val('');
            triggerSearch();
        });

        $('.js_mobile_search_button').on('click', function () {
            var $this = $(this);
            var $result = $('.js_mobile_search_result');
            var $input = $('.js_mobile_search_input');
            var $clearBtn = $('.js_mobile_search_clear');
            var isShow = !$input.hasClass('is-hidden');

            if (isShow) {
                if ($input.val().length > 0) {
                    var searchWord = $input.val().trim();
                    var resultObj = search(searchWord, HELP.searchWordMinLength);

                    resultObj.localization = HELP.localization;
                    resultObj.isMacProject = HELP.isMacProject;
                    var mobileSearchResultsHtml = MobileSearchResultsTemplateFunction(resultObj);

                    $result.html(mobileSearchResultsHtml).removeClass('is-hidden').addClass('is-active');

                    setTimeout(function () {
                        $('.js_aside_placeholder').removeClass('is-active');
                        $('.js_burger').removeClass('is-active');
                    });
                } else {
                    $result.removeClass('is-active').addClass('is-hidden');
                }

                /*$this.removeClass('is-active');
                $input.addClass('is-hidden');
                $clearBtn.addClass('is-hidden');*/
            } else {
                $input.removeClass('is-hidden');
                $clearBtn.removeClass('is-hidden');
                $this.addClass('is-active');

                if (!$result.is(':empty')) {
                    $result.removeClass('is-hidden').addClass('is-active');
                }

                setTimeout(function () {
                    $input.focus();
                }, 100);
            }
        });

        $('.js_mobile_search_clear').on('click', function () {
            var $searchBtn = $('.js_mobile_search_button');
            var $result = $('.js_mobile_search_result');
            var $input = $('.js_mobile_search_input');

            if ($input.val().length > 0) {
                $input.val('');
                HELP.searchWord = null;
                setParam('searchWord', null, true);

                $result.empty();
            }

            $searchBtn.removeClass('is-active');
            $result.addClass('is-hidden');
            $input.addClass('is-hidden');
            $(this).addClass('is-hidden');
        });

        var triggerMobileSearch = _.debounce(function() {
            $('.js_mobile_search_button').trigger('click');
        }, 350);

        $('.js_mobile_search_input').on('keyup', function (event) {
            if (event.keyCode === 13) {
                $('.js_mobile_search_button').trigger('click');
            // } else {
            //     triggerMobileSearch();
            }
        });

        $('.js_contents_toggle').on('click', function (event) {
            event.preventDefault();

            var $toggler = $(this);
            $toggler.toggleClass('is-toggled');

            if ($toggler.hasClass('is-toggled')) {
                $toggler.siblings('.contents').slideDown();
            } else {
                $toggler.siblings('.contents').slideUp();
            }
        });

        $('.js_dropdown_btn').on('click', function (event) {
            event.preventDefault();

            var $list = $(this).siblings('.js_dropdown_list');

            $list.css({
                maxHeight: html.clientHeight - $list.offset().top - this.clientHeight
            }).toggleClass('dropdown__list--opened');

            $body.on('click.dropdown', function (event) {
                if (!$(event.target).closest('.js_dropdown').length) {
                    $list.toggleClass('dropdown__list--opened');
                    $body.off('click.dropdown');
                }
            });
        });

        bindEvents();
    }

    function loadContent(url, saveToHistory, callback, originalUrl) {
        if (saveToHistory == null) {
            saveToHistory = true;
        }

        var loadingTimeout = setTimeout(function () {
            $('.js_container').addClass('is-loading');
        }, 300);

        $.ajax(url, {
            crossDomain: true,
            dataType: "html",
            success: function (response) {
                if (saveToHistory && window.history && window.history.pushState) {
                    window.history.pushState({
                        url: url,
                        originalUrl: originalUrl
                    }, null, originalUrl || url);
                }

                var frameHtml = processHtml(response);
                var langMatches = frameHtml.match(/\slang="(.+?)"/);

                if ((langMatches != null ? langMatches.length : void 0) > 1 && langMatches[1] !== HELP.currentLangId) {
                    window.location = HELP.isMacProject ? originalUrl : url;
                    return;
                }

                var $cont = $(frameHtml).filter('.cont');
                $content.html($cont);

                $(".js_content, .js_main").animate({
                    scrollTop: 0
                }, '200', 'swing');

                title = $cont.find('.heading1, .heading2, .heading3, .heading4').first().text();
                document.title = title;
                $(".js_menu_item").removeClass('is-active');

                var scrollToUrl = HELP.isMacProject ? originalUrl : url || HELP.nav.currentPage.url;
                var $menuItem = $(".js_menu_link[href='" + scrollToUrl + "']").closest('.js_menu_item');
                var $index = $('.js_index_literals');
                var $indexLinks = $index.find('.indexlink > a');
                $indexLinks.removeClass('is-active').filter("[href='" + url + "']").addClass('is-active');

                autoScrollContents($menuItem);
                processContent($container);

                if (loadingTimeout) {
                    clearTimeout(loadingTimeout);
                }

                if (callback && typeof callback === 'function') {
                    callback();
                }

                $('.js_container').removeClass('is-loading');
                $('.js_main').removeClass('swipe-left swipe-right');

                trackPage();
            },
            error: function () {
                window.history.back();
                return window.location = url;
            }
        });
    }

    function processHtml(content, menu) {
        if (menu) {
            var AllInOneMenuHtml = AllInOneMenuTemplateFunction({
                menu: menu,
                localization: HELP.localization
            });
            var resultContent = $();

            menu.forEach(getContent);

            function getContent(item) {
                resultContent = resultContent.add('#' + item.o + ', [name=' + item.o + ']');

                if (item.children) {
                    item.children.forEach(getContent);
                }
            }

            content = AllInOneMenuHtml + $('<div/>').html(resultContent).html();
        }

        if (typeof content === 'string') {
            content = content.replace(/[™®]|&reg;|&#8482;|&#174;/g, '');

            if (HELP.isMacProject) {
                content = content.replace(/"title.htm#([\w]+.htm)"/gi,'"index.htm#$1"');
            }

            if (HELP.searchWord) {
                var searchRegExp = new RegExp(escapeRegExp(HELP.searchWord) + '(?!([^<]+)?>)', "ig");
                content = content.replace(searchRegExp, "<mark>$&</mark>");
            }
        }

        return content;
    }

    function processContent($container) {
        $container.find('.links').remove();
        buildLinks($container);

        $container.find('.cont').toggleClass('mactitlepage', Boolean(location.pathname.match(/title\.htm/)));
        $container.find('style').remove();

        if (!HELP.isAllInOne) {
            $container.find('.popuponclick, .expandingblock').each(function () {
                var $self = $(this);
                var $toggler = $($self.attr('id').replace('d', '#h'));

                if ($toggler.length > 0) {
                    var $wrapper = $toggler.closest(".settingdescr");

                    if ($wrapper.length === 0) {
                        $wrapper = $toggler.parent();
                    }

                    $wrapper.append($self);

                    if ($self.hasClass('expandingblock')) {
                        $wrapper.addClass('expandingblock-wrapper');

                        var img = $toggler.next('img');

                        if (img.length) {
                            $toggler.append(img);
                        }
                    }
                }
            });
        }

        $container.find('.cont [title]').each(function(index, item) {
            var classes = item.className;
            var $item = $(item);

            if (!$item.is('img') &&
                classes.indexOf('hyperlinktemplate') === -1 &&
                classes.indexOf('crossreferencetemplate') === -1) {
                $item.removeAttr('title');
            }
        });

        $container.find('.hyperlinktemplate').each(function() {
            var $self = $(this);
            var $siblingLink = $self.next('span').find('.hyperlinktemplate');

            if ($siblingLink.length) {
                var text = $siblingLink.text();
                $self.append($siblingLink.parent().text(text));
            }
        });

        var $tables = $container.find(".tableintopic");
        $tables.wrap("<div class='tableintopic-wrapper'/>");
        var $tableRows = $tables.find('tr');
        $tableRows.filter(':nth-child(2n)').addClass('is-even');
        $tableRows.filter(':nth-child(2n+1)').addClass('is-odd');

        $container.find('.popuponhover, .popuponclick').each(function () {
            var $self = $(this);
            var $toggler = $($self.attr('id').replace('d', '#h'));

            if ($toggler.length > 0) {
                return $toggler.wrap("<div class='link-wrapper'/>").after($self);
            }
        });

        $container.find('.js_feedback_link').attr('href', getMailtoLink());

        $container.find('.program').each(function(index, item) {
            var $item = $(item);
            if (!$item.parent().hasClass('js_code')) {
                var siblings = $(item).nextUntil(':not(.program)').addBack();

                if (siblings.length > 1) {
                    siblings.wrapAll('<div class="js_code"></div>');
                    siblings.after('\n');
                }
            }
        });

        $container.find('.exampleheading, .examplebodytext, .exampleheadingblue2015, .examplebodytextblue2015')
            .parent().each(function(index, item) {
                $(item).addClass('example-wrapper');
            });

        setTimeout(function() {
            $container.find('.js_code').each(function(index, item) {
                window.hljs.highlightBlock(item);
            });
        });

        $window.resize();
    }

    function buildLinks($container) {
        $pageTitle = $container.find('.heading1, .heading2, .heading3, .heading4').first();
        var $homeBtn = $container.find('.bt-home');
        var $prevBtnPlaceholder = $container.find('.js_prev_btn_placeholder');
        var $nextBtnPlaceholder = $container.find('.js_next_btn_placeholder');
        var PageTitleTemplateFunction = _.template(PageTitleTemplate);
        var BottomLinksTemlateFunctions = _.template(BottomLinksTemplate);
        var NextLinkTemplateTemlateFunctions = _.template(NextLinkTemplate);
        var PrevLinkTemplateTemlateFunctions = _.template(PrevLinkTemplate);

        if (HELP.nav) {
            var PageTitleHtml = PageTitleTemplateFunction({
                titleHtml: $pageTitle.html(),
                localization: HELP.localization
            });

            $pageTitle.html(PageTitleHtml);

            if (!HELP.isAllInOne) {
                var NextLinkHtml = NextLinkTemplateTemlateFunctions({
                    nextPage: HELP.nav.nextPage,
                    isMacProject: HELP.isMacProject
                });

                var PrevLinkHtml = PrevLinkTemplateTemlateFunctions({
                    prevPage: HELP.nav.prevPage,
                    isMacProject: HELP.isMacProject
                });

                $prevBtnPlaceholder.html(PrevLinkHtml);
                $nextBtnPlaceholder.html(NextLinkHtml);

                if ($homeBtn.length === 1) {
                    $homeBtn = $homeBtn.first();

                    var BottomLinksHtmls = BottomLinksTemlateFunctions({
                        homeBtnHtml: $homeBtn[0].outerHTML,
                        localization: HELP.localization,
                        serviceInfo: {
                            id:  HELP.isMacProject ? window.location.hash.slice(1) : window.location.pathname.match(/\/(\w+)\.htm/)[1],
                            reviewDate: window.reviewDate ? (new Date(window.reviewDate)).toLocaleString(HELP.currentLangId, {
                                year: 'numeric',
                                month: 'short',
                                day: 'numeric'
                            }) : null
                        }
                    });

                    $homeBtn.replaceWith(BottomLinksHtmls);
                }
            } else {
                $('.js_all_in_one_header').text(HELP.localization.TableOfContents);
            }
        }
    }

    function autoScrollContents($target, animateSpeed) {
        if (animateSpeed == null) {
            animateSpeed = 2;
        }

        if (!$target || !$target.length) {
            return;
        }

        var $view = $('.js_tabs_viewport');
        var $menuItem = $view.find('.js-menu-content:not(.is-hidden)').find($target);

        if (!$menuItem.length || !$view.length) {
            return;
        }

        var targetTop;
        if (localStorageChecker() && window['localStorage']['asideScrollPosition'] !== void 0) {
            targetTop = window['localStorage']['asideScrollPosition'];
            setParam('asideScrollPosition', null);
            var isFromLocalStorage = true;
        } else {
            var view = $view[0];
            var delta1 = view.clientHeight / 5;
            var delta2 = view.clientHeight / 4;
            var isOverBottom = $menuItem.offset().top > view.clientHeight + $view.offset().top - delta1;
            var isOverTop = $menuItem.offset().top < $view.offset().top + delta1 + $menuItem[0].offsetHeight;
            var targetDelta;
            if (isOverBottom) {
                targetDelta = $menuItem.offset().top - $view.offset().top - view.clientHeight + delta2;
            } else if (isOverTop) {
                targetDelta = $menuItem.offset().top - $view.offset().top - delta2 - $menuItem[0].offsetHeight;
            }
            targetTop = view.scrollTop + targetDelta;
        }

        var scrollingDuration = Math.min(animateSpeed * Math.abs(targetDelta), 1500);
        if (isFromLocalStorage || isOverTop || isOverBottom) {
            $view.animate({
                scrollTop: targetTop
            }, scrollingDuration, 'swing');
        }

        $menuItem
            .addClass('is-active')
            .parents('.js_contents_level')
            .add($menuItem.children('.js_contents_level'))
            .slideDown()
            .siblings('.js_contents_toggle')
            .addClass('is-toggled');
    }

    function loadVersions() {
        var url = window.location.pathname.split('/');
        var productKey = url[1];
        var currentVersionUrl = url[2];
        var product =
            _.findWhere(HELP.localization.products_b2c, {url: productKey}) ||
            _.findWhere(HELP.localization.products_b2b, {url: productKey});
        var $productLogo = $('.js_product_logo');

        if (!product) {
            return;
        }

        $productLogo.addClass('top-bar__product_' + product.icon);

        var currentVersion;
        _.some(product.versions, function(item) {
            if (item.url.split('/')[0] === currentVersionUrl) {
                currentVersion = item;
                return true;
            }
            return false;
        });

        if (currentVersion && product.versions.length > 1) {
            var VersionsResultsHtml = VersionsTemplateFunction({
                currentVersion: currentVersion,
                versions: product.versions
            });

            $header.find('.js_header_versions_list').html(VersionsResultsHtml);
            $('.js_selector_mobile_versions')
                .html(VersionsResultsHtml).find('.js_dropdown').addClass('dropdown_large');

            $header.on('click', '.js_version_item', function (event) {
                event.preventDefault();

                var versionUrl = $(this).data('version-url');
                /*var path = window.location.pathname.split('/');
                var currentPage = path[path.length - 1];

                window.location.href  = '/' + productKey + '/' + versionUrl + '/' + currentPage;*/
                window.location.href = '/' + productKey + '/' + versionUrl;
            });
        } else {
            $('.js_selector_mobile_versions').remove();
        }
    }

    function calcAsideWidth(aside) {
        aside.children().width(aside.width());
    }

    function getMailtoLink() {
        return 'mailto://?subject=Shared from Kaspersky Online Help: "' +
            window.parsedMainTitle + ' - ' + window.document.title + '"&body=' + window.parsedMainTitle +
            ' - ' + window.document.title + '%0A' + window.location.href;
    }

    function findSection(menuList, sectionUrl) {
        var result =[];

        menuList.forEach(function(item) {
            if (item.url === sectionUrl) {
                result.push(item);
            } else if (item.children) {
                result = result.concat(findSection(item.children, sectionUrl));
            }
        });

        return result;
    }

    function scrollToHash(hash) {
        var $target = $("[name='" + hash + "'], #" + hash);
        var $main = $('.js_main');

        if ($target.length) {
            $main.animate({
                scrollTop: $target[0].offsetTop - $main[0].offsetTop
            }, '500', 'swing');

            document.documentElement.scrollTop = 0;
        }
    }

    function escapeRegExp(text) {
        return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    }

    function localStorageChecker() {
        // localstorage & sessionstorage falls with error in EDGE for local files
        try {
            return Boolean(window.localStorage);
        } catch (e) {
            return false;
        }
    }

    function trackPage() {
        if (window._gaq) {
            window._gaq.push(['_trackPageview', location.pathname + location.search + location.hash]);
        }
    }

    function setNavigation(url) {
        _.each(HELP.nav.flatMenu, function (item, index) {
            if (item.url === url) {
                HELP.nav.currentPage = item;

                if (index > 0) {
                    HELP.nav.prevPage = HELP.nav.flatMenu[index - 1];
                } else {
                    HELP.nav.prevPage = null;
                }

                if (index !== HELP.nav.flatMenu.length - 1) {
                    HELP.nav.nextPage = HELP.nav.flatMenu[index + 1];
                } else {
                    HELP.nav.nextPage = null;
                }
            }
        });
    }

    /*
    #* Первичный рендеринг --------------------------------------------------------------------------------------------------
     */
    function firstRender() {
        var $footer, $menuItem, arrOpenedMenus, i, j;
        var sectionUrl = location.search.split('sectionUrl=')[1];
        var menu = window['Toc'];

        if (sectionUrl) {
            menu = findSection(menu, sectionUrl);
        }

        HELP.localization = window.Localization || {};
        HELP.customization = window.Customization || {};
                
        $html.toggleClass('ie7', HELP.isIE7).toggleClass('ie8', HELP.isIE8)
             .toggleClass('ie9', HELP.isIE9).toggleClass('ie10', HELP.isIE10)
             .toggleClass('is-opera-mini', HELP.isOperaMini)
             .toggleClass('is-offline', HELP.isFileProtocol);

        if (window['HelpViewer'] !== void 0 && window.sessionStorage && JSON.parse && window.sessionStorage.getItem('isTOCHidden') && JSON.parse(window.sessionStorage.getItem('isTOCHidden'))) {
            $html.removeClass('is-menu-shown');
        }

        if (location.hostname === 'localhost' || location.hostname === 'stage.help.kaspersky.com') {
            $html.addClass('is-test-mode');
        }

        var containerHtml = ContainerTemplateFunction({
            localization: HELP.localization
        });

        var parsedMainTitle = window.parsedMainTitle;
        if (parsedMainTitle.indexOf('Kaspersky') === 0) {
            var titlePreffix = parsedMainTitle.slice(0, 9);
            parsedMainTitle = parsedMainTitle.slice(10, parsedMainTitle.length);
        }

        var headerHtml = HeaderTemplateFunction({
            titlePreffix: titlePreffix || '',
            title: parsedMainTitle,
            localization: HELP.localization,
            customization: HELP.customization,
            isAllInOne: HELP.isAllInOne,
            isOffline: HELP.isFileProtocol
        });

        var footerHtml = FooterTemplateFunction({
            localization: HELP.localization,
            customization: HELP.customization
        });

        var asideHtml = AsideTemplateFunction({
            localization: HELP.localization
        });

        if (window.Customization) {
            var customStyles = CustomStylesTemplateFunction({
                customization: HELP.customization
            });

            $head.append(customStyles);
        }

        $container = $(containerHtml);
        $header = $(headerHtml);
        $footer = $(footerHtml);
        $aside = $(asideHtml);

        var $headerPlaceholder = $container.find('.js_header_placeholder');
        var $asidePlaceholder = $container.find('.js_aside_placeholder');
        var $footerPlaceholder = $container.find('.js_footer_placeholder');

        $headerPlaceholder.append($header);
        $asidePlaceholder.append($aside);
        $footerPlaceholder.append($footer);
        $content = $container.find('.js_content');
        $content.append(processHtml($body.html(), sectionUrl ? menu : null));
        $body.html($container);
        processContent($container);
        $body.addClass('js_tabs');

        var $viewport = $('<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">');
        $head.append($viewport);
        $html.find('base').remove();

        if ($.inArray($html.attr('lang'), ['ar-AE', 'fa-IR']) > -1) {
            $html.attr('dir', 'rtl');
        } else {
            $html.attr('dir', 'ltr');
        }

        FastClick.attach(document.body);

        $overlay = $body.find('.js_overlay');
        loadLangs();
        loadVersions();
        loadMenu(menu);

        if (HELP.searchWord) {
            $body.find('.js_search_text').val(HELP.searchWord);
            triggerSearch();
        }

        if (HELP.nav.currentPage && HELP.nav.currentPage.url) {
            $menuItem = $(".js_menu_link[href='" + HELP.nav.currentPage.url + "']").closest('.js_menu_item');
            autoScrollContents($menuItem, 0);
        }

        var localUrlRegExp = /([\w_]+\.htm)[l]?(#[\w]+(.htm))?/i;
        var urlMatches = window.location.href.match(localUrlRegExp);
        if (HELP.isMacProject && urlMatches[2] && urlMatches[3]) {
            loadContent("./pgs/" + urlMatches[2].slice(1), false, null, urlMatches[0]);
        } else if (window.history && window.history.replaceState && !HELP.isAllInOne) {
            var initialUrl = /\/([\w_-]+\.\w+$)/.exec(location.pathname)[1];
            window.history.replaceState({
                url: initialUrl
            }, null, initialUrl);
        }

        $modalContent = $overlay.find('.js_modal_content');
        $modalHeader = $overlay.find('.js_modal_header');
        $tooltip = $body.find('.js_tooltip');
        $tooltipContent = $body.find('.js_tooltip_content');

        setTimeout(function () {
            $html.show();
            $window.resize();
        }, 100);

        if (HELP.isIE7 || HELP.isIE8) {
            setTimeout(function () {
                calcAsideWidth($asidePlaceholder);
            }, 500);
        }

        $(".downloadhyperlinktemplate").attr("download", "").addClass("hyperlinktemplate");
    }

    firstRender();
});