/*!
 * https://github.com/es-shims/es5-shim
 * @license es5-shim Copyright 2009-2015 by contributors, MIT License
 * see https://github.com/es-shims/es5-shim/blob/master/LICENSE
 */

// vim: ts=4 sts=4 sw=4 expandtab

// Add semicolon to prevent IIFE from being passed as argument to concatenated code.
;

// UMD (Universal Module Definition)
// see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
(function (root, factory) {
    'use strict';

    /* global define, exports, module */
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals (root is window)
        root.returnExports = factory();
    }
}(this, function () {

/**
 * Brings an environment as close to ECMAScript 5 compliance
 * as is possible with the facilities of erstwhile engines.
 *
 * Annotated ES5: http://es5.github.com/ (specific links below)
 * ES5 Spec: http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf
 * Required reading: http://javascriptweblog.wordpress.com/2011/12/05/extending-javascript-natives/
 */

// Shortcut to an often accessed properties, in order to avoid multiple
// dereference that costs universally. This also holds a reference to known-good
// functions.
var $Array = Array;
var ArrayPrototype = $Array.prototype;
var $Object = Object;
var ObjectPrototype = $Object.prototype;
var $Function = Function;
var FunctionPrototype = $Function.prototype;
var $String = String;
var StringPrototype = $String.prototype;
var $Number = Number;
var NumberPrototype = $Number.prototype;
var array_slice = ArrayPrototype.slice;
var array_splice = ArrayPrototype.splice;
var array_push = ArrayPrototype.push;
var array_unshift = ArrayPrototype.unshift;
var array_concat = ArrayPrototype.concat;
var array_join = ArrayPrototype.join;
var call = FunctionPrototype.call;
var apply = FunctionPrototype.apply;
var max = Math.max;
var min = Math.min;

// Having a toString local variable name breaks in Opera so use to_string.
var to_string = ObjectPrototype.toString;

/* global Symbol */
/* eslint-disable one-var-declaration-per-line, no-redeclare */
var hasToStringTag = typeof Symbol === 'function' && typeof Symbol.toStringTag === 'symbol';
var isCallable; /* inlined from https://npmjs.com/is-callable */ var fnToStr = Function.prototype.toString, constructorRegex = /^\s*class /, isES6ClassFn = function isES6ClassFn(value) { try { var fnStr = fnToStr.call(value); var singleStripped = fnStr.replace(/\/\/.*\n/g, ''); var multiStripped = singleStripped.replace(/\/\*[.\s\S]*\*\//g, ''); var spaceStripped = multiStripped.replace(/\n/mg, ' ').replace(/ {2}/g, ' '); return constructorRegex.test(spaceStripped); } catch (e) { return false; /* not a function */ } }, tryFunctionObject = function tryFunctionObject(value) { try { if (isES6ClassFn(value)) { return false; } fnToStr.call(value); return true; } catch (e) { return false; } }, fnClass = '[object Function]', genClass = '[object GeneratorFunction]', isCallable = function isCallable(value) { if (!value) { return false; } if (typeof value !== 'function' && typeof value !== 'object') { return false; } if (hasToStringTag) { return tryFunctionObject(value); } if (isES6ClassFn(value)) { return false; } var strClass = to_string.call(value); return strClass === fnClass || strClass === genClass; };

var isRegex; /* inlined from https://npmjs.com/is-regex */ var regexExec = RegExp.prototype.exec, tryRegexExec = function tryRegexExec(value) { try { regexExec.call(value); return true; } catch (e) { return false; } }, regexClass = '[object RegExp]'; isRegex = function isRegex(value) { if (typeof value !== 'object') { return false; } return hasToStringTag ? tryRegexExec(value) : to_string.call(value) === regexClass; };
var isString; /* inlined from https://npmjs.com/is-string */ var strValue = String.prototype.valueOf, tryStringObject = function tryStringObject(value) { try { strValue.call(value); return true; } catch (e) { return false; } }, stringClass = '[object String]'; isString = function isString(value) { if (typeof value === 'string') { return true; } if (typeof value !== 'object') { return false; } return hasToStringTag ? tryStringObject(value) : to_string.call(value) === stringClass; };
/* eslint-enable one-var-declaration-per-line, no-redeclare */

/* inlined from http://npmjs.com/define-properties */
var supportsDescriptors = $Object.defineProperty && (function () {
    try {
        var obj = {};
        $Object.defineProperty(obj, 'x', { enumerable: false, value: obj });
        for (var _ in obj) { return false; }
        return obj.x === obj;
    } catch (e) { /* this is ES3 */
        return false;
    }
}());
var defineProperties = (function (has) {
  // Define configurable, writable, and non-enumerable props
  // if they don't exist.
  var defineProperty;
  if (supportsDescriptors) {
      defineProperty = function (object, name, method, forceAssign) {
          if (!forceAssign && (name in object)) { return; }
          $Object.defineProperty(object, name, {
              configurable: true,
              enumerable: false,
              writable: true,
              value: method
          });
      };
  } else {
      defineProperty = function (object, name, method, forceAssign) {
          if (!forceAssign && (name in object)) { return; }
          object[name] = method;
      };
  }
  return function defineProperties(object, map, forceAssign) {
      for (var name in map) {
          if (has.call(map, name)) {
            defineProperty(object, name, map[name], forceAssign);
          }
      }
  };
}(ObjectPrototype.hasOwnProperty));

//
// Util
// ======
//

/* replaceable with https://npmjs.com/package/es-abstract /helpers/isPrimitive */
var isPrimitive = function isPrimitive(input) {
    var type = typeof input;
    return input === null || (type !== 'object' && type !== 'function');
};

var isActualNaN = $Number.isNaN || function (x) { return x !== x; };

var ES = {
    // ES5 9.4
    // http://es5.github.com/#x9.4
    // http://jsperf.com/to-integer
    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToInteger */
    ToInteger: function ToInteger(num) {
        var n = +num;
        if (isActualNaN(n)) {
            n = 0;
        } else if (n !== 0 && n !== (1 / 0) && n !== -(1 / 0)) {
            n = (n > 0 || -1) * Math.floor(Math.abs(n));
        }
        return n;
    },

    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToPrimitive */
    ToPrimitive: function ToPrimitive(input) {
        var val, valueOf, toStr;
        if (isPrimitive(input)) {
            return input;
        }
        valueOf = input.valueOf;
        if (isCallable(valueOf)) {
            val = valueOf.call(input);
            if (isPrimitive(val)) {
                return val;
            }
        }
        toStr = input.toString;
        if (isCallable(toStr)) {
            val = toStr.call(input);
            if (isPrimitive(val)) {
                return val;
            }
        }
        throw new TypeError();
    },

    // ES5 9.9
    // http://es5.github.com/#x9.9
    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToObject */
    ToObject: function (o) {
        if (o == null) { // this matches both null and undefined
            throw new TypeError("can't convert " + o + ' to object');
        }
        return $Object(o);
    },

    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToUint32 */
    ToUint32: function ToUint32(x) {
        return x >>> 0;
    }
};

//
// Function
// ========
//

// ES-5 15.3.4.5
// http://es5.github.com/#x15.3.4.5

var Empty = function Empty() {};

defineProperties(FunctionPrototype, {
    bind: function bind(that) { // .length is 1
        // 1. Let Target be the this value.
        var target = this;
        // 2. If IsCallable(Target) is false, throw a TypeError exception.
        if (!isCallable(target)) {
            throw new TypeError('Function.prototype.bind called on incompatible ' + target);
        }
        // 3. Let A be a new (possibly empty) internal list of all of the
        //   argument values provided after thisArg (arg1, arg2 etc), in order.
        // XXX slicedArgs will stand in for "A" if used
        var args = array_slice.call(arguments, 1); // for normal call
        // 4. Let F be a new native ECMAScript object.
        // 11. Set the [[Prototype]] internal property of F to the standard
        //   built-in Function prototype object as specified in 15.3.3.1.
        // 12. Set the [[Call]] internal property of F as described in
        //   15.3.4.5.1.
        // 13. Set the [[Construct]] internal property of F as described in
        //   15.3.4.5.2.
        // 14. Set the [[HasInstance]] internal property of F as described in
        //   15.3.4.5.3.
        var bound;
        var binder = function () {

            if (this instanceof bound) {
                // 15.3.4.5.2 [[Construct]]
                // When the [[Construct]] internal method of a function object,
                // F that was created using the bind function is called with a
                // list of arguments ExtraArgs, the following steps are taken:
                // 1. Let target be the value of F's [[TargetFunction]]
                //   internal property.
                // 2. If target has no [[Construct]] internal method, a
                //   TypeError exception is thrown.
                // 3. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Construct]] internal
                //   method of target providing args as the arguments.

                var result = apply.call(
                    target,
                    this,
                    array_concat.call(args, array_slice.call(arguments))
                );
                if ($Object(result) === result) {
                    return result;
                }
                return this;

            } else {
                // 15.3.4.5.1 [[Call]]
                // When the [[Call]] internal method of a function object, F,
                // which was created using the bind function is called with a
                // this value and a list of arguments ExtraArgs, the following
                // steps are taken:
                // 1. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 2. Let boundThis be the value of F's [[BoundThis]] internal
                //   property.
                // 3. Let target be the value of F's [[TargetFunction]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Call]] internal method
                //   of target providing boundThis as the this value and
                //   providing args as the arguments.

                // equiv: target.call(this, ...boundArgs, ...args)
                return apply.call(
                    target,
                    that,
                    array_concat.call(args, array_slice.call(arguments))
                );

            }

        };

        // 15. If the [[Class]] internal property of Target is "Function", then
        //     a. Let L be the length property of Target minus the length of A.
        //     b. Set the length own property of F to either 0 or L, whichever is
        //       larger.
        // 16. Else set the length own property of F to 0.

        var boundLength = max(0, target.length - args.length);

        // 17. Set the attributes of the length own property of F to the values
        //   specified in 15.3.5.1.
        var boundArgs = [];
        for (var i = 0; i < boundLength; i++) {
            array_push.call(boundArgs, '$' + i);
        }

        // XXX Build a dynamic function with desired amount of arguments is the only
        // way to set the length property of a function.
        // In environments where Content Security Policies enabled (Chrome extensions,
        // for ex.) all use of eval or Function costructor throws an exception.
        // However in all of these environments Function.prototype.bind exists
        // and so this code will never be executed.
        bound = $Function('binder', 'return function (' + array_join.call(boundArgs, ',') + '){ return binder.apply(this, arguments); }')(binder);

        if (target.prototype) {
            Empty.prototype = target.prototype;
            bound.prototype = new Empty();
            // Clean up dangling references.
            Empty.prototype = null;
        }

        // TODO
        // 18. Set the [[Extensible]] internal property of F to true.

        // TODO
        // 19. Let thrower be the [[ThrowTypeError]] function Object (13.2.3).
        // 20. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "caller", PropertyDescriptor {[[Get]]: thrower, [[Set]]:
        //   thrower, [[Enumerable]]: false, [[Configurable]]: false}, and
        //   false.
        // 21. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "arguments", PropertyDescriptor {[[Get]]: thrower,
        //   [[Set]]: thrower, [[Enumerable]]: false, [[Configurable]]: false},
        //   and false.

        // TODO
        // NOTE Function objects created using Function.prototype.bind do not
        // have a prototype property or the [[Code]], [[FormalParameters]], and
        // [[Scope]] internal properties.
        // XXX can't delete prototype in pure-js.

        // 22. Return F.
        return bound;
    }
});

// _Please note: Shortcuts are defined after `Function.prototype.bind` as we
// use it in defining shortcuts.
var owns = call.bind(ObjectPrototype.hasOwnProperty);
var toStr = call.bind(ObjectPrototype.toString);
var arraySlice = call.bind(array_slice);
var arraySliceApply = apply.bind(array_slice);
var strSlice = call.bind(StringPrototype.slice);
var strSplit = call.bind(StringPrototype.split);
var strIndexOf = call.bind(StringPrototype.indexOf);
var pushCall = call.bind(array_push);
var isEnum = call.bind(ObjectPrototype.propertyIsEnumerable);
var arraySort = call.bind(ArrayPrototype.sort);

//
// Array
// =====
//

var isArray = $Array.isArray || function isArray(obj) {
    return toStr(obj) === '[object Array]';
};

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.13
// Return len+argCount.
// [bugfix, ielt8]
// IE < 8 bug: [].unshift(0) === undefined but should be "1"
var hasUnshiftReturnValueBug = [].unshift(0) !== 1;
defineProperties(ArrayPrototype, {
    unshift: function () {
        array_unshift.apply(this, arguments);
        return this.length;
    }
}, hasUnshiftReturnValueBug);

// ES5 15.4.3.2
// http://es5.github.com/#x15.4.3.2
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/isArray
defineProperties($Array, { isArray: isArray });

// The IsCallable() check in the Array functions
// has been replaced with a strict check on the
// internal class of the object to trap cases where
// the provided function was actually a regular
// expression literal, which in V8 and
// JavaScriptCore is a typeof "function".  Only in
// V8 are regular expression literals permitted as
// reduce parameters, so it is desirable in the
// general case for the shim to match the more
// strict and common behavior of rejecting regular
// expressions.

// ES5 15.4.4.18
// http://es5.github.com/#x15.4.4.18
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/array/forEach

// Check failure of by-index access of string characters (IE < 9)
// and failure of `0 in boxedString` (Rhino)
var boxedString = $Object('a');
var splitString = boxedString[0] !== 'a' || !(0 in boxedString);

var properlyBoxesContext = function properlyBoxed(method) {
    // Check node 0.6.21 bug where third parameter is not boxed
    var properlyBoxesNonStrict = true;
    var properlyBoxesStrict = true;
    var threwException = false;
    if (method) {
        try {
            method.call('foo', function (_, __, context) {
                if (typeof context !== 'object') { properlyBoxesNonStrict = false; }
            });

            method.call([1], function () {
                'use strict';

                properlyBoxesStrict = typeof this === 'string';
            }, 'x');
        } catch (e) {
            threwException = true;
        }
    }
    return !!method && !threwException && properlyBoxesNonStrict && properlyBoxesStrict;
};

defineProperties(ArrayPrototype, {
    forEach: function forEach(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var i = -1;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
          T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.forEach callback must be a function');
        }

        while (++i < length) {
            if (i in self) {
                // Invoke the callback function with call, passing arguments:
                // context, property value, property key, thisArg object
                if (typeof T === 'undefined') {
                    callbackfn(self[i], i, object);
                } else {
                    callbackfn.call(T, self[i], i, object);
                }
            }
        }
    }
}, !properlyBoxesContext(ArrayPrototype.forEach));

// ES5 15.4.4.19
// http://es5.github.com/#x15.4.4.19
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/map
defineProperties(ArrayPrototype, {
    map: function map(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var result = $Array(length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.map callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                if (typeof T === 'undefined') {
                    result[i] = callbackfn(self[i], i, object);
                } else {
                    result[i] = callbackfn.call(T, self[i], i, object);
                }
            }
        }
        return result;
    }
}, !properlyBoxesContext(ArrayPrototype.map));

// ES5 15.4.4.20
// http://es5.github.com/#x15.4.4.20
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/filter
defineProperties(ArrayPrototype, {
    filter: function filter(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var result = [];
        var value;
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.filter callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                value = self[i];
                if (typeof T === 'undefined' ? callbackfn(value, i, object) : callbackfn.call(T, value, i, object)) {
                    pushCall(result, value);
                }
            }
        }
        return result;
    }
}, !properlyBoxesContext(ArrayPrototype.filter));

// ES5 15.4.4.16
// http://es5.github.com/#x15.4.4.16
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/every
defineProperties(ArrayPrototype, {
    every: function every(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.every callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self && !(typeof T === 'undefined' ? callbackfn(self[i], i, object) : callbackfn.call(T, self[i], i, object))) {
                return false;
            }
        }
        return true;
    }
}, !properlyBoxesContext(ArrayPrototype.every));

// ES5 15.4.4.17
// http://es5.github.com/#x15.4.4.17
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/some
defineProperties(ArrayPrototype, {
    some: function some(callbackfn/*, thisArg */) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.some callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self && (typeof T === 'undefined' ? callbackfn(self[i], i, object) : callbackfn.call(T, self[i], i, object))) {
                return true;
            }
        }
        return false;
    }
}, !properlyBoxesContext(ArrayPrototype.some));

// ES5 15.4.4.21
// http://es5.github.com/#x15.4.4.21
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduce
var reduceCoercesToObject = false;
if (ArrayPrototype.reduce) {
    reduceCoercesToObject = typeof ArrayPrototype.reduce.call('es5', function (_, __, ___, list) { return list; }) === 'object';
}
defineProperties(ArrayPrototype, {
    reduce: function reduce(callbackfn/*, initialValue*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.reduce callback must be a function');
        }

        // no value to return if no initial value and an empty array
        if (length === 0 && arguments.length === 1) {
            throw new TypeError('reduce of empty array with no initial value');
        }

        var i = 0;
        var result;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i++];
                    break;
                }

                // if array contains no values, no initial value to return
                if (++i >= length) {
                    throw new TypeError('reduce of empty array with no initial value');
                }
            } while (true);
        }

        for (; i < length; i++) {
            if (i in self) {
                result = callbackfn(result, self[i], i, object);
            }
        }

        return result;
    }
}, !reduceCoercesToObject);

// ES5 15.4.4.22
// http://es5.github.com/#x15.4.4.22
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduceRight
var reduceRightCoercesToObject = false;
if (ArrayPrototype.reduceRight) {
    reduceRightCoercesToObject = typeof ArrayPrototype.reduceRight.call('es5', function (_, __, ___, list) { return list; }) === 'object';
}
defineProperties(ArrayPrototype, {
    reduceRight: function reduceRight(callbackfn/*, initial*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.reduceRight callback must be a function');
        }

        // no value to return if no initial value, empty array
        if (length === 0 && arguments.length === 1) {
            throw new TypeError('reduceRight of empty array with no initial value');
        }

        var result;
        var i = length - 1;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i--];
                    break;
                }

                // if array contains no values, no initial value to return
                if (--i < 0) {
                    throw new TypeError('reduceRight of empty array with no initial value');
                }
            } while (true);
        }

        if (i < 0) {
            return result;
        }

        do {
            if (i in self) {
                result = callbackfn(result, self[i], i, object);
            }
        } while (i--);

        return result;
    }
}, !reduceRightCoercesToObject);

// ES5 15.4.4.14
// http://es5.github.com/#x15.4.4.14
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/indexOf
var hasFirefox2IndexOfBug = ArrayPrototype.indexOf && [0, 1].indexOf(1, 2) !== -1;
defineProperties(ArrayPrototype, {
    indexOf: function indexOf(searchElement/*, fromIndex */) {
        var self = splitString && isString(this) ? strSplit(this, '') : ES.ToObject(this);
        var length = ES.ToUint32(self.length);

        if (length === 0) {
            return -1;
        }

        var i = 0;
        if (arguments.length > 1) {
            i = ES.ToInteger(arguments[1]);
        }

        // handle negative indices
        i = i >= 0 ? i : max(0, length + i);
        for (; i < length; i++) {
            if (i in self && self[i] === searchElement) {
                return i;
            }
        }
        return -1;
    }
}, hasFirefox2IndexOfBug);

// ES5 15.4.4.15
// http://es5.github.com/#x15.4.4.15
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/lastIndexOf
var hasFirefox2LastIndexOfBug = ArrayPrototype.lastIndexOf && [0, 1].lastIndexOf(0, -3) !== -1;
defineProperties(ArrayPrototype, {
    lastIndexOf: function lastIndexOf(searchElement/*, fromIndex */) {
        var self = splitString && isString(this) ? strSplit(this, '') : ES.ToObject(this);
        var length = ES.ToUint32(self.length);

        if (length === 0) {
            return -1;
        }
        var i = length - 1;
        if (arguments.length > 1) {
            i = min(i, ES.ToInteger(arguments[1]));
        }
        // handle negative indices
        i = i >= 0 ? i : length - Math.abs(i);
        for (; i >= 0; i--) {
            if (i in self && searchElement === self[i]) {
                return i;
            }
        }
        return -1;
    }
}, hasFirefox2LastIndexOfBug);

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.12
var spliceNoopReturnsEmptyArray = (function () {
    var a = [1, 2];
    var result = a.splice();
    return a.length === 2 && isArray(result) && result.length === 0;
}());
defineProperties(ArrayPrototype, {
    // Safari 5.0 bug where .splice() returns undefined
    splice: function splice(start, deleteCount) {
        if (arguments.length === 0) {
            return [];
        } else {
            return array_splice.apply(this, arguments);
        }
    }
}, !spliceNoopReturnsEmptyArray);

var spliceWorksWithEmptyObject = (function () {
    var obj = {};
    ArrayPrototype.splice.call(obj, 0, 0, 1);
    return obj.length === 1;
}());
defineProperties(ArrayPrototype, {
    splice: function splice(start, deleteCount) {
        if (arguments.length === 0) { return []; }
        var args = arguments;
        this.length = max(ES.ToInteger(this.length), 0);
        if (arguments.length > 0 && typeof deleteCount !== 'number') {
            args = arraySlice(arguments);
            if (args.length < 2) {
                pushCall(args, this.length - start);
            } else {
                args[1] = ES.ToInteger(deleteCount);
            }
        }
        return array_splice.apply(this, args);
    }
}, !spliceWorksWithEmptyObject);
var spliceWorksWithLargeSparseArrays = (function () {
    // Per https://github.com/es-shims/es5-shim/issues/295
    // Safari 7/8 breaks with sparse arrays of size 1e5 or greater
    var arr = new $Array(1e5);
    // note: the index MUST be 8 or larger or the test will false pass
    arr[8] = 'x';
    arr.splice(1, 1);
    // note: this test must be defined *after* the indexOf shim
    // per https://github.com/es-shims/es5-shim/issues/313
    return arr.indexOf('x') === 7;
}());
var spliceWorksWithSmallSparseArrays = (function () {
    // Per https://github.com/es-shims/es5-shim/issues/295
    // Opera 12.15 breaks on this, no idea why.
    var n = 256;
    var arr = [];
    arr[n] = 'a';
    arr.splice(n + 1, 0, 'b');
    return arr[n] === 'a';
}());
defineProperties(ArrayPrototype, {
    splice: function splice(start, deleteCount) {
        var O = ES.ToObject(this);
        var A = [];
        var len = ES.ToUint32(O.length);
        var relativeStart = ES.ToInteger(start);
        var actualStart = relativeStart < 0 ? max((len + relativeStart), 0) : min(relativeStart, len);
        var actualDeleteCount = min(max(ES.ToInteger(deleteCount), 0), len - actualStart);

        var k = 0;
        var from;
        while (k < actualDeleteCount) {
            from = $String(actualStart + k);
            if (owns(O, from)) {
                A[k] = O[from];
            }
            k += 1;
        }

        var items = arraySlice(arguments, 2);
        var itemCount = items.length;
        var to;
        if (itemCount < actualDeleteCount) {
            k = actualStart;
            var maxK = len - actualDeleteCount;
            while (k < maxK) {
                from = $String(k + actualDeleteCount);
                to = $String(k + itemCount);
                if (owns(O, from)) {
                    O[to] = O[from];
                } else {
                    delete O[to];
                }
                k += 1;
            }
            k = len;
            var minK = len - actualDeleteCount + itemCount;
            while (k > minK) {
                delete O[k - 1];
                k -= 1;
            }
        } else if (itemCount > actualDeleteCount) {
            k = len - actualDeleteCount;
            while (k > actualStart) {
                from = $String(k + actualDeleteCount - 1);
                to = $String(k + itemCount - 1);
                if (owns(O, from)) {
                    O[to] = O[from];
                } else {
                    delete O[to];
                }
                k -= 1;
            }
        }
        k = actualStart;
        for (var i = 0; i < items.length; ++i) {
            O[k] = items[i];
            k += 1;
        }
        O.length = len - actualDeleteCount + itemCount;

        return A;
    }
}, !spliceWorksWithLargeSparseArrays || !spliceWorksWithSmallSparseArrays);

var originalJoin = ArrayPrototype.join;
var hasStringJoinBug;
try {
    hasStringJoinBug = Array.prototype.join.call('123', ',') !== '1,2,3';
} catch (e) {
    hasStringJoinBug = true;
}
if (hasStringJoinBug) {
    defineProperties(ArrayPrototype, {
        join: function join(separator) {
            var sep = typeof separator === 'undefined' ? ',' : separator;
            return originalJoin.call(isString(this) ? strSplit(this, '') : this, sep);
        }
    }, hasStringJoinBug);
}

var hasJoinUndefinedBug = [1, 2].join(undefined) !== '1,2';
if (hasJoinUndefinedBug) {
    defineProperties(ArrayPrototype, {
        join: function join(separator) {
            var sep = typeof separator === 'undefined' ? ',' : separator;
            return originalJoin.call(this, sep);
        }
    }, hasJoinUndefinedBug);
}

var pushShim = function push(item) {
    var O = ES.ToObject(this);
    var n = ES.ToUint32(O.length);
    var i = 0;
    while (i < arguments.length) {
        O[n + i] = arguments[i];
        i += 1;
    }
    O.length = n + i;
    return n + i;
};

var pushIsNotGeneric = (function () {
    var obj = {};
    var result = Array.prototype.push.call(obj, undefined);
    return result !== 1 || obj.length !== 1 || typeof obj[0] !== 'undefined' || !owns(obj, 0);
}());
defineProperties(ArrayPrototype, {
    push: function push(item) {
        if (isArray(this)) {
            return array_push.apply(this, arguments);
        }
        return pushShim.apply(this, arguments);
    }
}, pushIsNotGeneric);

// This fixes a very weird bug in Opera 10.6 when pushing `undefined
var pushUndefinedIsWeird = (function () {
    var arr = [];
    var result = arr.push(undefined);
    return result !== 1 || arr.length !== 1 || typeof arr[0] !== 'undefined' || !owns(arr, 0);
}());
defineProperties(ArrayPrototype, { push: pushShim }, pushUndefinedIsWeird);

// ES5 15.2.3.14
// http://es5.github.io/#x15.4.4.10
// Fix boxed string bug
defineProperties(ArrayPrototype, {
    slice: function (start, end) {
        var arr = isString(this) ? strSplit(this, '') : this;
        return arraySliceApply(arr, arguments);
    }
}, splitString);

var sortIgnoresNonFunctions = (function () {
    try {
        [1, 2].sort(null);
        [1, 2].sort({});
        return true;
    } catch (e) { /**/ }
    return false;
}());
var sortThrowsOnRegex = (function () {
    // this is a problem in Firefox 4, in which `typeof /a/ === 'function'`
    try {
        [1, 2].sort(/a/);
        return false;
    } catch (e) { /**/ }
    return true;
}());
var sortIgnoresUndefined = (function () {
    // applies in IE 8, for one.
    try {
        [1, 2].sort(undefined);
        return true;
    } catch (e) { /**/ }
    return false;
}());
defineProperties(ArrayPrototype, {
    sort: function sort(compareFn) {
        if (typeof compareFn === 'undefined') {
            return arraySort(this);
        }
        if (!isCallable(compareFn)) {
            throw new TypeError('Array.prototype.sort callback must be a function');
        }
        return arraySort(this, compareFn);
    }
}, sortIgnoresNonFunctions || !sortIgnoresUndefined || !sortThrowsOnRegex);

//
// Object
// ======
//

// ES5 15.2.3.14
// http://es5.github.com/#x15.2.3.14

// http://whattheheadsaid.com/2010/10/a-safer-object-keys-compatibility-implementation
var hasDontEnumBug = !({ 'toString': null }).propertyIsEnumerable('toString');
var hasProtoEnumBug = function () {}.propertyIsEnumerable('prototype');
var hasStringEnumBug = !owns('x', '0');
var equalsConstructorPrototype = function (o) {
    var ctor = o.constructor;
    return ctor && ctor.prototype === o;
};
var blacklistedKeys = {
    $window: true,
    $console: true,
    $parent: true,
    $self: true,
    $frame: true,
    $frames: true,
    $frameElement: true,
    $webkitIndexedDB: true,
    $webkitStorageInfo: true,
    $external: true
};
var hasAutomationEqualityBug = (function () {
    /* globals window */
    if (typeof window === 'undefined') { return false; }
    for (var k in window) {
        try {
            if (!blacklistedKeys['$' + k] && owns(window, k) && window[k] !== null && typeof window[k] === 'object') {
                equalsConstructorPrototype(window[k]);
            }
        } catch (e) {
            return true;
        }
    }
    return false;
}());
var equalsConstructorPrototypeIfNotBuggy = function (object) {
    if (typeof window === 'undefined' || !hasAutomationEqualityBug) { return equalsConstructorPrototype(object); }
    try {
        return equalsConstructorPrototype(object);
    } catch (e) {
        return false;
    }
};
var dontEnums = [
    'toString',
    'toLocaleString',
    'valueOf',
    'hasOwnProperty',
    'isPrototypeOf',
    'propertyIsEnumerable',
    'constructor'
];
var dontEnumsLength = dontEnums.length;

// taken directly from https://github.com/ljharb/is-arguments/blob/master/index.js
// can be replaced with require('is-arguments') if we ever use a build process instead
var isStandardArguments = function isArguments(value) {
    return toStr(value) === '[object Arguments]';
};
var isLegacyArguments = function isArguments(value) {
    return value !== null &&
        typeof value === 'object' &&
        typeof value.length === 'number' &&
        value.length >= 0 &&
        !isArray(value) &&
        isCallable(value.callee);
};
var isArguments = isStandardArguments(arguments) ? isStandardArguments : isLegacyArguments;

defineProperties($Object, {
    keys: function keys(object) {
        var isFn = isCallable(object);
        var isArgs = isArguments(object);
        var isObject = object !== null && typeof object === 'object';
        var isStr = isObject && isString(object);

        if (!isObject && !isFn && !isArgs) {
            throw new TypeError('Object.keys called on a non-object');
        }

        var theKeys = [];
        var skipProto = hasProtoEnumBug && isFn;
        if ((isStr && hasStringEnumBug) || isArgs) {
            for (var i = 0; i < object.length; ++i) {
                pushCall(theKeys, $String(i));
            }
        }

        if (!isArgs) {
            for (var name in object) {
                if (!(skipProto && name === 'prototype') && owns(object, name)) {
                    pushCall(theKeys, $String(name));
                }
            }
        }

        if (hasDontEnumBug) {
            var skipConstructor = equalsConstructorPrototypeIfNotBuggy(object);
            for (var j = 0; j < dontEnumsLength; j++) {
                var dontEnum = dontEnums[j];
                if (!(skipConstructor && dontEnum === 'constructor') && owns(object, dontEnum)) {
                    pushCall(theKeys, dontEnum);
                }
            }
        }
        return theKeys;
    }
});

var keysWorksWithArguments = $Object.keys && (function () {
    // Safari 5.0 bug
    return $Object.keys(arguments).length === 2;
}(1, 2));
var keysHasArgumentsLengthBug = $Object.keys && (function () {
    var argKeys = $Object.keys(arguments);
    return arguments.length !== 1 || argKeys.length !== 1 || argKeys[0] !== 1;
}(1));
var originalKeys = $Object.keys;
defineProperties($Object, {
    keys: function keys(object) {
        if (isArguments(object)) {
            return originalKeys(arraySlice(object));
        } else {
            return originalKeys(object);
        }
    }
}, !keysWorksWithArguments || keysHasArgumentsLengthBug);

//
// Date
// ====
//

var hasNegativeMonthYearBug = new Date(-3509827329600292).getUTCMonth() !== 0;
var aNegativeTestDate = new Date(-1509842289600292);
var aPositiveTestDate = new Date(1449662400000);
var hasToUTCStringFormatBug = aNegativeTestDate.toUTCString() !== 'Mon, 01 Jan -45875 11:59:59 GMT';
var hasToDateStringFormatBug;
var hasToStringFormatBug;
var timeZoneOffset = aNegativeTestDate.getTimezoneOffset();
if (timeZoneOffset < -720) {
    hasToDateStringFormatBug = aNegativeTestDate.toDateString() !== 'Tue Jan 02 -45875';
    hasToStringFormatBug = !(/^Thu Dec 10 2015 \d\d:\d\d:\d\d GMT[-\+]\d\d\d\d(?: |$)/).test(aPositiveTestDate.toString());
} else {
    hasToDateStringFormatBug = aNegativeTestDate.toDateString() !== 'Mon Jan 01 -45875';
    hasToStringFormatBug = !(/^Wed Dec 09 2015 \d\d:\d\d:\d\d GMT[-\+]\d\d\d\d(?: |$)/).test(aPositiveTestDate.toString());
}

var originalGetFullYear = call.bind(Date.prototype.getFullYear);
var originalGetMonth = call.bind(Date.prototype.getMonth);
var originalGetDate = call.bind(Date.prototype.getDate);
var originalGetUTCFullYear = call.bind(Date.prototype.getUTCFullYear);
var originalGetUTCMonth = call.bind(Date.prototype.getUTCMonth);
var originalGetUTCDate = call.bind(Date.prototype.getUTCDate);
var originalGetUTCDay = call.bind(Date.prototype.getUTCDay);
var originalGetUTCHours = call.bind(Date.prototype.getUTCHours);
var originalGetUTCMinutes = call.bind(Date.prototype.getUTCMinutes);
var originalGetUTCSeconds = call.bind(Date.prototype.getUTCSeconds);
var originalGetUTCMilliseconds = call.bind(Date.prototype.getUTCMilliseconds);
var dayName = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
var monthName = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
var daysInMonth = function daysInMonth(month, year) {
    return originalGetDate(new Date(year, month, 0));
};

defineProperties(Date.prototype, {
    getFullYear: function getFullYear() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        if (year < 0 && originalGetMonth(this) > 11) {
            return year + 1;
        }
        return year;
    },
    getMonth: function getMonth() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        var month = originalGetMonth(this);
        if (year < 0 && month > 11) {
            return 0;
        }
        return month;
    },
    getDate: function getDate() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        var month = originalGetMonth(this);
        var date = originalGetDate(this);
        if (year < 0 && month > 11) {
            if (month === 12) {
                return date;
            }
            var days = daysInMonth(0, year + 1);
            return (days - date) + 1;
        }
        return date;
    },
    getUTCFullYear: function getUTCFullYear() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        if (year < 0 && originalGetUTCMonth(this) > 11) {
            return year + 1;
        }
        return year;
    },
    getUTCMonth: function getUTCMonth() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        var month = originalGetUTCMonth(this);
        if (year < 0 && month > 11) {
            return 0;
        }
        return month;
    },
    getUTCDate: function getUTCDate() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        var month = originalGetUTCMonth(this);
        var date = originalGetUTCDate(this);
        if (year < 0 && month > 11) {
            if (month === 12) {
                return date;
            }
            var days = daysInMonth(0, year + 1);
            return (days - date) + 1;
        }
        return date;
    }
}, hasNegativeMonthYearBug);

defineProperties(Date.prototype, {
    toUTCString: function toUTCString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = originalGetUTCDay(this);
        var date = originalGetUTCDate(this);
        var month = originalGetUTCMonth(this);
        var year = originalGetUTCFullYear(this);
        var hour = originalGetUTCHours(this);
        var minute = originalGetUTCMinutes(this);
        var second = originalGetUTCSeconds(this);
        return dayName[day] + ', ' +
            (date < 10 ? '0' + date : date) + ' ' +
            monthName[month] + ' ' +
            year + ' ' +
            (hour < 10 ? '0' + hour : hour) + ':' +
            (minute < 10 ? '0' + minute : minute) + ':' +
            (second < 10 ? '0' + second : second) + ' GMT';
    }
}, hasNegativeMonthYearBug || hasToUTCStringFormatBug);

// Opera 12 has `,`
defineProperties(Date.prototype, {
    toDateString: function toDateString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = this.getDay();
        var date = this.getDate();
        var month = this.getMonth();
        var year = this.getFullYear();
        return dayName[day] + ' ' +
            monthName[month] + ' ' +
            (date < 10 ? '0' + date : date) + ' ' +
            year;
    }
}, hasNegativeMonthYearBug || hasToDateStringFormatBug);

// can't use defineProperties here because of toString enumeration issue in IE <= 8
if (hasNegativeMonthYearBug || hasToStringFormatBug) {
    Date.prototype.toString = function toString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = this.getDay();
        var date = this.getDate();
        var month = this.getMonth();
        var year = this.getFullYear();
        var hour = this.getHours();
        var minute = this.getMinutes();
        var second = this.getSeconds();
        var timezoneOffset = this.getTimezoneOffset();
        var hoursOffset = Math.floor(Math.abs(timezoneOffset) / 60);
        var minutesOffset = Math.floor(Math.abs(timezoneOffset) % 60);
        return dayName[day] + ' ' +
            monthName[month] + ' ' +
            (date < 10 ? '0' + date : date) + ' ' +
            year + ' ' +
            (hour < 10 ? '0' + hour : hour) + ':' +
            (minute < 10 ? '0' + minute : minute) + ':' +
            (second < 10 ? '0' + second : second) + ' GMT' +
            (timezoneOffset > 0 ? '-' : '+') +
            (hoursOffset < 10 ? '0' + hoursOffset : hoursOffset) +
            (minutesOffset < 10 ? '0' + minutesOffset : minutesOffset);
    };
    if (supportsDescriptors) {
        $Object.defineProperty(Date.prototype, 'toString', {
            configurable: true,
            enumerable: false,
            writable: true
        });
    }
}

// ES5 15.9.5.43
// http://es5.github.com/#x15.9.5.43
// This function returns a String value represent the instance in time
// represented by this Date object. The format of the String is the Date Time
// string format defined in 15.9.1.15. All fields are present in the String.
// The time zone is always UTC, denoted by the suffix Z. If the time value of
// this object is not a finite Number a RangeError exception is thrown.
var negativeDate = -62198755200000;
var negativeYearString = '-000001';
var hasNegativeDateBug = Date.prototype.toISOString && new Date(negativeDate).toISOString().indexOf(negativeYearString) === -1;
var hasSafari51DateBug = Date.prototype.toISOString && new Date(-1).toISOString() !== '1969-12-31T23:59:59.999Z';

var getTime = call.bind(Date.prototype.getTime);

defineProperties(Date.prototype, {
    toISOString: function toISOString() {
        if (!isFinite(this) || !isFinite(getTime(this))) {
            // Adope Photoshop requires the second check.
            throw new RangeError('Date.prototype.toISOString called on non-finite value.');
        }

        var year = originalGetUTCFullYear(this);

        var month = originalGetUTCMonth(this);
        // see https://github.com/es-shims/es5-shim/issues/111
        year += Math.floor(month / 12);
        month = (month % 12 + 12) % 12;

        // the date time string format is specified in 15.9.1.15.
        var result = [month + 1, originalGetUTCDate(this), originalGetUTCHours(this), originalGetUTCMinutes(this), originalGetUTCSeconds(this)];
        year = (
            (year < 0 ? '-' : (year > 9999 ? '+' : '')) +
            strSlice('00000' + Math.abs(year), (0 <= year && year <= 9999) ? -4 : -6)
        );

        for (var i = 0; i < result.length; ++i) {
          // pad months, days, hours, minutes, and seconds to have two digits.
          result[i] = strSlice('00' + result[i], -2);
        }
        // pad milliseconds to have three digits.
        return (
            year + '-' + arraySlice(result, 0, 2).join('-') +
            'T' + arraySlice(result, 2).join(':') + '.' +
            strSlice('000' + originalGetUTCMilliseconds(this), -3) + 'Z'
        );
    }
}, hasNegativeDateBug || hasSafari51DateBug);

// ES5 15.9.5.44
// http://es5.github.com/#x15.9.5.44
// This function provides a String representation of a Date object for use by
// JSON.stringify (15.12.3).
var dateToJSONIsSupported = (function () {
    try {
        return Date.prototype.toJSON &&
            new Date(NaN).toJSON() === null &&
            new Date(negativeDate).toJSON().indexOf(negativeYearString) !== -1 &&
            Date.prototype.toJSON.call({ // generic
                toISOString: function () { return true; }
            });
    } catch (e) {
        return false;
    }
}());
if (!dateToJSONIsSupported) {
    Date.prototype.toJSON = function toJSON(key) {
        // When the toJSON method is called with argument key, the following
        // steps are taken:

        // 1.  Let O be the result of calling ToObject, giving it the this
        // value as its argument.
        // 2. Let tv be ES.ToPrimitive(O, hint Number).
        var O = $Object(this);
        var tv = ES.ToPrimitive(O);
        // 3. If tv is a Number and is not finite, return null.
        if (typeof tv === 'number' && !isFinite(tv)) {
            return null;
        }
        // 4. Let toISO be the result of calling the [[Get]] internal method of
        // O with argument "toISOString".
        var toISO = O.toISOString;
        // 5. If IsCallable(toISO) is false, throw a TypeError exception.
        if (!isCallable(toISO)) {
            throw new TypeError('toISOString property is not callable');
        }
        // 6. Return the result of calling the [[Call]] internal method of
        //  toISO with O as the this value and an empty argument list.
        return toISO.call(O);

        // NOTE 1 The argument is ignored.

        // NOTE 2 The toJSON function is intentionally generic; it does not
        // require that its this value be a Date object. Therefore, it can be
        // transferred to other kinds of objects for use as a method. However,
        // it does require that any such object have a toISOString method. An
        // object is free to use the argument key to filter its
        // stringification.
    };
}

// ES5 15.9.4.2
// http://es5.github.com/#x15.9.4.2
// based on work shared by Daniel Friesen (dantman)
// http://gist.github.com/303249
var supportsExtendedYears = Date.parse('+033658-09-27T01:46:40.000Z') === 1e15;
var acceptsInvalidDates = !isNaN(Date.parse('2012-04-04T24:00:00.500Z')) || !isNaN(Date.parse('2012-11-31T23:59:59.000Z')) || !isNaN(Date.parse('2012-12-31T23:59:60.000Z'));
var doesNotParseY2KNewYear = isNaN(Date.parse('2000-01-01T00:00:00.000Z'));
if (doesNotParseY2KNewYear || acceptsInvalidDates || !supportsExtendedYears) {
    // XXX global assignment won't work in embeddings that use
    // an alternate object for the context.
    /* global Date: true */
    /* eslint-disable no-undef */
    var maxSafeUnsigned32Bit = Math.pow(2, 31) - 1;
    var hasSafariSignedIntBug = isActualNaN(new Date(1970, 0, 1, 0, 0, 0, maxSafeUnsigned32Bit + 1).getTime());
    /* eslint-disable no-implicit-globals */
    Date = (function (NativeDate) {
    /* eslint-enable no-implicit-globals */
    /* eslint-enable no-undef */
        // Date.length === 7
        var DateShim = function Date(Y, M, D, h, m, s, ms) {
            var length = arguments.length;
            var date;
            if (this instanceof NativeDate) {
                var seconds = s;
                var millis = ms;
                if (hasSafariSignedIntBug && length >= 7 && ms > maxSafeUnsigned32Bit) {
                    // work around a Safari 8/9 bug where it treats the seconds as signed
                    var msToShift = Math.floor(ms / maxSafeUnsigned32Bit) * maxSafeUnsigned32Bit;
                    var sToShift = Math.floor(msToShift / 1e3);
                    seconds += sToShift;
                    millis -= sToShift * 1e3;
                }
                date = length === 1 && $String(Y) === Y ? // isString(Y)
                    // We explicitly pass it through parse:
                    new NativeDate(DateShim.parse(Y)) :
                    // We have to manually make calls depending on argument
                    // length here
                    length >= 7 ? new NativeDate(Y, M, D, h, m, seconds, millis) :
                    length >= 6 ? new NativeDate(Y, M, D, h, m, seconds) :
                    length >= 5 ? new NativeDate(Y, M, D, h, m) :
                    length >= 4 ? new NativeDate(Y, M, D, h) :
                    length >= 3 ? new NativeDate(Y, M, D) :
                    length >= 2 ? new NativeDate(Y, M) :
                    length >= 1 ? new NativeDate(Y instanceof NativeDate ? +Y : Y) :
                                  new NativeDate();
            } else {
                date = NativeDate.apply(this, arguments);
            }
            if (!isPrimitive(date)) {
              // Prevent mixups with unfixed Date object
              defineProperties(date, { constructor: DateShim }, true);
            }
            return date;
        };

        // 15.9.1.15 Date Time String Format.
        var isoDateExpression = new RegExp('^' +
            '(\\d{4}|[+-]\\d{6})' + // four-digit year capture or sign +
                                      // 6-digit extended year
            '(?:-(\\d{2})' + // optional month capture
            '(?:-(\\d{2})' + // optional day capture
            '(?:' + // capture hours:minutes:seconds.milliseconds
                'T(\\d{2})' + // hours capture
                ':(\\d{2})' + // minutes capture
                '(?:' + // optional :seconds.milliseconds
                    ':(\\d{2})' + // seconds capture
                    '(?:(\\.\\d{1,}))?' + // milliseconds capture
                ')?' +
            '(' + // capture UTC offset component
                'Z|' + // UTC capture
                '(?:' + // offset specifier +/-hours:minutes
                    '([-+])' + // sign capture
                    '(\\d{2})' + // hours offset capture
                    ':(\\d{2})' + // minutes offset capture
                ')' +
            ')?)?)?)?' +
        '$');

        var months = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365];

        var dayFromMonth = function dayFromMonth(year, month) {
            var t = month > 1 ? 1 : 0;
            return (
                months[month] +
                Math.floor((year - 1969 + t) / 4) -
                Math.floor((year - 1901 + t) / 100) +
                Math.floor((year - 1601 + t) / 400) +
                365 * (year - 1970)
            );
        };

        var toUTC = function toUTC(t) {
            var s = 0;
            var ms = t;
            if (hasSafariSignedIntBug && ms > maxSafeUnsigned32Bit) {
                // work around a Safari 8/9 bug where it treats the seconds as signed
                var msToShift = Math.floor(ms / maxSafeUnsigned32Bit) * maxSafeUnsigned32Bit;
                var sToShift = Math.floor(msToShift / 1e3);
                s += sToShift;
                ms -= sToShift * 1e3;
            }
            return $Number(new NativeDate(1970, 0, 1, 0, 0, s, ms));
        };

        // Copy any custom methods a 3rd party library may have added
        for (var key in NativeDate) {
            if (owns(NativeDate, key)) {
                DateShim[key] = NativeDate[key];
            }
        }

        // Copy "native" methods explicitly; they may be non-enumerable
        defineProperties(DateShim, {
            now: NativeDate.now,
            UTC: NativeDate.UTC
        }, true);
        DateShim.prototype = NativeDate.prototype;
        defineProperties(DateShim.prototype, {
            constructor: DateShim
        }, true);

        // Upgrade Date.parse to handle simplified ISO 8601 strings
        var parseShim = function parse(string) {
            var match = isoDateExpression.exec(string);
            if (match) {
                // parse months, days, hours, minutes, seconds, and milliseconds
                // provide default values if necessary
                // parse the UTC offset component
                var year = $Number(match[1]),
                    month = $Number(match[2] || 1) - 1,
                    day = $Number(match[3] || 1) - 1,
                    hour = $Number(match[4] || 0),
                    minute = $Number(match[5] || 0),
                    second = $Number(match[6] || 0),
                    millisecond = Math.floor($Number(match[7] || 0) * 1000),
                    // When time zone is missed, local offset should be used
                    // (ES 5.1 bug)
                    // see https://bugs.ecmascript.org/show_bug.cgi?id=112
                    isLocalTime = Boolean(match[4] && !match[8]),
                    signOffset = match[9] === '-' ? 1 : -1,
                    hourOffset = $Number(match[10] || 0),
                    minuteOffset = $Number(match[11] || 0),
                    result;
                var hasMinutesOrSecondsOrMilliseconds = minute > 0 || second > 0 || millisecond > 0;
                if (
                    hour < (hasMinutesOrSecondsOrMilliseconds ? 24 : 25) &&
                    minute < 60 && second < 60 && millisecond < 1000 &&
                    month > -1 && month < 12 && hourOffset < 24 &&
                    minuteOffset < 60 && // detect invalid offsets
                    day > -1 &&
                    day < (dayFromMonth(year, month + 1) - dayFromMonth(year, month))
                ) {
                    result = (
                        (dayFromMonth(year, month) + day) * 24 +
                        hour +
                        hourOffset * signOffset
                    ) * 60;
                    result = (
                        (result + minute + minuteOffset * signOffset) * 60 +
                        second
                    ) * 1000 + millisecond;
                    if (isLocalTime) {
                        result = toUTC(result);
                    }
                    if (-8.64e15 <= result && result <= 8.64e15) {
                        return result;
                    }
                }
                return NaN;
            }
            return NativeDate.parse.apply(this, arguments);
        };
        defineProperties(DateShim, { parse: parseShim });

        return DateShim;
    }(Date));
    /* global Date: false */
}

// ES5 15.9.4.4
// http://es5.github.com/#x15.9.4.4
if (!Date.now) {
    Date.now = function now() {
        return new Date().getTime();
    };
}

//
// Number
// ======
//

// ES5.1 15.7.4.5
// http://es5.github.com/#x15.7.4.5
var hasToFixedBugs = NumberPrototype.toFixed && (
  (0.00008).toFixed(3) !== '0.000' ||
  (0.9).toFixed(0) !== '1' ||
  (1.255).toFixed(2) !== '1.25' ||
  (1000000000000000128).toFixed(0) !== '1000000000000000128'
);

var toFixedHelpers = {
  base: 1e7,
  size: 6,
  data: [0, 0, 0, 0, 0, 0],
  multiply: function multiply(n, c) {
      var i = -1;
      var c2 = c;
      while (++i < toFixedHelpers.size) {
          c2 += n * toFixedHelpers.data[i];
          toFixedHelpers.data[i] = c2 % toFixedHelpers.base;
          c2 = Math.floor(c2 / toFixedHelpers.base);
      }
  },
  divide: function divide(n) {
      var i = toFixedHelpers.size;
      var c = 0;
      while (--i >= 0) {
          c += toFixedHelpers.data[i];
          toFixedHelpers.data[i] = Math.floor(c / n);
          c = (c % n) * toFixedHelpers.base;
      }
  },
  numToString: function numToString() {
      var i = toFixedHelpers.size;
      var s = '';
      while (--i >= 0) {
          if (s !== '' || i === 0 || toFixedHelpers.data[i] !== 0) {
              var t = $String(toFixedHelpers.data[i]);
              if (s === '') {
                  s = t;
              } else {
                  s += strSlice('0000000', 0, 7 - t.length) + t;
              }
          }
      }
      return s;
  },
  pow: function pow(x, n, acc) {
      return (n === 0 ? acc : (n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc)));
  },
  log: function log(x) {
      var n = 0;
      var x2 = x;
      while (x2 >= 4096) {
          n += 12;
          x2 /= 4096;
      }
      while (x2 >= 2) {
          n += 1;
          x2 /= 2;
      }
      return n;
  }
};

var toFixedShim = function toFixed(fractionDigits) {
    var f, x, s, m, e, z, j, k;

    // Test for NaN and round fractionDigits down
    f = $Number(fractionDigits);
    f = isActualNaN(f) ? 0 : Math.floor(f);

    if (f < 0 || f > 20) {
        throw new RangeError('Number.toFixed called with invalid number of decimals');
    }

    x = $Number(this);

    if (isActualNaN(x)) {
        return 'NaN';
    }

    // If it is too big or small, return the string value of the number
    if (x <= -1e21 || x >= 1e21) {
        return $String(x);
    }

    s = '';

    if (x < 0) {
        s = '-';
        x = -x;
    }

    m = '0';

    if (x > 1e-21) {
        // 1e-21 < x < 1e21
        // -70 < log2(x) < 70
        e = toFixedHelpers.log(x * toFixedHelpers.pow(2, 69, 1)) - 69;
        z = (e < 0 ? x * toFixedHelpers.pow(2, -e, 1) : x / toFixedHelpers.pow(2, e, 1));
        z *= 0x10000000000000; // Math.pow(2, 52);
        e = 52 - e;

        // -18 < e < 122
        // x = z / 2 ^ e
        if (e > 0) {
            toFixedHelpers.multiply(0, z);
            j = f;

            while (j >= 7) {
                toFixedHelpers.multiply(1e7, 0);
                j -= 7;
            }

            toFixedHelpers.multiply(toFixedHelpers.pow(10, j, 1), 0);
            j = e - 1;

            while (j >= 23) {
                toFixedHelpers.divide(1 << 23);
                j -= 23;
            }

            toFixedHelpers.divide(1 << j);
            toFixedHelpers.multiply(1, 1);
            toFixedHelpers.divide(2);
            m = toFixedHelpers.numToString();
        } else {
            toFixedHelpers.multiply(0, z);
            toFixedHelpers.multiply(1 << (-e), 0);
            m = toFixedHelpers.numToString() + strSlice('0.00000000000000000000', 2, 2 + f);
        }
    }

    if (f > 0) {
        k = m.length;

        if (k <= f) {
            m = s + strSlice('0.0000000000000000000', 0, f - k + 2) + m;
        } else {
            m = s + strSlice(m, 0, k - f) + '.' + strSlice(m, k - f);
        }
    } else {
        m = s + m;
    }

    return m;
};
defineProperties(NumberPrototype, { toFixed: toFixedShim }, hasToFixedBugs);

var hasToPrecisionUndefinedBug = (function () {
    try {
        return 1.0.toPrecision(undefined) === '1';
    } catch (e) {
        return true;
    }
}());
var originalToPrecision = NumberPrototype.toPrecision;
defineProperties(NumberPrototype, {
    toPrecision: function toPrecision(precision) {
        return typeof precision === 'undefined' ? originalToPrecision.call(this) : originalToPrecision.call(this, precision);
    }
}, hasToPrecisionUndefinedBug);

//
// String
// ======
//

// ES5 15.5.4.14
// http://es5.github.com/#x15.5.4.14

// [bugfix, IE lt 9, firefox 4, Konqueror, Opera, obscure browsers]
// Many browsers do not split properly with regular expressions or they
// do not perform the split correctly under obscure conditions.
// See http://blog.stevenlevithan.com/archives/cross-browser-split
// I've tested in many browsers and this seems to cover the deviant ones:
//    'ab'.split(/(?:ab)*/) should be ["", ""], not [""]
//    '.'.split(/(.?)(.?)/) should be ["", ".", "", ""], not ["", ""]
//    'tesst'.split(/(s)*/) should be ["t", undefined, "e", "s", "t"], not
//       [undefined, "t", undefined, "e", ...]
//    ''.split(/.?/) should be [], not [""]
//    '.'.split(/()()/) should be ["."], not ["", "", "."]

if (
    'ab'.split(/(?:ab)*/).length !== 2 ||
    '.'.split(/(.?)(.?)/).length !== 4 ||
    'tesst'.split(/(s)*/)[1] === 't' ||
    'test'.split(/(?:)/, -1).length !== 4 ||
    ''.split(/.?/).length ||
    '.'.split(/()()/).length > 1
) {
    (function () {
        var compliantExecNpcg = typeof (/()??/).exec('')[1] === 'undefined'; // NPCG: nonparticipating capturing group
        var maxSafe32BitInt = Math.pow(2, 32) - 1;

        StringPrototype.split = function (separator, limit) {
            var string = String(this);
            if (typeof separator === 'undefined' && limit === 0) {
                return [];
            }

            // If `separator` is not a regex, use native split
            if (!isRegex(separator)) {
                return strSplit(this, separator, limit);
            }

            var output = [];
            var flags = (separator.ignoreCase ? 'i' : '') +
                        (separator.multiline ? 'm' : '') +
                        (separator.unicode ? 'u' : '') + // in ES6
                        (separator.sticky ? 'y' : ''), // Firefox 3+ and ES6
                lastLastIndex = 0,
                // Make `global` and avoid `lastIndex` issues by working with a copy
                separator2, match, lastIndex, lastLength;
            var separatorCopy = new RegExp(separator.source, flags + 'g');
            if (!compliantExecNpcg) {
                // Doesn't need flags gy, but they don't hurt
                separator2 = new RegExp('^' + separatorCopy.source + '$(?!\\s)', flags);
            }
            /* Values for `limit`, per the spec:
             * If undefined: 4294967295 // maxSafe32BitInt
             * If 0, Infinity, or NaN: 0
             * If positive number: limit = Math.floor(limit); if (limit > 4294967295) limit -= 4294967296;
             * If negative number: 4294967296 - Math.floor(Math.abs(limit))
             * If other: Type-convert, then use the above rules
             */
            var splitLimit = typeof limit === 'undefined' ? maxSafe32BitInt : ES.ToUint32(limit);
            match = separatorCopy.exec(string);
            while (match) {
                // `separatorCopy.lastIndex` is not reliable cross-browser
                lastIndex = match.index + match[0].length;
                if (lastIndex > lastLastIndex) {
                    pushCall(output, strSlice(string, lastLastIndex, match.index));
                    // Fix browsers whose `exec` methods don't consistently return `undefined` for
                    // nonparticipating capturing groups
                    if (!compliantExecNpcg && match.length > 1) {
                        /* eslint-disable no-loop-func */
                        match[0].replace(separator2, function () {
                            for (var i = 1; i < arguments.length - 2; i++) {
                                if (typeof arguments[i] === 'undefined') {
                                    match[i] = void 0;
                                }
                            }
                        });
                        /* eslint-enable no-loop-func */
                    }
                    if (match.length > 1 && match.index < string.length) {
                        array_push.apply(output, arraySlice(match, 1));
                    }
                    lastLength = match[0].length;
                    lastLastIndex = lastIndex;
                    if (output.length >= splitLimit) {
                        break;
                    }
                }
                if (separatorCopy.lastIndex === match.index) {
                    separatorCopy.lastIndex++; // Avoid an infinite loop
                }
                match = separatorCopy.exec(string);
            }
            if (lastLastIndex === string.length) {
                if (lastLength || !separatorCopy.test('')) {
                    pushCall(output, '');
                }
            } else {
                pushCall(output, strSlice(string, lastLastIndex));
            }
            return output.length > splitLimit ? arraySlice(output, 0, splitLimit) : output;
        };
    }());

// [bugfix, chrome]
// If separator is undefined, then the result array contains just one String,
// which is the this value (converted to a String). If limit is not undefined,
// then the output array is truncated so that it contains no more than limit
// elements.
// "0".split(undefined, 0) -> []
} else if ('0'.split(void 0, 0).length) {
    StringPrototype.split = function split(separator, limit) {
        if (typeof separator === 'undefined' && limit === 0) { return []; }
        return strSplit(this, separator, limit);
    };
}

var str_replace = StringPrototype.replace;
var replaceReportsGroupsCorrectly = (function () {
    var groups = [];
    'x'.replace(/x(.)?/g, function (match, group) {
        pushCall(groups, group);
    });
    return groups.length === 1 && typeof groups[0] === 'undefined';
}());

if (!replaceReportsGroupsCorrectly) {
    StringPrototype.replace = function replace(searchValue, replaceValue) {
        var isFn = isCallable(replaceValue);
        var hasCapturingGroups = isRegex(searchValue) && (/\)[*?]/).test(searchValue.source);
        if (!isFn || !hasCapturingGroups) {
            return str_replace.call(this, searchValue, replaceValue);
        } else {
            var wrappedReplaceValue = function (match) {
                var length = arguments.length;
                var originalLastIndex = searchValue.lastIndex;
                searchValue.lastIndex = 0;
                var args = searchValue.exec(match) || [];
                searchValue.lastIndex = originalLastIndex;
                pushCall(args, arguments[length - 2], arguments[length - 1]);
                return replaceValue.apply(this, args);
            };
            return str_replace.call(this, searchValue, wrappedReplaceValue);
        }
    };
}

// ECMA-262, 3rd B.2.3
// Not an ECMAScript standard, although ECMAScript 3rd Edition has a
// non-normative section suggesting uniform semantics and it should be
// normalized across all browsers
// [bugfix, IE lt 9] IE < 9 substr() with negative value not working in IE
var string_substr = StringPrototype.substr;
var hasNegativeSubstrBug = ''.substr && '0b'.substr(-1) !== 'b';
defineProperties(StringPrototype, {
    substr: function substr(start, length) {
        var normalizedStart = start;
        if (start < 0) {
            normalizedStart = max(this.length + start, 0);
        }
        return string_substr.call(this, normalizedStart, length);
    }
}, hasNegativeSubstrBug);

// ES5 15.5.4.20
// whitespace from: http://es5.github.io/#x15.5.4.20
var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003' +
    '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028' +
    '\u2029\uFEFF';
var zeroWidth = '\u200b';
var wsRegexChars = '[' + ws + ']';
var trimBeginRegexp = new RegExp('^' + wsRegexChars + wsRegexChars + '*');
var trimEndRegexp = new RegExp(wsRegexChars + wsRegexChars + '*$');
var hasTrimWhitespaceBug = StringPrototype.trim && (ws.trim() || !zeroWidth.trim());
defineProperties(StringPrototype, {
    // http://blog.stevenlevithan.com/archives/faster-trim-javascript
    // http://perfectionkills.com/whitespace-deviations/
    trim: function trim() {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        return $String(this).replace(trimBeginRegexp, '').replace(trimEndRegexp, '');
    }
}, hasTrimWhitespaceBug);
var trim = call.bind(String.prototype.trim);

var hasLastIndexBug = StringPrototype.lastIndexOf && 'abcあい'.lastIndexOf('あい', 2) !== -1;
defineProperties(StringPrototype, {
    lastIndexOf: function lastIndexOf(searchString) {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        var S = $String(this);
        var searchStr = $String(searchString);
        var numPos = arguments.length > 1 ? $Number(arguments[1]) : NaN;
        var pos = isActualNaN(numPos) ? Infinity : ES.ToInteger(numPos);
        var start = min(max(pos, 0), S.length);
        var searchLen = searchStr.length;
        var k = start + searchLen;
        while (k > 0) {
            k = max(0, k - searchLen);
            var index = strIndexOf(strSlice(S, k, start + searchLen), searchStr);
            if (index !== -1) {
                return k + index;
            }
        }
        return -1;
    }
}, hasLastIndexBug);

var originalLastIndexOf = StringPrototype.lastIndexOf;
defineProperties(StringPrototype, {
    lastIndexOf: function lastIndexOf(searchString) {
        return originalLastIndexOf.apply(this, arguments);
    }
}, StringPrototype.lastIndexOf.length !== 1);

// ES-5 15.1.2.2
/* eslint-disable radix */
if (parseInt(ws + '08') !== 8 || parseInt(ws + '0x16') !== 22) {
/* eslint-enable radix */
    /* global parseInt: true */
    parseInt = (function (origParseInt) {
        var hexRegex = /^[\-+]?0[xX]/;
        return function parseInt(str, radix) {
            var string = trim(str);
            var defaultedRadix = $Number(radix) || (hexRegex.test(string) ? 16 : 10);
            return origParseInt(string, defaultedRadix);
        };
    }(parseInt));
}

// https://es5.github.io/#x15.1.2.3
if (1 / parseFloat('-0') !== -Infinity) {
    /* global parseFloat: true */
    parseFloat = (function (origParseFloat) {
        return function parseFloat(string) {
            var inputString = trim(string);
            var result = origParseFloat(inputString);
            return result === 0 && strSlice(inputString, 0, 1) === '-' ? -0 : result;
        };
    }(parseFloat));
}

if (String(new RangeError('test')) !== 'RangeError: test') {
    var errorToStringShim = function toString() {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        var name = this.name;
        if (typeof name === 'undefined') {
            name = 'Error';
        } else if (typeof name !== 'string') {
            name = $String(name);
        }
        var msg = this.message;
        if (typeof msg === 'undefined') {
            msg = '';
        } else if (typeof msg !== 'string') {
            msg = $String(msg);
        }
        if (!name) {
            return msg;
        }
        if (!msg) {
            return name;
        }
        return name + ': ' + msg;
    };
    // can't use defineProperties here because of toString enumeration issue in IE <= 8
    Error.prototype.toString = errorToStringShim;
}

if (supportsDescriptors) {
    var ensureNonEnumerable = function (obj, prop) {
        if (isEnum(obj, prop)) {
            var desc = Object.getOwnPropertyDescriptor(obj, prop);
            desc.enumerable = false;
            Object.defineProperty(obj, prop, desc);
        }
    };
    ensureNonEnumerable(Error.prototype, 'message');
    if (Error.prototype.message !== '') {
      Error.prototype.message = '';
    }
    ensureNonEnumerable(Error.prototype, 'name');
}

if (String(/a/mig) !== '/a/gim') {
    var regexToString = function toString() {
        var str = '/' + this.source + '/';
        if (this.global) {
            str += 'g';
        }
        if (this.ignoreCase) {
            str += 'i';
        }
        if (this.multiline) {
            str += 'm';
        }
        return str;
    };
    // can't use defineProperties here because of toString enumeration issue in IE <= 8
    RegExp.prototype.toString = regexToString;
}

}));

/*!
 * https://github.com/es-shims/es5-shim
 * @license es5-shim Copyright 2009-2015 by contributors, MIT License
 * see https://github.com/es-shims/es5-shim/blob/master/LICENSE
 */

// vim: ts=4 sts=4 sw=4 expandtab

// Add semicolon to prevent IIFE from being passed as argument to concatenated code.
;

// UMD (Universal Module Definition)
// see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
(function (root, factory) {
    'use strict';

    /* global define, exports, module */
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals (root is window)
        root.returnExports = factory();
    }
}(this, function () {

    var call = Function.call;
    var prototypeOfObject = Object.prototype;
    var owns = call.bind(prototypeOfObject.hasOwnProperty);
    var isEnumerable = call.bind(prototypeOfObject.propertyIsEnumerable);
    var toStr = call.bind(prototypeOfObject.toString);

    // If JS engine supports accessors creating shortcuts.
    var defineGetter;
    var defineSetter;
    var lookupGetter;
    var lookupSetter;
    var supportsAccessors = owns(prototypeOfObject, '__defineGetter__');
    if (supportsAccessors) {
        /* eslint-disable no-underscore-dangle, no-restricted-properties */
        defineGetter = call.bind(prototypeOfObject.__defineGetter__);
        defineSetter = call.bind(prototypeOfObject.__defineSetter__);
        lookupGetter = call.bind(prototypeOfObject.__lookupGetter__);
        lookupSetter = call.bind(prototypeOfObject.__lookupSetter__);
        /* eslint-enable no-underscore-dangle, no-restricted-properties */
    }

    var isPrimitive = function isPrimitive(o) {
        return o == null || (typeof o !== 'object' && typeof o !== 'function');
    };

    // ES5 15.2.3.2
    // http://es5.github.com/#x15.2.3.2
    if (!Object.getPrototypeOf) {
        // https://github.com/es-shims/es5-shim/issues#issue/2
        // http://ejohn.org/blog/objectgetprototypeof/
        // recommended by fschaefer on github
        //
        // sure, and webreflection says ^_^
        // ... this will nerever possibly return null
        // ... Opera Mini breaks here with infinite loops
        Object.getPrototypeOf = function getPrototypeOf(object) {
            // eslint-disable-next-line no-proto
            var proto = object.__proto__;
            if (proto || proto === null) {
                return proto;
            } else if (toStr(object.constructor) === '[object Function]') {
                return object.constructor.prototype;
            } else if (object instanceof Object) {
                return prototypeOfObject;
            } else {
                // Correctly return null for Objects created with `Object.create(null)`
                // (shammed or native) or `{ __proto__: null}`.  Also returns null for
                // cross-realm objects on browsers that lack `__proto__` support (like
                // IE <11), but that's the best we can do.
                return null;
            }
        };
    }

    // ES5 15.2.3.3
    // http://es5.github.com/#x15.2.3.3

    var doesGetOwnPropertyDescriptorWork = function doesGetOwnPropertyDescriptorWork(object) {
        try {
            object.sentinel = 0;
            return Object.getOwnPropertyDescriptor(object, 'sentinel').value === 0;
        } catch (exception) {
            return false;
        }
    };

    // check whether getOwnPropertyDescriptor works if it's given. Otherwise, shim partially.
    if (Object.defineProperty) {
        var getOwnPropertyDescriptorWorksOnObject = doesGetOwnPropertyDescriptorWork({});
        var getOwnPropertyDescriptorWorksOnDom = typeof document === 'undefined' ||
            doesGetOwnPropertyDescriptorWork(document.createElement('div'));
        if (!getOwnPropertyDescriptorWorksOnDom || !getOwnPropertyDescriptorWorksOnObject) {
            var getOwnPropertyDescriptorFallback = Object.getOwnPropertyDescriptor;
        }
    }

    if (!Object.getOwnPropertyDescriptor || getOwnPropertyDescriptorFallback) {
        var ERR_NON_OBJECT = 'Object.getOwnPropertyDescriptor called on a non-object: ';

        /* eslint-disable no-proto */
        Object.getOwnPropertyDescriptor = function getOwnPropertyDescriptor(object, property) {
            if (isPrimitive(object)) {
                throw new TypeError(ERR_NON_OBJECT + object);
            }

            // make a valiant attempt to use the real getOwnPropertyDescriptor
            // for I8's DOM elements.
            if (getOwnPropertyDescriptorFallback) {
                try {
                    return getOwnPropertyDescriptorFallback.call(Object, object, property);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            var descriptor;

            // If object does not owns property return undefined immediately.
            if (!owns(object, property)) {
                return descriptor;
            }

            // If object has a property then it's for sure `configurable`, and
            // probably `enumerable`. Detect enumerability though.
            descriptor = {
                enumerable: isEnumerable(object, property),
                configurable: true
            };

            // If JS engine supports accessor properties then property may be a
            // getter or setter.
            if (supportsAccessors) {
                // Unfortunately `__lookupGetter__` will return a getter even
                // if object has own non getter property along with a same named
                // inherited getter. To avoid misbehavior we temporary remove
                // `__proto__` so that `__lookupGetter__` will return getter only
                // if it's owned by an object.
                var prototype = object.__proto__;
                var notPrototypeOfObject = object !== prototypeOfObject;
                // avoid recursion problem, breaking in Opera Mini when
                // Object.getOwnPropertyDescriptor(Object.prototype, 'toString')
                // or any other Object.prototype accessor
                if (notPrototypeOfObject) {
                    object.__proto__ = prototypeOfObject;
                }

                var getter = lookupGetter(object, property);
                var setter = lookupSetter(object, property);

                if (notPrototypeOfObject) {
                    // Once we have getter and setter we can put values back.
                    object.__proto__ = prototype;
                }

                if (getter || setter) {
                    if (getter) {
                        descriptor.get = getter;
                    }
                    if (setter) {
                        descriptor.set = setter;
                    }
                    // If it was accessor property we're done and return here
                    // in order to avoid adding `value` to the descriptor.
                    return descriptor;
                }
            }

            // If we got this far we know that object has an own property that is
            // not an accessor so we set it as a value and return descriptor.
            descriptor.value = object[property];
            descriptor.writable = true;
            return descriptor;
        };
        /* eslint-enable no-proto */
    }

    // ES5 15.2.3.4
    // http://es5.github.com/#x15.2.3.4
    if (!Object.getOwnPropertyNames) {
        Object.getOwnPropertyNames = function getOwnPropertyNames(object) {
            return Object.keys(object);
        };
    }

    // ES5 15.2.3.5
    // http://es5.github.com/#x15.2.3.5
    if (!Object.create) {

        // Contributed by Brandon Benvie, October, 2012
        var createEmpty;
        var supportsProto = !({ __proto__: null } instanceof Object);
        // the following produces false positives
        // in Opera Mini => not a reliable check
        // Object.prototype.__proto__ === null

        // Check for document.domain and active x support
        // No need to use active x approach when document.domain is not set
        // see https://github.com/es-shims/es5-shim/issues/150
        // variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
        /* global ActiveXObject */
        var shouldUseActiveX = function shouldUseActiveX() {
            // return early if document.domain not set
            if (!document.domain) {
                return false;
            }

            try {
                return !!new ActiveXObject('htmlfile');
            } catch (exception) {
                return false;
            }
        };

        // This supports IE8 when document.domain is used
        // see https://github.com/es-shims/es5-shim/issues/150
        // variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
        var getEmptyViaActiveX = function getEmptyViaActiveX() {
            var empty;
            var xDoc;

            xDoc = new ActiveXObject('htmlfile');

            var script = 'script';
            xDoc.write('<' + script + '></' + script + '>');
            xDoc.close();

            empty = xDoc.parentWindow.Object.prototype;
            xDoc = null;

            return empty;
        };

        // The original implementation using an iframe
        // before the activex approach was added
        // see https://github.com/es-shims/es5-shim/issues/150
        var getEmptyViaIFrame = function getEmptyViaIFrame() {
            var iframe = document.createElement('iframe');
            var parent = document.body || document.documentElement;
            var empty;

            iframe.style.display = 'none';
            parent.appendChild(iframe);
            // eslint-disable-next-line no-script-url
            iframe.src = 'javascript:';

            empty = iframe.contentWindow.Object.prototype;
            parent.removeChild(iframe);
            iframe = null;

            return empty;
        };

        /* global document */
        if (supportsProto || typeof document === 'undefined') {
            createEmpty = function () {
                return { __proto__: null };
            };
        } else {
            // In old IE __proto__ can't be used to manually set `null`, nor does
            // any other method exist to make an object that inherits from nothing,
            // aside from Object.prototype itself. Instead, create a new global
            // object and *steal* its Object.prototype and strip it bare. This is
            // used as the prototype to create nullary objects.
            createEmpty = function () {
                // Determine which approach to use
                // see https://github.com/es-shims/es5-shim/issues/150
                var empty = shouldUseActiveX() ? getEmptyViaActiveX() : getEmptyViaIFrame();

                delete empty.constructor;
                delete empty.hasOwnProperty;
                delete empty.propertyIsEnumerable;
                delete empty.isPrototypeOf;
                delete empty.toLocaleString;
                delete empty.toString;
                delete empty.valueOf;

                var Empty = function Empty() {};
                Empty.prototype = empty;
                // short-circuit future calls
                createEmpty = function () {
                    return new Empty();
                };
                return new Empty();
            };
        }

        Object.create = function create(prototype, properties) {

            var object;
            var Type = function Type() {}; // An empty constructor.

            if (prototype === null) {
                object = createEmpty();
            } else {
                if (prototype !== null && isPrimitive(prototype)) {
                    // In the native implementation `parent` can be `null`
                    // OR *any* `instanceof Object`  (Object|Function|Array|RegExp|etc)
                    // Use `typeof` tho, b/c in old IE, DOM elements are not `instanceof Object`
                    // like they are in modern browsers. Using `Object.create` on DOM elements
                    // is...err...probably inappropriate, but the native version allows for it.
                    throw new TypeError('Object prototype may only be an Object or null'); // same msg as Chrome
                }
                Type.prototype = prototype;
                object = new Type();
                // IE has no built-in implementation of `Object.getPrototypeOf`
                // neither `__proto__`, but this manually setting `__proto__` will
                // guarantee that `Object.getPrototypeOf` will work as expected with
                // objects created using `Object.create`
                // eslint-disable-next-line no-proto
                object.__proto__ = prototype;
            }

            if (properties !== void 0) {
                Object.defineProperties(object, properties);
            }

            return object;
        };
    }

    // ES5 15.2.3.6
    // http://es5.github.com/#x15.2.3.6

    // Patch for WebKit and IE8 standard mode
    // Designed by hax <hax.github.com>
    // related issue: https://github.com/es-shims/es5-shim/issues#issue/5
    // IE8 Reference:
    //     http://msdn.microsoft.com/en-us/library/dd282900.aspx
    //     http://msdn.microsoft.com/en-us/library/dd229916.aspx
    // WebKit Bugs:
    //     https://bugs.webkit.org/show_bug.cgi?id=36423

    var doesDefinePropertyWork = function doesDefinePropertyWork(object) {
        try {
            Object.defineProperty(object, 'sentinel', {});
            return 'sentinel' in object;
        } catch (exception) {
            return false;
        }
    };

    // check whether defineProperty works if it's given. Otherwise,
    // shim partially.
    if (Object.defineProperty) {
        var definePropertyWorksOnObject = doesDefinePropertyWork({});
        var definePropertyWorksOnDom = typeof document === 'undefined' ||
            doesDefinePropertyWork(document.createElement('div'));
        if (!definePropertyWorksOnObject || !definePropertyWorksOnDom) {
            var definePropertyFallback = Object.defineProperty,
                definePropertiesFallback = Object.defineProperties;
        }
    }

    if (!Object.defineProperty || definePropertyFallback) {
        var ERR_NON_OBJECT_DESCRIPTOR = 'Property description must be an object: ';
        var ERR_NON_OBJECT_TARGET = 'Object.defineProperty called on non-object: ';
        var ERR_ACCESSORS_NOT_SUPPORTED = 'getters & setters can not be defined on this javascript engine';

        Object.defineProperty = function defineProperty(object, property, descriptor) {
            if (isPrimitive(object)) {
                throw new TypeError(ERR_NON_OBJECT_TARGET + object);
            }
            if (isPrimitive(descriptor)) {
                throw new TypeError(ERR_NON_OBJECT_DESCRIPTOR + descriptor);
            }
            // make a valiant attempt to use the real defineProperty
            // for I8's DOM elements.
            if (definePropertyFallback) {
                try {
                    return definePropertyFallback.call(Object, object, property, descriptor);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            // If it's a data property.
            if ('value' in descriptor) {
                // fail silently if 'writable', 'enumerable', or 'configurable'
                // are requested but not supported
                /*
                // alternate approach:
                if ( // can't implement these features; allow false but not true
                    ('writable' in descriptor && !descriptor.writable) ||
                    ('enumerable' in descriptor && !descriptor.enumerable) ||
                    ('configurable' in descriptor && !descriptor.configurable)
                ))
                    throw new RangeError(
                        'This implementation of Object.defineProperty does not support configurable, enumerable, or writable.'
                    );
                */

                if (supportsAccessors && (lookupGetter(object, property) || lookupSetter(object, property))) {
                    // As accessors are supported only on engines implementing
                    // `__proto__` we can safely override `__proto__` while defining
                    // a property to make sure that we don't hit an inherited
                    // accessor.
                    /* eslint-disable no-proto */
                    var prototype = object.__proto__;
                    object.__proto__ = prototypeOfObject;
                    // Deleting a property anyway since getter / setter may be
                    // defined on object itself.
                    delete object[property];
                    object[property] = descriptor.value;
                    // Setting original `__proto__` back now.
                    object.__proto__ = prototype;
                    /* eslint-enable no-proto */
                } else {
                    object[property] = descriptor.value;
                }
            } else {
                var hasGetter = 'get' in descriptor;
                var hasSetter = 'set' in descriptor;
                if (!supportsAccessors && (hasGetter || hasSetter)) {
                    throw new TypeError(ERR_ACCESSORS_NOT_SUPPORTED);
                }
                // If we got that far then getters and setters can be defined !!
                if (hasGetter) {
                    defineGetter(object, property, descriptor.get);
                }
                if (hasSetter) {
                    defineSetter(object, property, descriptor.set);
                }
            }
            return object;
        };
    }

    // ES5 15.2.3.7
    // http://es5.github.com/#x15.2.3.7
    if (!Object.defineProperties || definePropertiesFallback) {
        Object.defineProperties = function defineProperties(object, properties) {
            // make a valiant attempt to use the real defineProperties
            if (definePropertiesFallback) {
                try {
                    return definePropertiesFallback.call(Object, object, properties);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            Object.keys(properties).forEach(function (property) {
                if (property !== '__proto__') {
                    Object.defineProperty(object, property, properties[property]);
                }
            });
            return object;
        };
    }

    // ES5 15.2.3.8
    // http://es5.github.com/#x15.2.3.8
    if (!Object.seal) {
        Object.seal = function seal(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.seal can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // ES5 15.2.3.9
    // http://es5.github.com/#x15.2.3.9
    if (!Object.freeze) {
        Object.freeze = function freeze(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.freeze can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // detect a Rhino bug and patch it
    try {
        Object.freeze(function () {});
    } catch (exception) {
        Object.freeze = (function (freezeObject) {
            return function freeze(object) {
                if (typeof object === 'function') {
                    return object;
                } else {
                    return freezeObject(object);
                }
            };
        }(Object.freeze));
    }

    // ES5 15.2.3.10
    // http://es5.github.com/#x15.2.3.10
    if (!Object.preventExtensions) {
        Object.preventExtensions = function preventExtensions(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.preventExtensions can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // ES5 15.2.3.11
    // http://es5.github.com/#x15.2.3.11
    if (!Object.isSealed) {
        Object.isSealed = function isSealed(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.isSealed can only be called on Objects.');
            }
            return false;
        };
    }

    // ES5 15.2.3.12
    // http://es5.github.com/#x15.2.3.12
    if (!Object.isFrozen) {
        Object.isFrozen = function isFrozen(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.isFrozen can only be called on Objects.');
            }
            return false;
        };
    }

    // ES5 15.2.3.13
    // http://es5.github.com/#x15.2.3.13
    if (!Object.isExtensible) {
        Object.isExtensible = function isExtensible(object) {
            // 1. If Type(O) is not Object throw a TypeError exception.
            if (Object(object) !== object) {
                throw new TypeError('Object.isExtensible can only be called on Objects.');
            }
            // 2. Return the Boolean value of the [[Extensible]] internal property of O.
            var name = '';
            while (owns(object, name)) {
                name += '?';
            }
            object[name] = true;
            var returnValue = owns(object, name);
            delete object[name];
            return returnValue;
        };
    }

}));
/*!
 * jQuery JavaScript Library v1.11.3
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2015-04-28T16:19Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper window is present,
		// execute the factory and get jQuery
		// For environments that do not inherently posses a window with a document
		// (such as Node.js), expose a jQuery-making factory as module.exports
		// This accentuates the need for the creation of a real window
		// e.g. var jQuery = require("jquery")(window);
		// See ticket #14549 for more info
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Can't do this because several apps including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
// Support: Firefox 18+
//

var deletedIds = [];

var slice = deletedIds.slice;

var concat = deletedIds.concat;

var push = deletedIds.push;

var indexOf = deletedIds.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	version = "1.11.3",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1, IE<9
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: deletedIds.sort,
	splice: deletedIds.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var src, copyIsArray, copy, name, options, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		/* jshint eqeqeq: false */
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		// adding 1 corrects loss of precision from parseFloat (#15100)
		return !jQuery.isArray( obj ) && (obj - parseFloat( obj ) + 1) >= 0;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	isPlainObject: function( obj ) {
		var key;

		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!hasOwn.call(obj, "constructor") &&
				!hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Support: IE<9
		// Handle iteration over inherited properties before own properties.
		if ( support.ownLast ) {
			for ( key in obj ) {
				return hasOwn.call( obj, key );
			}
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.
		for ( key in obj ) {}

		return key === undefined || hasOwn.call( obj, key );
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && jQuery.trim( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1, IE<9
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		var len;

		if ( arr ) {
			if ( indexOf ) {
				return indexOf.call( arr, elem, i );
			}

			len = arr.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in arr && arr[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		while ( j < len ) {
			first[ i++ ] = second[ j++ ];
		}

		// Support: IE<9
		// Workaround casting of .length to NaN on otherwise arraylike objects (e.g., NodeLists)
		if ( len !== len ) {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var args, proxy, tmp;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: function() {
		return +( new Date() );
	},

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {

	// Support: iOS 8.2 (not reproducible in simulator)
	// `in` check used to prevent JIT error (gh-2145)
	// hasOwn isn't used here due to false negatives
	// regarding Nodelist length in IE
	var length = "length" in obj && obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v2.2.0-pre
 * http://sizzlejs.com/
 *
 * Copyright 2008, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-12-16
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + 1 * new Date(),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf as it's faster than native
	// http://jsperf.com/thor-indexof-vs-for/5
	indexOf = function( list, elem ) {
		var i = 0,
			len = list.length;
		for ( ; i < len; i++ ) {
			if ( list[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rwhitespace = new RegExp( whitespace + "+", "g" ),
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	},

	// Used for iframes
	// See setDocument()
	// Removing the function wrapper causes a "Permission Denied"
	// error in IE
	unloadHandler = function() {
		setDocument();
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];
	nodeType = context.nodeType;

	if ( typeof selector !== "string" || !selector ||
		nodeType !== 1 && nodeType !== 9 && nodeType !== 11 ) {

		return results;
	}

	if ( !seed && documentIsHTML ) {

		// Try to shortcut find operations when possible (e.g., not under DocumentFragment)
		if ( nodeType !== 11 && (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType !== 1 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== "undefined" && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare, parent,
		doc = node ? node.ownerDocument || node : preferredDoc;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;
	parent = doc.defaultView;

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", unloadHandler, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", unloadHandler );
		}
	}

	/* Support tests
	---------------------------------------------------------------------- */
	documentIsHTML = !isXML( doc );

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties
	// (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Support: IE<9
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName );

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== "undefined" && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( tag );

			// DocumentFragment nodes don't have gEBTN
			} else if ( support.qsa ) {
				return context.querySelectorAll( tag );
			}
		} :

		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				// By happy coincidence, a (broken) gEBTN appears on DocumentFragment nodes too
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			docElem.appendChild( div ).innerHTML = "<a id='" + expando + "'></a>" +
				"<select id='" + expando + "-\f]' msallowcapture=''>" +
				"<option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowcapture^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Support: Chrome<29, Android<4.2+, Safari<7.0+, iOS<7.0+, PhantomJS<1.9.7+
			if ( !div.querySelectorAll( "[id~=" + expando + "-]" ).length ) {
				rbuggyQSA.push("~=");
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}

			// Support: Safari 8+, iOS 8+
			// https://bugs.webkit.org/show_bug.cgi?id=136851
			// In-page `selector#id sibing-combinator selector` fails
			if ( !div.querySelectorAll( "a#" + expando + "+*" ).length ) {
				rbuggyQSA.push(".#.+[+~]");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch (e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== "undefined" && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result.replace( rwhitespace, " " ) + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					// Don't keep the element (issue #299)
					input[0] = null;
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			text = text.replace( runescape, funescape );
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			var ret = ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
			// Avoid hanging onto element (issue #299)
			checkContext = null;
			return ret;
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome 14-35+
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			ret = [],
			self = this,
			len = self.length;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var i,
			targets = jQuery( target, this ),
			len = targets.length;

		return this.filter(function() {
			for ( i = 0; i < len; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.first().prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	do {
		cur = cur[ dir ];
	} while ( cur && cur.nodeType !== 1 );

	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				ret = jQuery.unique( ret );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				ret = ret.reverse();
			}
		}

		return this.pushStack( ret );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Flag to know if list is currently firing
		firing,
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );

					} else if ( !(--remaining) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// if we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( !document.body ) {
			return setTimeout( jQuery.ready );
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * Clean-up method for dom ready events
 */
function detach() {
	if ( document.addEventListener ) {
		document.removeEventListener( "DOMContentLoaded", completed, false );
		window.removeEventListener( "load", completed, false );

	} else {
		document.detachEvent( "onreadystatechange", completed );
		window.detachEvent( "onload", completed );
	}
}

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	// readyState === "complete" is good enough for us to call the dom ready in oldIE
	if ( document.addEventListener || event.type === "load" || document.readyState === "complete" ) {
		detach();
		jQuery.ready();
	}
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// we once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		// Standards-based browsers support DOMContentLoaded
		} else if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );

		// If IE event model is used
		} else {
			// Ensure firing before onload, maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", completed );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", completed );

			// If IE and not a frame
			// continually check to see if the document is ready
			var top = false;

			try {
				top = window.frameElement == null && document.documentElement;
			} catch(e) {}

			if ( top && top.doScroll ) {
				(function doScrollCheck() {
					if ( !jQuery.isReady ) {

						try {
							// Use the trick by Diego Perini
							// http://javascript.nwbox.com/IEContentLoaded/
							top.doScroll("left");
						} catch(e) {
							return setTimeout( doScrollCheck, 50 );
						}

						// detach all dom ready events
						detach();

						// and execute any waiting functions
						jQuery.ready();
					}
				})();
			}
		}
	}
	return readyList.promise( obj );
};


var strundefined = typeof undefined;



// Support: IE<9
// Iteration over object's inherited properties before its own
var i;
for ( i in jQuery( support ) ) {
	break;
}
support.ownLast = i !== "0";

// Note: most support tests are defined in their respective modules.
// false until the test is run
support.inlineBlockNeedsLayout = false;

// Execute ASAP in case we need to set body.style.zoom
jQuery(function() {
	// Minified: var a,b,c,d
	var val, div, body, container;

	body = document.getElementsByTagName( "body" )[ 0 ];
	if ( !body || !body.style ) {
		// Return for frameset docs that don't have a body
		return;
	}

	// Setup
	div = document.createElement( "div" );
	container = document.createElement( "div" );
	container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
	body.appendChild( container ).appendChild( div );

	if ( typeof div.style.zoom !== strundefined ) {
		// Support: IE<8
		// Check if natively block-level elements act like inline-block
		// elements when setting their display to 'inline' and giving
		// them layout
		div.style.cssText = "display:inline;margin:0;border:0;padding:1px;width:1px;zoom:1";

		support.inlineBlockNeedsLayout = val = div.offsetWidth === 3;
		if ( val ) {
			// Prevent IE 6 from affecting layout for positioned elements #11048
			// Prevent IE from shrinking the body in IE 7 mode #12869
			// Support: IE<8
			body.style.zoom = 1;
		}
	}

	body.removeChild( container );
});




(function() {
	var div = document.createElement( "div" );

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( elem ) {
	var noData = jQuery.noData[ (elem.nodeName + " ").toLowerCase() ],
		nodeType = +elem.nodeType || 1;

	// Do not set data on non-element DOM nodes because it will not be cleared (#8335).
	return nodeType !== 1 && nodeType !== 9 ?
		false :

		// Nodes accept data unless otherwise specified; rejection can be conditional
		!noData || noData !== true && elem.getAttribute("classid") === noData;
};


var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	var name;
	for ( name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}

function internalData( elem, name, data, pvt /* Internal Use Only */ ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var ret, thisCache,
		internalKey = jQuery.expando,

		// We have to handle DOM nodes and JS objects differently because IE6-7
		// can't GC object references properly across the DOM-JS boundary
		isNode = elem.nodeType,

		// Only DOM nodes need the global jQuery cache; JS object data is
		// attached directly to the object so GC can occur automatically
		cache = isNode ? jQuery.cache : elem,

		// Only defining an ID for JS objects if its cache already exists allows
		// the code to shortcut on the same path as a DOM node with no cache
		id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey;

	// Avoid doing any more work than we need to when trying to get data on an
	// object that has no data at all
	if ( (!id || !cache[id] || (!pvt && !cache[id].data)) && data === undefined && typeof name === "string" ) {
		return;
	}

	if ( !id ) {
		// Only DOM nodes need a new unique ID for each element since their data
		// ends up in the global cache
		if ( isNode ) {
			id = elem[ internalKey ] = deletedIds.pop() || jQuery.guid++;
		} else {
			id = internalKey;
		}
	}

	if ( !cache[ id ] ) {
		// Avoid exposing jQuery metadata on plain JS objects when the object
		// is serialized using JSON.stringify
		cache[ id ] = isNode ? {} : { toJSON: jQuery.noop };
	}

	// An object can be passed to jQuery.data instead of a key/value pair; this gets
	// shallow copied over onto the existing cache
	if ( typeof name === "object" || typeof name === "function" ) {
		if ( pvt ) {
			cache[ id ] = jQuery.extend( cache[ id ], name );
		} else {
			cache[ id ].data = jQuery.extend( cache[ id ].data, name );
		}
	}

	thisCache = cache[ id ];

	// jQuery data() is stored in a separate object inside the object's internal data
	// cache in order to avoid key collisions between internal data and user-defined
	// data.
	if ( !pvt ) {
		if ( !thisCache.data ) {
			thisCache.data = {};
		}

		thisCache = thisCache.data;
	}

	if ( data !== undefined ) {
		thisCache[ jQuery.camelCase( name ) ] = data;
	}

	// Check for both converted-to-camel and non-converted data property names
	// If a data property was specified
	if ( typeof name === "string" ) {

		// First Try to find as-is property data
		ret = thisCache[ name ];

		// Test for null|undefined property data
		if ( ret == null ) {

			// Try to find the camelCased property
			ret = thisCache[ jQuery.camelCase( name ) ];
		}
	} else {
		ret = thisCache;
	}

	return ret;
}

function internalRemoveData( elem, name, pvt ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var thisCache, i,
		isNode = elem.nodeType,

		// See jQuery.data for more information
		cache = isNode ? jQuery.cache : elem,
		id = isNode ? elem[ jQuery.expando ] : jQuery.expando;

	// If there is already no cache entry for this object, there is no
	// purpose in continuing
	if ( !cache[ id ] ) {
		return;
	}

	if ( name ) {

		thisCache = pvt ? cache[ id ] : cache[ id ].data;

		if ( thisCache ) {

			// Support array or space separated string names for data keys
			if ( !jQuery.isArray( name ) ) {

				// try the string as a key before any manipulation
				if ( name in thisCache ) {
					name = [ name ];
				} else {

					// split the camel cased version by spaces unless a key with the spaces exists
					name = jQuery.camelCase( name );
					if ( name in thisCache ) {
						name = [ name ];
					} else {
						name = name.split(" ");
					}
				}
			} else {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = name.concat( jQuery.map( name, jQuery.camelCase ) );
			}

			i = name.length;
			while ( i-- ) {
				delete thisCache[ name[i] ];
			}

			// If there is no data left in the cache, we want to continue
			// and let the cache object itself get destroyed
			if ( pvt ? !isEmptyDataObject(thisCache) : !jQuery.isEmptyObject(thisCache) ) {
				return;
			}
		}
	}

	// See jQuery.data for more information
	if ( !pvt ) {
		delete cache[ id ].data;

		// Don't destroy the parent cache unless the internal data object
		// had been the only thing left in it
		if ( !isEmptyDataObject( cache[ id ] ) ) {
			return;
		}
	}

	// Destroy the cache
	if ( isNode ) {
		jQuery.cleanData( [ elem ], true );

	// Use delete when supported for expandos or `cache` is not a window per isWindow (#10080)
	/* jshint eqeqeq: false */
	} else if ( support.deleteExpando || cache != cache.window ) {
		/* jshint eqeqeq: true */
		delete cache[ id ];

	// When all else fails, null
	} else {
		cache[ id ] = null;
	}
}

jQuery.extend({
	cache: {},

	// The following elements (space-suffixed to avoid Object.prototype collisions)
	// throw uncatchable exceptions if you attempt to set expando properties
	noData: {
		"applet ": true,
		"embed ": true,
		// ...but Flash objects (which have this classid) *can* handle expandos
		"object ": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data ) {
		return internalData( elem, name, data );
	},

	removeData: function( elem, name ) {
		return internalRemoveData( elem, name );
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return internalData( elem, name, data, true );
	},

	_removeData: function( elem, name ) {
		return internalRemoveData( elem, name, true );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[0],
			attrs = elem && elem.attributes;

		// Special expections of .data basically thwart jQuery.access,
		// so implement the relevant behavior ourselves

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		return arguments.length > 1 ?

			// Sets one value
			this.each(function() {
				jQuery.data( this, key, value );
			}) :

			// Gets one value
			// Try to fetch any internally stored data first
			elem ? dataAttr( elem, key, jQuery.data( elem, key ) ) : undefined;
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray(data) ) {
					queue = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// not intended for public consumption - generates a queueHooks object, or returns the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return jQuery._data( elem, key ) || jQuery._data( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				jQuery._removeData( elem, type + "queue" );
				jQuery._removeData( elem, key );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = jQuery._data( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};



// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		length = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < length; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			length ? fn( elems[0], key ) : emptyGet;
};
var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	// Minified: var a,b,c
	var input = document.createElement( "input" ),
		div = document.createElement( "div" ),
		fragment = document.createDocumentFragment();

	// Setup
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";

	// IE strips leading whitespace when .innerHTML is used
	support.leadingWhitespace = div.firstChild.nodeType === 3;

	// Make sure that tbody elements aren't automatically inserted
	// IE will insert them into empty tables
	support.tbody = !div.getElementsByTagName( "tbody" ).length;

	// Make sure that link elements get serialized correctly by innerHTML
	// This requires a wrapper element in IE
	support.htmlSerialize = !!div.getElementsByTagName( "link" ).length;

	// Makes sure cloning an html5 element does not cause problems
	// Where outerHTML is undefined, this still works
	support.html5Clone =
		document.createElement( "nav" ).cloneNode( true ).outerHTML !== "<:nav></:nav>";

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	input.type = "checkbox";
	input.checked = true;
	fragment.appendChild( input );
	support.appendChecked = input.checked;

	// Make sure textarea (and checkbox) defaultValue is properly cloned
	// Support: IE6-IE11+
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;

	// #11217 - WebKit loses check when the name is after the checked attribute
	fragment.appendChild( div );
	div.innerHTML = "<input type='radio' checked='checked' name='t'/>";

	// Support: Safari 5.1, iOS 5.1, Android 4.x, Android 2.3
	// old WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<9
	// Opera does not clone events (and typeof div.attachEvent === undefined).
	// IE9-10 clones events bound via attachEvent, but they don't trigger with .click()
	support.noCloneEvent = true;
	if ( div.attachEvent ) {
		div.attachEvent( "onclick", function() {
			support.noCloneEvent = false;
		});

		div.cloneNode( true ).click();
	}

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}
})();


(function() {
	var i, eventName,
		div = document.createElement( "div" );

	// Support: IE<9 (lack submit/change bubble), Firefox 23+ (lack focusin event)
	for ( i in { submit: true, change: true, focusin: true }) {
		eventName = "on" + i;

		if ( !(support[ i + "Bubbles" ] = eventName in window) ) {
			// Beware of CSP restrictions (https://developer.mozilla.org/en/Security/CSP)
			div.setAttribute( eventName, "t" );
			support[ i + "Bubbles" ] = div.attributes[ eventName ].expando === false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


var rformElems = /^(?:input|select|textarea)$/i,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {
		var tmp, events, t, handleObjIn,
			special, eventHandle, handleObj,
			handlers, type, namespaces, origType,
			elemData = jQuery._data( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {
		var j, handleObj, tmp,
			origCount, t, events,
			special, handlers, type,
			namespaces, origType,
			elemData = jQuery.hasData( elem ) && jQuery._data( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery._removeData( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		var handle, ontype, cur,
			bubbleType, special, tmp, i,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && elem[ type ] && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					try {
						elem[ type ]();
					} catch ( e ) {
						// IE<9 dies on focus/blur to hidden element (#1486,#12518)
						// only reproducible on winXP IE8 native, not IE9 in IE8 mode
					}
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, ret, handleObj, matched, j,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( jQuery._data( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var sel, handleObj, matches, i,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			/* jshint eqeqeq: false */
			for ( ; cur != this; cur = cur.parentNode || this ) {
				/* jshint eqeqeq: true */

				// Don't check non-elements (#13208)
				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.nodeType === 1 && (cur.disabled !== true || event.type !== "click") ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: IE<9
		// Fix target property (#1925)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Support: Chrome 23+, Safari?
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// Support: IE<9
		// For mouse/key events, metaKey==false if it's undefined (#3368, #11328)
		event.metaKey = !!event.metaKey;

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var body, eventDoc, doc,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					try {
						this.focus();
						return false;
					} catch ( e ) {
						// Support: IE<9
						// If we error on focus to hidden element (#1486, #12518),
						// let .trigger() run the handlers
					}
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( jQuery.nodeName( this, "input" ) && this.type === "checkbox" && this.click ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		var name = "on" + type;

		if ( elem.detachEvent ) {

			// #8545, #7054, preventing memory leaks for custom events in IE6-8
			// detachEvent needed property on element, by name of that event, to properly expose it to GC
			if ( typeof elem[ name ] === strundefined ) {
				elem[ name ] = null;
			}

			elem.detachEvent( name, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: IE < 9, Android < 4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;
		if ( !e ) {
			return;
		}

		// If preventDefault exists, run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// Support: IE
		// Otherwise set the returnValue property of the original event to false
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;
		if ( !e ) {
			return;
		}
		// If stopPropagation exists, run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}

		// Support: IE
		// Set the cancelBubble property of the original event to true
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !jQuery._data( form, "submitBubbles" ) ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					jQuery._data( form, "submitBubbles", true );
				}
			});
			// return undefined since we don't need an event listener
		},

		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
						}
						// Allow triggered, simulated change events (#11500)
						jQuery.event.simulate( "change", this, event, true );
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !jQuery._data( elem, "changeBubbles" ) ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					jQuery._data( elem, "changeBubbles", true );
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return !rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				jQuery._data( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					jQuery._removeData( doc, fix );
				} else {
					jQuery._data( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var type, origFn;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
		safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:null|\d+)"/g,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		area: [ 1, "<map>", "</map>" ],
		param: [ 1, "<object>", "</object>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		// IE6-8 can't serialize link, script, style, or any html5 (NoScope) tags,
		// unless wrapped in a div with non-breaking characters in front of it.
		_default: support.htmlSerialize ? [ 0, "", "" ] : [ 1, "X<div>", "</div>"  ]
	},
	safeFragment = createSafeFragment( document ),
	fragmentDiv = safeFragment.appendChild( document.createElement("div") );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

function getAll( context, tag ) {
	var elems, elem,
		i = 0,
		found = typeof context.getElementsByTagName !== strundefined ? context.getElementsByTagName( tag || "*" ) :
			typeof context.querySelectorAll !== strundefined ? context.querySelectorAll( tag || "*" ) :
			undefined;

	if ( !found ) {
		for ( found = [], elems = context.childNodes || context; (elem = elems[i]) != null; i++ ) {
			if ( !tag || jQuery.nodeName( elem, tag ) ) {
				found.push( elem );
			} else {
				jQuery.merge( found, getAll( elem, tag ) );
			}
		}
	}

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], found ) :
		found;
}

// Used in buildFragment, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( rcheckableType.test( elem.type ) ) {
		elem.defaultChecked = elem.checked;
	}
}

// Support: IE<8
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (jQuery.find.attr( elem, "type" ) !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );
	if ( match ) {
		elem.type = match[1];
	} else {
		elem.removeAttribute("type");
	}
	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var elem,
		i = 0;
	for ( ; (elem = elems[i]) != null; i++ ) {
		jQuery._data( elem, "globalEval", !refElements || jQuery._data( refElements[i], "globalEval" ) );
	}
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function fixCloneNodeIssues( src, dest ) {
	var nodeName, e, data;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 copies events bound via attachEvent when using cloneNode.
	if ( !support.noCloneEvent && dest[ jQuery.expando ] ) {
		data = jQuery._data( dest );

		for ( e in data.events ) {
			jQuery.removeEvent( dest, e, data.handle );
		}

		// Event data gets referenced instead of copied if the expando gets copied too
		dest.removeAttribute( jQuery.expando );
	}

	// IE blanks contents when cloning scripts, and tries to evaluate newly-set text
	if ( nodeName === "script" && dest.text !== src.text ) {
		disableScript( dest ).text = src.text;
		restoreScript( dest );

	// IE6-10 improperly clones children of object elements using classid.
	// IE10 throws NoModificationAllowedError if parent is null, #12132.
	} else if ( nodeName === "object" ) {
		if ( dest.parentNode ) {
			dest.outerHTML = src.outerHTML;
		}

		// This path appears unavoidable for IE9. When cloning an object
		// element in IE9, the outerHTML strategy above is not sufficient.
		// If the src has innerHTML and the destination does not,
		// copy the src.innerHTML into the dest.innerHTML. #10324
		if ( support.html5Clone && ( src.innerHTML && !jQuery.trim(dest.innerHTML) ) ) {
			dest.innerHTML = src.innerHTML;
		}

	} else if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set

		dest.defaultChecked = dest.checked = src.checked;

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.defaultSelected = dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var destElements, node, clone, i, srcElements,
			inPage = jQuery.contains( elem.ownerDocument, elem );

		if ( support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ) {
			clone = elem.cloneNode( true );

		// IE<=8 does not properly clone detached, unknown element nodes
		} else {
			fragmentDiv.innerHTML = elem.outerHTML;
			fragmentDiv.removeChild( clone = fragmentDiv.firstChild );
		}

		if ( (!support.noCloneEvent || !support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			// Fix all IE cloning issues
			for ( i = 0; (node = srcElements[i]) != null; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					fixCloneNodeIssues( node, destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0; (node = srcElements[i]) != null; i++ ) {
					cloneCopyEvent( node, destElements[i] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		destElements = srcElements = node = null;

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var j, elem, contains,
			tmp, tag, tbody, wrap,
			l = elems.length,

			// Ensure a safe fragment
			safe = createSafeFragment( context ),

			nodes = [],
			i = 0;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || safe.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = (rtagName.exec( elem ) || [ "", "" ])[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;

					tmp.innerHTML = wrap[1] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[2];

					// Descend through wrappers to the right content
					j = wrap[0];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Manually add leading whitespace removed by IE
					if ( !support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						nodes.push( context.createTextNode( rleadingWhitespace.exec( elem )[0] ) );
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						elem = tag === "table" && !rtbody.test( elem ) ?
							tmp.firstChild :

							// String was a bare <thead> or <tfoot>
							wrap[1] === "<table>" && !rtbody.test( elem ) ?
								tmp :
								0;

						j = elem && elem.childNodes.length;
						while ( j-- ) {
							if ( jQuery.nodeName( (tbody = elem.childNodes[j]), "tbody" ) && !tbody.childNodes.length ) {
								elem.removeChild( tbody );
							}
						}
					}

					jQuery.merge( nodes, tmp.childNodes );

					// Fix #12392 for WebKit and IE > 9
					tmp.textContent = "";

					// Fix #12392 for oldIE
					while ( tmp.firstChild ) {
						tmp.removeChild( tmp.firstChild );
					}

					// Remember the top-level container for proper cleanup
					tmp = safe.lastChild;
				}
			}
		}

		// Fix #11356: Clear elements from fragment
		if ( tmp ) {
			safe.removeChild( tmp );
		}

		// Reset defaultChecked for any radios and checkboxes
		// about to be appended to the DOM in IE 6/7 (#8060)
		if ( !support.appendChecked ) {
			jQuery.grep( getAll( nodes, "input" ), fixDefaultChecked );
		}

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( safe.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		tmp = null;

		return safe;
	},

	cleanData: function( elems, /* internal */ acceptData ) {
		var elem, type, id, data,
			i = 0,
			internalKey = jQuery.expando,
			cache = jQuery.cache,
			deleteExpando = support.deleteExpando,
			special = jQuery.event.special;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( acceptData || jQuery.acceptData( elem ) ) {

				id = elem[ internalKey ];
				data = id && cache[ id ];

				if ( data ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}

					// Remove cache only if it was not already removed by jQuery.event.remove
					if ( cache[ id ] ) {

						delete cache[ id ];

						// IE does not allow us to delete expando properties from nodes,
						// nor does it have a removeAttribute function on Document nodes;
						// we must handle all of these cases
						if ( deleteExpando ) {
							delete elem[ internalKey ];

						} else if ( typeof elem.removeAttribute !== strundefined ) {
							elem.removeAttribute( internalKey );

						} else {
							elem[ internalKey ] = null;
						}

						deletedIds.push( id );
					}
				}
			}
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {

			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem, false ) );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}

			// If this is a select, ensure that it displays empty (#12336)
			// Support: IE<9
			if ( elem.options && jQuery.nodeName( elem, "select" ) ) {
				elem.options.length = 0;
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					undefined;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( support.htmlSerialize || !rnoshimcache.test( value )  ) &&
				( support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ (rtagName.exec( value ) || [ "", "" ])[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var first, node, hasScripts,
			scripts, doc, fragment,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[0],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[0] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[i], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!jQuery._data( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( ( node.text || node.textContent || node.innerHTML || "" ).replace( rcleanScript, "" ) );
							}
						}
					}
				}

				// Fix #11809: Avoid leaking memory
				fragment = first = null;
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			i = 0,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone(true);
			jQuery( insert[i] )[ original ]( elems );

			// Modern browsers can apply jQuery collections as arrays, but oldIE needs a .get()
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optmization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = ( iframe[ 0 ].contentWindow || iframe[ 0 ].contentDocument ).document;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}


(function() {
	var shrinkWrapBlocksVal;

	support.shrinkWrapBlocks = function() {
		if ( shrinkWrapBlocksVal != null ) {
			return shrinkWrapBlocksVal;
		}

		// Will be changed later if needed.
		shrinkWrapBlocksVal = false;

		// Minified: var b,c,d
		var div, body, container;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		// Support: IE6
		// Check if elements with layout shrink-wrap their children
		if ( typeof div.style.zoom !== strundefined ) {
			// Reset CSS: box-sizing; display; margin; border
			div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;" +
				"padding:1px;width:1px;zoom:1";
			div.appendChild( document.createElement( "div" ) ).style.width = "5px";
			shrinkWrapBlocksVal = div.offsetWidth !== 3;
		}

		body.removeChild( container );

		return shrinkWrapBlocksVal;
	};

})();
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );



var getStyles, curCSS,
	rposition = /^(top|right|bottom|left)$/;

if ( window.getComputedStyle ) {
	getStyles = function( elem ) {
		// Support: IE<=11+, Firefox<=30+ (#15098, #14150)
		// IE throws on elements created in popups
		// FF meanwhile throws on frame elements through "defaultView.getComputedStyle"
		if ( elem.ownerDocument.defaultView.opener ) {
			return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
		}

		return window.getComputedStyle( elem, null );
	};

	curCSS = function( elem, name, computed ) {
		var width, minWidth, maxWidth, ret,
			style = elem.style;

		computed = computed || getStyles( elem );

		// getPropertyValue is only needed for .css('filter') in IE9, see #12537
		ret = computed ? computed.getPropertyValue( name ) || computed[ name ] : undefined;

		if ( computed ) {

			if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
				ret = jQuery.style( elem, name );
			}

			// A tribute to the "awesome hack by Dean Edwards"
			// Chrome < 17 and Safari 5.0 uses "computed value" instead of "used value" for margin-right
			// Safari 5.1.7 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
			// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
			if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

				// Remember the original values
				width = style.width;
				minWidth = style.minWidth;
				maxWidth = style.maxWidth;

				// Put in the new values to get a computed value out
				style.minWidth = style.maxWidth = style.width = ret;
				ret = computed.width;

				// Revert the changed values
				style.width = width;
				style.minWidth = minWidth;
				style.maxWidth = maxWidth;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "";
	};
} else if ( document.documentElement.currentStyle ) {
	getStyles = function( elem ) {
		return elem.currentStyle;
	};

	curCSS = function( elem, name, computed ) {
		var left, rs, rsLeft, ret,
			style = elem.style;

		computed = computed || getStyles( elem );
		ret = computed ? computed[ name ] : undefined;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && style[ name ] ) {
			ret = style[ name ];
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		// but not position css attributes, as those are proportional to the parent element instead
		// and we can't measure the parent instead because it might trigger a "stacking dolls" problem
		if ( rnumnonpx.test( ret ) && !rposition.test( name ) ) {

			// Remember the original values
			left = style.left;
			rs = elem.runtimeStyle;
			rsLeft = rs && rs.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				rs.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				rs.left = rsLeft;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "" || "auto";
	};
}




function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			var condition = conditionFn();

			if ( condition == null ) {
				// The test was not ready at this point; screw the hook this time
				// but check again when needed next time.
				return;
			}

			if ( condition ) {
				// Hook not needed (or it's not possible to use it due to missing dependency),
				// remove it.
				// Since there are no other hooks for marginRight, remove the whole object.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.

			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	// Minified: var b,c,d,e,f,g, h,i
	var div, style, a, pixelPositionVal, boxSizingReliableVal,
		reliableHiddenOffsetsVal, reliableMarginRightVal;

	// Setup
	div = document.createElement( "div" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName( "a" )[ 0 ];
	style = a && a.style;

	// Finish early in limited (non-browser) environments
	if ( !style ) {
		return;
	}

	style.cssText = "float:left;opacity:.5";

	// Support: IE<9
	// Make sure that element opacity exists (as opposed to filter)
	support.opacity = style.opacity === "0.5";

	// Verify style float existence
	// (IE uses styleFloat instead of cssFloat)
	support.cssFloat = !!style.cssFloat;

	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	// Support: Firefox<29, Android 2.3
	// Vendor-prefix box-sizing
	support.boxSizing = style.boxSizing === "" || style.MozBoxSizing === "" ||
		style.WebkitBoxSizing === "";

	jQuery.extend(support, {
		reliableHiddenOffsets: function() {
			if ( reliableHiddenOffsetsVal == null ) {
				computeStyleTests();
			}
			return reliableHiddenOffsetsVal;
		},

		boxSizingReliable: function() {
			if ( boxSizingReliableVal == null ) {
				computeStyleTests();
			}
			return boxSizingReliableVal;
		},

		pixelPosition: function() {
			if ( pixelPositionVal == null ) {
				computeStyleTests();
			}
			return pixelPositionVal;
		},

		// Support: Android 2.3
		reliableMarginRight: function() {
			if ( reliableMarginRightVal == null ) {
				computeStyleTests();
			}
			return reliableMarginRightVal;
		}
	});

	function computeStyleTests() {
		// Minified: var b,c,d,j
		var div, body, container, contents;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";

		// Support: IE<9
		// Assume reasonable values in the absence of getComputedStyle
		pixelPositionVal = boxSizingReliableVal = false;
		reliableMarginRightVal = true;

		// Check for getComputedStyle so that this code is not run in IE<9.
		if ( window.getComputedStyle ) {
			pixelPositionVal = ( window.getComputedStyle( div, null ) || {} ).top !== "1%";
			boxSizingReliableVal =
				( window.getComputedStyle( div, null ) || { width: "4px" } ).width === "4px";

			// Support: Android 2.3
			// Div with explicit width and no margin-right incorrectly
			// gets computed margin-right based on width of container (#3333)
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			contents = div.appendChild( document.createElement( "div" ) );

			// Reset CSS: box-sizing; display; margin; border; padding
			contents.style.cssText = div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
			contents.style.marginRight = contents.style.width = "0";
			div.style.width = "1px";

			reliableMarginRightVal =
				!parseFloat( ( window.getComputedStyle( contents, null ) || {} ).marginRight );

			div.removeChild( contents );
		}

		// Support: IE8
		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		div.innerHTML = "<table><tr><td></td><td>t</td></tr></table>";
		contents = div.getElementsByTagName( "td" );
		contents[ 0 ].style.cssText = "margin:0;border:0;padding:0;display:none";
		reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		if ( reliableHiddenOffsetsVal ) {
			contents[ 0 ].style.display = "";
			contents[ 1 ].style.display = "none";
			reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		}

		body.removeChild( container );
	}

})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
		ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity\s*=\s*([^)]*)/,

	// swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// see here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];


// return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// check for vendor prefixed names
	var capName = name.charAt(0).toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = jQuery._data( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = jQuery._data( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display && display !== "none" || !hidden ) {
				jQuery._data( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// at this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// at this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// at this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// we need the check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox && ( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set. See: #7116
			if ( value == null || value !== value ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Fixes #8908, it can be done more correctly by specifing setters in cssHooks,
			// but it would mean to define eight (for every problematic property) identical functions
			if ( !support.clearCloneStyle && value === "" && name.indexOf("background") === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {

				// Support: IE
				// Swallow errors from 'invalid' CSS values (#5509)
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var num, val, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		//convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Return, converting to number if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				// certain elements can have dimension info if we invisibly show them
				// however, it must have a current display style that would benefit from this
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

if ( !support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( 0.01 * parseFloat( RegExp.$1 ) ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			// if value === "", then remove inline opacity #12685
			if ( ( value >= 1 || value === "" ) &&
					jQuery.trim( filter.replace( ralpha, "" ) ) === "" &&
					style.removeAttribute ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there is no filter style applied in a css rule or unset inline opacity, we are done
				if ( value === "" || currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			// Work around by temporarily setting element display to inline-block
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails
			// so, simple values such as "10px" are parsed to Float.
			// complex values such as "rotate(1rad)" are returned as is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// use step hook for back compat - use cssHook if its there - use .style if its
			// available and use plain properties where available
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE <=9
// Panic based approach to setting things on disconnected nodes

Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*
					// Use a string for doubling factor so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur()
				// And breaking the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		attrs = { height: type },
		i = 0;

	// if we include width, step value is 1 to do all cssExpand values,
	// if we don't include width, step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// we're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = jQuery._data( elem, "fxshow" );

	// handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// doing this makes sure that the complete handler will be called
			// before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE does not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			jQuery._data( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {

			// inline-level elements accept inline-block;
			// block-level elements need to be inline with layout
			if ( !support.inlineBlockNeedsLayout || defaultDisplay( elem.nodeName ) === "inline" ) {
				style.display = "inline-block";
			} else {
				style.zoom = 1;
			}
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		if ( !support.shrinkWrapBlocks() ) {
			anim.always(function() {
				style.overflow = opts.overflow[ 0 ];
				style.overflowX = opts.overflow[ 1 ];
				style.overflowY = opts.overflow[ 2 ];
			});
		}
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = jQuery._data( elem, "fxshow", {} );
		}

		// store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;
			jQuery._removeData( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// not quite $.extend, this wont overwrite keys already present.
			// also - reusing 'index' from above because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// archaic crash bug won't allow us to use 1 - ( 0.5 || 0 ) (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// if we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// resolve when we played the last frame
				// otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {
	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || jQuery._data( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = jQuery._data( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = jQuery._data( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// enable finishing flag on private data
			data.finish = true;

			// empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		timers = jQuery.timers,
		i = 0;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	// Minified: var a,b,c,d,e
	var input, div, select, a, opt;

	// Setup
	div = document.createElement( "div" );
	div.setAttribute( "className", "t" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName("a")[ 0 ];

	// First batch of tests.
	select = document.createElement("select");
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName("input")[ 0 ];

	a.style.cssText = "top:1px";

	// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
	support.getSetAttribute = div.className !== "t";

	// Get the style information from getAttribute
	// (IE uses .cssText instead)
	support.style = /top/.test( a.getAttribute("style") );

	// Make sure that URLs aren't manipulated
	// (IE normalizes it by default)
	support.hrefNormalized = a.getAttribute("href") === "/a";

	// Check the default checkbox/radio value ("" on WebKit; "on" elsewhere)
	support.checkOn = !!input.value;

	// Make sure that a selected-by-default option has a working selected property.
	// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
	support.optSelected = opt.selected;

	// Tests for enctype support on a form (#6743)
	support.enctype = !!document.createElement("form").enctype;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE8 only
	// Check if we can trust getAttribute("value")
	input = document.createElement( "input" );
	input.setAttribute( "value", "" );
	support.input = input.getAttribute( "value" ) === "";

	// Check if an input maintains its value after becoming a radio
	input.value = "t";
	input.setAttribute( "type", "radio" );
	support.radioValue = input.value === "t";
})();


var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// oldIE doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];

					if ( jQuery.inArray( jQuery.valHooks.option.get( option ), values ) >= 0 ) {

						// Support: IE6
						// When new option element is added to select box we need to
						// force reflow of newly added node in order to workaround delay
						// of initialization properties
						try {
							option.selected = optionSet = true;

						} catch ( _ ) {

							// Will be executed only in IE6
							option.scrollHeight;
						}

					} else {
						option.selected = false;
					}
				}

				// Force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}

				return options;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			// Support: Webkit
			// "" is returned instead of "on" if a value isn't specified
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle,
	ruseDefault = /^(?:checked|selected)$/i,
	getSetAttribute = support.getSetAttribute,
	getSetInput = support.input;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
						elem[ propName ] = false;
					// Support: IE<9
					// Also clear defaultChecked/defaultSelected (if appropriate)
					} else {
						elem[ jQuery.camelCase( "default-" + name ) ] =
							elem[ propName ] = false;
					}

				// See #9699 for explanation of this approach (setting first, then removal)
				} else {
					jQuery.attr( elem, name, "" );
				}

				elem.removeAttribute( getSetAttribute ? name : propName );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to default in case type is set after value during creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hook for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
			// IE<8 needs the *property* name
			elem.setAttribute( !getSetAttribute && jQuery.propFix[ name ] || name, name );

		// Use defaultChecked and defaultSelected for oldIE
		} else {
			elem[ jQuery.camelCase( "default-" + name ) ] = elem[ name ] = true;
		}

		return name;
	}
};

// Retrieve booleans specially
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {

	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = getSetInput && getSetAttribute || !ruseDefault.test( name ) ?
		function( elem, name, isXML ) {
			var ret, handle;
			if ( !isXML ) {
				// Avoid an infinite loop by temporarily removing this function from the getter
				handle = attrHandle[ name ];
				attrHandle[ name ] = ret;
				ret = getter( elem, name, isXML ) != null ?
					name.toLowerCase() :
					null;
				attrHandle[ name ] = handle;
			}
			return ret;
		} :
		function( elem, name, isXML ) {
			if ( !isXML ) {
				return elem[ jQuery.camelCase( "default-" + name ) ] ?
					name.toLowerCase() :
					null;
			}
		};
});

// fix oldIE attroperties
if ( !getSetInput || !getSetAttribute ) {
	jQuery.attrHooks.value = {
		set: function( elem, value, name ) {
			if ( jQuery.nodeName( elem, "input" ) ) {
				// Does not return so that setAttribute is also used
				elem.defaultValue = value;
			} else {
				// Use nodeHook if defined (#1954); otherwise setAttribute is fine
				return nodeHook && nodeHook.set( elem, value, name );
			}
		}
	};
}

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = {
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				elem.setAttributeNode(
					(ret = elem.ownerDocument.createAttribute( name ))
				);
			}

			ret.value = value += "";

			// Break association with cloned elements by also using setAttribute (#9646)
			if ( name === "value" || value === elem.getAttribute( name ) ) {
				return value;
			}
		}
	};

	// Some attributes are constructed with empty-string values when not defined
	attrHandle.id = attrHandle.name = attrHandle.coords =
		function( elem, name, isXML ) {
			var ret;
			if ( !isXML ) {
				return (ret = elem.getAttributeNode( name )) && ret.value !== "" ?
					ret.value :
					null;
			}
		};

	// Fixing value retrieval on a button requires this module
	jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret = elem.getAttributeNode( name );
			if ( ret && ret.specified ) {
				return ret.value;
			}
		},
		set: nodeHook.set
	};

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		set: function( elem, value, name ) {
			nodeHook.set( elem, value === "" ? false : value, name );
		}
	};

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		};
	});
}

if ( !support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Note: IE uppercases css property names, but if we were to .toLowerCase()
			// .cssText, that would destroy case senstitivity in URL's, like in "background"
			return elem.style.cssText || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = value + "" );
		}
	};
}




var rfocusable = /^(?:input|select|textarea|button|object)$/i,
	rclickable = /^(?:a|area)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				// Use proper attribute retrieval(#12072)
				var tabindex = jQuery.find.attr( elem, "tabindex" );

				return tabindex ?
					parseInt( tabindex, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						-1;
			}
		}
	}
});

// Some attributes require a special call on IE
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !support.hrefNormalized ) {
	// href/src property should get the full normalized URL (#10299/#12915)
	jQuery.each([ "href", "src" ], function( i, name ) {
		jQuery.propHooks[ name ] = {
			get: function( elem ) {
				return elem.getAttribute( name, 4 );
			}
		};
	});
}

// Support: Safari, IE9+
// mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});

// IE6/7 call enctype encoding
if ( !support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = arguments.length === 0 || typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed "false",
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



var rvalidtokens = /(,)|(\[|{)|(}|])|"(?:[^"\\\r\n]|\\["\\\/bfnrt]|\\u[\da-fA-F]{4})*"\s*:?|true|false|null|-?(?!0\d)\d+(?:\.\d+|)(?:[eE][+-]?\d+|)/g;

jQuery.parseJSON = function( data ) {
	// Attempt to parse using the native JSON parser first
	if ( window.JSON && window.JSON.parse ) {
		// Support: Android 2.3
		// Workaround failure to string-cast null input
		return window.JSON.parse( data + "" );
	}

	var requireNonComma,
		depth = null,
		str = jQuery.trim( data + "" );

	// Guard against invalid (and possibly dangerous) input by ensuring that nothing remains
	// after removing valid tokens
	return str && !jQuery.trim( str.replace( rvalidtokens, function( token, comma, open, close ) {

		// Force termination if we see a misplaced comma
		if ( requireNonComma && comma ) {
			depth = 0;
		}

		// Perform no more replacements after returning to outermost depth
		if ( depth === 0 ) {
			return token;
		}

		// Commas must not follow "[", "{", or ","
		requireNonComma = open || comma;

		// Determine new depth
		// array/object open ("[" or "{"): depth += true - false (increment)
		// array/object close ("]" or "}"): depth += false - true (decrement)
		// other cases ("," or primitive): depth += true - true (numeric cast)
		depth += !close - !open;

		// Remove this token
		return "";
	}) ) ?
		( Function( "return " + str ) )() :
		jQuery.error( "Invalid JSON: " + data );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	try {
		if ( window.DOMParser ) { // Standard
			tmp = new DOMParser();
			xml = tmp.parseFromString( data, "text/xml" );
		} else { // IE
			xml = new ActiveXObject( "Microsoft.XMLDOM" );
			xml.async = "false";
			xml.loadXML( data );
		}
	} catch( e ) {
		xml = undefined;
	}
	if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	// Document location
	ajaxLocParts,
	ajaxLocation,

	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat("*");

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType.charAt( 0 ) === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var deep, key,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {
	var firstDataType, ct, finalDataType, type,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

			// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Cross-domain detection vars
			parts,
			// Loop variable
			i,
			// URL without anti-cache param
			cacheURL,
			// Response headers as string
			responseHeadersString,
			// timeout handle
			timeoutTimer,

			// To know if global events are to be dispatched
			fireGlobals,

			transport,
			// Response headers
			responseHeaders,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		// Don't fire events if jQuery.event is undefined in an AMD-usage scenario (#15118)
		fireGlobals = jQuery.event && s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0 ||
		(!support.reliableHiddenOffsets() &&
			((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
};

jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;
			// Use .is(":disabled") so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject !== undefined ?
	// Support: IE6+
	function() {

		// XHR cannot access local files, always use ActiveX for that case
		return !this.isLocal &&

			// Support: IE7-8
			// oldIE XHR does not support non-RFC2616 methods (#13240)
			// See http://msdn.microsoft.com/en-us/library/ie/ms536648(v=vs.85).aspx
			// and http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html#sec9
			// Although this check for six methods instead of eight
			// since IE also does not support "trace" and "connect"
			/^(get|post|head|put|delete|options)$/i.test( this.type ) &&

			createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

var xhrId = 0,
	xhrCallbacks = {},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE<10
// Open requests must be manually aborted on unload (#5280)
// See https://support.microsoft.com/kb/2856746 for more info
if ( window.attachEvent ) {
	window.attachEvent( "onunload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]( undefined, true );
		}
	});
}

// Determine support properties
support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
xhrSupported = support.ajax = !!xhrSupported;

// Create transport if the browser can provide an xhr
if ( xhrSupported ) {

	jQuery.ajaxTransport(function( options ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !options.crossDomain || support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {
					var i,
						xhr = options.xhr(),
						id = ++xhrId;

					// Open the socket
					xhr.open( options.type, options.url, options.async, options.username, options.password );

					// Apply custom fields if provided
					if ( options.xhrFields ) {
						for ( i in options.xhrFields ) {
							xhr[ i ] = options.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( options.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( options.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !options.crossDomain && !headers["X-Requested-With"] ) {
						headers["X-Requested-With"] = "XMLHttpRequest";
					}

					// Set headers
					for ( i in headers ) {
						// Support: IE<9
						// IE's ActiveXObject throws a 'Type Mismatch' exception when setting
						// request header to a null-value.
						//
						// To keep consistent with other XHR implementations, cast the value
						// to string and ignore `undefined`.
						if ( headers[ i ] !== undefined ) {
							xhr.setRequestHeader( i, headers[ i ] + "" );
						}
					}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( options.hasContent && options.data ) || null );

					// Listener
					callback = function( _, isAbort ) {
						var status, statusText, responses;

						// Was never called and is aborted or complete
						if ( callback && ( isAbort || xhr.readyState === 4 ) ) {
							// Clean up
							delete xhrCallbacks[ id ];
							callback = undefined;
							xhr.onreadystatechange = jQuery.noop;

							// Abort manually if needed
							if ( isAbort ) {
								if ( xhr.readyState !== 4 ) {
									xhr.abort();
								}
							} else {
								responses = {};
								status = xhr.status;

								// Support: IE<10
								// Accessing binary-data responseText throws an exception
								// (#11426)
								if ( typeof xhr.responseText === "string" ) {
									responses.text = xhr.responseText;
								}

								// Firefox throws an exception when accessing
								// statusText for faulty cross-domain requests
								try {
									statusText = xhr.statusText;
								} catch( e ) {
									// We normalize with Webkit giving an empty statusText
									statusText = "";
								}

								// Filter status for non standard behaviors

								// If the request is local and we have data: assume a success
								// (success with no data won't get notified, that's the best we
								// can do given current implementations)
								if ( !status && options.isLocal && !options.crossDomain ) {
									status = responses.text ? 200 : 404;
								// IE - #1450: sometimes returns 1223 when it should be 204
								} else if ( status === 1223 ) {
									status = 204;
								}
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, xhr.getAllResponseHeaders() );
						}
					};

					if ( !options.async ) {
						// if we're in sync mode we fire the callback
						callback();
					} else if ( xhr.readyState === 4 ) {
						// (IE6 & IE7) if it's in cache and has been
						// retrieved directly we need to fire the callback
						setTimeout( callback );
					} else {
						// Add to the list of active xhr callbacks
						xhr.onreadystatechange = xhrCallbacks[ id ] = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback( undefined, true );
					}
				}
			};
		}
	});
}

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject( "Microsoft.XMLHTTP" );
	} catch( e ) {}
}




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || jQuery("head")[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement("script");

				script.async = true;

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( script.parentNode ) {
							script.parentNode.removeChild( script );
						}

						// Dereference the script
						script = null;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};

				// Circumvent IE6 bugs with base elements (#2709 and #4378) by prepending
				// Use native DOM manipulation to avoid our domManip AJAX trickery
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( undefined, true );
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, response, type,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off, url.length ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};





var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			jQuery.inArray("auto", [ curCSSTop, curCSSLeft ] ) > -1;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			box = { top: 0, left: 0 },
			elem = this[ 0 ],
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// If we don't have gBCR, just use 0,0 rather than error
		// BlackBerry 5, iOS 3 (original iPhone)
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top  + ( win.pageYOffset || docElem.scrollTop )  - ( docElem.clientTop  || 0 ),
			left: box.left + ( win.pageXOffset || docElem.scrollLeft ) - ( docElem.clientLeft || 0 )
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			parentOffset = { top: 0, left: 0 },
			elem = this[ 0 ];

		// fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// we assume that getBoundingClientRect is available when computed position is fixed
			offset = elem.getBoundingClientRect();
		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top  += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		return {
			top:  offset.top  - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true)
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					win.document.documentElement[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// getComputedStyle returns percent when specified for top/left/bottom/right
// rather than make the css module depend on the offset module, we just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// if curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height], whichever is greatest
					// unfortunately, this causes bug #3838 in IE6/8 only, but there is currently no good, small way to fix it.
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in
// AMD (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));

//     Underscore.js 1.8.3
//     http://underscorejs.org
//     (c) 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
//     Underscore may be freely distributed under the MIT license.

(function() {

  // Baseline setup
  // --------------

  // Establish the root object, `window` (`self`) in the browser, or `global` on the server.
  // We use `self` instead of `window` for `WebWorker` support.
  var root = typeof self === 'object' && self.self === self && self ||
            typeof global === 'object' && global.global === global && global;

  // Save the previous value of the `_` variable.
  var previousUnderscore = root._;

  // Save bytes in the minified (but not gzipped) version:
  var ArrayProto = Array.prototype, ObjProto = Object.prototype;

  // Create quick reference variables for speed access to core prototypes.
  var
    push = ArrayProto.push,
    slice = ArrayProto.slice,
    toString = ObjProto.toString,
    hasOwnProperty = ObjProto.hasOwnProperty;

  // All **ECMAScript 5** native function implementations that we hope to use
  // are declared here.
  var
    nativeIsArray = Array.isArray,
    nativeKeys = Object.keys,
    nativeCreate = Object.create;

  // Naked function reference for surrogate-prototype-swapping.
  var Ctor = function(){};

  // Create a safe reference to the Underscore object for use below.
  var _ = function(obj) {
    if (obj instanceof _) return obj;
    if (!(this instanceof _)) return new _(obj);
    this._wrapped = obj;
  };

  // Export the Underscore object for **Node.js**, with
  // backwards-compatibility for their old module API. If we're in
  // the browser, add `_` as a global object.
  if (typeof exports !== 'undefined') {
    if (typeof module !== 'undefined' && module.exports) {
      exports = module.exports = _;
    }
    exports._ = _;
  } else {
    root._ = _;
  }

  // Current version.
  _.VERSION = '1.8.3';

  // Internal function that returns an efficient (for current engines) version
  // of the passed-in callback, to be repeatedly applied in other Underscore
  // functions.
  var optimizeCb = function(func, context, argCount) {
    if (context === void 0) return func;
    switch (argCount == null ? 3 : argCount) {
      case 1: return function(value) {
        return func.call(context, value);
      };
      case 2: return function(value, other) {
        return func.call(context, value, other);
      };
      case 3: return function(value, index, collection) {
        return func.call(context, value, index, collection);
      };
      case 4: return function(accumulator, value, index, collection) {
        return func.call(context, accumulator, value, index, collection);
      };
    }
    return function() {
      return func.apply(context, arguments);
    };
  };

  // A mostly-internal function to generate callbacks that can be applied
  // to each element in a collection, returning the desired result — either
  // identity, an arbitrary callback, a property matcher, or a property accessor.
  var cb = function(value, context, argCount) {
    if (value == null) return _.identity;
    if (_.isFunction(value)) return optimizeCb(value, context, argCount);
    if (_.isObject(value)) return _.matcher(value);
    return _.property(value);
  };
  _.iteratee = function(value, context) {
    return cb(value, context, Infinity);
  };

  // Similar to ES6's rest param (http://ariya.ofilabs.com/2013/03/es6-and-rest-parameter.html)
  // This accumulates the arguments passed into an array, after a given index.
  var restArgs = function(func, startIndex) {
    startIndex = startIndex == null ? func.length - 1 : +startIndex;
    return function() {
      var length = Math.max(arguments.length - startIndex, 0);
      var rest = Array(length);
      var index;
      for (index = 0; index < length; index++) {
        rest[index] = arguments[index + startIndex];
      }
      switch (startIndex) {
        case 0: return func.call(this, rest);
        case 1: return func.call(this, arguments[0], rest);
        case 2: return func.call(this, arguments[0], arguments[1], rest);
      }
      var args = Array(startIndex + 1);
      for (index = 0; index < startIndex; index++) {
        args[index] = arguments[index];
      }
      args[startIndex] = rest;
      return func.apply(this, args);
    };
  };

  // An internal function for creating a new object that inherits from another.
  var baseCreate = function(prototype) {
    if (!_.isObject(prototype)) return {};
    if (nativeCreate) return nativeCreate(prototype);
    Ctor.prototype = prototype;
    var result = new Ctor;
    Ctor.prototype = null;
    return result;
  };

  var property = function(key) {
    return function(obj) {
      return obj == null ? void 0 : obj[key];
    };
  };

  // Helper for collection methods to determine whether a collection
  // should be iterated as an array or as an object
  // Related: http://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength
  // Avoids a very nasty iOS 8 JIT bug on ARM-64. #2094
  var MAX_ARRAY_INDEX = Math.pow(2, 53) - 1;
  var getLength = property('length');
  var isArrayLike = function(collection) {
    var length = getLength(collection);
    return typeof length == 'number' && length >= 0 && length <= MAX_ARRAY_INDEX;
  };

  // Collection Functions
  // --------------------

  // The cornerstone, an `each` implementation, aka `forEach`.
  // Handles raw objects in addition to array-likes. Treats all
  // sparse array-likes as if they were dense.
  _.each = _.forEach = function(obj, iteratee, context) {
    iteratee = optimizeCb(iteratee, context);
    var i, length;
    if (isArrayLike(obj)) {
      for (i = 0, length = obj.length; i < length; i++) {
        iteratee(obj[i], i, obj);
      }
    } else {
      var keys = _.keys(obj);
      for (i = 0, length = keys.length; i < length; i++) {
        iteratee(obj[keys[i]], keys[i], obj);
      }
    }
    return obj;
  };

  // Return the results of applying the iteratee to each element.
  _.map = _.collect = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length,
        results = Array(length);
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      results[index] = iteratee(obj[currentKey], currentKey, obj);
    }
    return results;
  };

  // Create a reducing function iterating left or right.
  var createReduce = function(dir) {
    // Optimized iterator function as using arguments.length
    // in the main function will deoptimize the, see #1991.
    var reducer = function(obj, iteratee, memo, initial) {
      var keys = !isArrayLike(obj) && _.keys(obj),
          length = (keys || obj).length,
          index = dir > 0 ? 0 : length - 1;
      if (!initial) {
        memo = obj[keys ? keys[index] : index];
        index += dir;
      }
      for (; index >= 0 && index < length; index += dir) {
        var currentKey = keys ? keys[index] : index;
        memo = iteratee(memo, obj[currentKey], currentKey, obj);
      }
      return memo;
    };

    return function(obj, iteratee, memo, context) {
      var initial = arguments.length >= 3;
      return reducer(obj, optimizeCb(iteratee, context, 4), memo, initial);
    };
  };

  // **Reduce** builds up a single result from a list of values, aka `inject`,
  // or `foldl`.
  _.reduce = _.foldl = _.inject = createReduce(1);

  // The right-associative version of reduce, also known as `foldr`.
  _.reduceRight = _.foldr = createReduce(-1);

  // Return the first value which passes a truth test. Aliased as `detect`.
  _.find = _.detect = function(obj, predicate, context) {
    var key;
    if (isArrayLike(obj)) {
      key = _.findIndex(obj, predicate, context);
    } else {
      key = _.findKey(obj, predicate, context);
    }
    if (key !== void 0 && key !== -1) return obj[key];
  };

  // Return all the elements that pass a truth test.
  // Aliased as `select`.
  _.filter = _.select = function(obj, predicate, context) {
    var results = [];
    predicate = cb(predicate, context);
    _.each(obj, function(value, index, list) {
      if (predicate(value, index, list)) results.push(value);
    });
    return results;
  };

  // Return all the elements for which a truth test fails.
  _.reject = function(obj, predicate, context) {
    return _.filter(obj, _.negate(cb(predicate)), context);
  };

  // Determine whether all of the elements match a truth test.
  // Aliased as `all`.
  _.every = _.all = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length;
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      if (!predicate(obj[currentKey], currentKey, obj)) return false;
    }
    return true;
  };

  // Determine if at least one element in the object matches a truth test.
  // Aliased as `any`.
  _.some = _.any = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length;
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      if (predicate(obj[currentKey], currentKey, obj)) return true;
    }
    return false;
  };

  // Determine if the array or object contains a given item (using `===`).
  // Aliased as `includes` and `include`.
  _.contains = _.includes = _.include = function(obj, item, fromIndex, guard) {
    if (!isArrayLike(obj)) obj = _.values(obj);
    if (typeof fromIndex != 'number' || guard) fromIndex = 0;
    return _.indexOf(obj, item, fromIndex) >= 0;
  };

  // Invoke a method (with arguments) on every item in a collection.
  _.invoke = restArgs(function(obj, method, args) {
    var isFunc = _.isFunction(method);
    return _.map(obj, function(value) {
      var func = isFunc ? method : value[method];
      return func == null ? func : func.apply(value, args);
    });
  });

  // Convenience version of a common use case of `map`: fetching a property.
  _.pluck = function(obj, key) {
    return _.map(obj, _.property(key));
  };

  // Convenience version of a common use case of `filter`: selecting only objects
  // containing specific `key:value` pairs.
  _.where = function(obj, attrs) {
    return _.filter(obj, _.matcher(attrs));
  };

  // Convenience version of a common use case of `find`: getting the first object
  // containing specific `key:value` pairs.
  _.findWhere = function(obj, attrs) {
    return _.find(obj, _.matcher(attrs));
  };

  // Return the maximum element (or element-based computation).
  _.max = function(obj, iteratee, context) {
    var result = -Infinity, lastComputed = -Infinity,
        value, computed;
    if (iteratee == null && obj != null) {
      obj = isArrayLike(obj) ? obj : _.values(obj);
      for (var i = 0, length = obj.length; i < length; i++) {
        value = obj[i];
        if (value > result) {
          result = value;
        }
      }
    } else {
      iteratee = cb(iteratee, context);
      _.each(obj, function(v, index, list) {
        computed = iteratee(v, index, list);
        if (computed > lastComputed || computed === -Infinity && result === -Infinity) {
          result = v;
          lastComputed = computed;
        }
      });
    }
    return result;
  };

  // Return the minimum element (or element-based computation).
  _.min = function(obj, iteratee, context) {
    var result = Infinity, lastComputed = Infinity,
        value, computed;
    if (iteratee == null && obj != null) {
      obj = isArrayLike(obj) ? obj : _.values(obj);
      for (var i = 0, length = obj.length; i < length; i++) {
        value = obj[i];
        if (value < result) {
          result = value;
        }
      }
    } else {
      iteratee = cb(iteratee, context);
      _.each(obj, function(v, index, list) {
        computed = iteratee(v, index, list);
        if (computed < lastComputed || computed === Infinity && result === Infinity) {
          result = v;
          lastComputed = computed;
        }
      });
    }
    return result;
  };

  // Shuffle a collection.
  _.shuffle = function(obj) {
    return _.sample(obj, Infinity);
  };

  // Sample **n** random values from a collection using the modern version of the
  // [Fisher-Yates shuffle](http://en.wikipedia.org/wiki/Fisher–Yates_shuffle).
  // If **n** is not specified, returns a single random element.
  // The internal `guard` argument allows it to work with `map`.
  _.sample = function(obj, n, guard) {
    if (n == null || guard) {
      if (!isArrayLike(obj)) obj = _.values(obj);
      return obj[_.random(obj.length - 1)];
    }
    var sample = isArrayLike(obj) ? _.clone(obj) : _.values(obj);
    var length = getLength(sample);
    n = Math.max(Math.min(n, length), 0);
    var last = length - 1;
    for (var index = 0; index < n; index++) {
      var rand = _.random(index, last);
      var temp = sample[index];
      sample[index] = sample[rand];
      sample[rand] = temp;
    }
    return sample.slice(0, n);
  };

  // Sort the object's values by a criterion produced by an iteratee.
  _.sortBy = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    return _.pluck(_.map(obj, function(value, index, list) {
      return {
        value: value,
        index: index,
        criteria: iteratee(value, index, list)
      };
    }).sort(function(left, right) {
      var a = left.criteria;
      var b = right.criteria;
      if (a !== b) {
        if (a > b || a === void 0) return 1;
        if (a < b || b === void 0) return -1;
      }
      return left.index - right.index;
    }), 'value');
  };

  // An internal function used for aggregate "group by" operations.
  var group = function(behavior, partition) {
    return function(obj, iteratee, context) {
      var result = partition ? [[], []] : {};
      iteratee = cb(iteratee, context);
      _.each(obj, function(value, index) {
        var key = iteratee(value, index, obj);
        behavior(result, value, key);
      });
      return result;
    };
  };

  // Groups the object's values by a criterion. Pass either a string attribute
  // to group by, or a function that returns the criterion.
  _.groupBy = group(function(result, value, key) {
    if (_.has(result, key)) result[key].push(value); else result[key] = [value];
  });

  // Indexes the object's values by a criterion, similar to `groupBy`, but for
  // when you know that your index values will be unique.
  _.indexBy = group(function(result, value, key) {
    result[key] = value;
  });

  // Counts instances of an object that group by a certain criterion. Pass
  // either a string attribute to count by, or a function that returns the
  // criterion.
  _.countBy = group(function(result, value, key) {
    if (_.has(result, key)) result[key]++; else result[key] = 1;
  });

  // Safely create a real, live array from anything iterable.
  _.toArray = function(obj) {
    if (!obj) return [];
    if (_.isArray(obj)) return slice.call(obj);
    if (isArrayLike(obj)) return _.map(obj, _.identity);
    return _.values(obj);
  };

  // Return the number of elements in an object.
  _.size = function(obj) {
    if (obj == null) return 0;
    return isArrayLike(obj) ? obj.length : _.keys(obj).length;
  };

  // Split a collection into two arrays: one whose elements all satisfy the given
  // predicate, and one whose elements all do not satisfy the predicate.
  _.partition = group(function(result, value, pass) {
    result[pass ? 0 : 1].push(value);
  }, true);

  // Array Functions
  // ---------------

  // Get the first element of an array. Passing **n** will return the first N
  // values in the array. Aliased as `head` and `take`. The **guard** check
  // allows it to work with `_.map`.
  _.first = _.head = _.take = function(array, n, guard) {
    if (array == null) return void 0;
    if (n == null || guard) return array[0];
    return _.initial(array, array.length - n);
  };

  // Returns everything but the last entry of the array. Especially useful on
  // the arguments object. Passing **n** will return all the values in
  // the array, excluding the last N.
  _.initial = function(array, n, guard) {
    return slice.call(array, 0, Math.max(0, array.length - (n == null || guard ? 1 : n)));
  };

  // Get the last element of an array. Passing **n** will return the last N
  // values in the array.
  _.last = function(array, n, guard) {
    if (array == null) return void 0;
    if (n == null || guard) return array[array.length - 1];
    return _.rest(array, Math.max(0, array.length - n));
  };

  // Returns everything but the first entry of the array. Aliased as `tail` and `drop`.
  // Especially useful on the arguments object. Passing an **n** will return
  // the rest N values in the array.
  _.rest = _.tail = _.drop = function(array, n, guard) {
    return slice.call(array, n == null || guard ? 1 : n);
  };

  // Trim out all falsy values from an array.
  _.compact = function(array) {
    return _.filter(array, _.identity);
  };

  // Internal implementation of a recursive `flatten` function.
  var flatten = function(input, shallow, strict, output) {
    output = output || [];
    var idx = output.length;
    for (var i = 0, length = getLength(input); i < length; i++) {
      var value = input[i];
      if (isArrayLike(value) && (_.isArray(value) || _.isArguments(value))) {
        //flatten current level of array or arguments object
        if (shallow) {
          var j = 0, len = value.length;
          while (j < len) output[idx++] = value[j++];
        } else {
          flatten(value, shallow, strict, output);
          idx = output.length;
        }
      } else if (!strict) {
        output[idx++] = value;
      }
    }
    return output;
  };

  // Flatten out an array, either recursively (by default), or just one level.
  _.flatten = function(array, shallow) {
    return flatten(array, shallow, false);
  };

  // Return a version of the array that does not contain the specified value(s).
  _.without = restArgs(function(array, otherArrays) {
    return _.difference(array, otherArrays);
  });

  // Produce a duplicate-free version of the array. If the array has already
  // been sorted, you have the option of using a faster algorithm.
  // Aliased as `unique`.
  _.uniq = _.unique = function(array, isSorted, iteratee, context) {
    if (!_.isBoolean(isSorted)) {
      context = iteratee;
      iteratee = isSorted;
      isSorted = false;
    }
    if (iteratee != null) iteratee = cb(iteratee, context);
    var result = [];
    var seen = [];
    for (var i = 0, length = getLength(array); i < length; i++) {
      var value = array[i],
          computed = iteratee ? iteratee(value, i, array) : value;
      if (isSorted) {
        if (!i || seen !== computed) result.push(value);
        seen = computed;
      } else if (iteratee) {
        if (!_.contains(seen, computed)) {
          seen.push(computed);
          result.push(value);
        }
      } else if (!_.contains(result, value)) {
        result.push(value);
      }
    }
    return result;
  };

  // Produce an array that contains the union: each distinct element from all of
  // the passed-in arrays.
  _.union = restArgs(function(arrays) {
    return _.uniq(flatten(arrays, true, true));
  });

  // Produce an array that contains every item shared between all the
  // passed-in arrays.
  _.intersection = function(array) {
    var result = [];
    var argsLength = arguments.length;
    for (var i = 0, length = getLength(array); i < length; i++) {
      var item = array[i];
      if (_.contains(result, item)) continue;
      var j;
      for (j = 1; j < argsLength; j++) {
        if (!_.contains(arguments[j], item)) break;
      }
      if (j === argsLength) result.push(item);
    }
    return result;
  };

  // Take the difference between one array and a number of other arrays.
  // Only the elements present in just the first array will remain.
  _.difference = restArgs(function(array, rest) {
    rest = flatten(rest, true, true);
    return _.filter(array, function(value){
      return !_.contains(rest, value);
    });
  });

  // Complement of _.zip. Unzip accepts an array of arrays and groups
  // each array's elements on shared indices
  _.unzip = function(array) {
    var length = array && _.max(array, getLength).length || 0;
    var result = Array(length);

    for (var index = 0; index < length; index++) {
      result[index] = _.pluck(array, index);
    }
    return result;
  };

  // Zip together multiple lists into a single array -- elements that share
  // an index go together.
  _.zip = restArgs(_.unzip);

  // Converts lists into objects. Pass either a single array of `[key, value]`
  // pairs, or two parallel arrays of the same length -- one of keys, and one of
  // the corresponding values.
  _.object = function(list, values) {
    var result = {};
    for (var i = 0, length = getLength(list); i < length; i++) {
      if (values) {
        result[list[i]] = values[i];
      } else {
        result[list[i][0]] = list[i][1];
      }
    }
    return result;
  };

  // Generator function to create the findIndex and findLastIndex functions
  var createPredicateIndexFinder = function(dir) {
    return function(array, predicate, context) {
      predicate = cb(predicate, context);
      var length = getLength(array);
      var index = dir > 0 ? 0 : length - 1;
      for (; index >= 0 && index < length; index += dir) {
        if (predicate(array[index], index, array)) return index;
      }
      return -1;
    };
  };

  // Returns the first index on an array-like that passes a predicate test
  _.findIndex = createPredicateIndexFinder(1);
  _.findLastIndex = createPredicateIndexFinder(-1);

  // Use a comparator function to figure out the smallest index at which
  // an object should be inserted so as to maintain order. Uses binary search.
  _.sortedIndex = function(array, obj, iteratee, context) {
    iteratee = cb(iteratee, context, 1);
    var value = iteratee(obj);
    var low = 0, high = getLength(array);
    while (low < high) {
      var mid = Math.floor((low + high) / 2);
      if (iteratee(array[mid]) < value) low = mid + 1; else high = mid;
    }
    return low;
  };

  // Generator function to create the indexOf and lastIndexOf functions
  var createIndexFinder = function(dir, predicateFind, sortedIndex) {
    return function(array, item, idx) {
      var i = 0, length = getLength(array);
      if (typeof idx == 'number') {
        if (dir > 0) {
          i = idx >= 0 ? idx : Math.max(idx + length, i);
        } else {
          length = idx >= 0 ? Math.min(idx + 1, length) : idx + length + 1;
        }
      } else if (sortedIndex && idx && length) {
        idx = sortedIndex(array, item);
        return array[idx] === item ? idx : -1;
      }
      if (item !== item) {
        idx = predicateFind(slice.call(array, i, length), _.isNaN);
        return idx >= 0 ? idx + i : -1;
      }
      for (idx = dir > 0 ? i : length - 1; idx >= 0 && idx < length; idx += dir) {
        if (array[idx] === item) return idx;
      }
      return -1;
    };
  };

  // Return the position of the first occurrence of an item in an array,
  // or -1 if the item is not included in the array.
  // If the array is large and already in sort order, pass `true`
  // for **isSorted** to use binary search.
  _.indexOf = createIndexFinder(1, _.findIndex, _.sortedIndex);
  _.lastIndexOf = createIndexFinder(-1, _.findLastIndex);

  // Generate an integer Array containing an arithmetic progression. A port of
  // the native Python `range()` function. See
  // [the Python documentation](http://docs.python.org/library/functions.html#range).
  _.range = function(start, stop, step) {
    if (stop == null) {
      stop = start || 0;
      start = 0;
    }
    step = step || 1;

    var length = Math.max(Math.ceil((stop - start) / step), 0);
    var range = Array(length);

    for (var idx = 0; idx < length; idx++, start += step) {
      range[idx] = start;
    }

    return range;
  };

  // Function (ahem) Functions
  // ------------------

  // Determines whether to execute a function as a constructor
  // or a normal function with the provided arguments
  var executeBound = function(sourceFunc, boundFunc, context, callingContext, args) {
    if (!(callingContext instanceof boundFunc)) return sourceFunc.apply(context, args);
    var self = baseCreate(sourceFunc.prototype);
    var result = sourceFunc.apply(self, args);
    if (_.isObject(result)) return result;
    return self;
  };

  // Create a function bound to a given object (assigning `this`, and arguments,
  // optionally). Delegates to **ECMAScript 5**'s native `Function.bind` if
  // available.
  _.bind = restArgs(function(func, context, args) {
    if (!_.isFunction(func)) throw new TypeError('Bind must be called on a function');
    var bound = restArgs(function(callArgs) {
      return executeBound(func, bound, context, this, args.concat(callArgs));
    });
    return bound;
  });

  // Partially apply a function by creating a version that has had some of its
  // arguments pre-filled, without changing its dynamic `this` context. _ acts
  // as a placeholder by default, allowing any combination of arguments to be
  // pre-filled. Set `_.partial.placeholder` for a custom placeholder argument.
  _.partial = restArgs(function(func, boundArgs) {
    var placeholder = _.partial.placeholder;
    var bound = function() {
      var position = 0, length = boundArgs.length;
      var args = Array(length);
      for (var i = 0; i < length; i++) {
        args[i] = boundArgs[i] === placeholder ? arguments[position++] : boundArgs[i];
      }
      while (position < arguments.length) args.push(arguments[position++]);
      return executeBound(func, bound, this, this, args);
    };
    return bound;
  });

  _.partial.placeholder = _;

  // Bind a number of an object's methods to that object. Remaining arguments
  // are the method names to be bound. Useful for ensuring that all callbacks
  // defined on an object belong to it.
  _.bindAll = restArgs(function(obj, keys) {
    keys = flatten(keys, false, false);
    var index = keys.length;
    if (index < 1) throw new Error('bindAll must be passed function names');
    while (index--) {
      var key = keys[index];
      obj[key] = _.bind(obj[key], obj);
    }
  });

  // Memoize an expensive function by storing its results.
  _.memoize = function(func, hasher) {
    var memoize = function(key) {
      var cache = memoize.cache;
      var address = '' + (hasher ? hasher.apply(this, arguments) : key);
      if (!_.has(cache, address)) cache[address] = func.apply(this, arguments);
      return cache[address];
    };
    memoize.cache = {};
    return memoize;
  };

  // Delays a function for the given number of milliseconds, and then calls
  // it with the arguments supplied.
  _.delay = restArgs(function(func, wait, args) {
    return setTimeout(function(){
      return func.apply(null, args);
    }, wait);
  });

  // Defers a function, scheduling it to run after the current call stack has
  // cleared.
  _.defer = _.partial(_.delay, _, 1);

  // Returns a function, that, when invoked, will only be triggered at most once
  // during a given window of time. Normally, the throttled function will run
  // as much as it can, without ever going more than once per `wait` duration;
  // but if you'd like to disable the execution on the leading edge, pass
  // `{leading: false}`. To disable execution on the trailing edge, ditto.
  _.throttle = function(func, wait, options) {
    var context, args, result;
    var timeout = null;
    var previous = 0;
    if (!options) options = {};
    var later = function() {
      previous = options.leading === false ? 0 : _.now();
      timeout = null;
      result = func.apply(context, args);
      if (!timeout) context = args = null;
    };
    return function() {
      var now = _.now();
      if (!previous && options.leading === false) previous = now;
      var remaining = wait - (now - previous);
      context = this;
      args = arguments;
      if (remaining <= 0 || remaining > wait) {
        if (timeout) {
          clearTimeout(timeout);
          timeout = null;
        }
        previous = now;
        result = func.apply(context, args);
        if (!timeout) context = args = null;
      } else if (!timeout && options.trailing !== false) {
        timeout = setTimeout(later, remaining);
      }
      return result;
    };
  };

  // Returns a function, that, as long as it continues to be invoked, will not
  // be triggered. The function will be called after it stops being called for
  // N milliseconds. If `immediate` is passed, trigger the function on the
  // leading edge, instead of the trailing.
  _.debounce = function(func, wait, immediate) {
    var timeout, args, context, timestamp, result;

    var later = function() {
      var last = _.now() - timestamp;

      if (last < wait && last >= 0) {
        timeout = setTimeout(later, wait - last);
      } else {
        timeout = null;
        if (!immediate) {
          result = func.apply(context, args);
          if (!timeout) context = args = null;
        }
      }
    };

    return function() {
      context = this;
      args = arguments;
      timestamp = _.now();
      var callNow = immediate && !timeout;
      if (!timeout) timeout = setTimeout(later, wait);
      if (callNow) {
        result = func.apply(context, args);
        context = args = null;
      }

      return result;
    };
  };

  // Returns the first function passed as an argument to the second,
  // allowing you to adjust arguments, run code before and after, and
  // conditionally execute the original function.
  _.wrap = function(func, wrapper) {
    return _.partial(wrapper, func);
  };

  // Returns a negated version of the passed-in predicate.
  _.negate = function(predicate) {
    return function() {
      return !predicate.apply(this, arguments);
    };
  };

  // Returns a function that is the composition of a list of functions, each
  // consuming the return value of the function that follows.
  _.compose = function() {
    var args = arguments;
    var start = args.length - 1;
    return function() {
      var i = start;
      var result = args[start].apply(this, arguments);
      while (i--) result = args[i].call(this, result);
      return result;
    };
  };

  // Returns a function that will only be executed on and after the Nth call.
  _.after = function(times, func) {
    return function() {
      if (--times < 1) {
        return func.apply(this, arguments);
      }
    };
  };

  // Returns a function that will only be executed up to (but not including) the Nth call.
  _.before = function(times, func) {
    var memo;
    return function() {
      if (--times > 0) {
        memo = func.apply(this, arguments);
      }
      if (times <= 1) func = null;
      return memo;
    };
  };

  // Returns a function that will be executed at most one time, no matter how
  // often you call it. Useful for lazy initialization.
  _.once = _.partial(_.before, 2);

  _.restArgs = restArgs;

  // Object Functions
  // ----------------

  // Keys in IE < 9 that won't be iterated by `for key in ...` and thus missed.
  var hasEnumBug = !{toString: null}.propertyIsEnumerable('toString');
  var nonEnumerableProps = ['valueOf', 'isPrototypeOf', 'toString',
                      'propertyIsEnumerable', 'hasOwnProperty', 'toLocaleString'];

  var collectNonEnumProps = function(obj, keys) {
    var nonEnumIdx = nonEnumerableProps.length;
    var constructor = obj.constructor;
    var proto = _.isFunction(constructor) && constructor.prototype || ObjProto;

    // Constructor is a special case.
    var prop = 'constructor';
    if (_.has(obj, prop) && !_.contains(keys, prop)) keys.push(prop);

    while (nonEnumIdx--) {
      prop = nonEnumerableProps[nonEnumIdx];
      if (prop in obj && obj[prop] !== proto[prop] && !_.contains(keys, prop)) {
        keys.push(prop);
      }
    }
  };

  // Retrieve the names of an object's own properties.
  // Delegates to **ECMAScript 5**'s native `Object.keys`
  _.keys = function(obj) {
    if (!_.isObject(obj)) return [];
    if (nativeKeys) return nativeKeys(obj);
    var keys = [];
    for (var key in obj) if (_.has(obj, key)) keys.push(key);
    // Ahem, IE < 9.
    if (hasEnumBug) collectNonEnumProps(obj, keys);
    return keys;
  };

  // Retrieve all the property names of an object.
  _.allKeys = function(obj) {
    if (!_.isObject(obj)) return [];
    var keys = [];
    for (var key in obj) keys.push(key);
    // Ahem, IE < 9.
    if (hasEnumBug) collectNonEnumProps(obj, keys);
    return keys;
  };

  // Retrieve the values of an object's properties.
  _.values = function(obj) {
    var keys = _.keys(obj);
    var length = keys.length;
    var values = Array(length);
    for (var i = 0; i < length; i++) {
      values[i] = obj[keys[i]];
    }
    return values;
  };

  // Returns the results of applying the iteratee to each element of the object
  // In contrast to _.map it returns an object
  _.mapObject = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    var keys = _.keys(obj),
      length = keys.length,
      results = {};
    for (var index = 0; index < length; index++) {
      var currentKey = keys[index];
      results[currentKey] = iteratee(obj[currentKey], currentKey, obj);
    }
    return results;
  };

  // Convert an object into a list of `[key, value]` pairs.
  _.pairs = function(obj) {
    var keys = _.keys(obj);
    var length = keys.length;
    var pairs = Array(length);
    for (var i = 0; i < length; i++) {
      pairs[i] = [keys[i], obj[keys[i]]];
    }
    return pairs;
  };

  // Invert the keys and values of an object. The values must be serializable.
  _.invert = function(obj) {
    var result = {};
    var keys = _.keys(obj);
    for (var i = 0, length = keys.length; i < length; i++) {
      result[obj[keys[i]]] = keys[i];
    }
    return result;
  };

  // Return a sorted list of the function names available on the object.
  // Aliased as `methods`
  _.functions = _.methods = function(obj) {
    var names = [];
    for (var key in obj) {
      if (_.isFunction(obj[key])) names.push(key);
    }
    return names.sort();
  };

  // An internal function for creating assigner functions.
  var createAssigner = function(keysFunc, undefinedOnly) {
    return function(obj) {
      var length = arguments.length;
      if (length < 2 || obj == null) return obj;
      for (var index = 1; index < length; index++) {
        var source = arguments[index],
            keys = keysFunc(source),
            l = keys.length;
        for (var i = 0; i < l; i++) {
          var key = keys[i];
          if (!undefinedOnly || obj[key] === void 0) obj[key] = source[key];
        }
      }
      return obj;
    };
  };

  // Extend a given object with all the properties in passed-in object(s).
  _.extend = createAssigner(_.allKeys);

  // Assigns a given object with all the own properties in the passed-in object(s)
  // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
  _.extendOwn = _.assign = createAssigner(_.keys);

  // Returns the first key on an object that passes a predicate test
  _.findKey = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = _.keys(obj), key;
    for (var i = 0, length = keys.length; i < length; i++) {
      key = keys[i];
      if (predicate(obj[key], key, obj)) return key;
    }
  };

  // Internal pick helper function to determine if `obj` has key `key`.
  var keyInObj = function(value, key, obj) {
    return key in obj;
  };

  // Return a copy of the object only containing the whitelisted properties.
  _.pick = restArgs(function(obj, keys) {
    var result = {}, iteratee = keys[0];
    if (obj == null) return result;
    if (_.isFunction(iteratee)) {
      if (keys.length > 1) iteratee = optimizeCb(iteratee, keys[1]);
      keys = _.allKeys(obj);
    } else {
      iteratee = keyInObj;
      keys = flatten(keys, false, false);
      obj = Object(obj);
    }
    for (var i = 0, length = keys.length; i < length; i++) {
      var key = keys[i];
      var value = obj[key];
      if (iteratee(value, key, obj)) result[key] = value;
    }
    return result;
  });

   // Return a copy of the object without the blacklisted properties.
  _.omit = restArgs(function(obj, keys) {
    var iteratee = keys[0], context;
    if (_.isFunction(iteratee)) {
      iteratee = _.negate(iteratee);
      if (keys.length > 1) context = keys[1];
    } else {
      keys = _.map(flatten(keys, false, false), String);
      iteratee = function(value, key) {
        return !_.contains(keys, key);
      };
    }
    return _.pick(obj, iteratee, context);
  });

  // Fill in a given object with default properties.
  _.defaults = createAssigner(_.allKeys, true);

  // Creates an object that inherits from the given prototype object.
  // If additional properties are provided then they will be added to the
  // created object.
  _.create = function(prototype, props) {
    var result = baseCreate(prototype);
    if (props) _.extendOwn(result, props);
    return result;
  };

  // Create a (shallow-cloned) duplicate of an object.
  _.clone = function(obj) {
    if (!_.isObject(obj)) return obj;
    return _.isArray(obj) ? obj.slice() : _.extend({}, obj);
  };

  // Invokes interceptor with the obj, and then returns obj.
  // The primary purpose of this method is to "tap into" a method chain, in
  // order to perform operations on intermediate results within the chain.
  _.tap = function(obj, interceptor) {
    interceptor(obj);
    return obj;
  };

  // Returns whether an object has a given set of `key:value` pairs.
  _.isMatch = function(object, attrs) {
    var keys = _.keys(attrs), length = keys.length;
    if (object == null) return !length;
    var obj = Object(object);
    for (var i = 0; i < length; i++) {
      var key = keys[i];
      if (attrs[key] !== obj[key] || !(key in obj)) return false;
    }
    return true;
  };


  // Internal recursive comparison function for `isEqual`.
  var eq, deepEq;
  eq = function(a, b, aStack, bStack) {
    // Identical objects are equal. `0 === -0`, but they aren't identical.
    // See the [Harmony `egal` proposal](http://wiki.ecmascript.org/doku.php?id=harmony:egal).
    if (a === b) return a !== 0 || 1 / a === 1 / b;
    // A strict comparison is necessary because `null == undefined`.
    if (a == null || b == null) return a === b;
    // `NaN`s are equivalent, but non-reflexive.
    if (a !== a) return b !== b;
    // Exhaust primitive checks
    var type = typeof a;
    if (type !== 'function' && type !== 'object' && typeof b !== 'object') return false;
    return deepEq(a, b, aStack, bStack);
  };

  // Internal recursive comparison function for `isEqual`.
  deepEq = function(a, b, aStack, bStack) {
    // Unwrap any wrapped objects.
    if (a instanceof _) a = a._wrapped;
    if (b instanceof _) b = b._wrapped;
    // Compare `[[Class]]` names.
    var className = toString.call(a);
    if (className !== toString.call(b)) return false;
    switch (className) {
      // Strings, numbers, regular expressions, dates, and booleans are compared by value.
      case '[object RegExp]':
      // RegExps are coerced to strings for comparison (Note: '' + /a/i === '/a/i')
      case '[object String]':
        // Primitives and their corresponding object wrappers are equivalent; thus, `"5"` is
        // equivalent to `new String("5")`.
        return '' + a === '' + b;
      case '[object Number]':
        // `NaN`s are equivalent, but non-reflexive.
        // Object(NaN) is equivalent to NaN
        if (+a !== +a) return +b !== +b;
        // An `egal` comparison is performed for other numeric values.
        return +a === 0 ? 1 / +a === 1 / b : +a === +b;
      case '[object Date]':
      case '[object Boolean]':
        // Coerce dates and booleans to numeric primitive values. Dates are compared by their
        // millisecond representations. Note that invalid dates with millisecond representations
        // of `NaN` are not equivalent.
        return +a === +b;
    }

    var areArrays = className === '[object Array]';
    if (!areArrays) {
      if (typeof a != 'object' || typeof b != 'object') return false;

      // Objects with different constructors are not equivalent, but `Object`s or `Array`s
      // from different frames are.
      var aCtor = a.constructor, bCtor = b.constructor;
      if (aCtor !== bCtor && !(_.isFunction(aCtor) && aCtor instanceof aCtor &&
                               _.isFunction(bCtor) && bCtor instanceof bCtor)
                          && ('constructor' in a && 'constructor' in b)) {
        return false;
      }
    }
    // Assume equality for cyclic structures. The algorithm for detecting cyclic
    // structures is adapted from ES 5.1 section 15.12.3, abstract operation `JO`.

    // Initializing stack of traversed objects.
    // It's done here since we only need them for objects and arrays comparison.
    aStack = aStack || [];
    bStack = bStack || [];
    var length = aStack.length;
    while (length--) {
      // Linear search. Performance is inversely proportional to the number of
      // unique nested structures.
      if (aStack[length] === a) return bStack[length] === b;
    }

    // Add the first object to the stack of traversed objects.
    aStack.push(a);
    bStack.push(b);

    // Recursively compare objects and arrays.
    if (areArrays) {
      // Compare array lengths to determine if a deep comparison is necessary.
      length = a.length;
      if (length !== b.length) return false;
      // Deep compare the contents, ignoring non-numeric properties.
      while (length--) {
        if (!eq(a[length], b[length], aStack, bStack)) return false;
      }
    } else {
      // Deep compare objects.
      var keys = _.keys(a), key;
      length = keys.length;
      // Ensure that both objects contain the same number of properties before comparing deep equality.
      if (_.keys(b).length !== length) return false;
      while (length--) {
        // Deep compare each member
        key = keys[length];
        if (!(_.has(b, key) && eq(a[key], b[key], aStack, bStack))) return false;
      }
    }
    // Remove the first object from the stack of traversed objects.
    aStack.pop();
    bStack.pop();
    return true;
  };

  // Perform a deep comparison to check if two objects are equal.
  _.isEqual = function(a, b) {
    return eq(a, b);
  };

  // Is a given array, string, or object empty?
  // An "empty" object has no enumerable own-properties.
  _.isEmpty = function(obj) {
    if (obj == null) return true;
    if (isArrayLike(obj) && (_.isArray(obj) || _.isString(obj) || _.isArguments(obj))) return obj.length === 0;
    return _.keys(obj).length === 0;
  };

  // Is a given value a DOM element?
  _.isElement = function(obj) {
    return !!(obj && obj.nodeType === 1);
  };

  // Is a given value an array?
  // Delegates to ECMA5's native Array.isArray
  _.isArray = nativeIsArray || function(obj) {
    return toString.call(obj) === '[object Array]';
  };

  // Is a given variable an object?
  _.isObject = function(obj) {
    var type = typeof obj;
    return type === 'function' || type === 'object' && !!obj;
  };

  // Add some isType methods: isArguments, isFunction, isString, isNumber, isDate, isRegExp, isError.
  _.each(['Arguments', 'Function', 'String', 'Number', 'Date', 'RegExp', 'Error'], function(name) {
    _['is' + name] = function(obj) {
      return toString.call(obj) === '[object ' + name + ']';
    };
  });

  // Define a fallback version of the method in browsers (ahem, IE < 9), where
  // there isn't any inspectable "Arguments" type.
  if (!_.isArguments(arguments)) {
    _.isArguments = function(obj) {
      return _.has(obj, 'callee');
    };
  }

  // Optimize `isFunction` if appropriate. Work around some typeof bugs in old v8,
  // IE 11 (#1621), and in Safari 8 (#1929).
  if (typeof /./ != 'function' && typeof Int8Array != 'object') {
    _.isFunction = function(obj) {
      return typeof obj == 'function' || false;
    };
  }

  // Is a given object a finite number?
  _.isFinite = function(obj) {
    return isFinite(obj) && !isNaN(parseFloat(obj));
  };

  // Is the given value `NaN`? (NaN is the only number which does not equal itself).
  _.isNaN = function(obj) {
    return _.isNumber(obj) && obj !== +obj;
  };

  // Is a given value a boolean?
  _.isBoolean = function(obj) {
    return obj === true || obj === false || toString.call(obj) === '[object Boolean]';
  };

  // Is a given value equal to null?
  _.isNull = function(obj) {
    return obj === null;
  };

  // Is a given variable undefined?
  _.isUndefined = function(obj) {
    return obj === void 0;
  };

  // Shortcut function for checking if an object has a given property directly
  // on itself (in other words, not on a prototype).
  _.has = function(obj, key) {
    return obj != null && hasOwnProperty.call(obj, key);
  };

  // Utility Functions
  // -----------------

  // Run Underscore.js in *noConflict* mode, returning the `_` variable to its
  // previous owner. Returns a reference to the Underscore object.
  _.noConflict = function() {
    root._ = previousUnderscore;
    return this;
  };

  // Keep the identity function around for default iteratees.
  _.identity = function(value) {
    return value;
  };

  // Predicate-generating functions. Often useful outside of Underscore.
  _.constant = function(value) {
    return function() {
      return value;
    };
  };

  _.noop = function(){};

  _.property = property;

  // Generates a function for a given object that returns a given property.
  _.propertyOf = function(obj) {
    return obj == null ? function(){} : function(key) {
      return obj[key];
    };
  };

  // Returns a predicate for checking whether an object has a given set of
  // `key:value` pairs.
  _.matcher = _.matches = function(attrs) {
    attrs = _.extendOwn({}, attrs);
    return function(obj) {
      return _.isMatch(obj, attrs);
    };
  };

  // Run a function **n** times.
  _.times = function(n, iteratee, context) {
    var accum = Array(Math.max(0, n));
    iteratee = optimizeCb(iteratee, context, 1);
    for (var i = 0; i < n; i++) accum[i] = iteratee(i);
    return accum;
  };

  // Return a random integer between min and max (inclusive).
  _.random = function(min, max) {
    if (max == null) {
      max = min;
      min = 0;
    }
    return min + Math.floor(Math.random() * (max - min + 1));
  };

  // A (possibly faster) way to get the current timestamp as an integer.
  _.now = Date.now || function() {
    return new Date().getTime();
  };

   // List of HTML entities for escaping.
  var escapeMap = {
    '&': '&amp;',
    '<': '&lt;',
    '>': '&gt;',
    '"': '&quot;',
    "'": '&#x27;',
    '`': '&#x60;'
  };
  var unescapeMap = _.invert(escapeMap);

  // Functions for escaping and unescaping strings to/from HTML interpolation.
  var createEscaper = function(map) {
    var escaper = function(match) {
      return map[match];
    };
    // Regexes for identifying a key that needs to be escaped
    var source = '(?:' + _.keys(map).join('|') + ')';
    var testRegexp = RegExp(source);
    var replaceRegexp = RegExp(source, 'g');
    return function(string) {
      string = string == null ? '' : '' + string;
      return testRegexp.test(string) ? string.replace(replaceRegexp, escaper) : string;
    };
  };
  _.escape = createEscaper(escapeMap);
  _.unescape = createEscaper(unescapeMap);

  // If the value of the named `property` is a function then invoke it with the
  // `object` as context; otherwise, return it.
  _.result = function(object, prop, fallback) {
    var value = object == null ? void 0 : object[prop];
    if (value === void 0) {
      value = fallback;
    }
    return _.isFunction(value) ? value.call(object) : value;
  };

  // Generate a unique integer id (unique within the entire client session).
  // Useful for temporary DOM ids.
  var idCounter = 0;
  _.uniqueId = function(prefix) {
    var id = ++idCounter + '';
    return prefix ? prefix + id : id;
  };

  // By default, Underscore uses ERB-style template delimiters, change the
  // following template settings to use alternative delimiters.
  _.templateSettings = {
    evaluate: /<%([\s\S]+?)%>/g,
    interpolate: /<%=([\s\S]+?)%>/g,
    escape: /<%-([\s\S]+?)%>/g
  };

  // When customizing `templateSettings`, if you don't want to define an
  // interpolation, evaluation or escaping regex, we need one that is
  // guaranteed not to match.
  var noMatch = /(.)^/;

  // Certain characters need to be escaped so that they can be put into a
  // string literal.
  var escapes = {
    "'": "'",
    '\\': '\\',
    '\r': 'r',
    '\n': 'n',
    '\u2028': 'u2028',
    '\u2029': 'u2029'
  };

  var escapeRegExp = /\\|'|\r|\n|\u2028|\u2029/g;

  var escapeChar = function(match) {
    return '\\' + escapes[match];
  };

  // JavaScript micro-templating, similar to John Resig's implementation.
  // Underscore templating handles arbitrary delimiters, preserves whitespace,
  // and correctly escapes quotes within interpolated code.
  // NB: `oldSettings` only exists for backwards compatibility.
  _.template = function(text, settings, oldSettings) {
    if (!settings && oldSettings) settings = oldSettings;
    settings = _.defaults({}, settings, _.templateSettings);

    // Combine delimiters into one regular expression via alternation.
    var matcher = RegExp([
      (settings.escape || noMatch).source,
      (settings.interpolate || noMatch).source,
      (settings.evaluate || noMatch).source
    ].join('|') + '|$', 'g');

    // Compile the template source, escaping string literals appropriately.
    var index = 0;
    var source = "__p+='";
    text.replace(matcher, function(match, escape, interpolate, evaluate, offset) {
      source += text.slice(index, offset).replace(escapeRegExp, escapeChar);
      index = offset + match.length;

      if (escape) {
        source += "'+\n((__t=(" + escape + "))==null?'':_.escape(__t))+\n'";
      } else if (interpolate) {
        source += "'+\n((__t=(" + interpolate + "))==null?'':__t)+\n'";
      } else if (evaluate) {
        source += "';\n" + evaluate + "\n__p+='";
      }

      // Adobe VMs need the match returned to produce the correct offest.
      return match;
    });
    source += "';\n";

    // If a variable is not specified, place data values in local scope.
    if (!settings.variable) source = 'with(obj||{}){\n' + source + '}\n';

    source = "var __t,__p='',__j=Array.prototype.join," +
      "print=function(){__p+=__j.call(arguments,'');};\n" +
      source + 'return __p;\n';

    var render;
    try {
      render = new Function(settings.variable || 'obj', '_', source);
    } catch (e) {
      e.source = source;
      throw e;
    }

    var template = function(data) {
      return render.call(this, data, _);
    };

    // Provide the compiled source as a convenience for precompilation.
    var argument = settings.variable || 'obj';
    template.source = 'function(' + argument + '){\n' + source + '}';

    return template;
  };

  // Add a "chain" function. Start chaining a wrapped Underscore object.
  _.chain = function(obj) {
    var instance = _(obj);
    instance._chain = true;
    return instance;
  };

  // OOP
  // ---------------
  // If Underscore is called as a function, it returns a wrapped object that
  // can be used OO-style. This wrapper holds altered versions of all the
  // underscore functions. Wrapped objects may be chained.

  // Helper function to continue chaining intermediate results.
  var chainResult = function(instance, obj) {
    return instance._chain ? _(obj).chain() : obj;
  };

  // Add your own custom functions to the Underscore object.
  _.mixin = function(obj) {
    _.each(_.functions(obj), function(name) {
      var func = _[name] = obj[name];
      _.prototype[name] = function() {
        var args = [this._wrapped];
        push.apply(args, arguments);
        return chainResult(this, func.apply(_, args));
      };
    });
  };

  // Add all of the Underscore functions to the wrapper object.
  _.mixin(_);

  // Add all mutator Array functions to the wrapper.
  _.each(['pop', 'push', 'reverse', 'shift', 'sort', 'splice', 'unshift'], function(name) {
    var method = ArrayProto[name];
    _.prototype[name] = function() {
      var obj = this._wrapped;
      method.apply(obj, arguments);
      if ((name === 'shift' || name === 'splice') && obj.length === 0) delete obj[0];
      return chainResult(this, obj);
    };
  });

  // Add all accessor Array functions to the wrapper.
  _.each(['concat', 'join', 'slice'], function(name) {
    var method = ArrayProto[name];
    _.prototype[name] = function() {
      return chainResult(this, method.apply(this._wrapped, arguments));
    };
  });

  // Extracts the result from a wrapped and chained object.
  _.prototype.value = function() {
    return this._wrapped;
  };

  // Provide unwrapping proxy for some methods used in engine operations
  // such as arithmetic and JSON stringification.
  _.prototype.valueOf = _.prototype.toJSON = _.prototype.value;

  _.prototype.toString = function() {
    return '' + this._wrapped;
  };

  // AMD registration happens at the end for compatibility with AMD loaders
  // that may not enforce next-turn semantics on modules. Even though general
  // practice for AMD registration is to be anonymous, underscore registers
  // as a named module because, like jQuery, it is a base library that is
  // popular enough to be bundled in a third party lib, but not be part of
  // an AMD load request. Those cases could generate an error when an
  // anonymous define() is called outside of a loader request.
  if (typeof define === 'function' && define.amd) {
    define('underscore', [], function() {
      return _;
    });
  }
}());

;(function () {
	'use strict';

	/**
	 * @preserve FastClick: polyfill to remove click delays on browsers with touch UIs.
	 *
	 * @codingstandard ftlabs-jsv2
	 * @copyright The Financial Times Limited [All Rights Reserved]
	 * @license MIT License (see LICENSE.txt)
	 */

	/*jslint browser:true, node:true*/
	/*global define, Event, Node*/


	/**
	 * Instantiate fast-clicking listeners on the specified layer.
	 *
	 * @constructor
	 * @param {Element} layer The layer to listen on
	 * @param {Object} [options={}] The options to override the defaults
	 */
	function FastClick(layer, options) {
		var oldOnClick;

		options = options || {};

		/**
		 * Whether a click is currently being tracked.
		 *
		 * @type boolean
		 */
		this.trackingClick = false;


		/**
		 * Timestamp for when click tracking started.
		 *
		 * @type number
		 */
		this.trackingClickStart = 0;


		/**
		 * The element being tracked for a click.
		 *
		 * @type EventTarget
		 */
		this.targetElement = null;


		/**
		 * X-coordinate of touch start event.
		 *
		 * @type number
		 */
		this.touchStartX = 0;


		/**
		 * Y-coordinate of touch start event.
		 *
		 * @type number
		 */
		this.touchStartY = 0;


		/**
		 * ID of the last touch, retrieved from Touch.identifier.
		 *
		 * @type number
		 */
		this.lastTouchIdentifier = 0;


		/**
		 * Touchmove boundary, beyond which a click will be cancelled.
		 *
		 * @type number
		 */
		this.touchBoundary = options.touchBoundary || 10;


		/**
		 * The FastClick layer.
		 *
		 * @type Element
		 */
		this.layer = layer;

		/**
		 * The minimum time between tap(touchstart and touchend) events
		 *
		 * @type number
		 */
		this.tapDelay = options.tapDelay || 200;

		/**
		 * The maximum time for a tap
		 *
		 * @type number
		 */
		this.tapTimeout = options.tapTimeout || 700;

		if (FastClick.notNeeded(layer)) {
			return;
		}

		// Some old versions of Android don't have Function.prototype.bind
		function bind(method, context) {
			return function() { return method.apply(context, arguments); };
		}


		var methods = ['onMouse', 'onClick', 'onTouchStart', 'onTouchMove', 'onTouchEnd', 'onTouchCancel'];
		var context = this;
		for (var i = 0, l = methods.length; i < l; i++) {
			context[methods[i]] = bind(context[methods[i]], context);
		}

		// Set up event handlers as required
		if (deviceIsAndroid) {
			layer.addEventListener('mouseover', this.onMouse, true);
			layer.addEventListener('mousedown', this.onMouse, true);
			layer.addEventListener('mouseup', this.onMouse, true);
		}

		layer.addEventListener('click', this.onClick, true);
		layer.addEventListener('touchstart', this.onTouchStart, false);
		layer.addEventListener('touchmove', this.onTouchMove, false);
		layer.addEventListener('touchend', this.onTouchEnd, false);
		layer.addEventListener('touchcancel', this.onTouchCancel, false);

		// Hack is required for browsers that don't support Event#stopImmediatePropagation (e.g. Android 2)
		// which is how FastClick normally stops click events bubbling to callbacks registered on the FastClick
		// layer when they are cancelled.
		if (!Event.prototype.stopImmediatePropagation) {
			layer.removeEventListener = function(type, callback, capture) {
				var rmv = Node.prototype.removeEventListener;
				if (type === 'click') {
					rmv.call(layer, type, callback.hijacked || callback, capture);
				} else {
					rmv.call(layer, type, callback, capture);
				}
			};

			layer.addEventListener = function(type, callback, capture) {
				var adv = Node.prototype.addEventListener;
				if (type === 'click') {
					adv.call(layer, type, callback.hijacked || (callback.hijacked = function(event) {
						if (!event.propagationStopped) {
							callback(event);
						}
					}), capture);
				} else {
					adv.call(layer, type, callback, capture);
				}
			};
		}

		// If a handler is already declared in the element's onclick attribute, it will be fired before
		// FastClick's onClick handler. Fix this by pulling out the user-defined handler function and
		// adding it as listener.
		if (typeof layer.onclick === 'function') {

			// Android browser on at least 3.2 requires a new reference to the function in layer.onclick
			// - the old one won't work if passed to addEventListener directly.
			oldOnClick = layer.onclick;
			layer.addEventListener('click', function(event) {
				oldOnClick(event);
			}, false);
			layer.onclick = null;
		}
	}

	/**
	* Windows Phone 8.1 fakes user agent string to look like Android and iPhone.
	*
	* @type boolean
	*/
	var deviceIsWindowsPhone = navigator.userAgent.indexOf("Windows Phone") >= 0;

	/**
	 * Android requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsAndroid = navigator.userAgent.indexOf('Android') > 0 && !deviceIsWindowsPhone;


	/**
	 * iOS requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsIOS = /iP(ad|hone|od)/.test(navigator.userAgent) && !deviceIsWindowsPhone;


	/**
	 * iOS 4 requires an exception for select elements.
	 *
	 * @type boolean
	 */
	var deviceIsIOS4 = deviceIsIOS && (/OS 4_\d(_\d)?/).test(navigator.userAgent);


	/**
	 * iOS 6.0-7.* requires the target element to be manually derived
	 *
	 * @type boolean
	 */
	var deviceIsIOSWithBadTarget = deviceIsIOS && (/OS [6-7]_\d/).test(navigator.userAgent);

	/**
	 * BlackBerry requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsBlackBerry10 = navigator.userAgent.indexOf('BB10') > 0;

	/**
	 * Determine whether a given element requires a native click.
	 *
	 * @param {EventTarget|Element} target Target DOM element
	 * @returns {boolean} Returns true if the element needs a native click
	 */
	FastClick.prototype.needsClick = function(target) {
		switch (target.nodeName.toLowerCase()) {

		// Don't send a synthetic click to disabled inputs (issue #62)
		case 'button':
		case 'select':
		case 'textarea':
			if (target.disabled) {
				return true;
			}

			break;
		case 'input':

			// File inputs need real clicks on iOS 6 due to a browser bug (issue #68)
			if ((deviceIsIOS && target.type === 'file') || target.disabled) {
				return true;
			}

			break;
		case 'label':
		case 'iframe': // iOS8 homescreen apps can prevent events bubbling into frames
		case 'video':
			return true;
		}

		return (/\bneedsclick\b/).test(target.className);
	};


	/**
	 * Determine whether a given element requires a call to focus to simulate click into element.
	 *
	 * @param {EventTarget|Element} target Target DOM element
	 * @returns {boolean} Returns true if the element requires a call to focus to simulate native click.
	 */
	FastClick.prototype.needsFocus = function(target) {
		switch (target.nodeName.toLowerCase()) {
		case 'textarea':
			return true;
		case 'select':
			return !deviceIsAndroid;
		case 'input':
			switch (target.type) {
			case 'button':
			case 'checkbox':
			case 'file':
			case 'image':
			case 'radio':
			case 'submit':
				return false;
			}

			// No point in attempting to focus disabled inputs
			return !target.disabled && !target.readOnly;
		default:
			return (/\bneedsfocus\b/).test(target.className);
		}
	};


	/**
	 * Send a click event to the specified element.
	 *
	 * @param {EventTarget|Element} targetElement
	 * @param {Event} event
	 */
	FastClick.prototype.sendClick = function(targetElement, event) {
		var clickEvent, touch;

		// On some Android devices activeElement needs to be blurred otherwise the synthetic click will have no effect (#24)
		if (document.activeElement && document.activeElement !== targetElement) {
			document.activeElement.blur();
		}

		touch = event.changedTouches[0];

		// Synthesise a click event, with an extra attribute so it can be tracked
		clickEvent = document.createEvent('MouseEvents');
		clickEvent.initMouseEvent(this.determineEventType(targetElement), true, true, window, 1, touch.screenX, touch.screenY, touch.clientX, touch.clientY, false, false, false, false, 0, null);
		clickEvent.forwardedTouchEvent = true;
		targetElement.dispatchEvent(clickEvent);
	};

	FastClick.prototype.determineEventType = function(targetElement) {

		//Issue #159: Android Chrome Select Box does not open with a synthetic click event
		if (deviceIsAndroid && targetElement.tagName.toLowerCase() === 'select') {
			return 'mousedown';
		}

		return 'click';
	};


	/**
	 * @param {EventTarget|Element} targetElement
	 */
	FastClick.prototype.focus = function(targetElement) {
		var length;

		// Issue #160: on iOS 7, some input elements (e.g. date datetime month) throw a vague TypeError on setSelectionRange. These elements don't have an integer value for the selectionStart and selectionEnd properties, but unfortunately that can't be used for detection because accessing the properties also throws a TypeError. Just check the type instead. Filed as Apple bug #15122724.
		if (deviceIsIOS && targetElement.setSelectionRange && targetElement.type.indexOf('date') !== 0 && targetElement.type !== 'time' && targetElement.type !== 'month') {
			length = targetElement.value.length;
			targetElement.setSelectionRange(length, length);
		} else {
			targetElement.focus();
		}
	};


	/**
	 * Check whether the given target element is a child of a scrollable layer and if so, set a flag on it.
	 *
	 * @param {EventTarget|Element} targetElement
	 */
	FastClick.prototype.updateScrollParent = function(targetElement) {
		var scrollParent, parentElement;

		scrollParent = targetElement.fastClickScrollParent;

		// Attempt to discover whether the target element is contained within a scrollable layer. Re-check if the
		// target element was moved to another parent.
		if (!scrollParent || !scrollParent.contains(targetElement)) {
			parentElement = targetElement;
			do {
				if (parentElement.scrollHeight > parentElement.offsetHeight) {
					scrollParent = parentElement;
					targetElement.fastClickScrollParent = parentElement;
					break;
				}

				parentElement = parentElement.parentElement;
			} while (parentElement);
		}

		// Always update the scroll top tracker if possible.
		if (scrollParent) {
			scrollParent.fastClickLastScrollTop = scrollParent.scrollTop;
		}
	};


	/**
	 * @param {EventTarget} targetElement
	 * @returns {Element|EventTarget}
	 */
	FastClick.prototype.getTargetElementFromEventTarget = function(eventTarget) {

		// On some older browsers (notably Safari on iOS 4.1 - see issue #56) the event target may be a text node.
		if (eventTarget.nodeType === Node.TEXT_NODE) {
			return eventTarget.parentNode;
		}

		return eventTarget;
	};


	/**
	 * On touch start, record the position and scroll offset.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchStart = function(event) {
		var targetElement, touch, selection;

		// Ignore multiple touches, otherwise pinch-to-zoom is prevented if both fingers are on the FastClick element (issue #111).
		if (event.targetTouches.length > 1) {
			return true;
		}

		targetElement = this.getTargetElementFromEventTarget(event.target);
		touch = event.targetTouches[0];

		if (deviceIsIOS) {

			// Only trusted events will deselect text on iOS (issue #49)
			selection = window.getSelection();
			if (selection.rangeCount && !selection.isCollapsed) {
				return true;
			}

			if (!deviceIsIOS4) {

				// Weird things happen on iOS when an alert or confirm dialog is opened from a click event callback (issue #23):
				// when the user next taps anywhere else on the page, new touchstart and touchend events are dispatched
				// with the same identifier as the touch event that previously triggered the click that triggered the alert.
				// Sadly, there is an issue on iOS 4 that causes some normal touch events to have the same identifier as an
				// immediately preceeding touch event (issue #52), so this fix is unavailable on that platform.
				// Issue 120: touch.identifier is 0 when Chrome dev tools 'Emulate touch events' is set with an iOS device UA string,
				// which causes all touch events to be ignored. As this block only applies to iOS, and iOS identifiers are always long,
				// random integers, it's safe to to continue if the identifier is 0 here.
				if (touch.identifier && touch.identifier === this.lastTouchIdentifier) {
					event.preventDefault();
					return false;
				}

				this.lastTouchIdentifier = touch.identifier;

				// If the target element is a child of a scrollable layer (using -webkit-overflow-scrolling: touch) and:
				// 1) the user does a fling scroll on the scrollable layer
				// 2) the user stops the fling scroll with another tap
				// then the event.target of the last 'touchend' event will be the element that was under the user's finger
				// when the fling scroll was started, causing FastClick to send a click event to that layer - unless a check
				// is made to ensure that a parent layer was not scrolled before sending a synthetic click (issue #42).
				this.updateScrollParent(targetElement);
			}
		}

		this.trackingClick = true;
		this.trackingClickStart = event.timeStamp;
		this.targetElement = targetElement;

		this.touchStartX = touch.pageX;
		this.touchStartY = touch.pageY;

		// Prevent phantom clicks on fast double-tap (issue #36)
		if ((event.timeStamp - this.lastClickTime) < this.tapDelay) {
			event.preventDefault();
		}

		return true;
	};


	/**
	 * Based on a touchmove event object, check whether the touch has moved past a boundary since it started.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.touchHasMoved = function(event) {
		var touch = event.changedTouches[0], boundary = this.touchBoundary;

		if (Math.abs(touch.pageX - this.touchStartX) > boundary || Math.abs(touch.pageY - this.touchStartY) > boundary) {
			return true;
		}

		return false;
	};


	/**
	 * Update the last position.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchMove = function(event) {
		if (!this.trackingClick) {
			return true;
		}

		// If the touch has moved, cancel the click tracking
		if (this.targetElement !== this.getTargetElementFromEventTarget(event.target) || this.touchHasMoved(event)) {
			this.trackingClick = false;
			this.targetElement = null;
		}

		return true;
	};


	/**
	 * Attempt to find the labelled control for the given label element.
	 *
	 * @param {EventTarget|HTMLLabelElement} labelElement
	 * @returns {Element|null}
	 */
	FastClick.prototype.findControl = function(labelElement) {

		// Fast path for newer browsers supporting the HTML5 control attribute
		if (labelElement.control !== undefined) {
			return labelElement.control;
		}

		// All browsers under test that support touch events also support the HTML5 htmlFor attribute
		if (labelElement.htmlFor) {
			return document.getElementById(labelElement.htmlFor);
		}

		// If no for attribute exists, attempt to retrieve the first labellable descendant element
		// the list of which is defined here: http://www.w3.org/TR/html5/forms.html#category-label
		return labelElement.querySelector('button, input:not([type=hidden]), keygen, meter, output, progress, select, textarea');
	};


	/**
	 * On touch end, determine whether to send a click event at once.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchEnd = function(event) {
		var forElement, trackingClickStart, targetTagName, scrollParent, touch, targetElement = this.targetElement;

		if (!this.trackingClick) {
			return true;
		}

		// Prevent phantom clicks on fast double-tap (issue #36)
		if ((event.timeStamp - this.lastClickTime) < this.tapDelay) {
			this.cancelNextClick = true;
			return true;
		}

		if ((event.timeStamp - this.trackingClickStart) > this.tapTimeout) {
			return true;
		}

		// Reset to prevent wrong click cancel on input (issue #156).
		this.cancelNextClick = false;

		this.lastClickTime = event.timeStamp;

		trackingClickStart = this.trackingClickStart;
		this.trackingClick = false;
		this.trackingClickStart = 0;

		// On some iOS devices, the targetElement supplied with the event is invalid if the layer
		// is performing a transition or scroll, and has to be re-detected manually. Note that
		// for this to function correctly, it must be called *after* the event target is checked!
		// See issue #57; also filed as rdar://13048589 .
		if (deviceIsIOSWithBadTarget) {
			touch = event.changedTouches[0];

			// In certain cases arguments of elementFromPoint can be negative, so prevent setting targetElement to null
			targetElement = document.elementFromPoint(touch.pageX - window.pageXOffset, touch.pageY - window.pageYOffset) || targetElement;
			targetElement.fastClickScrollParent = this.targetElement.fastClickScrollParent;
		}

		targetTagName = targetElement.tagName.toLowerCase();
		if (targetTagName === 'label') {
			forElement = this.findControl(targetElement);
			if (forElement) {
				this.focus(targetElement);
				if (deviceIsAndroid) {
					return false;
				}

				targetElement = forElement;
			}
		} else if (this.needsFocus(targetElement)) {

			// Case 1: If the touch started a while ago (best guess is 100ms based on tests for issue #36) then focus will be triggered anyway. Return early and unset the target element reference so that the subsequent click will be allowed through.
			// Case 2: Without this exception for input elements tapped when the document is contained in an iframe, then any inputted text won't be visible even though the value attribute is updated as the user types (issue #37).
			if ((event.timeStamp - trackingClickStart) > 100 || (deviceIsIOS && window.top !== window && targetTagName === 'input')) {
				this.targetElement = null;
				return false;
			}

			this.focus(targetElement);
			this.sendClick(targetElement, event);

			// Select elements need the event to go through on iOS 4, otherwise the selector menu won't open.
			// Also this breaks opening selects when VoiceOver is active on iOS6, iOS7 (and possibly others)
			if (!deviceIsIOS || targetTagName !== 'select') {
				this.targetElement = null;
				event.preventDefault();
			}

			return false;
		}

		if (deviceIsIOS && !deviceIsIOS4) {

			// Don't send a synthetic click event if the target element is contained within a parent layer that was scrolled
			// and this tap is being used to stop the scrolling (usually initiated by a fling - issue #42).
			scrollParent = targetElement.fastClickScrollParent;
			if (scrollParent && scrollParent.fastClickLastScrollTop !== scrollParent.scrollTop) {
				return true;
			}
		}

		// Prevent the actual click from going though - unless the target node is marked as requiring
		// real clicks or if it is in the whitelist in which case only non-programmatic clicks are permitted.
		if (!this.needsClick(targetElement)) {
			event.preventDefault();
			this.sendClick(targetElement, event);
		}

		return false;
	};


	/**
	 * On touch cancel, stop tracking the click.
	 *
	 * @returns {void}
	 */
	FastClick.prototype.onTouchCancel = function() {
		this.trackingClick = false;
		this.targetElement = null;
	};


	/**
	 * Determine mouse events which should be permitted.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onMouse = function(event) {

		// If a target element was never set (because a touch event was never fired) allow the event
		if (!this.targetElement) {
			return true;
		}

		if (event.forwardedTouchEvent) {
			return true;
		}

		// Programmatically generated events targeting a specific element should be permitted
		if (!event.cancelable) {
			return true;
		}

		// Derive and check the target element to see whether the mouse event needs to be permitted;
		// unless explicitly enabled, prevent non-touch click events from triggering actions,
		// to prevent ghost/doubleclicks.
		if (!this.needsClick(this.targetElement) || this.cancelNextClick) {

			// Prevent any user-added listeners declared on FastClick element from being fired.
			if (event.stopImmediatePropagation) {
				event.stopImmediatePropagation();
			} else {

				// Part of the hack for browsers that don't support Event#stopImmediatePropagation (e.g. Android 2)
				event.propagationStopped = true;
			}

			// Cancel the event
			event.stopPropagation();
			event.preventDefault();

			return false;
		}

		// If the mouse event is permitted, return true for the action to go through.
		return true;
	};


	/**
	 * On actual clicks, determine whether this is a touch-generated click, a click action occurring
	 * naturally after a delay after a touch (which needs to be cancelled to avoid duplication), or
	 * an actual click which should be permitted.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onClick = function(event) {
		var permitted;

		// It's possible for another FastClick-like library delivered with third-party code to fire a click event before FastClick does (issue #44). In that case, set the click-tracking flag back to false and return early. This will cause onTouchEnd to return early.
		if (this.trackingClick) {
			this.targetElement = null;
			this.trackingClick = false;
			return true;
		}

		// Very odd behaviour on iOS (issue #18): if a submit element is present inside a form and the user hits enter in the iOS simulator or clicks the Go button on the pop-up OS keyboard the a kind of 'fake' click event will be triggered with the submit-type input element as the target.
		if (event.target.type === 'submit' && event.detail === 0) {
			return true;
		}

		permitted = this.onMouse(event);

		// Only unset targetElement if the click is not permitted. This will ensure that the check for !targetElement in onMouse fails and the browser's click doesn't go through.
		if (!permitted) {
			this.targetElement = null;
		}

		// If clicks are permitted, return true for the action to go through.
		return permitted;
	};


	/**
	 * Remove all FastClick's event listeners.
	 *
	 * @returns {void}
	 */
	FastClick.prototype.destroy = function() {
		var layer = this.layer;

		if (deviceIsAndroid) {
			layer.removeEventListener('mouseover', this.onMouse, true);
			layer.removeEventListener('mousedown', this.onMouse, true);
			layer.removeEventListener('mouseup', this.onMouse, true);
		}

		layer.removeEventListener('click', this.onClick, true);
		layer.removeEventListener('touchstart', this.onTouchStart, false);
		layer.removeEventListener('touchmove', this.onTouchMove, false);
		layer.removeEventListener('touchend', this.onTouchEnd, false);
		layer.removeEventListener('touchcancel', this.onTouchCancel, false);
	};


	/**
	 * Check whether FastClick is needed.
	 *
	 * @param {Element} layer The layer to listen on
	 */
	FastClick.notNeeded = function(layer) {
		var metaViewport;
		var chromeVersion;
		var blackberryVersion;
		var firefoxVersion;

		// Devices that don't support touch don't need FastClick
		if (typeof window.ontouchstart === 'undefined') {
			return true;
		}

		// Chrome version - zero for other browsers
		chromeVersion = +(/Chrome\/([0-9]+)/.exec(navigator.userAgent) || [,0])[1];

		if (chromeVersion) {

			if (deviceIsAndroid) {
				metaViewport = document.querySelector('meta[name=viewport]');

				if (metaViewport) {
					// Chrome on Android with user-scalable="no" doesn't need FastClick (issue #89)
					if (metaViewport.content.indexOf('user-scalable=no') !== -1) {
						return true;
					}
					// Chrome 32 and above with width=device-width or less don't need FastClick
					if (chromeVersion > 31 && document.documentElement.scrollWidth <= window.outerWidth) {
						return true;
					}
				}

			// Chrome desktop doesn't need FastClick (issue #15)
			} else {
				return true;
			}
		}

		if (deviceIsBlackBerry10) {
			blackberryVersion = navigator.userAgent.match(/Version\/([0-9]*)\.([0-9]*)/);

			// BlackBerry 10.3+ does not require Fastclick library.
			// https://github.com/ftlabs/fastclick/issues/251
			if (blackberryVersion[1] >= 10 && blackberryVersion[2] >= 3) {
				metaViewport = document.querySelector('meta[name=viewport]');

				if (metaViewport) {
					// user-scalable=no eliminates click delay.
					if (metaViewport.content.indexOf('user-scalable=no') !== -1) {
						return true;
					}
					// width=device-width (or less than device-width) eliminates click delay.
					if (document.documentElement.scrollWidth <= window.outerWidth) {
						return true;
					}
				}
			}
		}

		// IE10 with -ms-touch-action: none or manipulation, which disables double-tap-to-zoom (issue #97)
		if (layer.style.msTouchAction === 'none' || layer.style.touchAction === 'manipulation') {
			return true;
		}

		// Firefox version - zero for other browsers
		firefoxVersion = +(/Firefox\/([0-9]+)/.exec(navigator.userAgent) || [,0])[1];

		if (firefoxVersion >= 27) {
			// Firefox 27+ does not have tap delay if the content is not zoomable - https://bugzilla.mozilla.org/show_bug.cgi?id=922896

			metaViewport = document.querySelector('meta[name=viewport]');
			if (metaViewport && (metaViewport.content.indexOf('user-scalable=no') !== -1 || document.documentElement.scrollWidth <= window.outerWidth)) {
				return true;
			}
		}

		// IE11: prefixed -ms-touch-action is no longer supported and it's recomended to use non-prefixed version
		// http://msdn.microsoft.com/en-us/library/windows/apps/Hh767313.aspx
		if (layer.style.touchAction === 'none' || layer.style.touchAction === 'manipulation') {
			return true;
		}

		return false;
	};


	/**
	 * Factory method for creating a FastClick object
	 *
	 * @param {Element} layer The layer to listen on
	 * @param {Object} [options={}] The options to override the defaults
	 */
	FastClick.attach = function(layer, options) {
		return new FastClick(layer, options);
	};


	if (typeof define === 'function' && typeof define.amd === 'object' && define.amd) {

		// AMD. Register as an anonymous module.
		define(function() {
			return FastClick;
		});
	} else if (typeof module !== 'undefined' && module.exports) {
		module.exports = FastClick.attach;
		module.exports.FastClick = FastClick;
	} else {
		window.FastClick = FastClick;
	}
}());

/**
 * Simple localStorage with Cookie Fallback
 * v.1.0.0
 *
 * USAGE:
 * ----------------------------------------
 * Set New / Modify:
 *   store('my_key', 'some_value');
 *
 * Retrieve:
 *   store('my_key');
 *
 * Delete / Remove:
 *   store('my_key', null);
 */
 
var store = function store(key, value) {
 
    var lsSupport = false;
    
    // Check for native support
    if (window['localStorage']) {
        lsSupport = true;
    }
    
    // If value is detected, set new or modify store
    if (typeof value !== "undefined" && value !== null) {
        // Convert object values to JSON
        if ( typeof value === 'object' ) {
            value = JSON.stringify(value);
        }
        // Set the store
        if (lsSupport) { // Native support
            window['localStorage'].setItem(key, value);
        } else { // Use Cookie
            createCookie(key, value, 30);
        }
    }
    
    // No value supplied, return value
    if (typeof value === "undefined") {
        // Get value
        if (lsSupport) { // Native support
            data = window['localStorage'].getItem(key);
        } else { // Use cookie 
            data = readCookie(key);
        }
        
        // Try to parse JSON...
        try {
           data = JSON.parse(data);
        }
        catch(e) {
           data = data;
        }
        
        return data;
        
    }
    
    // Null specified, remove store
    if (value === null) {
        if (lsSupport) { // Native support
            window['localStorage'].removeItem(key);
        } else { // Use cookie
            createCookie(key, '', -1);
        }
    }
    
    /**
     * Creates new cookie or removes cookie with negative expiration
     * @param  key       The key or identifier for the store
     * @param  value     Contents of the store
     * @param  exp       Expiration - creation defaults to 30 days
     */
    
    function createCookie(key, value, exp) {
        var date = new Date();
        date.setTime(date.getTime() + (exp * 24 * 60 * 60 * 1000));
        var expires = "; expires=" + date.toGMTString();
        document.cookie = key + "=" + value + expires + "; path=/";
    }
    
    /**
     * Returns contents of cookie
     * @param  key       The key or identifier for the store
     */
    
    function readCookie(key) {
        var nameEQ = key + "=";
        var ca = document.cookie.split(';');
        for (var i = 0, max = ca.length; i < max; i++) {
            var c = ca[i];
            while (c.charAt(0) === ' ') c = c.substring(1, c.length);
            if (c.indexOf(nameEQ) === 0) return c.substring(nameEQ.length, c.length);
        }
        return null;
    }
    
};
/*! highlight.js v9.12.0 | BSD3 License | git.io/hljslicense */
!function(e){var t="object"==typeof window&&window||"object"==typeof self&&self;"undefined"!=typeof exports?e(exports):t&&(t.hljs=e({}),"function"==typeof define&&define.amd&&define([],function(){return t.hljs}))}(function(e){function t(e){return e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;")}function r(e){return e.nodeName.toLowerCase()}function a(e,t){var r=e&&e.exec(t);return r&&0===r.index}function n(e){return E.test(e)}function i(e){var t,r,a,i,s=e.className+" ";if(s+=e.parentNode?e.parentNode.className:"",r=M.exec(s))return w(r[1])?r[1]:"no-highlight";for(s=s.split(/\s+/),t=0,a=s.length;a>t;t++)if(i=s[t],n(i)||w(i))return i}function s(e){var t,r={},a=Array.prototype.slice.call(arguments,1);for(t in e)r[t]=e[t];return a.forEach(function(e){for(t in e)r[t]=e[t]}),r}function c(e){var t=[];return function a(e,n){for(var i=e.firstChild;i;i=i.nextSibling)3===i.nodeType?n+=i.nodeValue.length:1===i.nodeType&&(t.push({event:"start",offset:n,node:i}),n=a(i,n),r(i).match(/br|hr|img|input/)||t.push({event:"stop",offset:n,node:i}));return n}(e,0),t}function o(e,a,n){function i(){return e.length&&a.length?e[0].offset!==a[0].offset?e[0].offset<a[0].offset?e:a:"start"===a[0].event?e:a:e.length?e:a}function s(e){function a(e){return" "+e.nodeName+'="'+t(e.value).replace('"',"&quot;")+'"'}u+="<"+r(e)+N.map.call(e.attributes,a).join("")+">"}function c(e){u+="</"+r(e)+">"}function o(e){("start"===e.event?s:c)(e.node)}for(var l=0,u="",d=[];e.length||a.length;){var b=i();if(u+=t(n.substring(l,b[0].offset)),l=b[0].offset,b===e){d.reverse().forEach(c);do o(b.splice(0,1)[0]),b=i();while(b===e&&b.length&&b[0].offset===l);d.reverse().forEach(s)}else"start"===b[0].event?d.push(b[0].node):d.pop(),o(b.splice(0,1)[0])}return u+t(n.substr(l))}function l(e){return e.v&&!e.cached_variants&&(e.cached_variants=e.v.map(function(t){return s(e,{v:null},t)})),e.cached_variants||e.eW&&[s(e)]||[e]}function u(e){function t(e){return e&&e.source||e}function r(r,a){return new RegExp(t(r),"m"+(e.cI?"i":"")+(a?"g":""))}function a(n,i){if(!n.compiled){if(n.compiled=!0,n.k=n.k||n.bK,n.k){var s={},c=function(t,r){e.cI&&(r=r.toLowerCase()),r.split(" ").forEach(function(e){var r=e.split("|");s[r[0]]=[t,r[1]?Number(r[1]):1]})};"string"==typeof n.k?c("keyword",n.k):k(n.k).forEach(function(e){c(e,n.k[e])}),n.k=s}n.lR=r(n.l||/\w+/,!0),i&&(n.bK&&(n.b="\\b("+n.bK.split(" ").join("|")+")\\b"),n.b||(n.b=/\B|\b/),n.bR=r(n.b),n.e||n.eW||(n.e=/\B|\b/),n.e&&(n.eR=r(n.e)),n.tE=t(n.e)||"",n.eW&&i.tE&&(n.tE+=(n.e?"|":"")+i.tE)),n.i&&(n.iR=r(n.i)),null==n.r&&(n.r=1),n.c||(n.c=[]),n.c=Array.prototype.concat.apply([],n.c.map(function(e){return l("self"===e?n:e)})),n.c.forEach(function(e){a(e,n)}),n.starts&&a(n.starts,i);var o=n.c.map(function(e){return e.bK?"\\.?("+e.b+")\\.?":e.b}).concat([n.tE,n.i]).map(t).filter(Boolean);n.t=o.length?r(o.join("|"),!0):{exec:function(){return null}}}}a(e)}function d(e,r,n,i){function s(e,t){var r,n;for(r=0,n=t.c.length;n>r;r++)if(a(t.c[r].bR,e))return t.c[r]}function c(e,t){if(a(e.eR,t)){for(;e.endsParent&&e.parent;)e=e.parent;return e}return e.eW?c(e.parent,t):void 0}function o(e,t){return!n&&a(t.iR,e)}function l(e,t){var r=v.cI?t[0].toLowerCase():t[0];return e.k.hasOwnProperty(r)&&e.k[r]}function p(e,t,r,a){var n=a?"":L.classPrefix,i='<span class="'+n,s=r?"":R;return i+=e+'">',i+t+s}function m(){var e,r,a,n;if(!N.k)return t(E);for(n="",r=0,N.lR.lastIndex=0,a=N.lR.exec(E);a;)n+=t(E.substring(r,a.index)),e=l(N,a),e?(M+=e[1],n+=p(e[0],t(a[0]))):n+=t(a[0]),r=N.lR.lastIndex,a=N.lR.exec(E);return n+t(E.substr(r))}function f(){var e="string"==typeof N.sL;if(e&&!x[N.sL])return t(E);var r=e?d(N.sL,E,!0,k[N.sL]):b(E,N.sL.length?N.sL:void 0);return N.r>0&&(M+=r.r),e&&(k[N.sL]=r.top),p(r.language,r.value,!1,!0)}function g(){C+=null!=N.sL?f():m(),E=""}function _(e){C+=e.cN?p(e.cN,"",!0):"",N=Object.create(e,{parent:{value:N}})}function h(e,t){if(E+=e,null==t)return g(),0;var r=s(t,N);if(r)return r.skip?E+=t:(r.eB&&(E+=t),g(),r.rB||r.eB||(E=t)),_(r,t),r.rB?0:t.length;var a=c(N,t);if(a){var n=N;n.skip?E+=t:(n.rE||n.eE||(E+=t),g(),n.eE&&(E=t));do N.cN&&(C+=R),N.skip||(M+=N.r),N=N.parent;while(N!==a.parent);return a.starts&&_(a.starts,""),n.rE?0:t.length}if(o(t,N))throw new Error('Illegal lexeme "'+t+'" for mode "'+(N.cN||"<unnamed>")+'"');return E+=t,t.length||1}var v=w(e);if(!v)throw new Error('Unknown language: "'+e+'"');u(v);var y,N=i||v,k={},C="";for(y=N;y!==v;y=y.parent)y.cN&&(C=p(y.cN,"",!0)+C);var E="",M=0;try{for(var B,S,$=0;;){if(N.t.lastIndex=$,B=N.t.exec(r),!B)break;S=h(r.substring($,B.index),B[0]),$=B.index+S}for(h(r.substr($)),y=N;y.parent;y=y.parent)y.cN&&(C+=R);return{r:M,value:C,language:e,top:N}}catch(A){if(A.message&&-1!==A.message.indexOf("Illegal"))return{r:0,value:t(r)};throw A}}function b(e,r){r=r||L.languages||k(x);var a={r:0,value:t(e)},n=a;return r.filter(w).forEach(function(t){var r=d(t,e,!1);r.language=t,r.r>n.r&&(n=r),r.r>a.r&&(n=a,a=r)}),n.language&&(a.second_best=n),a}function p(e){return L.tabReplace||L.useBR?e.replace(B,function(e,t){return L.useBR&&"\n"===e?"<br>":L.tabReplace?t.replace(/\t/g,L.tabReplace):""}):e}function m(e,t,r){var a=t?C[t]:r,n=[e.trim()];return e.match(/\bhljs\b/)||n.push("hljs"),-1===e.indexOf(a)&&n.push(a),n.join(" ").trim()}function f(e){var t,r,a,s,l,u=i(e);n(u)||(L.useBR?(t=document.createElementNS("http://www.w3.org/1999/xhtml","div"),t.innerHTML=e.innerHTML.replace(/\n/g,"").replace(/<br[ \/]*>/g,"\n")):t=e,l=t.textContent,a=u?d(u,l,!0):b(l),r=c(t),r.length&&(s=document.createElementNS("http://www.w3.org/1999/xhtml","div"),s.innerHTML=a.value,a.value=o(r,c(s),l)),a.value=p(a.value),e.innerHTML=a.value,e.className=m(e.className,u,a.language),e.result={language:a.language,re:a.r},a.second_best&&(e.second_best={language:a.second_best.language,re:a.second_best.r}))}function g(e){L=s(L,e)}function _(){if(!_.called){_.called=!0;var e=document.querySelectorAll("pre code");N.forEach.call(e,f)}}function h(){addEventListener("DOMContentLoaded",_,!1),addEventListener("load",_,!1)}function v(t,r){var a=x[t]=r(e);a.aliases&&a.aliases.forEach(function(e){C[e]=t})}function y(){return k(x)}function w(e){return e=(e||"").toLowerCase(),x[e]||x[C[e]]}var N=[],k=Object.keys,x={},C={},E=/^(no-?highlight|plain|text)$/i,M=/\blang(?:uage)?-([\w-]+)\b/i,B=/((^(<[^>]+>|\t|)+|(?:\n)))/gm,R="</span>",L={classPrefix:"hljs-",tabReplace:null,useBR:!1,languages:void 0};return e.highlight=d,e.highlightAuto=b,e.fixMarkup=p,e.highlightBlock=f,e.configure=g,e.initHighlighting=_,e.initHighlightingOnLoad=h,e.registerLanguage=v,e.listLanguages=y,e.getLanguage=w,e.inherit=s,e.IR="[a-zA-Z]\\w*",e.UIR="[a-zA-Z_]\\w*",e.NR="\\b\\d+(\\.\\d+)?",e.CNR="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",e.BNR="\\b(0b[01]+)",e.RSR="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",e.BE={b:"\\\\[\\s\\S]",r:0},e.ASM={cN:"string",b:"'",e:"'",i:"\\n",c:[e.BE]},e.QSM={cN:"string",b:'"',e:'"',i:"\\n",c:[e.BE]},e.PWM={b:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},e.C=function(t,r,a){var n=e.inherit({cN:"comment",b:t,e:r,c:[]},a||{});return n.c.push(e.PWM),n.c.push({cN:"doctag",b:"(?:TODO|FIXME|NOTE|BUG|XXX):",r:0}),n},e.CLCM=e.C("//","$"),e.CBCM=e.C("/\\*","\\*/"),e.HCM=e.C("#","$"),e.NM={cN:"number",b:e.NR,r:0},e.CNM={cN:"number",b:e.CNR,r:0},e.BNM={cN:"number",b:e.BNR,r:0},e.CSSNM={cN:"number",b:e.NR+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",r:0},e.RM={cN:"regexp",b:/\//,e:/\/[gimuy]*/,i:/\n/,c:[e.BE,{b:/\[/,e:/\]/,r:0,c:[e.BE]}]},e.TM={cN:"title",b:e.IR,r:0},e.UTM={cN:"title",b:e.UIR,r:0},e.METHOD_GUARD={b:"\\.\\s*"+e.UIR,r:0},e.registerLanguage("apache",function(e){var t={cN:"number",b:"[\\$%]\\d+"};return{aliases:["apacheconf"],cI:!0,c:[e.HCM,{cN:"section",b:"</?",e:">"},{cN:"attribute",b:/\w+/,r:0,k:{nomarkup:"order deny allow setenv rewriterule rewriteengine rewritecond documentroot sethandler errordocument loadmodule options header listen serverroot servername"},starts:{e:/$/,r:0,k:{literal:"on off all"},c:[{cN:"meta",b:"\\s\\[",e:"\\]$"},{cN:"variable",b:"[\\$%]\\{",e:"\\}",c:["self",t]},t,e.QSM]}}],i:/\S/}}),e.registerLanguage("bash",function(e){var t={cN:"variable",v:[{b:/\$[\w\d#@][\w\d_]*/},{b:/\$\{(.*?)}/}]},r={cN:"string",b:/"/,e:/"/,c:[e.BE,t,{cN:"variable",b:/\$\(/,e:/\)/,c:[e.BE]}]},a={cN:"string",b:/'/,e:/'/};return{aliases:["sh","zsh"],l:/\b-?[a-z\._]+\b/,k:{keyword:"if then else elif fi for while in do done case esac function",literal:"true false",built_in:"break cd continue eval exec exit export getopts hash pwd readonly return shift test times trap umask unset alias bind builtin caller command declare echo enable help let local logout mapfile printf read readarray source type typeset ulimit unalias set shopt autoload bg bindkey bye cap chdir clone comparguments compcall compctl compdescribe compfiles compgroups compquote comptags comptry compvalues dirs disable disown echotc echoti emulate fc fg float functions getcap getln history integer jobs kill limit log noglob popd print pushd pushln rehash sched setcap setopt stat suspend ttyctl unfunction unhash unlimit unsetopt vared wait whence where which zcompile zformat zftp zle zmodload zparseopts zprof zpty zregexparse zsocket zstyle ztcp",_:"-ne -eq -lt -gt -f -d -e -s -l -a"},c:[{cN:"meta",b:/^#![^\n]+sh\s*$/,r:10},{cN:"function",b:/\w[\w\d_]*\s*\(\s*\)\s*\{/,rB:!0,c:[e.inherit(e.TM,{b:/\w[\w\d_]*/})],r:0},e.HCM,r,a,t]}}),e.registerLanguage("coffeescript",function(e){var t={keyword:"in if for while finally new do return else break catch instanceof throw try this switch continue typeof delete debugger super yield import export from as default await then unless until loop of by when and or is isnt not",literal:"true false null undefined yes no on off",built_in:"npm require console print module global window document"},r="[A-Za-z$_][0-9A-Za-z$_]*",a={cN:"subst",b:/#\{/,e:/}/,k:t},n=[e.BNM,e.inherit(e.CNM,{starts:{e:"(\\s*/)?",r:0}}),{cN:"string",v:[{b:/'''/,e:/'''/,c:[e.BE]},{b:/'/,e:/'/,c:[e.BE]},{b:/"""/,e:/"""/,c:[e.BE,a]},{b:/"/,e:/"/,c:[e.BE,a]}]},{cN:"regexp",v:[{b:"///",e:"///",c:[a,e.HCM]},{b:"//[gim]*",r:0},{b:/\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/}]},{b:"@"+r},{sL:"javascript",eB:!0,eE:!0,v:[{b:"```",e:"```"},{b:"`",e:"`"}]}];a.c=n;var i=e.inherit(e.TM,{b:r}),s="(\\(.*\\))?\\s*\\B[-=]>",c={cN:"params",b:"\\([^\\(]",rB:!0,c:[{b:/\(/,e:/\)/,k:t,c:["self"].concat(n)}]};return{aliases:["coffee","cson","iced"],k:t,i:/\/\*/,c:n.concat([e.C("###","###"),e.HCM,{cN:"function",b:"^\\s*"+r+"\\s*=\\s*"+s,e:"[-=]>",rB:!0,c:[i,c]},{b:/[:\(,=]\s*/,r:0,c:[{cN:"function",b:s,e:"[-=]>",rB:!0,c:[c]}]},{cN:"class",bK:"class",e:"$",i:/[:="\[\]]/,c:[{bK:"extends",eW:!0,i:/[:="\[\]]/,c:[i]},i]},{b:r+":",e:":",rB:!0,rE:!0,r:0}])}}),e.registerLanguage("cpp",function(e){var t={cN:"keyword",b:"\\b[a-z\\d_]*_t\\b"},r={cN:"string",v:[{b:'(u8?|U)?L?"',e:'"',i:"\\n",c:[e.BE]},{b:'(u8?|U)?R"',e:'"',c:[e.BE]},{b:"'\\\\?.",e:"'",i:"."}]},a={cN:"number",v:[{b:"\\b(0b[01']+)"},{b:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{b:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],r:0},n={cN:"meta",b:/#\s*[a-z]+\b/,e:/$/,k:{"meta-keyword":"if else elif endif define undef warning error line pragma ifdef ifndef include"},c:[{b:/\\\n/,r:0},e.inherit(r,{cN:"meta-string"}),{cN:"meta-string",b:/<[^\n>]*>/,e:/$/,i:"\\n"},e.CLCM,e.CBCM]},i=e.IR+"\\s*\\(",s={keyword:"int float while private char catch import module export virtual operator sizeof dynamic_cast|10 typedef const_cast|10 const for static_cast|10 union namespace unsigned long volatile static protected bool template mutable if public friend do goto auto void enum else break extern using asm case typeid short reinterpret_cast|10 default double register explicit signed typename try this switch continue inline delete alignof constexpr decltype noexcept static_assert thread_local restrict _Bool complex _Complex _Imaginary atomic_bool atomic_char atomic_schar atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong atomic_ullong new throw return and or not",built_in:"std string cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap array shared_ptr abort abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr",literal:"true false nullptr NULL"},c=[t,e.CLCM,e.CBCM,a,r];return{aliases:["c","cc","h","c++","h++","hpp"],k:s,i:"</",c:c.concat([n,{b:"\\b(deque|list|queue|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<",e:">",k:s,c:["self",t]},{b:e.IR+"::",k:s},{v:[{b:/=/,e:/;/},{b:/\(/,e:/\)/},{bK:"new throw return else",e:/;/}],k:s,c:c.concat([{b:/\(/,e:/\)/,k:s,c:c.concat(["self"]),r:0}]),r:0},{cN:"function",b:"("+e.IR+"[\\*&\\s]+)+"+i,rB:!0,e:/[{;=]/,eE:!0,k:s,i:/[^\w\s\*&]/,c:[{b:i,rB:!0,c:[e.TM],r:0},{cN:"params",b:/\(/,e:/\)/,k:s,r:0,c:[e.CLCM,e.CBCM,r,a,t]},e.CLCM,e.CBCM,n]},{cN:"class",bK:"class struct",e:/[{;:]/,c:[{b:/</,e:/>/,c:["self"]},e.TM]}]),exports:{preprocessor:n,strings:r,k:s}}}),e.registerLanguage("cs",function(e){var t={keyword:"abstract as base bool break byte case catch char checked const continue decimal default delegate do double enum event explicit extern finally fixed float for foreach goto if implicit in int interface internal is lock long nameof object operator out override params private protected public readonly ref sbyte sealed short sizeof stackalloc static string struct switch this try typeof uint ulong unchecked unsafe ushort using virtual void volatile while add alias ascending async await by descending dynamic equals from get global group into join let on orderby partial remove select set value var where yield",literal:"null false true"},r={cN:"string",b:'@"',e:'"',c:[{b:'""'}]},a=e.inherit(r,{i:/\n/}),n={cN:"subst",b:"{",e:"}",k:t},i=e.inherit(n,{i:/\n/}),s={cN:"string",b:/\$"/,e:'"',i:/\n/,c:[{b:"{{"},{b:"}}"},e.BE,i]},c={cN:"string",b:/\$@"/,e:'"',c:[{b:"{{"},{b:"}}"},{b:'""'},n]},o=e.inherit(c,{i:/\n/,c:[{b:"{{"},{b:"}}"},{b:'""'},i]});n.c=[c,s,r,e.ASM,e.QSM,e.CNM,e.CBCM],i.c=[o,s,a,e.ASM,e.QSM,e.CNM,e.inherit(e.CBCM,{i:/\n/})];var l={v:[c,s,r,e.ASM,e.QSM]},u=e.IR+"(<"+e.IR+"(\\s*,\\s*"+e.IR+")*>)?(\\[\\])?";return{aliases:["csharp"],k:t,i:/::/,c:[e.C("///","$",{rB:!0,c:[{cN:"doctag",v:[{b:"///",r:0},{b:"<!--|-->"},{b:"</?",e:">"}]}]}),e.CLCM,e.CBCM,{cN:"meta",b:"#",e:"$",k:{"meta-keyword":"if else elif endif define undef warning error line region endregion pragma checksum"}},l,e.CNM,{bK:"class interface",e:/[{;=]/,i:/[^\s:]/,c:[e.TM,e.CLCM,e.CBCM]},{bK:"namespace",e:/[{;=]/,i:/[^\s:]/,c:[e.inherit(e.TM,{b:"[a-zA-Z](\\.?\\w)*"}),e.CLCM,e.CBCM]},{cN:"meta",b:"^\\s*\\[",eB:!0,e:"\\]",eE:!0,c:[{cN:"meta-string",b:/"/,e:/"/}]},{bK:"new return throw await else",r:0},{cN:"function",b:"("+u+"\\s+)+"+e.IR+"\\s*\\(",rB:!0,e:/[{;=]/,eE:!0,k:t,c:[{b:e.IR+"\\s*\\(",rB:!0,c:[e.TM],r:0},{cN:"params",b:/\(/,e:/\)/,eB:!0,eE:!0,k:t,r:0,c:[l,e.CNM,e.CBCM]},e.CLCM,e.CBCM]}]}}),e.registerLanguage("css",function(e){var t="[a-zA-Z-][a-zA-Z0-9_-]*",r={b:/[A-Z\_\.\-]+\s*:/,rB:!0,e:";",eW:!0,c:[{cN:"attribute",b:/\S/,e:":",eE:!0,starts:{eW:!0,eE:!0,c:[{b:/[\w-]+\(/,rB:!0,c:[{cN:"built_in",b:/[\w-]+/},{b:/\(/,e:/\)/,c:[e.ASM,e.QSM]}]},e.CSSNM,e.QSM,e.ASM,e.CBCM,{cN:"number",b:"#[0-9A-Fa-f]+"},{cN:"meta",b:"!important"}]}}]};return{cI:!0,i:/[=\/|'\$]/,c:[e.CBCM,{cN:"selector-id",b:/#[A-Za-z0-9_-]+/},{cN:"selector-class",b:/\.[A-Za-z0-9_-]+/},{cN:"selector-attr",b:/\[/,e:/\]/,i:"$"},{cN:"selector-pseudo",b:/:(:)?[a-zA-Z0-9\_\-\+\(\)"'.]+/},{b:"@(font-face|page)",l:"[a-z-]+",k:"font-face page"},{b:"@",e:"[{;]",i:/:/,c:[{cN:"keyword",b:/\w+/},{b:/\s/,eW:!0,eE:!0,r:0,c:[e.ASM,e.QSM,e.CSSNM]}]},{cN:"selector-tag",b:t,r:0},{b:"{",e:"}",i:/\S/,c:[e.CBCM,r]}]}}),e.registerLanguage("diff",function(e){return{aliases:["patch"],c:[{cN:"meta",r:10,v:[{b:/^@@ +\-\d+,\d+ +\+\d+,\d+ +@@$/},{b:/^\*\*\* +\d+,\d+ +\*\*\*\*$/},{b:/^\-\-\- +\d+,\d+ +\-\-\-\-$/}]},{cN:"comment",v:[{b:/Index: /,e:/$/},{b:/={3,}/,e:/$/},{b:/^\-{3}/,e:/$/},{b:/^\*{3} /,e:/$/},{b:/^\+{3}/,e:/$/},{b:/\*{5}/,e:/\*{5}$/}]},{cN:"addition",b:"^\\+",e:"$"},{cN:"deletion",b:"^\\-",e:"$"},{cN:"addition",b:"^\\!",e:"$"}]}}),e.registerLanguage("http",function(e){var t="HTTP/[0-9\\.]+";return{aliases:["https"],i:"\\S",c:[{b:"^"+t,e:"$",c:[{cN:"number",b:"\\b\\d{3}\\b"}]},{b:"^[A-Z]+ (.*?) "+t+"$",rB:!0,e:"$",c:[{cN:"string",b:" ",e:" ",eB:!0,eE:!0},{b:t},{cN:"keyword",b:"[A-Z]+"}]},{cN:"attribute",b:"^\\w",e:": ",eE:!0,i:"\\n|\\s|=",starts:{e:"$",r:0}},{b:"\\n\\n",starts:{sL:[],eW:!0}}]}}),e.registerLanguage("ini",function(e){var t={cN:"string",c:[e.BE],v:[{b:"'''",e:"'''",r:10},{b:'"""',e:'"""',r:10},{b:'"',e:'"'},{b:"'",e:"'"}]};return{aliases:["toml"],cI:!0,i:/\S/,c:[e.C(";","$"),e.HCM,{cN:"section",b:/^\s*\[+/,e:/\]+/},{b:/^[a-z0-9\[\]_-]+\s*=\s*/,e:"$",rB:!0,c:[{cN:"attr",b:/[a-z0-9\[\]_-]+/},{b:/=/,eW:!0,r:0,c:[{cN:"literal",b:/\bon|off|true|false|yes|no\b/},{cN:"variable",v:[{b:/\$[\w\d"][\w\d_]*/},{b:/\$\{(.*?)}/}]},t,{cN:"number",b:/([\+\-]+)?[\d]+_[\d_]+/},e.NM]}]}]}}),e.registerLanguage("java",function(e){var t="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",r=t+"(<"+t+"(\\s*,\\s*"+t+")*>)?",a="false synchronized int abstract float private char boolean static null if const for true while long strictfp finally protected import native final void enum else break transient catch instanceof byte super volatile case assert short package default double public try this switch continue throws protected public private module requires exports do",n="\\b(0[bB]([01]+[01_]+[01]+|[01]+)|0[xX]([a-fA-F0-9]+[a-fA-F0-9_]+[a-fA-F0-9]+|[a-fA-F0-9]+)|(([\\d]+[\\d_]+[\\d]+|[\\d]+)(\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))?|\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))([eE][-+]?\\d+)?)[lLfF]?",i={cN:"number",b:n,r:0};return{aliases:["jsp"],k:a,i:/<\/|#/,c:[e.C("/\\*\\*","\\*/",{r:0,c:[{b:/\w+@/,r:0},{cN:"doctag",b:"@[A-Za-z]+"}]}),e.CLCM,e.CBCM,e.ASM,e.QSM,{cN:"class",bK:"class interface",e:/[{;=]/,eE:!0,k:"class interface",i:/[:"\[\]]/,c:[{bK:"extends implements"},e.UTM]},{bK:"new throw return else",r:0},{cN:"function",b:"("+r+"\\s+)+"+e.UIR+"\\s*\\(",rB:!0,e:/[{;=]/,eE:!0,k:a,c:[{b:e.UIR+"\\s*\\(",rB:!0,r:0,c:[e.UTM]},{cN:"params",b:/\(/,e:/\)/,k:a,r:0,c:[e.ASM,e.QSM,e.CNM,e.CBCM]},e.CLCM,e.CBCM]},i,{cN:"meta",b:"@[A-Za-z]+"}]}}),e.registerLanguage("javascript",function(e){var t="[A-Za-z$_][0-9A-Za-z$_]*",r={keyword:"in of if for while finally var new function do return void else break catch instanceof with throw case default try this switch continue typeof delete let yield const export super debugger as async await static import from as",literal:"true false null undefined NaN Infinity",built_in:"eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent encodeURI encodeURIComponent escape unescape Object Function Boolean Error EvalError InternalError RangeError ReferenceError StopIteration SyntaxError TypeError URIError Number Math Date String RegExp Array Float32Array Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require module console window document Symbol Set Map WeakSet WeakMap Proxy Reflect Promise"},a={cN:"number",v:[{b:"\\b(0[bB][01]+)"},{b:"\\b(0[oO][0-7]+)"},{b:e.CNR}],r:0},n={cN:"subst",b:"\\$\\{",e:"\\}",k:r,c:[]},i={cN:"string",b:"`",e:"`",c:[e.BE,n]};n.c=[e.ASM,e.QSM,i,a,e.RM];var s=n.c.concat([e.CBCM,e.CLCM]);return{aliases:["js","jsx"],k:r,c:[{cN:"meta",r:10,b:/^\s*['"]use (strict|asm)['"]/},{cN:"meta",b:/^#!/,e:/$/},e.ASM,e.QSM,i,e.CLCM,e.CBCM,a,{b:/[{,]\s*/,r:0,c:[{b:t+"\\s*:",rB:!0,r:0,c:[{cN:"attr",b:t,r:0}]}]},{b:"("+e.RSR+"|\\b(case|return|throw)\\b)\\s*",k:"return throw case",c:[e.CLCM,e.CBCM,e.RM,{cN:"function",b:"(\\(.*?\\)|"+t+")\\s*=>",rB:!0,e:"\\s*=>",c:[{cN:"params",v:[{b:t},{b:/\(\s*\)/},{b:/\(/,e:/\)/,eB:!0,eE:!0,k:r,c:s}]}]},{b:/</,e:/(\/\w+|\w+\/)>/,sL:"xml",c:[{b:/<\w+\s*\/>/,skip:!0},{b:/<\w+/,e:/(\/\w+|\w+\/)>/,skip:!0,c:[{b:/<\w+\s*\/>/,skip:!0},"self"]}]}],r:0},{cN:"function",bK:"function",e:/\{/,eE:!0,c:[e.inherit(e.TM,{b:t}),{cN:"params",b:/\(/,e:/\)/,eB:!0,eE:!0,c:s}],i:/\[|%/},{b:/\$[(.]/},e.METHOD_GUARD,{cN:"class",bK:"class",e:/[{;=]/,eE:!0,i:/[:"\[\]]/,c:[{bK:"extends"},e.UTM]},{bK:"constructor",e:/\{/,eE:!0}],i:/#(?!!)/}}),e.registerLanguage("json",function(e){var t={literal:"true false null"},r=[e.QSM,e.CNM],a={e:",",eW:!0,eE:!0,c:r,k:t},n={b:"{",e:"}",c:[{cN:"attr",b:/"/,e:/"/,c:[e.BE],i:"\\n"},e.inherit(a,{b:/:/})],i:"\\S"},i={b:"\\[",e:"\\]",c:[e.inherit(a)],i:"\\S"};return r.splice(r.length,0,n,i),{c:r,k:t,i:"\\S"}}),e.registerLanguage("makefile",function(e){var t={cN:"variable",v:[{b:"\\$\\("+e.UIR+"\\)",c:[e.BE]},{b:/\$[@%<?\^\+\*]/}]},r={cN:"string",b:/"/,e:/"/,c:[e.BE,t]},a={cN:"variable",b:/\$\([\w-]+\s/,e:/\)/,k:{built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"},c:[t]},n={b:"^"+e.UIR+"\\s*[:+?]?=",i:"\\n",rB:!0,c:[{b:"^"+e.UIR,e:"[:+?]?=",eE:!0}]},i={cN:"meta",b:/^\.PHONY:/,e:/$/,k:{"meta-keyword":".PHONY"},l:/[\.\w]+/},s={cN:"section",b:/^[^\s]+:/,e:/$/,c:[t]};return{aliases:["mk","mak"],k:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath",l:/[\w-]+/,c:[e.HCM,t,r,a,n,i,s]}}),e.registerLanguage("xml",function(e){var t="[A-Za-z0-9\\._:-]+",r={eW:!0,i:/</,r:0,c:[{cN:"attr",b:t,r:0},{b:/=\s*/,r:0,c:[{cN:"string",endsParent:!0,v:[{b:/"/,e:/"/},{b:/'/,e:/'/},{b:/[^\s"'=<>`]+/}]}]}]};return{aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist"],cI:!0,c:[{cN:"meta",b:"<!DOCTYPE",e:">",r:10,c:[{b:"\\[",e:"\\]"}]},e.C("<!--","-->",{r:10}),{b:"<\\!\\[CDATA\\[",e:"\\]\\]>",r:10},{b:/<\?(php)?/,e:/\?>/,sL:"php",c:[{b:"/\\*",e:"\\*/",skip:!0}]},{cN:"tag",b:"<style(?=\\s|>|$)",e:">",k:{name:"style"},c:[r],starts:{e:"</style>",rE:!0,sL:["css","xml"]}},{cN:"tag",b:"<script(?=\\s|>|$)",e:">",k:{name:"script"},c:[r],starts:{e:"</script>",rE:!0,sL:["actionscript","javascript","handlebars","xml"]}},{cN:"meta",v:[{b:/<\?xml/,e:/\?>/,r:10},{b:/<\?\w+/,e:/\?>/}]},{cN:"tag",b:"</?",e:"/?>",c:[{cN:"name",b:/[^\/><\s]+/,r:0},r]}]}}),e.registerLanguage("markdown",function(e){return{aliases:["md","mkdown","mkd"],c:[{cN:"section",v:[{b:"^#{1,6}",e:"$"},{b:"^.+?\\n[=-]{2,}$"}]},{b:"<",e:">",sL:"xml",r:0},{cN:"bullet",b:"^([*+-]|(\\d+\\.))\\s+"},{cN:"strong",b:"[*_]{2}.+?[*_]{2}"},{cN:"emphasis",v:[{b:"\\*.+?\\*"},{b:"_.+?_",r:0}]},{cN:"quote",b:"^>\\s+",e:"$"},{cN:"code",v:[{b:"^```w*s*$",e:"^```s*$"},{b:"`.+?`"},{b:"^( {4}|	)",e:"$",r:0}]},{b:"^[-\\*]{3,}",e:"$"},{b:"\\[.+?\\][\\(\\[].*?[\\)\\]]",rB:!0,c:[{cN:"string",b:"\\[",e:"\\]",eB:!0,rE:!0,r:0},{cN:"link",b:"\\]\\(",e:"\\)",eB:!0,eE:!0},{cN:"symbol",b:"\\]\\[",e:"\\]",eB:!0,eE:!0}],r:10},{b:/^\[[^\n]+\]:/,rB:!0,c:[{cN:"symbol",b:/\[/,e:/\]/,eB:!0,eE:!0},{cN:"link",b:/:\s*/,e:/$/,eB:!0}]}]}}),e.registerLanguage("nginx",function(e){var t={cN:"variable",v:[{b:/\$\d+/},{b:/\$\{/,e:/}/},{b:"[\\$\\@]"+e.UIR}]},r={eW:!0,l:"[a-z/_]+",k:{literal:"on off yes no true false none blocked debug info notice warn error crit select break last permanent redirect kqueue rtsig epoll poll /dev/poll"},r:0,i:"=>",c:[e.HCM,{cN:"string",c:[e.BE,t],v:[{b:/"/,e:/"/},{b:/'/,e:/'/}]},{b:"([a-z]+):/",e:"\\s",eW:!0,eE:!0,c:[t]},{cN:"regexp",c:[e.BE,t],v:[{b:"\\s\\^",e:"\\s|{|;",rE:!0},{b:"~\\*?\\s+",e:"\\s|{|;",rE:!0},{b:"\\*(\\.[a-z\\-]+)+"},{b:"([a-z\\-]+\\.)+\\*"}]},{cN:"number",b:"\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b"},{cN:"number",b:"\\b\\d+[kKmMgGdshdwy]*\\b",r:0},t]};return{aliases:["nginxconf"],c:[e.HCM,{b:e.UIR+"\\s+{",rB:!0,e:"{",c:[{cN:"section",b:e.UIR}],r:0},{b:e.UIR+"\\s",e:";|{",rB:!0,c:[{cN:"attribute",b:e.UIR,starts:r}],r:0}],i:"[^\\s\\}]"}}),e.registerLanguage("objectivec",function(e){var t={cN:"built_in",b:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"},r={keyword:"int float while char export sizeof typedef const struct for union unsigned long volatile static bool mutable if do return goto void enum else break extern asm case short default double register explicit signed typename this switch continue wchar_t inline readonly assign readwrite self @synchronized id typeof nonatomic super unichar IBOutlet IBAction strong weak copy in out inout bycopy byref oneway __strong __weak __block __autoreleasing @private @protected @public @try @property @end @throw @catch @finally @autoreleasepool @synthesize @dynamic @selector @optional @required @encode @package @import @defs @compatibility_alias __bridge __bridge_transfer __bridge_retained __bridge_retain __covariant __contravariant __kindof _Nonnull _Nullable _Null_unspecified __FUNCTION__ __PRETTY_FUNCTION__ __attribute__ getter setter retain unsafe_unretained nonnull nullable null_unspecified null_resettable class instancetype NS_DESIGNATED_INITIALIZER NS_UNAVAILABLE NS_REQUIRES_SUPER NS_RETURNS_INNER_POINTER NS_INLINE NS_AVAILABLE NS_DEPRECATED NS_ENUM NS_OPTIONS NS_SWIFT_UNAVAILABLE NS_ASSUME_NONNULL_BEGIN NS_ASSUME_NONNULL_END NS_REFINED_FOR_SWIFT NS_SWIFT_NAME NS_SWIFT_NOTHROW NS_DURING NS_HANDLER NS_ENDHANDLER NS_VALUERETURN NS_VOIDRETURN",literal:"false true FALSE TRUE nil YES NO NULL",built_in:"BOOL dispatch_once_t dispatch_queue_t dispatch_sync dispatch_async dispatch_once"},a=/[a-zA-Z@][a-zA-Z0-9_]*/,n="@interface @class @protocol @implementation";return{aliases:["mm","objc","obj-c"],k:r,l:a,i:"</",c:[t,e.CLCM,e.CBCM,e.CNM,e.QSM,{cN:"string",v:[{b:'@"',e:'"',i:"\\n",c:[e.BE]},{b:"'",e:"[^\\\\]'",i:"[^\\\\][^']"}]},{cN:"meta",b:"#",e:"$",c:[{cN:"meta-string",v:[{b:'"',e:'"'},{b:"<",e:">"}]}]},{cN:"class",b:"("+n.split(" ").join("|")+")\\b",e:"({|$)",eE:!0,k:n,l:a,c:[e.UTM]},{b:"\\."+e.UIR,r:0}]}}),e.registerLanguage("perl",function(e){var t="getpwent getservent quotemeta msgrcv scalar kill dbmclose undef lc ma syswrite tr send umask sysopen shmwrite vec qx utime local oct semctl localtime readpipe do return format read sprintf dbmopen pop getpgrp not getpwnam rewinddir qqfileno qw endprotoent wait sethostent bless s|0 opendir continue each sleep endgrent shutdown dump chomp connect getsockname die socketpair close flock exists index shmgetsub for endpwent redo lstat msgctl setpgrp abs exit select print ref gethostbyaddr unshift fcntl syscall goto getnetbyaddr join gmtime symlink semget splice x|0 getpeername recv log setsockopt cos last reverse gethostbyname getgrnam study formline endhostent times chop length gethostent getnetent pack getprotoent getservbyname rand mkdir pos chmod y|0 substr endnetent printf next open msgsnd readdir use unlink getsockopt getpriority rindex wantarray hex system getservbyport endservent int chr untie rmdir prototype tell listen fork shmread ucfirst setprotoent else sysseek link getgrgid shmctl waitpid unpack getnetbyname reset chdir grep split require caller lcfirst until warn while values shift telldir getpwuid my getprotobynumber delete and sort uc defined srand accept package seekdir getprotobyname semop our rename seek if q|0 chroot sysread setpwent no crypt getc chown sqrt write setnetent setpriority foreach tie sin msgget map stat getlogin unless elsif truncate exec keys glob tied closedirioctl socket readlink eval xor readline binmode setservent eof ord bind alarm pipe atan2 getgrent exp time push setgrent gt lt or ne m|0 break given say state when",r={cN:"subst",b:"[$@]\\{",e:"\\}",k:t},a={b:"->{",e:"}"},n={v:[{b:/\$\d/},{b:/[\$%@](\^\w\b|#\w+(::\w+)*|{\w+}|\w+(::\w*)*)/},{b:/[\$%@][^\s\w{]/,r:0}]},i=[e.BE,r,n],s=[n,e.HCM,e.C("^\\=\\w","\\=cut",{eW:!0}),a,{cN:"string",c:i,v:[{b:"q[qwxr]?\\s*\\(",e:"\\)",r:5},{b:"q[qwxr]?\\s*\\[",e:"\\]",r:5},{b:"q[qwxr]?\\s*\\{",e:"\\}",r:5},{b:"q[qwxr]?\\s*\\|",e:"\\|",r:5},{b:"q[qwxr]?\\s*\\<",e:"\\>",r:5},{b:"qw\\s+q",e:"q",r:5},{b:"'",e:"'",c:[e.BE]},{b:'"',e:'"'},{b:"`",e:"`",c:[e.BE]},{b:"{\\w+}",c:[],r:0},{b:"-?\\w+\\s*\\=\\>",c:[],r:0}]},{cN:"number",b:"(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",r:0},{b:"(\\/\\/|"+e.RSR+"|\\b(split|return|print|reverse|grep)\\b)\\s*",k:"split return print reverse grep",r:0,c:[e.HCM,{cN:"regexp",b:"(s|tr|y)/(\\\\.|[^/])*/(\\\\.|[^/])*/[a-z]*",r:10},{cN:"regexp",b:"(m|qr)?/",e:"/[a-z]*",c:[e.BE],r:0}]},{cN:"function",bK:"sub",e:"(\\s*\\(.*?\\))?[;{]",eE:!0,r:5,c:[e.TM]},{b:"-\\w\\b",r:0},{b:"^__DATA__$",e:"^__END__$",sL:"mojolicious",c:[{b:"^@@.*",e:"$",cN:"comment"}]}];return r.c=s,a.c=s,{aliases:["pl","pm"],l:/[\w\.]+/,k:t,c:s}}),e.registerLanguage("php",function(e){var t={b:"\\$+[a-zA-Z_-ÿ][a-zA-Z0-9_-ÿ]*"},r={cN:"meta",b:/<\?(php)?|\?>/},a={cN:"string",c:[e.BE,r],v:[{b:'b"',e:'"'},{b:"b'",e:"'"},e.inherit(e.ASM,{i:null}),e.inherit(e.QSM,{i:null})]},n={v:[e.BNM,e.CNM]};return{aliases:["php3","php4","php5","php6"],cI:!0,k:"and include_once list abstract global private echo interface as static endswitch array null if endwhile or const for endforeach self var while isset public protected exit foreach throw elseif include __FILE__ empty require_once do xor return parent clone use __CLASS__ __LINE__ else break print eval new catch __METHOD__ case exception default die require __FUNCTION__ enddeclare final try switch continue endfor endif declare unset true false trait goto instanceof insteadof __DIR__ __NAMESPACE__ yield finally",c:[e.HCM,e.C("//","$",{c:[r]}),e.C("/\\*","\\*/",{c:[{cN:"doctag",b:"@[A-Za-z]+"}]}),e.C("__halt_compiler.+?;",!1,{eW:!0,k:"__halt_compiler",l:e.UIR}),{cN:"string",b:/<<<['"]?\w+['"]?$/,e:/^\w+;?$/,c:[e.BE,{cN:"subst",v:[{b:/\$\w+/},{b:/\{\$/,e:/\}/}]}]},r,{cN:"keyword",b:/\$this\b/},t,{b:/(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/},{cN:"function",bK:"function",e:/[;{]/,eE:!0,i:"\\$|\\[|%",c:[e.UTM,{cN:"params",b:"\\(",e:"\\)",c:["self",t,e.CBCM,a,n]}]},{cN:"class",bK:"class interface",e:"{",eE:!0,i:/[:\(\$"]/,c:[{bK:"extends implements"},e.UTM]},{bK:"namespace",e:";",i:/[\.']/,c:[e.UTM]},{bK:"use",e:";",c:[e.UTM]},{b:"=>"},a,n]}}),e.registerLanguage("python",function(e){var t={keyword:"and elif is global as in if from raise for except finally print import pass return exec else break not with class assert yield try while continue del or def lambda async await nonlocal|10 None True False",built_in:"Ellipsis NotImplemented"},r={cN:"meta",b:/^(>>>|\.\.\.) /},a={cN:"subst",b:/\{/,e:/\}/,k:t,i:/#/},n={cN:"string",c:[e.BE],v:[{b:/(u|b)?r?'''/,e:/'''/,c:[r],r:10},{b:/(u|b)?r?"""/,e:/"""/,c:[r],r:10},{b:/(fr|rf|f)'''/,e:/'''/,c:[r,a]},{b:/(fr|rf|f)"""/,e:/"""/,c:[r,a]},{b:/(u|r|ur)'/,e:/'/,r:10},{b:/(u|r|ur)"/,e:/"/,r:10},{b:/(b|br)'/,e:/'/},{b:/(b|br)"/,e:/"/},{b:/(fr|rf|f)'/,e:/'/,c:[a]},{b:/(fr|rf|f)"/,e:/"/,c:[a]},e.ASM,e.QSM]},i={cN:"number",r:0,v:[{b:e.BNR+"[lLjJ]?"},{b:"\\b(0o[0-7]+)[lLjJ]?"},{b:e.CNR+"[lLjJ]?"}]},s={cN:"params",b:/\(/,e:/\)/,c:["self",r,i,n]};return a.c=[n,i,r],{aliases:["py","gyp"],k:t,i:/(<\/|->|\?)|=>/,c:[r,i,n,e.HCM,{v:[{cN:"function",bK:"def"},{cN:"class",bK:"class"}],e:/:/,i:/[${=;\n,]/,c:[e.UTM,s,{b:/->/,eW:!0,k:"None"}]},{cN:"meta",b:/^[\t ]*@/,e:/$/},{b:/\b(print|exec)\(/}]}}),e.registerLanguage("ruby",function(e){
var t="[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?",r={keyword:"and then defined module in return redo if BEGIN retry end for self when next until do begin unless END rescue else break undef not super class case require yield alias while ensure elsif or include attr_reader attr_writer attr_accessor",literal:"true false nil"},a={cN:"doctag",b:"@[A-Za-z]+"},n={b:"#<",e:">"},i=[e.C("#","$",{c:[a]}),e.C("^\\=begin","^\\=end",{c:[a],r:10}),e.C("^__END__","\\n$")],s={cN:"subst",b:"#\\{",e:"}",k:r},c={cN:"string",c:[e.BE,s],v:[{b:/'/,e:/'/},{b:/"/,e:/"/},{b:/`/,e:/`/},{b:"%[qQwWx]?\\(",e:"\\)"},{b:"%[qQwWx]?\\[",e:"\\]"},{b:"%[qQwWx]?{",e:"}"},{b:"%[qQwWx]?<",e:">"},{b:"%[qQwWx]?/",e:"/"},{b:"%[qQwWx]?%",e:"%"},{b:"%[qQwWx]?-",e:"-"},{b:"%[qQwWx]?\\|",e:"\\|"},{b:/\B\?(\\\d{1,3}|\\x[A-Fa-f0-9]{1,2}|\\u[A-Fa-f0-9]{4}|\\?\S)\b/},{b:/<<(-?)\w+$/,e:/^\s*\w+$/}]},o={cN:"params",b:"\\(",e:"\\)",endsParent:!0,k:r},l=[c,n,{cN:"class",bK:"class module",e:"$|;",i:/=/,c:[e.inherit(e.TM,{b:"[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?"}),{b:"<\\s*",c:[{b:"("+e.IR+"::)?"+e.IR}]}].concat(i)},{cN:"function",bK:"def",e:"$|;",c:[e.inherit(e.TM,{b:t}),o].concat(i)},{b:e.IR+"::"},{cN:"symbol",b:e.UIR+"(\\!|\\?)?:",r:0},{cN:"symbol",b:":(?!\\s)",c:[c,{b:t}],r:0},{cN:"number",b:"(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",r:0},{b:"(\\$\\W)|((\\$|\\@\\@?)(\\w+))"},{cN:"params",b:/\|/,e:/\|/,k:r},{b:"("+e.RSR+"|unless)\\s*",k:"unless",c:[n,{cN:"regexp",c:[e.BE,s],i:/\n/,v:[{b:"/",e:"/[a-z]*"},{b:"%r{",e:"}[a-z]*"},{b:"%r\\(",e:"\\)[a-z]*"},{b:"%r!",e:"![a-z]*"},{b:"%r\\[",e:"\\][a-z]*"}]}].concat(i),r:0}].concat(i);s.c=l,o.c=l;var u="[>?]>",d="[\\w#]+\\(\\w+\\):\\d+:\\d+>",b="(\\w+-)?\\d+\\.\\d+\\.\\d(p\\d+)?[^>]+>",p=[{b:/^\s*=>/,starts:{e:"$",c:l}},{cN:"meta",b:"^("+u+"|"+d+"|"+b+")",starts:{e:"$",c:l}}];return{aliases:["rb","gemspec","podspec","thor","irb"],k:r,i:/\/\*/,c:i.concat(p).concat(l)}}),e.registerLanguage("shell",function(e){return{aliases:["console"],c:[{cN:"meta",b:"^\\s{0,3}[\\w\\d\\[\\]()@-]*[>%$#]",starts:{e:"$",sL:"bash"}}]}}),e.registerLanguage("sql",function(e){var t=e.C("--","$");return{cI:!0,i:/[<>{}*#]/,c:[{bK:"begin end start commit rollback savepoint lock alter create drop rename call delete do handler insert load replace select truncate update set show pragma grant merge describe use explain help declare prepare execute deallocate release unlock purge reset change stop analyze cache flush optimize repair kill install uninstall checksum restore check backup revoke comment",e:/;/,eW:!0,l:/[\w\.]+/,k:{keyword:"abort abs absolute acc acce accep accept access accessed accessible account acos action activate add addtime admin administer advanced advise aes_decrypt aes_encrypt after agent aggregate ali alia alias allocate allow alter always analyze ancillary and any anydata anydataset anyschema anytype apply archive archived archivelog are as asc ascii asin assembly assertion associate asynchronous at atan atn2 attr attri attrib attribu attribut attribute attributes audit authenticated authentication authid authors auto autoallocate autodblink autoextend automatic availability avg backup badfile basicfile before begin beginning benchmark between bfile bfile_base big bigfile bin binary_double binary_float binlog bit_and bit_count bit_length bit_or bit_xor bitmap blob_base block blocksize body both bound buffer_cache buffer_pool build bulk by byte byteordermark bytes cache caching call calling cancel capacity cascade cascaded case cast catalog category ceil ceiling chain change changed char_base char_length character_length characters characterset charindex charset charsetform charsetid check checksum checksum_agg child choose chr chunk class cleanup clear client clob clob_base clone close cluster_id cluster_probability cluster_set clustering coalesce coercibility col collate collation collect colu colum column column_value columns columns_updated comment commit compact compatibility compiled complete composite_limit compound compress compute concat concat_ws concurrent confirm conn connec connect connect_by_iscycle connect_by_isleaf connect_by_root connect_time connection consider consistent constant constraint constraints constructor container content contents context contributors controlfile conv convert convert_tz corr corr_k corr_s corresponding corruption cos cost count count_big counted covar_pop covar_samp cpu_per_call cpu_per_session crc32 create creation critical cross cube cume_dist curdate current current_date current_time current_timestamp current_user cursor curtime customdatum cycle data database databases datafile datafiles datalength date_add date_cache date_format date_sub dateadd datediff datefromparts datename datepart datetime2fromparts day day_to_second dayname dayofmonth dayofweek dayofyear days db_role_change dbtimezone ddl deallocate declare decode decompose decrement decrypt deduplicate def defa defau defaul default defaults deferred defi defin define degrees delayed delegate delete delete_all delimited demand dense_rank depth dequeue des_decrypt des_encrypt des_key_file desc descr descri describ describe descriptor deterministic diagnostics difference dimension direct_load directory disable disable_all disallow disassociate discardfile disconnect diskgroup distinct distinctrow distribute distributed div do document domain dotnet double downgrade drop dumpfile duplicate duration each edition editionable editions element ellipsis else elsif elt empty enable enable_all enclosed encode encoding encrypt end end-exec endian enforced engine engines enqueue enterprise entityescaping eomonth error errors escaped evalname evaluate event eventdata events except exception exceptions exchange exclude excluding execu execut execute exempt exists exit exp expire explain export export_set extended extent external external_1 external_2 externally extract failed failed_login_attempts failover failure far fast feature_set feature_value fetch field fields file file_name_convert filesystem_like_logging final finish first first_value fixed flash_cache flashback floor flush following follows for forall force form forma format found found_rows freelist freelists freepools fresh from from_base64 from_days ftp full function general generated get get_format get_lock getdate getutcdate global global_name globally go goto grant grants greatest group group_concat group_id grouping grouping_id groups gtid_subtract guarantee guard handler hash hashkeys having hea head headi headin heading heap help hex hierarchy high high_priority hosts hour http id ident_current ident_incr ident_seed identified identity idle_time if ifnull ignore iif ilike ilm immediate import in include including increment index indexes indexing indextype indicator indices inet6_aton inet6_ntoa inet_aton inet_ntoa infile initial initialized initially initrans inmemory inner innodb input insert install instance instantiable instr interface interleaved intersect into invalidate invisible is is_free_lock is_ipv4 is_ipv4_compat is_not is_not_null is_used_lock isdate isnull isolation iterate java join json json_exists keep keep_duplicates key keys kill language large last last_day last_insert_id last_value lax lcase lead leading least leaves left len lenght length less level levels library like like2 like4 likec limit lines link list listagg little ln load load_file lob lobs local localtime localtimestamp locate locator lock locked log log10 log2 logfile logfiles logging logical logical_reads_per_call logoff logon logs long loop low low_priority lower lpad lrtrim ltrim main make_set makedate maketime managed management manual map mapping mask master master_pos_wait match matched materialized max maxextents maximize maxinstances maxlen maxlogfiles maxloghistory maxlogmembers maxsize maxtrans md5 measures median medium member memcompress memory merge microsecond mid migration min minextents minimum mining minus minute minvalue missing mod mode model modification modify module monitoring month months mount move movement multiset mutex name name_const names nan national native natural nav nchar nclob nested never new newline next nextval no no_write_to_binlog noarchivelog noaudit nobadfile nocheck nocompress nocopy nocycle nodelay nodiscardfile noentityescaping noguarantee nokeep nologfile nomapping nomaxvalue nominimize nominvalue nomonitoring none noneditionable nonschema noorder nopr nopro noprom nopromp noprompt norely noresetlogs noreverse normal norowdependencies noschemacheck noswitch not nothing notice notrim novalidate now nowait nth_value nullif nulls num numb numbe nvarchar nvarchar2 object ocicoll ocidate ocidatetime ociduration ociinterval ociloblocator ocinumber ociref ocirefcursor ocirowid ocistring ocitype oct octet_length of off offline offset oid oidindex old on online only opaque open operations operator optimal optimize option optionally or oracle oracle_date oradata ord ordaudio orddicom orddoc order ordimage ordinality ordvideo organization orlany orlvary out outer outfile outline output over overflow overriding package pad parallel parallel_enable parameters parent parse partial partition partitions pascal passing password password_grace_time password_lock_time password_reuse_max password_reuse_time password_verify_function patch path patindex pctincrease pctthreshold pctused pctversion percent percent_rank percentile_cont percentile_disc performance period period_add period_diff permanent physical pi pipe pipelined pivot pluggable plugin policy position post_transaction pow power pragma prebuilt precedes preceding precision prediction prediction_cost prediction_details prediction_probability prediction_set prepare present preserve prior priority private private_sga privileges procedural procedure procedure_analyze processlist profiles project prompt protection public publishingservername purge quarter query quick quiesce quota quotename radians raise rand range rank raw read reads readsize rebuild record records recover recovery recursive recycle redo reduced ref reference referenced references referencing refresh regexp_like register regr_avgx regr_avgy regr_count regr_intercept regr_r2 regr_slope regr_sxx regr_sxy reject rekey relational relative relaylog release release_lock relies_on relocate rely rem remainder rename repair repeat replace replicate replication required reset resetlogs resize resource respect restore restricted result result_cache resumable resume retention return returning returns reuse reverse revoke right rlike role roles rollback rolling rollup round row row_count rowdependencies rowid rownum rows rtrim rules safe salt sample save savepoint sb1 sb2 sb4 scan schema schemacheck scn scope scroll sdo_georaster sdo_topo_geometry search sec_to_time second section securefile security seed segment select self sequence sequential serializable server servererror session session_user sessions_per_user set sets settings sha sha1 sha2 share shared shared_pool short show shrink shutdown si_averagecolor si_colorhistogram si_featurelist si_positionalcolor si_stillimage si_texture siblings sid sign sin size size_t sizes skip slave sleep smalldatetimefromparts smallfile snapshot some soname sort soundex source space sparse spfile split sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows sql_small_result sql_variant_property sqlcode sqldata sqlerror sqlname sqlstate sqrt square standalone standby start starting startup statement static statistics stats_binomial_test stats_crosstab stats_ks_test stats_mode stats_mw_test stats_one_way_anova stats_t_test_ stats_t_test_indep stats_t_test_one stats_t_test_paired stats_wsr_test status std stddev stddev_pop stddev_samp stdev stop storage store stored str str_to_date straight_join strcmp strict string struct stuff style subdate subpartition subpartitions substitutable substr substring subtime subtring_index subtype success sum suspend switch switchoffset switchover sync synchronous synonym sys sys_xmlagg sysasm sysaux sysdate sysdatetimeoffset sysdba sysoper system system_user sysutcdatetime table tables tablespace tan tdo template temporary terminated tertiary_weights test than then thread through tier ties time time_format time_zone timediff timefromparts timeout timestamp timestampadd timestampdiff timezone_abbr timezone_minute timezone_region to to_base64 to_date to_days to_seconds todatetimeoffset trace tracking transaction transactional translate translation treat trigger trigger_nestlevel triggers trim truncate try_cast try_convert try_parse type ub1 ub2 ub4 ucase unarchived unbounded uncompress under undo unhex unicode uniform uninstall union unique unix_timestamp unknown unlimited unlock unpivot unrecoverable unsafe unsigned until untrusted unusable unused update updated upgrade upped upper upsert url urowid usable usage use use_stored_outlines user user_data user_resources users using utc_date utc_timestamp uuid uuid_short validate validate_password_strength validation valist value values var var_samp varcharc vari varia variab variabl variable variables variance varp varraw varrawc varray verify version versions view virtual visible void wait wallet warning warnings week weekday weekofyear wellformed when whene whenev wheneve whenever where while whitespace with within without work wrapped xdb xml xmlagg xmlattributes xmlcast xmlcolattval xmlelement xmlexists xmlforest xmlindex xmlnamespaces xmlpi xmlquery xmlroot xmlschema xmlserialize xmltable xmltype xor year year_to_month years yearweek",literal:"true false null",built_in:"array bigint binary bit blob boolean char character date dec decimal float int int8 integer interval number numeric real record serial serial8 smallint text varchar varying void"},c:[{cN:"string",b:"'",e:"'",c:[e.BE,{b:"''"}]},{cN:"string",b:'"',e:'"',c:[e.BE,{b:'""'}]},{cN:"string",b:"`",e:"`",c:[e.BE]},e.CNM,e.CBCM,t]},e.CBCM,t]}}),e});
/*!
 * Fuse.js v3.1.0 - Lightweight fuzzy-search (http://fusejs.io)
 *
 * Copyright (c) 2012-2017 Kirollos Risk (http://kiro.me)
 * All Rights Reserved. Apache Software License 2.0
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 */
(function webpackUniversalModuleDefinition(root, factory) {
    if(typeof exports === 'object' && typeof module === 'object')
        module.exports = factory();
    else if(typeof define === 'function' && define.amd)
        define("Fuse", [], factory);
    else if(typeof exports === 'object')
        exports["Fuse"] = factory();
    else
        root["Fuse"] = factory();
})(this, function() {
    return /******/ (function(modules) { // webpackBootstrap
        /******/ 	// The module cache
        /******/ 	var installedModules = {};
        /******/
        /******/ 	// The require function
        /******/ 	function __webpack_require__(moduleId) {
            /******/
            /******/ 		// Check if module is in cache
            /******/ 		if(installedModules[moduleId]) {
                /******/ 			return installedModules[moduleId].exports;
                /******/ 		}
            /******/ 		// Create a new module (and put it into the cache)
            /******/ 		var module = installedModules[moduleId] = {
                /******/ 			i: moduleId,
                /******/ 			l: false,
                /******/ 			exports: {}
                /******/ 		};
            /******/
            /******/ 		// Execute the module function
            /******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
            /******/
            /******/ 		// Flag the module as loaded
            /******/ 		module.l = true;
            /******/
            /******/ 		// Return the exports of the module
            /******/ 		return module.exports;
            /******/ 	}
        /******/
        /******/
        /******/ 	// expose the modules object (__webpack_modules__)
        /******/ 	__webpack_require__.m = modules;
        /******/
        /******/ 	// expose the module cache
        /******/ 	__webpack_require__.c = installedModules;
        /******/
        /******/ 	// identity function for calling harmony imports with the correct context
        /******/ 	__webpack_require__.i = function(value) { return value; };
        /******/
        /******/ 	// define getter function for harmony exports
        /******/ 	__webpack_require__.d = function(exports, name, getter) {
            /******/ 		if(!__webpack_require__.o(exports, name)) {
                /******/ 			Object.defineProperty(exports, name, {
                    /******/ 				configurable: false,
                    /******/ 				enumerable: true,
                    /******/ 				get: getter
                    /******/ 			});
                /******/ 		}
            /******/ 	};
        /******/
        /******/ 	// getDefaultExport function for compatibility with non-harmony modules
        /******/ 	__webpack_require__.n = function(module) {
            /******/ 		var getter = module && module.__esModule ?
                /******/ 			function getDefault() { return module['default']; } :
                /******/ 			function getModuleExports() { return module; };
            /******/ 		__webpack_require__.d(getter, 'a', getter);
            /******/ 		return getter;
            /******/ 	};
        /******/
        /******/ 	// Object.prototype.hasOwnProperty.call
        /******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
        /******/
        /******/ 	// __webpack_public_path__
        /******/ 	__webpack_require__.p = "";
        /******/
        /******/ 	// Load entry module and return exports
        /******/ 	return __webpack_require__(__webpack_require__.s = 8);
        /******/ })
    /************************************************************************/
    /******/ ([
        /* 0 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (obj) {
                return Object.prototype.toString.call(obj) === '[object Array]';
            };

            /***/ }),
        /* 1 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

            function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

            var bitapRegexSearch = __webpack_require__(5);
            var bitapSearch = __webpack_require__(7);
            var patternAlphabet = __webpack_require__(4);

            var Bitap = function () {
                function Bitap(pattern, _ref) {
                    var _ref$location = _ref.location,
                        location = _ref$location === undefined ? 0 : _ref$location,
                        _ref$distance = _ref.distance,
                        distance = _ref$distance === undefined ? 100 : _ref$distance,
                        _ref$threshold = _ref.threshold,
                        threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                        _ref$maxPatternLength = _ref.maxPatternLength,
                        maxPatternLength = _ref$maxPatternLength === undefined ? 32 : _ref$maxPatternLength,
                        _ref$isCaseSensitive = _ref.isCaseSensitive,
                        isCaseSensitive = _ref$isCaseSensitive === undefined ? false : _ref$isCaseSensitive,
                        _ref$tokenSeparator = _ref.tokenSeparator,
                        tokenSeparator = _ref$tokenSeparator === undefined ? / +/g : _ref$tokenSeparator,
                        _ref$findAllMatches = _ref.findAllMatches,
                        findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                        _ref$minMatchCharLeng = _ref.minMatchCharLength,
                        minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng;

                    _classCallCheck(this, Bitap);

                    this.options = {
                        location: location,
                        distance: distance,
                        threshold: threshold,
                        maxPatternLength: maxPatternLength,
                        isCaseSensitive: isCaseSensitive,
                        tokenSeparator: tokenSeparator,
                        findAllMatches: findAllMatches,
                        minMatchCharLength: minMatchCharLength
                    };

                    this.pattern = this.options.isCaseSensitive ? pattern : pattern.toLowerCase();

                    if (this.pattern.length <= maxPatternLength) {
                        this.patternAlphabet = patternAlphabet(this.pattern);
                    }
                }

                _createClass(Bitap, [{
                    key: 'search',
                    value: function search(text) {
                        if (!this.options.isCaseSensitive) {
                            text = text.toLowerCase();
                        }

                        // Exact match
                        if (this.pattern === text) {
                            return {
                                isMatch: true,
                                score: 0,
                                matchedIndices: [[0, text.length - 1]]
                            };
                        }

                        // When pattern length is greater than the machine word length, just do a a regex comparison
                        var _options = this.options,
                            maxPatternLength = _options.maxPatternLength,
                            tokenSeparator = _options.tokenSeparator;

                        if (this.pattern.length > maxPatternLength) {
                            return bitapRegexSearch(text, this.pattern, tokenSeparator);
                        }

                        // Otherwise, use Bitap algorithm
                        var _options2 = this.options,
                            location = _options2.location,
                            distance = _options2.distance,
                            threshold = _options2.threshold,
                            findAllMatches = _options2.findAllMatches,
                            minMatchCharLength = _options2.minMatchCharLength;

                        return bitapSearch(text, this.pattern, this.patternAlphabet, {
                            location: location,
                            distance: distance,
                            threshold: threshold,
                            findAllMatches: findAllMatches,
                            minMatchCharLength: minMatchCharLength
                        });
                    }
                }]);

                return Bitap;
            }();

// let x = new Bitap("od mn war", {})
// let result = x.search("Old Man's War")
// console.log(result)

            module.exports = Bitap;

            /***/ }),
        /* 2 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var isArray = __webpack_require__(0);

            var deepValue = function deepValue(obj, path, list) {
                if (!path) {
                    // If there's no path left, we've gotten to the object we care about.
                    list.push(obj);
                } else {
                    var dotIndex = path.indexOf('.');
                    var firstSegment = path;
                    var remaining = null;

                    if (dotIndex !== -1) {
                        firstSegment = path.slice(0, dotIndex);
                        remaining = path.slice(dotIndex + 1);
                    }

                    var value = obj[firstSegment];

                    if (value !== null && value !== undefined) {
                        if (!remaining && (typeof value === 'string' || typeof value === 'number')) {
                            list.push(value.toString());
                        } else if (isArray(value)) {
                            // Search each item in the array.
                            for (var i = 0, len = value.length; i < len; i += 1) {
                                deepValue(value[i], remaining, list);
                            }
                        } else if (remaining) {
                            // An object. Recurse further.
                            deepValue(value, remaining, list);
                        }
                    }
                }

                return list;
            };

            module.exports = function (obj, path) {
                return deepValue(obj, path, []);
            };

            /***/ }),
        /* 3 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function () {
                var matchmask = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
                var minMatchCharLength = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;

                var matchedIndices = [];
                var start = -1;
                var end = -1;
                var i = 0;

                for (var len = matchmask.length; i < len; i += 1) {
                    var match = matchmask[i];
                    if (match && start === -1) {
                        start = i;
                    } else if (!match && start !== -1) {
                        end = i - 1;
                        if (end - start + 1 >= minMatchCharLength) {
                            matchedIndices.push([start, end]);
                        }
                        start = -1;
                    }
                }

                // (i-1 - start) + 1 => i - start
                if (matchmask[i - 1] && i - start >= minMatchCharLength) {
                    matchedIndices.push([start, i - 1]);
                }

                return matchedIndices;
            };

            /***/ }),
        /* 4 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (pattern) {
                var mask = {};
                var len = pattern.length;

                for (var i = 0; i < len; i += 1) {
                    mask[pattern.charAt(i)] = 0;
                }

                for (var _i = 0; _i < len; _i += 1) {
                    mask[pattern.charAt(_i)] |= 1 << len - _i - 1;
                }

                return mask;
            };

            /***/ }),
        /* 5 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var SPECIAL_CHARS_REGEX = /[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g;

            module.exports = function (text, pattern) {
                var tokenSeparator = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : / +/g;

                var regex = new RegExp(pattern.replace(SPECIAL_CHARS_REGEX, '\\$&').replace(tokenSeparator, '|'));
                var matches = text.match(regex);
                var isMatch = !!matches;
                var matchedIndices = [];

                if (isMatch) {
                    for (var i = 0, matchesLen = matches.length; i < matchesLen; i += 1) {
                        var match = matches[i];
                        matchedIndices.push([text.indexOf(match), match.length - 1]);
                    }
                }

                return {
                    // TODO: revisit this score
                    score: isMatch ? 0.5 : 1,
                    isMatch: isMatch,
                    matchedIndices: matchedIndices
                };
            };

            /***/ }),
        /* 6 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (pattern, _ref) {
                var _ref$errors = _ref.errors,
                    errors = _ref$errors === undefined ? 0 : _ref$errors,
                    _ref$currentLocation = _ref.currentLocation,
                    currentLocation = _ref$currentLocation === undefined ? 0 : _ref$currentLocation,
                    _ref$expectedLocation = _ref.expectedLocation,
                    expectedLocation = _ref$expectedLocation === undefined ? 0 : _ref$expectedLocation,
                    _ref$distance = _ref.distance,
                    distance = _ref$distance === undefined ? 100 : _ref$distance;

                var accuracy = errors / pattern.length;
                var proximity = Math.abs(expectedLocation - currentLocation);

                if (!distance) {
                    // Dodge divide by zero error.
                    return proximity ? 1.0 : accuracy;
                }

                return accuracy + proximity / distance;
            };

            /***/ }),
        /* 7 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var bitapScore = __webpack_require__(6);
            var matchedIndices = __webpack_require__(3);

            module.exports = function (text, pattern, patternAlphabet, _ref) {
                var _ref$location = _ref.location,
                    location = _ref$location === undefined ? 0 : _ref$location,
                    _ref$distance = _ref.distance,
                    distance = _ref$distance === undefined ? 100 : _ref$distance,
                    _ref$threshold = _ref.threshold,
                    threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                    _ref$findAllMatches = _ref.findAllMatches,
                    findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                    _ref$minMatchCharLeng = _ref.minMatchCharLength,
                    minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng;

                var expectedLocation = location;
                // Set starting location at beginning text and initialize the alphabet.
                var textLen = text.length;
                // Highest score beyond which we give up.
                var currentThreshold = threshold;
                // Is there a nearby exact match? (speedup)
                var bestLocation = text.indexOf(pattern, expectedLocation);

                var patternLen = pattern.length;

                // a mask of the matches
                var matchMask = [];
                for (var i = 0; i < textLen; i += 1) {
                    matchMask[i] = 0;
                }

                if (bestLocation !== -1) {
                    var score = bitapScore(pattern, {
                        errors: 0,
                        currentLocation: bestLocation,
                        expectedLocation: expectedLocation,
                        distance: distance
                    });
                    currentThreshold = Math.min(score, currentThreshold);

                    // What about in the other direction? (speed up)
                    bestLocation = text.lastIndexOf(pattern, expectedLocation + patternLen);

                    if (bestLocation !== -1) {
                        var _score = bitapScore(pattern, {
                            errors: 0,
                            currentLocation: bestLocation,
                            expectedLocation: expectedLocation,
                            distance: distance
                        });
                        currentThreshold = Math.min(_score, currentThreshold);
                    }
                }

                // Reset the best location
                bestLocation = -1;

                var lastBitArr = [];
                var finalScore = 1;
                var binMax = patternLen + textLen;

                var mask = 1 << patternLen - 1;

                for (var _i = 0; _i < patternLen; _i += 1) {
                    // Scan for the best match; each iteration allows for one more error.
                    // Run a binary search to determine how far from the match location we can stray
                    // at this error level.
                    var binMin = 0;
                    var binMid = binMax;

                    while (binMin < binMid) {
                        var _score3 = bitapScore(pattern, {
                            errors: _i,
                            currentLocation: expectedLocation + binMid,
                            expectedLocation: expectedLocation,
                            distance: distance
                        });

                        if (_score3 <= currentThreshold) {
                            binMin = binMid;
                        } else {
                            binMax = binMid;
                        }

                        binMid = Math.floor((binMax - binMin) / 2 + binMin);
                    }

                    // Use the result from this iteration as the maximum for the next.
                    binMax = binMid;

                    var start = Math.max(1, expectedLocation - binMid + 1);
                    var finish = findAllMatches ? textLen : Math.min(expectedLocation + binMid, textLen) + patternLen;

                    // Initialize the bit array
                    var bitArr = Array(finish + 2);

                    bitArr[finish + 1] = (1 << _i) - 1;

                    for (var j = finish; j >= start; j -= 1) {
                        var currentLocation = j - 1;
                        var charMatch = patternAlphabet[text.charAt(currentLocation)];

                        if (charMatch) {
                            matchMask[currentLocation] = 1;
                        }

                        // First pass: exact match
                        bitArr[j] = (bitArr[j + 1] << 1 | 1) & charMatch;

                        // Subsequent passes: fuzzy match
                        if (_i !== 0) {
                            bitArr[j] |= (lastBitArr[j + 1] | lastBitArr[j]) << 1 | 1 | lastBitArr[j + 1];
                        }

                        if (bitArr[j] & mask) {
                            finalScore = bitapScore(pattern, {
                                errors: _i,
                                currentLocation: currentLocation,
                                expectedLocation: expectedLocation,
                                distance: distance
                            });

                            // This match will almost certainly be better than any existing match.
                            // But check anyway.
                            if (finalScore <= currentThreshold) {
                                // Indeed it is
                                currentThreshold = finalScore;
                                bestLocation = currentLocation;

                                // Already passed `loc`, downhill from here on in.
                                if (bestLocation <= expectedLocation) {
                                    break;
                                }

                                // When passing `bestLocation`, don't exceed our current distance from `expectedLocation`.
                                start = Math.max(1, 2 * expectedLocation - bestLocation);
                            }
                        }
                    }

                    // No hope for a (better) match at greater error levels.
                    var _score2 = bitapScore(pattern, {
                        errors: _i + 1,
                        currentLocation: expectedLocation,
                        expectedLocation: expectedLocation,
                        distance: distance
                    });

                    if (_score2 > currentThreshold) {
                        break;
                    }

                    lastBitArr = bitArr;
                }

                // Count exact matches (those with a score of 0) to be "almost" exact
                return {
                    isMatch: bestLocation >= 0,
                    score: finalScore === 0 ? 0.001 : finalScore,
                    matchedIndices: matchedIndices(matchMask, minMatchCharLength)
                };
            };

            /***/ }),
        /* 8 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

            function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

            var Bitap = __webpack_require__(1);
            var deepValue = __webpack_require__(2);
            var isArray = __webpack_require__(0);

            var Fuse = function () {
                function Fuse(list, _ref) {
                    var _ref$location = _ref.location,
                        location = _ref$location === undefined ? 0 : _ref$location,
                        _ref$distance = _ref.distance,
                        distance = _ref$distance === undefined ? 100 : _ref$distance,
                        _ref$threshold = _ref.threshold,
                        threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                        _ref$maxPatternLength = _ref.maxPatternLength,
                        maxPatternLength = _ref$maxPatternLength === undefined ? 32 : _ref$maxPatternLength,
                        _ref$caseSensitive = _ref.caseSensitive,
                        caseSensitive = _ref$caseSensitive === undefined ? false : _ref$caseSensitive,
                        _ref$tokenSeparator = _ref.tokenSeparator,
                        tokenSeparator = _ref$tokenSeparator === undefined ? / +/g : _ref$tokenSeparator,
                        _ref$findAllMatches = _ref.findAllMatches,
                        findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                        _ref$minMatchCharLeng = _ref.minMatchCharLength,
                        minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng,
                        _ref$id = _ref.id,
                        id = _ref$id === undefined ? null : _ref$id,
                        _ref$keys = _ref.keys,
                        keys = _ref$keys === undefined ? [] : _ref$keys,
                        _ref$shouldSort = _ref.shouldSort,
                        shouldSort = _ref$shouldSort === undefined ? true : _ref$shouldSort,
                        _ref$getFn = _ref.getFn,
                        getFn = _ref$getFn === undefined ? deepValue : _ref$getFn,
                        _ref$sortFn = _ref.sortFn,
                        sortFn = _ref$sortFn === undefined ? function (a, b) {
                            return a.score - b.score;
                        } : _ref$sortFn,
                        _ref$tokenize = _ref.tokenize,
                        tokenize = _ref$tokenize === undefined ? false : _ref$tokenize,
                        _ref$matchAllTokens = _ref.matchAllTokens,
                        matchAllTokens = _ref$matchAllTokens === undefined ? false : _ref$matchAllTokens,
                        _ref$includeMatches = _ref.includeMatches,
                        includeMatches = _ref$includeMatches === undefined ? false : _ref$includeMatches,
                        _ref$includeScore = _ref.includeScore,
                        includeScore = _ref$includeScore === undefined ? false : _ref$includeScore,
                        _ref$verbose = _ref.verbose,
                        verbose = _ref$verbose === undefined ? false : _ref$verbose;

                    _classCallCheck(this, Fuse);

                    this.options = {
                        location: location,
                        distance: distance,
                        threshold: threshold,
                        maxPatternLength: maxPatternLength,
                        isCaseSensitive: caseSensitive,
                        tokenSeparator: tokenSeparator,
                        findAllMatches: findAllMatches,
                        minMatchCharLength: minMatchCharLength,
                        id: id,
                        keys: keys,
                        includeMatches: includeMatches,
                        includeScore: includeScore,
                        shouldSort: shouldSort,
                        getFn: getFn,
                        sortFn: sortFn,
                        verbose: verbose,
                        tokenize: tokenize,
                        matchAllTokens: matchAllTokens
                    };

                    this.setCollection(list);
                }

                _createClass(Fuse, [{
                    key: 'setCollection',
                    value: function setCollection(list) {
                        this.list = list;
                        return list;
                    }
                }, {
                    key: 'search',
                    value: function search(pattern) {
                        this._log('---------\nSearch pattern: "' + pattern + '"');

                        var _prepareSearchers2 = this._prepareSearchers(pattern),
                            tokenSearchers = _prepareSearchers2.tokenSearchers,
                            fullSearcher = _prepareSearchers2.fullSearcher;

                        var _search2 = this._search(tokenSearchers, fullSearcher),
                            weights = _search2.weights,
                            results = _search2.results;

                        this._computeScore(weights, results);

                        if (this.options.shouldSort) {
                            this._sort(results);
                        }

                        return this._format(results);
                    }
                }, {
                    key: '_prepareSearchers',
                    value: function _prepareSearchers() {
                        var pattern = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

                        var tokenSearchers = [];

                        if (this.options.tokenize) {
                            // Tokenize on the separator
                            var tokens = pattern.split(this.options.tokenSeparator);
                            for (var i = 0, len = tokens.length; i < len; i += 1) {
                                tokenSearchers.push(new Bitap(tokens[i], this.options));
                            }
                        }

                        var fullSearcher = new Bitap(pattern, this.options);

                        return { tokenSearchers: tokenSearchers, fullSearcher: fullSearcher };
                    }
                }, {
                    key: '_search',
                    value: function _search() {
                        var tokenSearchers = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
                        var fullSearcher = arguments[1];

                        var list = this.list;
                        var resultMap = {};
                        var results = [];

                        // Check the first item in the list, if it's a string, then we assume
                        // that every item in the list is also a string, and thus it's a flattened array.
                        if (typeof list[0] === 'string') {
                            // Iterate over every item
                            for (var i = 0, len = list.length; i < len; i += 1) {
                                this._analyze({
                                    key: '',
                                    value: list[i],
                                    record: i,
                                    index: i
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }

                            return { weights: null, results: results };
                        }

                        // Otherwise, the first item is an Object (hopefully), and thus the searching
                        // is done on the values of the keys of each item.
                        var weights = {};
                        for (var _i = 0, _len = list.length; _i < _len; _i += 1) {
                            var item = list[_i];
                            // Iterate over every key
                            for (var j = 0, keysLen = this.options.keys.length; j < keysLen; j += 1) {
                                var key = this.options.keys[j];
                                if (typeof key !== 'string') {
                                    weights[key.name] = {
                                        weight: 1 - key.weight || 1
                                    };
                                    if (key.weight <= 0 || key.weight > 1) {
                                        throw new Error('Key weight has to be > 0 and <= 1');
                                    }
                                    key = key.name;
                                } else {
                                    weights[key] = {
                                        weight: 1
                                    };
                                }

                                this._analyze({
                                    key: key,
                                    value: this.options.getFn(item, key),
                                    record: item,
                                    index: _i
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }
                        }

                        return { weights: weights, results: results };
                    }
                }, {
                    key: '_analyze',
                    value: function _analyze(_ref2, _ref3) {
                        var key = _ref2.key,
                            _ref2$arrayIndex = _ref2.arrayIndex,
                            arrayIndex = _ref2$arrayIndex === undefined ? -1 : _ref2$arrayIndex,
                            value = _ref2.value,
                            record = _ref2.record,
                            index = _ref2.index;
                        var _ref3$tokenSearchers = _ref3.tokenSearchers,
                            tokenSearchers = _ref3$tokenSearchers === undefined ? [] : _ref3$tokenSearchers,
                            _ref3$fullSearcher = _ref3.fullSearcher,
                            fullSearcher = _ref3$fullSearcher === undefined ? [] : _ref3$fullSearcher,
                            _ref3$resultMap = _ref3.resultMap,
                            resultMap = _ref3$resultMap === undefined ? {} : _ref3$resultMap,
                            _ref3$results = _ref3.results,
                            results = _ref3$results === undefined ? [] : _ref3$results;

                        // Check if the texvaluet can be searched
                        if (value === undefined || value === null) {
                            return;
                        }

                        var exists = false;
                        var averageScore = -1;
                        var numTextMatches = 0;

                        if (typeof value === 'string') {
                            this._log('\nKey: ' + (key === '' ? '-' : key));

                            var mainSearchResult = fullSearcher.search(value);
                            this._log('Full text: "' + value + '", score: ' + mainSearchResult.score);

                            if (this.options.tokenize) {
                                var words = value.split(this.options.tokenSeparator);
                                var scores = [];

                                for (var i = 0; i < tokenSearchers.length; i += 1) {
                                    var tokenSearcher = tokenSearchers[i];

                                    this._log('\nPattern: "' + tokenSearcher.pattern + '"');

                                    // let tokenScores = []
                                    var hasMatchInText = false;

                                    for (var j = 0; j < words.length; j += 1) {
                                        var word = words[j];
                                        var tokenSearchResult = tokenSearcher.search(word);
                                        var obj = {};
                                        if (tokenSearchResult.isMatch) {
                                            obj[word] = tokenSearchResult.score;
                                            exists = true;
                                            hasMatchInText = true;
                                            scores.push(tokenSearchResult.score);
                                        } else {
                                            obj[word] = 1;
                                            if (!this.options.matchAllTokens) {
                                                scores.push(1);
                                            }
                                        }
                                        this._log('Token: "' + word + '", score: ' + obj[word]);
                                        // tokenScores.push(obj)
                                    }

                                    if (hasMatchInText) {
                                        numTextMatches += 1;
                                    }
                                }

                                averageScore = scores[0];
                                var scoresLen = scores.length;
                                for (var _i2 = 1; _i2 < scoresLen; _i2 += 1) {
                                    averageScore += scores[_i2];
                                }
                                averageScore = averageScore / scoresLen;

                                this._log('Token score average:', averageScore);
                            }

                            var finalScore = mainSearchResult.score;
                            if (averageScore > -1) {
                                finalScore = (finalScore + averageScore) / 2;
                            }

                            this._log('Score average:', finalScore);

                            var checkTextMatches = this.options.tokenize && this.options.matchAllTokens ? numTextMatches >= tokenSearchers.length : true;

                            this._log('\nCheck Matches: ' + checkTextMatches);

                            // If a match is found, add the item to <rawResults>, including its score
                            if ((exists || mainSearchResult.isMatch) && checkTextMatches) {
                                // Check if the item already exists in our results
                                var existingResult = resultMap[index];
                                if (existingResult) {
                                    // Use the lowest score
                                    // existingResult.score, bitapResult.score
                                    existingResult.output.push({
                                        key: key,
                                        arrayIndex: arrayIndex,
                                        value: value,
                                        score: finalScore,
                                        matchedIndices: mainSearchResult.matchedIndices
                                    });
                                } else {
                                    // Add it to the raw result list
                                    resultMap[index] = {
                                        item: record,
                                        output: [{
                                            key: key,
                                            arrayIndex: arrayIndex,
                                            value: value,
                                            score: finalScore,
                                            matchedIndices: mainSearchResult.matchedIndices
                                        }]
                                    };

                                    results.push(resultMap[index]);
                                }
                            }
                        } else if (isArray(value)) {
                            for (var _i3 = 0, len = value.length; _i3 < len; _i3 += 1) {
                                this._analyze({
                                    key: key,
                                    arrayIndex: _i3,
                                    value: value[_i3],
                                    record: record,
                                    index: index
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }
                        }
                    }
                }, {
                    key: '_computeScore',
                    value: function _computeScore(weights, results) {
                        this._log('\n\nComputing score:\n');

                        for (var i = 0, len = results.length; i < len; i += 1) {
                            var output = results[i].output;
                            var scoreLen = output.length;

                            var totalScore = 0;
                            var bestScore = 1;

                            for (var j = 0; j < scoreLen; j += 1) {
                                var score = output[j].score;
                                var weight = weights ? weights[output[j].key].weight : 1;
                                var nScore = score * weight;

                                if (weight !== 1) {
                                    bestScore = Math.min(bestScore, nScore);
                                } else {
                                    output[j].nScore = nScore;
                                    totalScore += nScore;
                                }
                            }

                            results[i].score = bestScore === 1 ? totalScore / scoreLen : bestScore;

                            this._log(results[i]);
                        }
                    }
                }, {
                    key: '_sort',
                    value: function _sort(results) {
                        this._log('\n\nSorting....');
                        results.sort(this.options.sortFn);
                    }
                }, {
                    key: '_format',
                    value: function _format(results) {
                        var finalOutput = [];

                        this._log('\n\nOutput:\n\n', JSON.stringify(results));

                        var transformers = [];

                        if (this.options.includeMatches) {
                            transformers.push(function (result, data) {
                                var output = result.output;
                                data.matches = [];

                                for (var i = 0, len = output.length; i < len; i += 1) {
                                    var item = output[i];

                                    if (item.matchedIndices.length === 0) {
                                        continue;
                                    }

                                    var obj = {
                                        indices: item.matchedIndices,
                                        value: item.value
                                    };
                                    if (item.key) {
                                        obj.key = item.key;
                                    }
                                    if (item.hasOwnProperty('arrayIndex') && item.arrayIndex > -1) {
                                        obj.arrayIndex = item.arrayIndex;
                                    }
                                    data.matches.push(obj);
                                }
                            });
                        }

                        if (this.options.includeScore) {
                            transformers.push(function (result, data) {
                                data.score = result.score;
                            });
                        }

                        for (var i = 0, len = results.length; i < len; i += 1) {
                            var result = results[i];

                            if (this.options.id) {
                                result.item = this.options.getFn(result.item, this.options.id)[0];
                            }

                            if (!transformers.length) {
                                finalOutput.push(result.item);
                                continue;
                            }

                            var data = {
                                item: result.item
                            };

                            for (var j = 0, _len2 = transformers.length; j < _len2; j += 1) {
                                transformers[j](result, data);
                            }

                            finalOutput.push(data);
                        }

                        return finalOutput;
                    }
                }, {
                    key: '_log',
                    value: function _log() {
                        if (this.options.verbose) {
                            var _console;

                            (_console = console).log.apply(_console, arguments);
                        }
                    }
                }]);

                return Fuse;
            }();

            module.exports = Fuse;

            /***/ })
        /******/ ]);
});
//# sourceMappingURL=fuse.js.map
var AllInOneMenuTemplate = '<%var chunks = ["<div class=\'cont all-in-one-toc\'><h1 class=\'heading1\'>" + localization.TableOfContents + "</h1>"],    markup;function htmlTreeBuilder(items) {    if (items.length) {        chunks.push("<ul class=\'contents contents_all-in-one\'>");    }    items.forEach(function (item) {        if (!item.hidden) {            chunks.push("<li class=\'contents__item\'>");            chunks.push("<a href=\'");            chunks.push(item.url.match(/([\\w_]+\\.htm[l]?)/i)[1]);            chunks.push("\'>");            chunks.push(item.text);            chunks.push("</a>");            if (item.children) {                htmlTreeBuilder(item.children);            }            chunks.push("</li>");        }    });    if (items.length) {        chunks.push("</ul>");    }}htmlTreeBuilder(menu);chunks.push("</div>");markup = chunks.join("");%><%= markup %>';
var AsideTemplate = '<div class="aside ">    <div class="aside__inner">        <div class="aside__search search hidden-xs hidden-sm">            <div class="search__wrapper">                <input  class="search__field js_search_text" id="serch-text"                        placeholder="<%= localization.SearchLabel %>" type="text" />                <button class="search__btn js_search" id="search-button"></button>                <button class="search__clear is-hidden js_search_clear"></button>            </div>        </div>        <div class="selector-mobile js_selector_mobile_versions"></div>        <div class="selector-mobile js_selector_mobile_langs"></div>        <div class="aside__menu js_tabs_viewport">            <div class="js-menu-content">                <div class="js_menu"></div>            </div><!--            <div id="tab-names" class="b-tab__content js-tab-content">                <div class="b-index js_index_literals"></div>            </div>-->            <div class="js-search-content js_not_default">                <div class="search-results js_search_result_wrapper"></div>            </div>        </div>    </div></div>';
var BottomLinksTemplate = '<div class="bottom-links">    <!--<div class="feedback">        <div class="feedback__heading">Feedback</div>        <div class="feedback__text">            Was this article helpful?        </div>        <div>            <button class="button" type="button">Yes</button>            <button class="button" type="button">No</button>        </div>    </div>-->    <% if ((localization.ArticleIdText && localization.ArticleIdText.trim() && serviceInfo.id) ||            (localization.LastReviewText && localization.LastReviewText.trim() && serviceInfo.reviewDate)) { %>        <div class="bottom-links__service-info">            <% if (serviceInfo.id) { %>                <%= localization.ArticleIdText %> <%= serviceInfo.id %>,            <% } %>            <% if (serviceInfo.reviewDate) { %>                <%= localization.LastReviewText %> <%= serviceInfo.reviewDate %>            <% } %>        </div>    <% } %>    <div class="bottom-links__link">        <%= homeBtnHtml %>    </div></div>';
var ContainerTemplate = '<div class="main js_container">    <header class="js_header_placeholder"></header>    <div class="content js_main">        <div class="container">            <div class="row">                <div class="col-md-4 col-xs-20 menu-box js_aside_placeholder"></div>                <div class="col-md-1 hidden-xs hidden-sm js_prev_btn_placeholder"></div>                <div class="col-md-14 col-xs-20 js_content"></div>                <div class="col-md-1 hidden-xs hidden-sm js_next_btn_placeholder"></div>                <div class="col-md-16 col-xs-20 align-flex-end">                    <footer class="js_footer_placeholder"></footer>                </div>            </div>        </div>    </div>    <aside class="mobile-search-results is-hidden g-scrollable js_scrollable js_mobile_search_result js_mobile_aside"></aside></div><!--<div class="b-modal js_overlay">    <div class="b-modal__window js_modal">        <header class="b-modal__header js_modal_header"></header>        <div class="b-modal__content js_modal_content"></div>        <button href="#" class="b-modal__close-button js_modal_close"></button>    </div></div>--><div class="tooltip js_tooltip" data-id="">    <div class="tooltip__content js_tooltip_content"></div></div>';
var CustomStylesTemplate = '<style>    html {        color: <%= customization.ContentColorMain %>;    }    a {        color: <%= customization.LinkColor %>    }    a:hover {        color: <%= customization.LinkColorHover %>    }    a:visited {        color: <%= customization.LinkColorVisited %>    }    .page-title {        color: <%= customization.TitleColor %>;    }    /*.tablename,    .picturename,    .examplebodytext,    .examplebodytextblue2015,    .bottom-links__service-info,    .search-results__total,    .footer {        color: <%= customization.ContentColorSecondary %>;    }*/    .attentionbody,    .attentionbodytextindent,    .attentioncontinue1,    .attentioncontinue2,    .attentioncontinue3 {        color: <%= customization.AttentionBlockColor %>;    }    .warningbody,    .warningbodytextindent,    .warningcontinue1,    .warningcontinue2,    .warningcontinue3 {        color: <%= customization.WarningBlockColor %>;        border-color: <%= customization.WarningBlockBorder %>;        background: <%= customization.WarningBlockBackground %>;    }    .example-wrapper {        background: <%= customization.ExampleBlockBackground %> !important;    }    .exampleheading,    .examplebodytext,    .exampleheadingblue2015,    .examplebodytextblue2015 {        color: <%= customization.ExampleBlockColor %>;    }    mark {        background: <%= customization.SearchHighlightBackground %>;        color: <%= customization.SearchHighlightColor %>;    }</style>';
var FooterTemplate = '<div class="footer footer_inner">    <!--<div class="container">-->        <div class="row">            <div class="col-xs-20">                <div class="footer__divider"></div>            </div>            <div class="col-md-10 col-xs-20">                <div class="footer__text">                    <%= localization.FooterCopyrightText %>                </div>            </div>            <div class="col-md-10 col-xs-20">                <div class="footer__links">                    <% var hasOldFormatLinks = false %>                    <% if ( localization.FooterPrivacyPolicyLink && localization.FooterPrivacyPolicyLink.trim() &&                            localization.FooterPrivacyPolicyText && localization.FooterPrivacyPolicyText.trim() &&                            (!customization.FooterPrivacyPolicyLink || !customization.FooterPrivacyPolicyLink.hidden)) { %>                        <% hasOldFormatLinks = true %>                        <span class="footer__links-item">                            <% if (customization.FooterPrivacyPolicyLink && customization.FooterPrivacyPolicyLink.disabled) { %>                                <span class="footer__link">                                    <%= localization.FooterPrivacyPolicyText %>                                </span>                            <% } else { %>                                <a class="footer__link" target="blank" href="<%= localization.FooterPrivacyPolicyLink %>">                                    <%= localization.FooterPrivacyPolicyText %>                                </a>                            <% } %>                        </span>                    <% } %>                    <% if ( localization.FooterLegalLink && localization.FooterLegalLink.trim() &&                            localization.FooterLegalText && localization.FooterLegalText.trim() &&                            (!customization.FooterLegalLink || !customization.FooterLegalLink.hidden)) { %>                        <% hasOldFormatLinks = true %>                        <span class="footer__links-item">                            <% if (customization.FooterLegalLink && customization.FooterLegalLink.disabled) { %>                                <span class="footer__link">                                    <%= localization.FooterLegalText %>                                </span>                            <% } else { %>                                <a class="footer__link" target="blank" href="<%= localization.FooterLegalLink %>">                                    <%= localization.FooterLegalText %>                                </a>                            <% } %>                        </span>                    <% } %>                    <% if ( localization.FooterLinks && !hasOldFormatLinks ) { %>                        <% for (var i = 0, link; i < localization.FooterLinks.length; i++ ) { %>                            <% link = localization.FooterLinks[i] %>                            <span class="footer__links-item">                                <a class="footer__link" target="blank" href="<%= link.url %>">                                    <%= link.label %>                                </a>                            </span>                        <% } %>                    <% } %>                </div>            </div>        </div>    <!--</div>--></div>';
var HeaderTemplate = '<div class="header header_inner-help">    <div class="container">        <div class="row">            <div class="col-md-10 col-xs-20">                <button class="header__mobile-menu-btn js_burger" type="button"></button>                <div class="header__title hidden-xs hidden-sm">                    <% if ((!customization.HeaderLogoLink || !customization.HeaderLogoLink.hidden) && localization.HeaderTitle) { %>                        <% if ((customization.HeaderLogoLink && customization.HeaderLogoLink.disabled) || isOffline) { %>                            <span class="header__title-link">                        <% } else { %>                            <a href="<%= localization.HeaderLogoLink %>" class="header__title-link">                        <% } %>                            <% var index = localization.HeaderTitle.indexOf(" ") %>                            <%= localization.HeaderTitle.slice(0, index) %>                            <div class="header__title-big header__title-big_inner-help">                                <%= localization.HeaderTitle.slice(index, localization.HeaderTitle.length) %>                            </div>                        <%= (customization.HeaderLogoLink && customization.HeaderLogoLink.disabled) ? "</span>" : "</a>" %>                    <% } %>                </div>                <div class="header__title header__title_product"><%= titlePreffix %> <%= title %></div>                <div class="header__search">                    <button class="header__search-btn js_mobile_search_button" type="button"></button>                    <input type="search" class="header__search-input is-hidden js_mobile_search_input"                           placeholder="<%= localization.SearchPlaceholder %>" />                    <button class="header__clear-btn is-hidden js_mobile_search_clear" type="button"></button>                </div>            </div>            <div class="col-md-10 hidden-xs hidden-sm">                <div class="header__logo">                    <% if (!customization.FooterLogoLink || !customization.FooterLogoLink.hidden) { %>                        <% if (customization.FooterLogoLink && customization.FooterLogoLink.disabled) { %>                            <span class="logo"></span>                        <% } else { %>                            <a href="<%= localization.FooterLogoLink %>" class="logo"                               title="<%= localization.FooterLogoTitle %>"></a>                        <% } %>                    <% } %>                </div>            </div>        </div>    </div></div><div class="top-bar hidden-xs hidden-sm">    <div class="container">        <div class="row">            <div class="col-md-5">                <div class="top-bar__product-box">                    <div class="top-bar__product js_product_logo"></div>                    <h1 class="top-bar__title js_title">                        <% if (titlePreffix && titlePreffix.trim() ) { %>                            <span class="top-bar__title-small"><%= titlePreffix %></span>                        <% } %>                        <%= title %>                    </h1>                </div>            </div>            <div class="col-md-15">                <div class="top-bar__links-box">                    <div class="top-bar__links">                        <% if ( localization.PrintButtonText && localization.PrintButtonText.trim() ) { %>                            <% if (isAllInOne) { %>                                <a class="top-bar__link top-bar__link_print" href="javascript:print();">                                    <span class="top-bar__icon top-bar__icon_print"></span><%= localization.PrintButtonText %>                                </a>                            <% } else { %>                                <div class="dropdown js_dropdown">                                    <a class="top-bar__link top-bar__link_print js_dropdown_btn" href="#">                                        <span class="top-bar__icon top-bar__icon_print"></span><%= localization.PrintButtonText %>                                        <span class="top-bar__triangle"></span>                                    </a>                                    <ul class="dropdown__list js_dropdown_list">                                        <li class="dropdown__item">                                            <a class="dropdown__link" href="javascript:print();">                                                <%= localization.PrintPageText %>                                            </a>                                        </li>                                        <li class="dropdown__item">                                            <a class="dropdown__link js_print_section" href="">                                                <%= localization.PrintSectionText %>                                            </a>                                        </li>                                        <li class="dropdown__item">                                            <a class="dropdown__link js_print_all" href="all-in-one.htm" target="_blank">                                                <%= localization.PrintAllText %>                                            </a>                                        </li>                                    </ul>                                </div>                            <% } %>                        <% } %>                        <% if ( localization.SupportButtonText && localization.SupportButtonText.trim() &&                                localization.SupportButtonLink && localization.SupportButtonLink.trim() &&                                (!customization.SupportButtonLink || !customization.SupportButtonLink.hidden)) { %>                            <% if (customization.SupportButtonLink && customization.SupportButtonLink.disabled) { %>                                <span class="top-bar__link top-bar__link_support">                                    <span class="top-bar__icon top-bar__icon_support"></span><%= localization.SupportButtonText %>                                </span>                            <% } else { %>                                <a class="top-bar__link top-bar__link_support" href="<%= localization.SupportButtonLink %>" target="blank">                                    <span class="top-bar__icon top-bar__icon_support"></span><%= localization.SupportButtonText %>                                </a>                            <% } %>                        <% } %>                        <% if ( localization.SendLinkButtonText && localization.SendLinkButtonText.trim() &&                                (!customization.SendLinkButton || !customization.SendLinkButton.hidden)) { %>                            <% if (customization.SendLinkButton && customization.SendLinkButton.disabled) { %>                                <span class="top-bar__link top-bar__link_feedback">                                    <span class="top-bar__icon top-bar__icon_feedback"></span><%= localization.SendLinkButtonText %>                                </span>                            <% } else { %>                                <a class="top-bar__link top-bar__link_feedback js_feedback_link" href="">                                    <span class="top-bar__icon top-bar__icon_feedback"></span><%= localization.SendLinkButtonText %>                                </a>                            <% } %>                        <% } %>                    </div>                    <div class="top-bar__langs">                        <span class="top-bar__versions js_header_versions_list"></span>                        <span class="js_header_lang_list"></span>                    </div>                </div>            </div>        </div>    </div></div>';
var IndexLiteralsTemplate = '<ul class="b-index__list"><%    var result,        html = [];    for (var i= 0, item; i < index.length; i++ ) {        item = index[i];        if ( item.nested) {            html.push( "<li class=\'b-index__item js_menu_item b-index__item--nested\'>" );        } else {            html.push( "<li class=\'b-index__item js_menu_item\'>" );        }        if ( item["class"] === "indexlink" ) {            html.push( "<a class=\'b-index__link js_menu_link\' href=\'");            html.push( item.href );            html.push( "\'>" );            html.push( item.text );            html.push( "</a>" )        } else if ( item["class"] === "indexheading" ) {            html.push( "<span class=\'b-index__header\'>" );            html.push( item.text );            html.push( "</span>" )        } else {            html.push( "<span class=\'b-index__subheader\'>" );            html.push( item.text );            html.push( "</span>" )        }        html.push( "</li>" );    }    result = html.join("");%><%= result %></ul>';
var LangListTemplate = '<div class="dropdown dropdown_right js_dropdown">    <a class="dropdown__btn js_dropdown_btn">        <%= currentLang.name %>        <span class="dropdown__arrow"></span>    </a>    <ul class="dropdown__list js_dropdown_list">        <% _.each( langs, function( lang ) {%>            <% var dir = lang.dirname || lang.id %>            <% if (lang.id !== currentLang.id ) { %>                <li class="dropdown__item">                    <% if ( isMac ) { %>                        <a class="dropdown__link js_lang_item" data-lang-id="<%= dir %>" href="../../<%= dir %>/pgs">                            <%= lang.name %>                        </a>                    <% } else { %>                        <a class="dropdown__link js_lang_item" data-lang-id="<%= dir %>" href="../<%= dir %>">                            <%= lang.name %>                        </a>                    <% } %>                </li>            <% } %>        <% }) %>    </ul></div>';
var MenuTemplate = '<%var chunks = [],    isMac = isMacProject,    markup;function htmlTreeBuilder( items, opened ) {    if (items.length) {        chunks.push( "<ul class=\'contents js_contents_level\'" );        chunks.push( !opened ? " style=\'display:none\' ": "" );        chunks.push( ">" );    }    for (var i = 0, item; i < items.length; i++) {        item = items[i];        if ( !item.hidden ) {            if ( item.isActive ) {                chunks.push( "<li class=\'contents__item js_menu_item is-active\'>" );            } else {                chunks.push( "<li class=\'contents__item js_menu_item\'>" );            }            if ( item.children ) {                chunks.push( "<button class=\'contents__toggle js_contents_toggle" );                chunks.push( item.childIsActive || item.isActive ? " is-toggled" : "" );                chunks.push( "\' href=\'#\'></button>" );            }            chunks.push( "<a class=\'contents__item-link js_menu_link\' href=\'" );            chunks.push( (isMac ? "index.htm#" : "") + item.url );            chunks.push( "\'>" );            chunks.push( item.text );            chunks.push( "</a>" );            if ( item.children ) {                /*chunks.push( "<a class=\'contents__item-link-direct js_menu_link_direct\' href=\'" );                chunks.push( item.url );                chunks.push( "\'>" );                chunks.push( "</a>" );*/            }            if ( item.children ) {                htmlTreeBuilder( item.children, item.childIsActive || item.isActive );            }        }    }    if (items.length) {        chunks.push( "</ul>" );    }}htmlTreeBuilder( menu, true );markup = chunks.join("");%><%= markup %>';
var MobileSearchResultsTemplate = '<%if (!isInit){%>    <div class="mobile-search-results__total">        <% if ( resultsCount > 0) { %>            <%= localization.FoundTextBegin %> <%= resultsCount %> <%= localization.FoundTextEnd %>        <% } else { %>            <%= localization.NothingFoundText %>        <%}%>    </div>    <div class="mobile-search-results__content">        <%if ( found ){%>            <ul class="mobile-search-results__list">                <%_.each(results, function( page ){%>                    <li class="mobile-search-result">                        <% var link = isMacProject ? "index.htm#" + page.link : page.link %>                        <a class="mobile-search-result__title" href="<%= link %>"><%= page.title %></a>                        <%_.each( page.texts, function( text ){%>                            <p class="mobile-search-result__content"><%= text %></p>                        <%})%>                    </li>                <%})%>            </ul>        <%}%>    </div><%}%>';
var NextLinkTemplate = '<div class="nav-btn">    <% if (nextPage && nextPage.url) { %>        <% var link = isMacProject ? "index.htm#" + nextPage.url : nextPage.url %>        <a class="nav-btn__link-next js_next_link"           href="<%= link %>"           title="<%= nextPage.text %>"></a>    <% } else { %>        <span class="nav-btn__link-next-inactive"></span>    <% } %></div>';
var PageTitleTemplate = '<div class="page-title">    <div class="page-title__text">        <%= titleHtml %>    </div></div>';
var PrevLinkTemplate = '<div class="nav-btn">    <% if (prevPage && prevPage.url) { %>        <% var link = isMacProject ? "index.htm#" + prevPage.url : prevPage.url %>        <a class="nav-btn__link-prev js_prev_link"           href="<%= link %>"           title="<%= prevPage.text %>"></a>    <% } else { %>        <span class="nav-btn__link-prev-inactive"></span>    <% } %></div>';
var SearchResultsTemplate = '<%if (!isInit){%>    <div class="search-results__header">        <div class="search-results__total">            <%= localization.FoundTextBegin %> <%= resultsCount %> <%= localization.FoundTextEnd %>        </div>    </div>    <%if ( found ){%>        <div class="search-results__content">            <ul class="search-results__list">                <%_.each(results, function( page ){%>                    <li class="search-result">                        <% var link = isMacProject ? "index.htm#" + page.link : page.link %>                        <a class="search-result__title" href="<%= link %>"><%= page.title %></a>                        <%_.each( page.texts, function( text ){%>                            <p class="search-result__content"><%= text %></p>                        <%})%>                    </li>                <%})%>            </ul>        </div>    <%}%><%}%>';
var VersionsTemplate = '<div class="dropdown dropdown_right js_dropdown">    <a class="dropdown__btn js_dropdown_btn">        <%= currentVersion.label %>        <span class="dropdown__arrow"></span>    </a>    <ul class="dropdown__list js_dropdown_list">        <% _.each(versions, function(version)  {%>            <% if (version.url !== currentVersion.url) { %>                <li class="dropdown__item">                    <a class="dropdown__link js_version_item"                       data-version-url="<%= version.url %>" href="../../<%= version.url %>">                        <%= version.label %>                    </a>                </li>            <% } %>        <% }) %>    </ul></div>';
var LangsLocalization = {"en-US":"English","id-ID":"Bahasa Indonesia","cs-CZ":"Čeština &#x202A;(Česká republika)","da-DK":"Dansk &#x202A;(Danmark)","de-DE":"Deutsch","et-EE":"Eesti","es-ES":"Español &#x202A;(España, alfabetización internacional)","es-MX":"Español &#x202A;(México)","fr-FR":"Français","it-IT":"Italiano","lv-LV":"Latviešu","lt-LT":"Lietuvių","hu-HU":"Magyar &#x202A;(Magyarország)","nl-NL":"Nederlands &#x202A;(Nederland)","nb-NO":"Norsk, bokmål &#x202A;(Norge)","pl-PL":"Polski &#x202A;(Polska)","pt-BR":"Português &#x202A;(Brasil)","pt-PT":"Português &#x202A;(Portugal)","ro-RO":"Română &#x202A;(România)","sr-Latn":"Srpski","fi-FI":"Suomi &#x202A;(Suomi)","sv-SE":"Svenska &#x202A;(Sverige)","vi-VN":"Tiếng Việt &#x202A;(Việt Nam)","tr-TR":"Türkçe &#x202A;(Türkiye)","el-GR":"Ελληνικά &#x202A;(Ελλάδα)","bg-BG":"Български","kk-KZ":"Қазақ","ru-RU":"Русский","sr-Cyrl":"Српски","uk-UA":"Українська","ar-AE":"العربية (الإمارات العربية المتحدة&#x202B;)","fa-IR":"فارسى (ایران&#x202B;)","hi-IN":"हिंदी &#x202A;(भारत)","th-TH":"ไทย &#x202A;(ไทย)","ko-KR":"한국어 &#x202A;(대한민국)","ja-JP":"日本語&#x202A;(日本)","zh-Hans":"简体中文","zh-Hant":"繁體中文"};
var Page=new Array("Droits d'auteur"," "," "," "," ","Cher utilisateur, ","Merci d'avoir choisi Kaspersky Lab comme fournisseur de logiciels de sécurité. Nous espérons que ce document vous aidera à utiliser notre produit.","Attention ! Ce document est la propriété de Kaspersky Lab AO (également dénommé ici Kaspersky Lab) : tous les droits sur ce document sont réservés par les droits d'auteur de la Fédération de Russie et par les traités internationaux. Toute reproduction et distribution illégale de ce document en totalité ou en partie engage la responsabilité civile, administrative ou pénale en vertu de la loi en vigueur. ","Toute reproduction ou distribution de contenu, y compris des traductions n'est autorisée qu'avec l'accord écrit de Kaspersky Lab.","Ce document et les illustrations qui l'accompagnent ne peuvent être utilisés que pour information et à des fins non commerciales et personnelles.","Kaspersky Lab se réserve le droit de modifier ce document sans avertissement préalable.","Kaspersky Lab décline toute responsabilité quant au contenu, à la qualité, à la pertinence ou à l'exactitude du contenu utilisé dans le présent document dont les droits sont détenus par des tiers ou pour tout préjudice potentiel associé à l'utilisation du document.","Date de révision du document : 01/03/2018","© 2018 AO Kaspersky Lab. Tous droits réservés.","https://www.kaspersky.comhttps://support.kaspersky.com"," Droits d&apos;auteur ","55937.htm");
Page[1]=new Array("A propos de ce document","Le Manuel de l'utilisateur de Kaspersky Endpoint Security 10 Service Pack 1 for Linux (ci-après \"Kaspersky Endpoint Security\") s'adresse aux spécialistes de l'installation et de l'administration de Kaspersky Endpoint Security, et aux spécialistes de l'assistance technique des organisations qui utilise Kaspersky Endpoint Security.","Les informations reprises dans ce manuel peuvent être utiles dans l'exécution des tâches suivantes :","préparatifs de l'installation, installation et activation de Kaspersky Endpoint Security.configuration et utilisation de Kaspersky Endpoint Security.Ce manuel présente également les autres sources d'informations sur l'application ainsi que les différentes méthodes d'obtention de l'assistance technique.","Dans cette sectionDans ce documentConventions"," A propos de ce document ","161208.htm");
Page[2]=new Array("Dans ce document","Ce manuel contient les sections suivantes :","Sources d'informations sur l'application","Cette section présente les différentes sources d'informations sur l'application.","Kaspersky Endpoint Security","Cette section décrit les capacités de l'application et fournit de brèves informations sur ses composants. Vous y découvrirez le contenu du kit de distribution et les services offerts aux utilisateurs enregistrés de l'application.","Installation de l'application","Cette section explique comment installer Kaspersky Endpoint Security sur l'ordinateur et réaliser la configuration initiale.","Suppression de l'application","Cette section explique comment supprimer l'application sur l'ordinateur.","Licence de l'application","Cette section aborde les principaux aspects liés à la licence de l'application.","Lancement et arrêt de l'application","Cette section contient des informations indiquant comment lancer, relancer et terminer le fonctionnement de l'application à partir de la ligne de commande.","Paramètres généraux de Kaspersky Endpoint Security","Cette section fournit des informations générales sur les paramètres de l'application.","Administration des tâches de Kaspersky Endpoint Security via la ligne de commande","Cette section contient des informations sur les types de tâches de Kaspersky Endpoint Security et des instructions relatives à la gestion de ces tâches via la ligne de commande.","Tâche de protection en temps réel (ID File_Monitoring :1)","Cette section fournit des informations sur la tâche de protection en temps réel. Elle explique également comment configurer les paramètres de cette tâche.","Tâche d'analyse à la demande (Scan_My_Computer ID:2)","Cette section fournit des informations sur la tâche d'analyse à la demande. Elle explique également comment configurer les paramètres de cette tâche.","Tâche d'analyse personnalisée (Scan_File ID :3)","Cette section fournit des informations sur la tâche d'analyse personnalisée. Elle explique également comment configurer les paramètres de cette tâche.","Tâche d'analyse des secteurs d'amorçage (Boot_Scan ID:4)","Cette section fournit des informations sur la tâche d'analyse des secteurs d'amorçage. Elle explique également comment configurer les paramètres de cette tâche.","Tâche d'analyse de la mémoire des processus (Memory_Scan ID_5)","Cette section fournit des informations sur la tâche d'analyse de la mémoire des processus. Elle explique également comment configurer les paramètres de cette tâche.","Tâche de mise à jour (ID de mise à jour :6)","Cette section contient des informations sur la mise à jour des bases antivirus et des modules de l'application (également appelées ci-après \"mises à jour\") et des instructions indiquant comment configurer les paramètres de mise à jour.","Tâche de recul de mise à jour des bases (Rollback ID:7)","Cette section fournit des informations sur la tâche de recul de mise à jour des bases. Elle explique également comment configurer les paramètres de cette tâche.","Tâche de copie des mises à jour (Retranslate ID:8)","Cette section fournit des informations sur les bases antivirus et sur la reconversion des mises à jour de l'application. Elle explique également comment configurer les paramètres de cette tâche.","Tâche License (License ID:9)","Cette section fournit des informations sur la tâche Licence. Elle explique également comment gérer cette tâche.","Tâche d'administration du stockage (Backup ID :10)","Cette section explique comment configurer les paramètres du stockage et présente les actions exécutables sur les objets qui se trouvent dans ce stockage.","Tâche de contrôle de l'intégrité des fichiers (Integrity_Monitoring ID:11)","Cette section fournit des informations sur la tâche Contrôle de l'intégrité des fichiers. Elle explique également comment gérer cette tâche.","Tâche Gestion du pare-feu (Identifiant du Pare-feu :12)","Cette section fournit des informations sur la tâche Firewall Manager. Elle explique également comment gérer cette tâche.","Tâche Protection contre le chiffrement (AntiCryptor ID:13)","Cette section fournit des informations sur la tâche Anti-Cryptor. Elle explique également comment gérer cette tâche.","Participation au Kaspersky Security Network","Cette section contient des informations relatives à la participation au Kaspersky Security Network et explique comment activer ou désactiver l'utilisation de Kaspersky Security Network.","Utilisation de l'interface utilisateur graphique de Kaspersky Endpoint Security","Cette section contient des informations relatives à l'interface graphique de l'application et explique comment l'activer ou la désactiver.","Contacter le Support Technique","Cette section contient des informations sur les modes et les conditions d'obtention de l'assistance technique.","Appendices","Cette section contient des informations relatives aux paramètres par défaut des fichiers de configuration et des codes retour de la ligne de commande. Elle explique également comment configurer le serveur de messagerie de Kaspersky Antivirus for Linux.","AO Kaspersky Lab","Cette section contient des informations sur Kaspersky Lab.","Informations sur le code tiers","Cette section fournit des informations sur le code tiers.","Notice sur les marques de commerce","Cette section contient des informations sur les marques déposées mentionnées dans le document.","Glossaire","Cette section contient une liste des termes qui apparaissent dans le document et leurs définitions respectives.","Index","Cette section permet de trouver rapidement les informations souhaitées dans le document."," Dans ce document ","161209.htm");
Page[3]=new Array("Conventions","Le présent document respecte des conventions (cf. tableau ci-dessous).","Conventions"," ","Exemple de texte","Description de la convention du document","N'oubliez pas que...","Les avertissements apparaissent en rouge et sont encadrés. Ils contiennent des informations sur les actions pouvant avoir des conséquences indésirables.","Nous vous avons recommandé d'utiliser...","Les remarques sont encadrées. Les remarques contiennent des informations complémentaires ou d'aide."," "," ","Exemple :","…"," ","Les exemples sont présentés en blocs sur un fond bleu clair sous le titre \"Exemple\".","La mise à jour, c’est...","L'événement Les bases de données sont périmées survient.","Les éléments de sens suivants sont en italique :","Nouveaux termesNoms des états et des événements de l'application","Appuyez sur la touche ENTREE.","Appuyez sur la combinaison des touches ALT+F4.","Les noms des touches du clavier sont en caractères mi-gras et en lettres majuscules.","Les noms de touches regroupés par un signe + (plus) représentent des combinaisons de touches. Ces touches doivent être enfoncées simultanément.","Cliquez sur le bouton Activer.","Les noms des éléments de l'interface de l'application, par exemple, les champs de saisie, les options du menu, les boutons, sont en caractères mi-gras. ","Pour planifier une tâche, procédez comme suit :","Les phrases d'introduction des instructions sont en italique et ont l'icône \"flèche\".","Dans la ligne de commande, saisissez le texte help.","Les informations suivantes s'affichent :","Indiquez la date au format JJ:MM:AA.","Les types suivants du texte apparaissent dans un style spécial :","Texte de la ligne de commandeTexte des messages affichés sur l'écran par l'applicationDonnées à saisir à l'aide du clavier","<Nom d'utilisateur>","Les variables apparaissent entre crochets obliques. Au lieu de la variable, insérez la valeur correspondante sans inclure les crochets obliques."," Conventions ","68566.htm");
Page[4]=new Array("Sources d'informations sur l'application","la page de Kaspersky Endpoint Security sur le site Web de Kaspersky Lab ;","La page Kaspersky Endpoint Security page sur le site Internet de Kaspersky Lab propose des informations générales sur l'application, ses possibilités et les particularités de son fonctionnement.","Page de Kaspersky Endpoint Security dans la base de connaissances","La Base de connaissances est une section du site Internet du Support Technique de Kaspersky Lab.","La page de Kaspersky Endpoint Security dans la Base de connaissances propose des articles qui contiennent des informations utiles, des recommandations et des réponses aux questions souvent posées sur l'acquisition, l'installation et l'utilisation de l'application.","Les articles de la Base de connaissances peuvent apporter des réponses aux questions concernant Kaspersky Endpoint Security et les autres applications Kaspersky Lab. Les articles de la Base de connaissances peuvent également contenir de nouvelles informations sur le Support Technique.","Discussions sur les applications de Kaspersky Lab sur le forum","Si votre question n'est pas urgente, vous pouvez en discuter avec les spécialistes de Kaspersky Lab et d'autres utilisateurs sur notre forum.","Sur le forum, vous pouvez consulter les sujets publiés, ajouter des commentaires ou créer de nouveaux sujets de discussion.","Une connexion Internet est nécessaire pour accéder aux ressources du site Internet.","Si vous ne trouvez pas la solution à votre problème, contactez le Support Technique.","Dans cette sectionSources pour les recherches indépendantes d'informationsDiscussions sur les applications de Kaspersky Lab sur le forum"," Sources d&apos;informations sur l&apos;application ","80831.htm");
Page[5]=new Array("Sources pour les recherches indépendantes d'informations","Vous pouvez utiliser les sources d'informations suivantes sur Kaspersky Endpoint Security pour effectuer une recherche seul :","la page de Kaspersky Endpoint Security sur le site Web de Kaspersky Lab ;Page de Kaspersky Endpoint Security sur le site du Support Technique (base de connaissances)Documentation d'aide incluse avec l'application","Si vous ne trouvez pas la solution à un problème par vous-même, nous vous recommandons de contacter le Support Technique.","Une connexion Internet est nécessaire pour l'accès aux ressources Internet.","la page de Kaspersky Endpoint Security sur le site Web de Kaspersky Lab ;","La page de Kaspersky Endpoint Security propose des informations générales sur l'application, ses possibilités et les particularités de son fonctionnement.","La page de Kaspersky Endpoint Security contient un lien vers la boutique en ligne où vous pouvez acheter l'application ou renouveler votre licence pour l'application.","Page de Kaspersky Endpoint Security dans la base de connaissances","La base de connaissances est une section du site Web du Support Technique de Kaspersky Lab.","Sur la page de Kaspersky Endpoint Security dans la base de connaissances, vous pouvez lire des articles qui contiennent des informations utiles, des recommandations et des réponses aux questions souvent posées sur l'acquisition, l'installation et l'utilisation de l'application.","Les articles de la Base de connaissances peuvent apporter des réponses aux questions concernant Kaspersky Endpoint Security et les autres applications Kaspersky Lab. Les articles de la base de connaissances peuvent également comporter des actualités sur le Service de Support technique.","Documentation d'aide incluse avec l'application","L'application inclut une aide complète et une aide contextuelle.","L'aide complète fournit des informations sur la configuration et l'utilisation de Kaspersky Endpoint Security.","L'aide contextuelle fournit des informations sur les fenêtres de Kaspersky Endpoint Security, décrit les paramètres de Kaspersky Endpoint Security et contient des liens sur les descriptions de la tâche où ces paramètres sont utilisés.","L'aide peut être incluse dans le kit de distribution ou située sur le site Internet de Kaspersky Lab. Si l'aide en ligne est disponible, une fenêtre de navigateur s'ouvre lorsque cette aide en ligne est consultée. Une connexion Internet est nécessaire pour afficher l'aide en ligne.","Documentation","Le Manuel de l'utilisateur de l'application fournit des informations sur l'installation, l'activation et la configuration de l'application, ainsi que sur l'utilisation de l'application. Le document décrit également l'interface de l'application et les manières d'effectuer les tâches utilisateur les plus habituelles."," Sources pour les recherches ind&#xE9;pendantes d&apos;informations ","166041.htm");
Page[6]=new Array("Discussions sur les applications de Kaspersky Lab sur le forum","Si votre question n'est pas urgente, vous pouvez en discuter avec les spécialistes de Kaspersky Lab et d'autres utilisateurs sur notre forum.","Sur le forum, vous pouvez consulter les sujets publiés, ajouter des commentaires ou créer de nouveaux sujets de discussion."," Discussions sur les applications de Kaspersky Lab sur le forum ","35700.htm");
Page[7]=new Array("Kaspersky Endpoint Security 10 Service Pack 1 for Linux","Cette section décrit les fonctions, les modules et le kit de distribution de Kaspersky Endpoint Security ainsi que les configurations matérielle et logicielle requises pour Kaspersky Endpoint Security.","Dans cette sectionPrésentation de Kaspersky Endpoint SecurityNouveautésDistributionConfigurations logicielle et matérielle"," Kaspersky Endpoint Security 10 Service Pack 1 for Linux ","161213.htm");
Page[8]=new Array("Présentation de Kaspersky Endpoint Security","Kaspersky Endpoint Security protège les ordinateurs qui tournent sous les systèmes d'exploitation Linux® contre les applications malveillantes. Les menaces peuvent pénétrer le système via les canaux de transmission de données du réseau ou depuis des disques amovibles.","L'application permet :","D'analyser les objets du système de fichiers sur les disques locaux de l'ordinateur, ainsi que sur les ressources montées et partagées accessibles via les protocoles SMB et NFS.D'analyser les objets du système de fichiers aussi bien en temps réel à l'aide des tâches de protection en temps réel qu'à la demande de l'utilisateur à l'aide de tâches d'analyse à la demande.analyse des secteurs d'amorçage ;analyse de la mémoire des processus ;De détecter les objets infectés. Kaspersky Endpoint Security considère qu'un objet est infecté s'il contient le code d'un virus connu.De neutraliser les menaces détectées dans les fichiers.De choisir automatiquement l'action à exécuter pour neutraliser la menace.D'enregistrer des copies de sauvegarde des fichiers avant la désinfection et de restaurer les fichiers à partir des copies de sauvegarde.D'administrer les tâches et de configurer leurs paramètres.D'administrer la tâche de protection en temps réel, ainsi que les tâches d'analyse à la demande, d'analyse des secteurs d'amorçage, d'analyse de la mémoire des processus, de mise à jour, sans oublier les tâches de recul de mises à jour des bases et de copie de celles-ci.D'ajouter des clés et d'activer l'application à l'aide de codes d'activation.De signaler à l'administrateur les événements qui ont eu lieu pendant le fonctionnement de Kaspersky Endpoint Security.De mettre à jour les bases de Kaspersky Endpoint Security depuis les serveurs de mise à jour de Kaspersky Lab, via le Serveur d'administration ou depuis une source de mise à jour programmée ou à la demande définie par l'utilisateur.D'utiliser les bases antivirus pour détecter et désinfecter les fichiers infectés. Kaspersky Endpoint Security recherche la présence éventuelle de menaces dans chaque fichier dans le cadre de l'analyse : le code du fichier est comparé à un code qui ressemble à une menace particulière.De surveiller l'intégrité des fichiers indiquer et de signaler les modifications. Le contrôle de l'intégrité des fichiers peut avoir lieu en mode continu ou dans le cadre d'une tâche d'analyse à la demande.De gérer le pare-feu d'un système d'exploitation et, le cas échéant, de rétablir les valeurs d'un ensemble de règles de pare-feu modifiées.De protéger vos fichiers dans des répertoires locaux accessibles via le réseau à l'aide des protocoles SMB/NFS contre le chiffrement malveillant à distance.De permettre aux utilisateurs privés des autorisations root d'administrer les fonctions de base de l'application via l'interface utilisateur graphique.De mettre à jour l'application à l'aide des paquets de mise à jour.D'administrer Kaspersky Endpoint Security à l'aide des moyens suivants :à l'aide des commandes d'administration de l'application depuis la ligne de commande ;via l'interface utilisateur graphique.via Kaspersky Security Center."," Pr&#xE9;sentation de Kaspersky Endpoint Security ","161214.htm");
Page[9]=new Array("Nouveautés","Kaspersky Endpoint Security 10 Service Pack 1 for Linux offre les fonctions et les améliorations suivantes :","Contrôle de l'intégrité des fichiersSurveille l'intégrité des fichiers indiqués et signale les modifications. Le Contrôle de l'intégrité des fichiers peut avoir lieu en temps réel ou dans le cadre d'une tâche d'analyse à la demande.","Gestion du pare-feuVous permet de gérer le pare-feu d'un système d'exploitation et, le cas échéant, de rétablir un ensemble de règles de pare-feu modifiées.","Anti-CryptorProtège vos fichiers dans des répertoires locaux accessibles via le réseau à l'aide des protocoles SMB/NFS contre le chiffrement malveillant à distance.","Interface utilisateur graphiquePermet aux utilisateurs non root d'administrer les fonctions de base de l'application via l'interface utilisateur graphique.","Mises à jour de l'applicationVous pouvez mettre à jour l'application à l'aide des paquets de mise à jour.","L'utilitaire kesl-control se trouve désormais dans le répertoire système /usr/bin."," Nouveaut&#xE9;s ","162018.htm");
Page[10]=new Array("Distribution","Le kit de distribution de Kaspersky Endpoint Security contient les fichiers suivants :","kesl-10.1.0-<numéro de version>.i386.rpm, kesl_10.1.0-<numéro de version>_i386.debIls contiennent les fichiers principaux de Kaspersky Endpoint Security. Ces paquets peuvent être installés sur des systèmes d'exploitation de 32 bits conformément au type de gestionnaire de paquet.","kesl-10.1.0-<numéro de version>.x86_64.rpm, kesl_10.1.0-<numéro de version>_amd64.debIls contiennent les fichiers principaux de Kaspersky Endpoint Security. Ces paquets peuvent être installés sur des systèmes d'exploitation de 64 bits conformément au type de gestionnaire de paquet.","kesl.zipContient les fichiers utilisés dans la procédure d'installation à distance de Kaspersky Endpoint Security à l'aide de Kaspersky Security Center.","klnagent-<numéro de version>.i386.rpm, klnagent_<numéro de version>_i386.deb, klnagent64-<numéro de version>.x86_64.rpm, klnagent64_<numéro de version>_amd64.debIls contiennent l'Agent d'administration (l'utilitaire de communication entre Kaspersky Endpoint Security et Kaspersky Security Center.","klnagent-rpm.tar.gz, klnagent-deb.tar.gzIls contiennent les fichiers klnagent.kpd et akinstall.sh utilisés dans la procédure d'installation à distance de l'Agent d'administration à l'aide de Kaspersky Security Center.","Le fichier ksn_license.<ID de la langue> qui vous permet de prendre connaissance des conditions de participation à Kaspersky Security Network.Le fichier license.<ID de la langue> qui permet de prendre connaissance du Contrat de licence utilisateur final. Le Contrat de licence utilisateur final indique les conditions dans le cadre desquelles vous pouvez utiliser l'application."," Distribution ","161216.htm");
Page[11]=new Array("Configurations logicielle et matérielle","Afin de garantir le fonctionnement de Kaspersky Endpoint Security, l'ordinateur doit posséder la configuration minimum suivante :","Configuration minimale requise :","processeur Core™ 2 Duo 1,86 GHz ou supérieur ;1 Go de mémoire vive pour les systèmes d'exploitation de 32 bits ;2 Go de mémoire vive pour les systèmes d'exploitation de 64 bits ;un secteur de pagination d'au moins 1 Go ;1 Go d'espace libre sur le disque dur.Configuration logicielle :","Systèmes d'exploitation 32 bits pris en charge :Red Hat® Enterprise Linux® 6.9 ;CentOS-6.9 ;Ubuntu Server 14.04.5 LTS ;Ubuntu Server 16.04.5 LTS ;Ubuntu Server 17.10.1 LTS ;Debian GNU/Linux 7, toutes les éditions (l'interface utilisateur graphique n'est pas prise en charge)Debian GNU/Linux 8.10 ;Debian GNU/Linux 9.3 ;Systèmes d'exploitation 64 bits pris en charge :Red Hat Enterprise Linux 6.9 ;Red Hat Enterprise Linux 7.4 ;CentOS-6.9 ;CentOS-7.4 ;Ubuntu Server 14.04.5 LTS ;Ubuntu Server 16.04.5 LTS ;Ubuntu Server 17.10.1 LTS ;Debian GNU/Linux 7, toutes les éditions (l'interface utilisateur graphique n'est pas prise en charge)Debian GNU/Linux 8.10 ;Debian GNU/Linux 9.3 ;openSUSE 42.3 ;SUSE Linux Enterprise Server 12.3 ;Novell OES2015, toutes les éditions (l'interface utilisateur graphique n'est pas prise en charge)Oracle Linux 7.4 ;Interpréteur de langage Perl version 5.10 ou suivante.Utilitaire which ;Paquets pour compiler les applications (gcc, binutils, glibc, glibc-devel, make, ld) ;Code source du noyau du système d'exploitation, afin de compiler les modules de Kaspersky Endpoint Security sur les systèmes d'exploitation qui ne sont pas compatibles avec la technologie fanotify.Kaspersky Endpoint Security 10 for Linux est compatible avec Kaspersky Security Center 10 SP1 et Kaspersky Security Center 10 SP2.Pour garantir le bon fonctionnement du plug-in d'administration de Kaspersky Endpoint Security, Microsoft® Visual C ++ 2015 Redistributable Update 3 RC doit être installé.Avant d'installer l'Agent d'administration, il faut installer les modules suivants :Le module libc6-i386 doit être installé sur les versions 64 bits de Debian et Ubuntu.Le module glibc.i686 doit être installé sur Red Hat Enterprise Linux 7 et suivant, CentOS 6 et suivant, ainsi que sur Oracle Linux 7 et suivant et Novel.Le module glibc 32 bit doit être installé sur openSUSE 42.2, CentOS 6 et suivant et Novel."," Configurations logicielle et mat&#xE9;rielle ","161217.htm");
Page[12]=new Array("Installation de l'application","Cette section explique comment installer le paquet d'installation (ci-après, le \"paquet\") de Kaspersky Endpoint Security et de l'Agent d'administration.","Dans cette sectionPrésentation de l'installation de Kaspersky Endpoint SecurityInstallation du paquet de Kaspersky Endpoint SecurityConfiguration initiale des paramètres de Kaspersky Endpoint SecurityMode automatique de configuration initiale de Kaspersky Endpoint SecurityInstallation de Kaspersky Endpoint Security à l'aide de Kaspersky Security CenterInstallation de l'Agent d'administrationMise à niveau d'une ancienne version de l'applicationConfiguration des règles d'autorisation dans le système SELinuxConfiguration des règles d'autorisation dans le système AppArmor"," Installation de l&apos;application ","161219.htm");
Page[13]=new Array("Présentation de l'installation de Kaspersky Endpoint Security","Kaspersky Endpoint Security est diffusé sous forme de paquets aux formats DEB et RPM.","Pour pouvoir utiliser Kaspersky Endpoint Security, il faut réaliser les opérations suivantes :","installer le paquet de Kaspersky Endpoint Security ;lancer le script de mise à jour des paramètres ;installer le paquet de l'Agent d'administration et le plug-in d'administration de Kaspersky Endpoint Security, en cas d'intention d'administrer Kaspersky Endpoint Security à l'aide de Kaspersky Security Center.L'accès aux fichiers de l'application et aux répertoires durant l'installation et le téléchargement et l'application de la mise à jour de l'application requièrent l'autorisation root."," Pr&#xE9;sentation de l&apos;installation de Kaspersky Endpoint Security ","161220.htm");
Page[14]=new Array("Installation du paquet de Kaspersky Endpoint Security","Kaspersky Endpoint Security est diffusé sous forme de paquets aux formats DEB et RPM.","Pour installer Kaspersky Endpoint Security depuis un paquet au format RPM sur un système d'exploitation 32 bits, exécutez la commande suivante :","# rpm -i kesl-10.1.0-<numéro de version>.i386.rpm","Pour installer Kaspersky Endpoint Security depuis un paquet au format RPM sur un système d'exploitation 64 bits, exécutez la commande suivante :","# rpm -i kesl-10.1.0-<numéro de version>.x86_64.rpm","Pour installer Kaspersky Endpoint Security depuis un paquet au format DEB sur un système d'exploitation 32 bits, exécutez la commande suivante :","# dpkg -i kesl-10.1.0-<numéro de version>_i386.deb","Pour installer Kaspersky Endpoint Security depuis un paquet au format DEB sur un système d'exploitation 64 bits, exécutez la commande suivante :","# dpkg -i kesl_10.1.0-<numéro de version>_amd64.deb"," Installation du paquet de Kaspersky Endpoint Security ","161221.htm");
Page[15]=new Array("Configuration initiale des paramètres de Kaspersky Endpoint Security","Après l'installation de Kaspersky Endpoint Security, il faut lancer le script de configuration post-installation de Kaspersky Endpoint Security. Le script de configuration de Kaspersky Endpoint Security après l'installation figure dans le paquet de Kaspersky Endpoint Security.","Si vous ne réalisez pas la procédure de configuration initiale de Kaspersky Endpoint Security, la protection antivirus de l'ordinateur ne fonctionne pas.","Pour lancer manuellement le script de configuration post-installation de Kaspersky Endpoint Security, exécutez la commande suivante :","# /opt/kaspersky/kesl/bin/kesl-setup.pl","Le script de configuration après l'installation requiert de Kaspersky Endpoint Security des valeurs de paramètres étape par étape.","Le script de configuration post-installation de Kaspersky Endpoint Security doit être lancé sous les autorisations root après la fin de l'installation du paquet de Kaspersky Endpoint Security.","Vous pouvez réaliser une mise à niveau depuis Kaspersky Endpoint Security 10 for Linux jusqu'à Kaspersky Endpoint Security 10 Service Pack 1 for Linux. ","Il est impossible de réaliser une mise à niveau de Kaspersky Anti-Virus 8.0 for Linux File Server vers Kaspersky Endpoint Security 10 Service Pack 1 for Linux. Il faut supprimer la version antérieure de l'application avant d'installer Kaspersky Endpoint Security 10 Service Pack 1 for Linux."," Configuration initiale des param&#xE8;tres de Kaspersky Endpoint Security ","161222.htm");
Page[16]=new Array("Etape 1. Sélection de la locale","Cette étape correspond à la définition de la locale utilisée par Kaspersky Endpoint Security.","Vous pouvez désigner la locale au format défini dans RFC 3066.","Pour obtenir la liste complète des valeurs de locales, exécutez la commande suivante :","# locale -a","L'application propose d'utiliser par défaut la locale définie pour root."," Etape 1. S&#xE9;lection de la locale ","161223.htm");
Page[17]=new Array("Etape 2. Acceptation du Contrat de licence utilisateur final","Cette étape correspond à l'acceptation ou au rejet des conditions du Contrat de licence utilisateur final.","Vous pouvez consulter le texte à l'aide de l'utilitaire less. Pour naviguer dans texte, utilisez les touches de direction du curseur ou les touches B (pour revenir à l'écran antérieur) et F (pour passer à l'écran suivant). Pour obtenir l'aide, appuyez sur la touche H. Pour quitter la consultation, appuyez sur la touche Q.","Après avoir quitté le mode de consultation, saisissez une des valeurs suivantes :","• yes (ou y), si vous acceptez les conditions du Contrat de licence utilisateur final.• no (ou n), si vous refusez les conditions du Contrat de licence utilisateur final.Si vous refusez les conditions du Contrat de licence utilisateur final, l'application interrompt le processus de configuration de Kaspersky Endpoint Security."," Etape 2. Acceptation du Contrat de licence utilisateur final ","161224.htm");
Page[18]=new Array("Etape 3. Acceptation de la Politique de confidentialité","Cette étape correspond à l'acceptation ou au rejet des conditions de la Politique de confidentialité.","Vous pouvez consulter le texte à l'aide de l'utilitaire less. Pour naviguer dans texte, utilisez les touches de direction du curseur ou les touches B (pour revenir à l'écran antérieur) et F (pour passer à l'écran suivant). Pour obtenir l'aide, appuyez sur la touche H. Pour quitter la consultation, appuyez sur la touche Q.","Après avoir quitté le mode de consultation, saisissez une des valeurs suivantes :","oui (ou o) si vous acceptez la Politique de confidentialité.non (ou n) si vous n'acceptez pas la Politique de confidentialité.Si vous refusez la Politique de confidentialité, l'application interrompt le processus de configuration de Kaspersky Endpoint Security."," Etape 3. Acceptation de la Politique de confidentialit&#xE9; ","166206.htm");
Page[19]=new Array("Etape 4. Participation au Kaspersky Security Network","Cette étape correspond à l'acceptation ou au rejet des conditions de la Déclaration de Kaspersky Security Network. Le fichier contenant le texte de la Déclaration de Kaspersky Security Network se trouve dans le répertoire /opt/kaspersky/kesl/doc/ksn_license.<ID de la langue>.","Saisissez une des valeurs suivantes :","yes (ou y), si vous acceptez les conditions de la Déclaration de Kaspersky Security Network ; Le mode étendu de Kaspersky Security Network est activé. no (ou n), si vous refusez les conditions de la Déclaration de Kaspersky Security Network.Le rejet d'une participation au Kaspersky Security Network n'entraîne pas l'arrêt de l'installation de Kaspersky Endpoint Security. Vous pouvez activer, désactiver ou modifier le mode de Kaspersky Security Network à tout moment."," Etape 4. Participation au Kaspersky Security Network ","161225.htm");
Page[20]=new Array("Etape 5. Définition du type d'intercepteur des opérations sur les fichiers","Cette étape correspond à la définition du type d'intercepteur des opérations de fichier pour le système d'exploitation utilisé. Pour les systèmes d'exploitation qui ne prennent pas en charge la technologie fanotify, la compilation du module du noyau est lancée. Le module du noyau est requis pour le fonctionnement de la tâche de protection en temps réel.","Pour pouvoir compiler le module de noyau, le fichier System.map-<version du noyau> doit se trouver dans le répertoire /boot.","Si le script détecte les codes sources du module noyau du système d'exploitation dans le répertoire par défaut, l'application utilise le chemin d'accès à ce répertoire. Dans le cas contraire, il convient d'indiquer le chemin d'accès au code source du module noyau.","Si les paquets requis ne sont pas détectés lors de la compilation du module noyau, Kaspersky Endpoint Security tente de les télécharger lui-même. En cas d'échec du téléchargement des paquets, un message d'erreur s'affiche.","Il est possible de compiler le module du noyau plus tard, après la configuration initiale de Kaspersky Endpoint Security."," Etape 5. D&#xE9;finition du type d&apos;intercepteur des op&#xE9;rations sur les fichiers ","161226.htm");
Page[21]=new Array("Etape 6. Chargement des bases antivirus de Kaspersky Endpoint Security","Cette étape correspond au téléchargement des bases antivirus de Kaspersky Endpoint Security sur l'ordinateur. Les bases antivirus contiennent les descriptions des signatures des menaces et les méthodes de lutte contre celles-ci. Kaspersky Endpoint Security utilise ces enregistrements pour détecter et neutraliser les menaces. Les experts antivirus de Kaspersky Lab ajoutent régulièrement des enregistrements sur les nouvelles menaces.","Pour télécharger les bases antivirus de Kaspersky Endpoint Security sur l'ordinateur, vous devez saisir la réponse yes.","Saisissez no si vous souhaitez refuser le téléchargement immédiat des bases antivirus.","La réponse proposée par défaut est yes.","L'application garantit la protection antivirus de l'ordinateur uniquement après le téléchargement des bases antivirus de Kaspersky Endpoint Security.","Vous pouvez lancer une tâche de mise à jour sans utiliser le script de configuration initiale."," Etape 6. Chargement des bases antivirus de Kaspersky Endpoint Security ","161228.htm");
Page[22]=new Array("Etape 7. Configuration des paramètres du serveur proxy","Dans le cadre de cette étape, vous devez définir les paramètres du serveur proxy si vous accédez à Internet via un tel serveur. La connexion à Internet est nécessaire pour pouvoir télécharger les bases antivirus de Kaspersky Endpoint Security depuis les serveurs de mise à jour.","Pour configurer le serveur proxy, exécutez une des actions suivantes :","Si la connexion à Internet s'opère via un serveur proxy, indiquez l'adresse de ce dernier dans un des formats suivants :adresse_IP_du_serveur_proxy:port si l'authentification n'est pas requise lors de la connexion au serveur proxy ;nom_de_l'utilisateur:mot_de_passe@adresse_IP_du_serveur_proxy:port si l'authentification est requise pour la connexion au serveur proxy.Si la connexion à Internet s'opère sans serveur proxy, introduisez la réponse no.","L'application propose par défaut la réponse no.","Vous pouvez configurer les paramètres de proxy serveur sans utilisation du script de la configuration initiale."," Etape 7. Configuration des param&#xE8;tres du serveur proxy ","161227.htm");
Page[23]=new Array("Etape 8. Activation de la mise à jour automatique des bases antivirus","Cette étape correspond à l'activation de la mise à jour automatique des bases antivirus.","Saisissez la réponse yes pour activer la mise à jour automatique des bases antivirus. Kaspersky Endpoint Security recherche la présence éventuelle de mises à jour pour les bases antivirus toutes les 60 minutes par défaut. Si des mises à jour des bases antivirus sont disponibles, Kaspersky Endpoint Security les télécharge.","Saisissez la réponse no si vous ne souhaitez pas que Kaspersky Endpoint Security mette à jour automatiquement les bases antivirus.","Vous pouvez activer les mises à jour des bases antivirus sans utiliser le script de configuration initiale en gérant la planification de la tâche de mise à jour."," Etape 8. Activation de la mise &#xE0; jour automatique des bases antivirus ","161229.htm");
Page[24]=new Array("Etape 9. Activation de l'application","Cette étape correspond à l'activation de l'application à l'aide du code d'activation ou du fichier clé.","Pour activer l'application à l'aide du code d'activation, il faut saisir le code d'activation.","Pour activer l'application à l'aide du fichier clé, il faut indiquer le chemin d'accès complet au fichier clé.","Si le code d'activation ou le fichier clé ne sont pas indiqués, l'application est activée à l'aide de la clé d'évaluation pour un mois.","Vous pouvez installer le fichier de licence sans utilisation du script de la configuration initiale."," Etape 9. Activation de l&apos;application ","161230.htm");
Page[25]=new Array("Etape 10. Configuration de l'interface utilisateur graphique","Cette étape permet d'activer l'utilisation de l'interface utilisateur graphique (GUI).","Définissez une des valeurs suivantes :","yes (ou y) si vous souhaitez activer l'utilisation de l'interface graphique utilisateur. Kaspersky Endpoint Security vérifie toutes les bibliothèques requises et le cas échéant, tente d'installer les bibliothèques manquantes.no (ou n) si vous ne souhaitez pas activer l'utilisation de l'interface utilisateur graphique.Vous pouvez activer ou désactiver l'utilisation de l'interface utilisateur graphique à tout moment."," Etape 10. Configuration de l&apos;interface utilisateur graphique ","161231.htm");
Page[26]=new Array("Mode automatique de configuration initiale de Kaspersky Endpoint Security","Vous pouvez réaliser la configuration initiale de Kaspersky Endpoint Security en mode automatique. L'application applique les valeurs des paramètres indiquées dans le fichier de configuration de la configuration initiale.","Pour lancer la configuration initiale de Kaspersky Endpoint Security en mode automatique, exécutez la commande suivante :","kesl-setup.pl --autoinstall=<chemin d'accès complet au fichier de configuration initiale>"," Mode automatique de configuration initiale de Kaspersky Endpoint Security ","161232.htm");
Page[27]=new Array("Paramètres du fichier de configuration de la configuration initiale de  Kaspersky Endpoint Security","Le fichier de configuration de la configuration initiale de Kaspersky Endpoint Security contient les paramètres repris dans le tableau ci-dessous.","Paramètres du fichier de configuration de la configuration initiale de  Kaspersky Endpoint Security","Paramètre","Description","Valeurs possibles :","EULA_AGREED","Paramètre obligatoire","Acceptation du Contrat de licence utilisateur final","yes : pour continuer la procédure d'installation, il faut accepter les dispositions du Contrat de licence utilisateur final.","no - Refus du Contrat de licence utilisateur final Cela entraîne l'interruption de l'installation de l'application.","PRIVACY_POLICY_AGREED","Paramètre obligatoire","Acceptation de la Politique de confidentialité","Oui : vous acceptez la Politique de confidentialité pour poursuivre la procédure d'installation de l'application","Non : vous n'acceptez pas la Politique de confidentialité. Cela entraîne l'interruption de l'installation de l'application.","USE_KSN","Acceptation de la Déclaration de Kaspersky Security Network","yes : acceptation de la Déclaration de Kaspersky Security Network","no : refus de la Déclaration de Kaspersky Security Network","SERVICE_LOCALE","Paramètre facultatif","Locale utilisée lors de l'utilisation de Kaspersky Endpoint Security","La locale au format défini par la norme RFC 3066.","Si le paramètre SERVICE_LOCALE n'est pas défini, la locale du système est utilisée par défaut.","INSTALL_LICENSE","Code d'activation ou fichier clé","—","UPDATER_SOURCE","Source des mises à jour","SCServer : le serveur d'administration Kaspersky Security Center est la source des mises à jourKLServers : les serveurs de Kaspersky Lab sont la source des mises à jouradresse de la source des mises à jour.","PROXY_SERVER","Adresse du serveur proxy à utiliser pour la connexion à Internet","adresse du serveur proxyno : ne pas utiliser de serveur proxy","UPDATE_EXECUTE","Lancer la mise à jour des bases de données lors de l'installation","yes : lancer la tâche de mise à journo : ne pas lancer la tâche de mise à jour.","KERNEL_SRCS_INSTALL","Lancement automatique de la compilation du module du noyau","yes : compiler le module du noyauno : ne pas compiler le module du noyau.","USE_GUI","Activer l'utilisation de l'interface utilisateur graphique","yes : activer l'utilisation de l'interface utilisateur graphiqueno : désactiver l'utilisation de l'interface utilisateur graphique","IMPORT_SETTINGS","Utiliser les paramètres de l'application repris dans un fichier de configuration ","yes : utiliser les paramètres de l'application repris dans un fichier de configurationno : ne pas utiliser les paramètres de l'application repris dans un fichier de configuration","Si vous voulez modifier les paramètres dans le fichier de configuration de la configuration initiale de Kaspersky Endpoint Security, saisissez les valeurs des paramètres au format nom du paramètre=valeur_du_paramètre (l'application ne traite pas les espaces entre le nom du paramètre et sa valeur)."," Param&#xE8;tres du fichier de configuration de la configuration initiale de  Kaspersky Endpoint Security ","161233.htm");
Page[28]=new Array("Installation de Kaspersky Endpoint Security à l'aide de Kaspersky Security Center","Vous pouvez installer Kaspersky Endpoint Security sur l'ordinateur à l'aide de Kaspersky Security Center.","Pour en savoir plus sur ce type d'installation de l'application, lisez la documentation de Kaspersky Security Center."," Installation de Kaspersky Endpoint Security &#xE0; l&apos;aide de Kaspersky Security Center ","161234.htm");
Page[29]=new Array("Installation de l'Agent d'administration","L'installation de l'Agent d'administration est requise si vous envisagez d'administrer Kaspersky Endpoint Security à l'aide de Kaspersky Security Center.","Il faut posséder les autorisations root pour lancer l'installation de l'Agent d'administration.","Pour installer l'Agent d'administration depuis un paquet au format RPM sur un système d'exploitation 32 bits, exécutez la commande suivante :","# rpm -i klnagent-<numéro de version>.i386.rpm","Pour installer l'Agent d'administration depuis un paquet au format RPM sur un système d'exploitation 64 bits, exécutez la commande suivante :","# rpm -i klnagent64-<numéro de version>.x86_64.rpm","Pour installer l'Agent d'administration depuis un paquet au format DEB sur un système d'exploitation 32 bits, exécutez la commande suivante :","# dpkg -i klnagent_<numéro de version>_i386.deb","Pour installer l'Agent d'administration depuis un paquet au format DEB sur un système d'exploitation 64 bits, exécutez la commande suivante :","# dpkg -i klnagent64_<numéro de version>_amd64.deb","Une fois que le paquet a été installé, lancez le script de configuration post-installation de Kaspersky Endpoint Security en exécutant la commande suivante :","pour un système d'exploitation 32 bits :/opt/kaspersky/klnagent/lib/bin/setup/postinstall.pl","pour un système d'exploitation 64 bits :/opt/kaspersky/klnagent64/lib/bin/setup/postinstall.pl"," Installation de l&apos;Agent d&apos;administration ","161235.htm");
Page[30]=new Array("Configuration initiale des paramètres de l'Agent d'administration","Si vous envisagez d'administrer Kaspersky Endpoint Security à l'aide de Kaspersky Security Center, il faut configurer les paramètres de l'Agent d'administration.","Pour configurer les paramètres de l'Agent d'administration, procédez comme suit :","Exécutez la commande :pour un système d'exploitation 32 bits :# /opt/kaspersky/klnagent/lib/bin/setup/postinstall.pl","pour un système d'exploitation 64 bits :# /opt/kaspersky/klnagent64/lib/bin/setup/postinstall.pl","Indiquez le nom DNS ou l'adresse IP du Serveur d'administration.Indiquez le numéro de port du Serveur d'administration.Par défaut, le port 14000 est utilisé.","Si vous voulez utiliser une connexion SSL, indiquez le numéro du port SSL du Serveur d'administration.Par défaut, le port 13000 est utilisé.","Exécutez une des actions suivantes :Saisissez yes si vous voulez utiliser une connexion SSL.Saisissez no si vous ne voulez pas utiliser de connexion SSL.La connexion SSL est activée par défaut.","Le cas échéant, définissez le mode de passerelle de connexion :0 : ne pas utiliser de passerelle de connexion.1 : utiliser cet Agent d'administration en tant que passerelle de connexion.2 : se connecter au Serveur d'administration via une passerelle de connexion.Pour obtenir de plus amples informations sur la configuration de l'Agent d'administration, consultez la documentation de Kaspersky Security Center."," Configuration initiale des param&#xE8;tres de l&apos;Agent d&apos;administration ","161236.htm");
Page[31]=new Array("Mise à niveau d'une ancienne version de l'application","Il est possible de passer de Kaspersky Endpoint Security 10 for Linux à Kaspersky Endpoint Security 10 Service Pack 1 for Linux. ","Vous pouvez réaliser la mise à niveau depuis la version antérieure de la manière suivante :","localement, via la ligne de commande ;A distance : à l'aide de la suite logicielle Kaspersky Security Center (cf. la documentation de Kaspersky Security Center)Lors de la mise à niveau depuis une version antérieure de l'application vers Kaspersky Endpoint Security 10 Service Pack 1 for Linux, vous n'avez pas besoin de supprimer la version antérieure. Il est conseillé de quitter toutes les applications en cours d'exécution avant de réaliser la mise à niveau depuis une version antérieure."," Mise &#xE0; niveau d&apos;une ancienne version de l&apos;application ","161237.htm");
Page[32]=new Array("Mise à niveau de l'application via la ligne de commande","Vous pouvez réaliser la mise à niveau de Kaspersky Endpoint Security 10 for Linux à Kaspersky Endpoint Security 10 Service Pack 1 for Linux localement en suivant la procédure ci-dessous.","Un redémarrage du système d'exploitation ou de l'application peut être requis à l'issue de la procédure de mise à niveau.","Pour mettre l'application à niveau :","Exécutez le paquet d'installation de Kaspersky Endpoint Security 10 Service Pack 1 for Linux requis.Kaspersky Endpoint Security 10 for Linux est arrêté et les paramètres de l'application et le journal des événements sont exportés.","Exécutez le script de configuration post-installation.Le script de configuration post-installation sollicite les valeurs des paramètres de Kaspersky Endpoint Security étape par étape.","Vous devez accepter les dispositions du Contrat de licence utilisateur final et de la politique de confidentialité.","Les paramètres de l'application et le journal des événements sont transférés à la version mise à niveau de l'application ; les nouveaux paramètres prennent la valeur par défaut. Lorsque les paramètres de l'application sont transférés, l'application s'arrête.","Le cas échéant, redémarrez l'ordinateur ou l'application.En cas d'erreur lors de la mise à niveau, il est impossible de restaurer automatiquement la version antérieure de l'application. Un message d'erreur s'affiche.","Si le transfert des paramètres de l'application échoue pour une raison ou une autre, l'application est définie sur les valeurs par défaut."," Mise &#xE0; niveau de l&apos;application via la ligne de commande ","165607.htm");
Page[33]=new Array("Mise à niveau de l'application via Kaspersky Security Center","Vous pouvez réaliser la mise à niveau à distance de Kaspersky Endpoint Security 10 for Linux à Kaspersky Endpoint Security 10 Service Pack 1 for Linux via Kaspersky Security Center en suivant la procédure suivante.","Pour mettre à niveau une application administrée par une stratégie de Kaspersky Security Center :","Mettez à niveau l'agent d'administration.Si l'Agent d'administration n'a pas été mis à niveau, il est impossible d'administrer l'application via Kaspersky Security Center.","L'application fonctionne correctement lors de la mise à niveau de l'agent d'administration.","Installez à distance Kaspersky Endpoint Security 10 Service Pack 1 for Linux.Pour en savoir plus sur ce type de mise à niveau de l'application, lisez la documentation de Kaspersky Security Center."," Mise &#xE0; niveau de l&apos;application via Kaspersky Security Center ","165608.htm");
Page[34]=new Array("Configuration des règles d'autorisation dans le système SELinux","Pour créer le module SELinux avec les règles indispensables au fonctionnement de Kaspersky Endpoint Security, procédez comme suit :","Placez SELinux en mode d'autorisation :Si SELinux a été activé, exécutez la commande suivante :# setenforce Permissive","Si SELinux était désactivé, ouvrez le fichier de configuration /etc/selinux/config, attribuez la valeur suivante au paramètre SELINUX=permissive et redémarrez le système d'exploitation.Lancez les tâches suivantes :Tâche de protection en temps réel :kesl-control --start-t 1","tâche d'analyse de la mémoire des processus :kesl-control --start-t 4 -W","tâche d'analyse des secteurs d'amorçage :kesl-control --start-t 5 -W","Créez le module des règles sur la base des enregistrements de blocage :grep kesl /var/log/audit/audit.log | audit2allow -M kesl","Assurez-vous que la liste créée contient uniquement les règles qui se rapportent à Kaspersky Endpoint Security.","Chargez le module de règles obtenu :# semodule -i kesl.pp","Placez SELinux en mode d'imposition :# setenforce Enforcing","En cas d'apparition de nouveaux messages audit relatifs à Kaspersky Endpoint Security, il faut mettre à jour le fichier du module des règles.","Pour obtenir de plus amples informations, consultez la documentation du système d'exploitation utilisé."," Configuration des r&#xE8;gles d&apos;autorisation dans le syst&#xE8;me SELinux ","161238.htm");
Page[35]=new Array("Configuration des règles d'autorisation dans le système AppArmor","Pour mettre à jour les profils AppArmor nécessaires au fonctionnement de Kaspersky Endpoint Security, procédez comme suit :","Utilisez une des méthodes suivantes pour confirmer que le module AppArmor est chargé :systemctl status apparmor/etc/init.d/apparmor statusCréez un profil Kaspersky Endpoint Security :Dans la première console, exécutez les commandes :cd /etc/apparmor.d","aa-genprof /opt/kaspersky/kesl/libexec/kesl","Dans la deuxième console, lancez les tâches suivantes :Tâche de protection en temps réel :kesl-control --start-t 1","tâche d'analyse de la mémoire des processus :kesl-control --start-t 4 -W","tâche d'analyse des secteurs d'amorçage :kesl-control --start-t 5 -W","tâche de la mise à jour :kesl-control --start-t 6 -W","Dans la première console, appuyez sur S. Une fois l'analyse de l'événement terminé, appuyez sur F.Transférez le profil Kaspersky Endpoint Security créé dans le mode d'affichage des messages :aa-complain opt.kaspersky.kesl.libexec.kesl","Après quelques jours de fonctionnement de l'application, actualisez le profil à l'aide de la commande :aa-logprof","Octroyez les autorisations Allow ou Glob à l'ensemble des fichiers que Kaspersky Endpoint Security a utilisé pendant cette période.","Transférez le profil Kaspersky Endpoint Security dans le mode de blocage :aa-enforce opt.kaspersky.kesl.libexec.kesl","En cas d'apparition de nouveaux messages audit relatifs à Kaspersky Endpoint Security, il faut mettre à jour le fichier du module des règles.","Pour obtenir de plus amples informations, consultez la documentation du système d'exploitation utilisé."," Configuration des r&#xE8;gles d&apos;autorisation dans le syst&#xE8;me AppArmor ","161239.htm");
Page[36]=new Array("Suppression de l'application","Cette section explique comment supprimer Kaspersky Endpoint Security localement ou via Kaspersky Security Center.","Dans cette sectionSuppression locale de Kaspersky Endpoint SecuritySuppression de Kaspersky Endpoint Security via Kaspersky Security Center"," Suppression de l&apos;application ","161240.htm");
Page[37]=new Array("Suppression locale de Kaspersky Endpoint Security","Pendant la suppression de l'application, toutes les tâches de Kaspersky Endpoint Security sont arrêtées.","Pour supprimer une copie de Kaspersky Endpoint Security installée à l'aide d'un paquet au format RPM, exécutez la commande suivante :","# rpm -e kesl","Pour supprimer une copie de Kaspersky Endpoint Security installée à l'aide d'un paquet au format DEB, exécutez la commande suivante :","# dpkg -r kesl","Pour supprimer l'Agent d'administration installé à l'aide d'un paquet au format RPM, exécutez la commande suivante :","# rpm -e klnagent","Pour supprimer l'Agent d'administration installé à l'aide d'un paquet au format DEB, exécutez la commande suivante :","# dpkg -r klnagent","L'application exécute automatiquement la procédure de suppression. À la fin de celle-ci, l'application affiche un message sur les résultats de la suppression.","Après la suppression de Kaspersky Endpoint Security, la base de données des licences est conservée et peut être utilisée lors de la réinstallation de l'application."," Suppression locale de Kaspersky Endpoint Security ","161241.htm");
Page[38]=new Array("Suppression de Kaspersky Endpoint Security via Kaspersky Security Center","Vous pouvez supprimer Kaspersky Endpoint Security via Kaspersky Security Center. Pour ce faire, il faut créer, puis lancer une tâche de suppression de Kaspersky Endpoint Security.","Pour en savoir plus sur la création et le lancement de la tâche de suppression de Kaspersky Endpoint Security, consultez la documentation de Kaspersky Security Center."," Suppression de Kaspersky Endpoint Security via Kaspersky Security Center ","161242.htm");
Page[39]=new Array("Licence de l'application","Cette section aborde les principaux aspects liés à la licence de l'application.","Dans cette sectionA propos du contrat de licenceA propos de la licenceA propos du certificat de licenceA propos du code d'activationA propos de la cléA propos du fichier cléA propos de l'abonnementA propos des données"," Licence de l&apos;application ","161243.htm");
Page[40]=new Array("A propos du contrat de licence","Le Contrat de licence utilisateur final est un accord juridique conclu entre vous et AO Kaspersky Lab qui prévoit les conditions d’utilisation de l’application que vous avez achetée.","Lisez attentivement le contrat de licence avant de commencer à utiliser l'application.","Vous pouvez prendre connaissance des conditions du Contrat de licence de l'une des manières suivantes :","Pendant l'installation de Kaspersky Endpoint Security.En lisant le fichier license.<ID de la langue>. Ce document est fourni dans le kit de distribution de l'application.Vous acceptez les conditions du Contrat de licence utilisateur final, en confirmant votre accord avec le texte du Contrat de licence utilisateur final lors de l'installation de l'application. Si vous n'êtes pas d'accord avec les termes du Contrat de licence utilisateur final, vous devez interrompre l'installation de l'application et ne pas l'utiliser."," A propos du contrat de licence ","161244.htm");
Page[41]=new Array("A propos de la licence","La licence est un droit d'utilisation de l'application, limité dans le temps et octroyé dans le cadre du Contrat de licence utilisateur final.","Une licence valide vous accorde le droit d'obtenir les types de service suivants :","utilisation de l'application conformément aux conditions du Contrat de licence utilisateur final ;accès au Support Technique.Le volume de services offerts et la durée d'utilisation de l'application dépendent du type de licence utilisée pour activer l'application.","Il existe différents types de licence :","Evaluation : une licence gratuite qui permet de découvrir les fonctionnalités de l'application.La durée de validité de la licence d'évaluation est courte. Une fois que la licence d'évaluation de Kaspersky Endpoint Security arrive à échéance, toutes les fonctions de l'application sont désactivées. Pour continuer à utiliser l'application, il faut acheter une licence commerciale.","Vous pouvez activer l'application à l'aide d'une licence d'évaluation une seule fois uniquement.","Commerciale : licence payante délivrée lors de l'achat de l'application.A l'expiration de la licence commerciale, l'application continue à fonctionner, mais ses fonctionnalités sont limitées (par exemple, la mise à jour des bases de données de Kaspersky Endpoint Security n'est pas disponible). Pour pouvoir profiter de toutes les fonctionnalités de Kaspersky Endpoint Security, il faut renouveler la licence commerciale.","Il est conseillé de renouveler la durée de validité de la licence avant sa date d'expiration afin de garantir la protection antivirus maximale contre les menaces informatiques."," A propos de la licence ","161245.htm");
Page[42]=new Array("A propos du certificat de licence","Le Certificat de licence est un document qui vous est transmis avec le fichier clé ou le code d'activation.","Le Certificat de licence comporte les informations suivantes à propos de la licence :","numéro de la commande ;informations relatives à l'utilisateur qui reçoit la licence ;informations relatives à l'application qui peut être activée à l'aide de la licence octroyée ;restrictions associées au niveau du nombre (par exemple, le nombre d'appareils sur lesquels la licence permet l'utilisation de l'application) ;début de validité de la licence ;date d'expiration de la licence ou de l'abonnement ou durée de validité de la licence ;type de licence."," A propos du certificat de licence ","161246.htm");
Page[43]=new Array("A propos du code d'activation","Le code d'activation est une suite unique de 20 caractères alphanumériques (alphabet latin). Vous le saisissez pour ajouter une clé qui active Kaspersky Endpoint Security. Le code d'activation est envoyé à l'adresse email que vous avez indiquée à l'achat de Kaspersky Endpoint Security ou lors de la commande de la version d'essai de Kaspersky Endpoint Security.","Pour activer l'application avec un code d'activation, il est nécessaire de disposer d'un accès Internet en vue de se connecter aux serveurs d'activation Kaspersky Lab.","En cas de perte du code d'activation après l'activation de l'application, il est possible de le récupérer. Par exemple, vous pourriez avoir besoin du code d'activation pour créer un compte Kaspersky CompanyAccount. Pour récupérer le code d'activation, contactez le Support Technique de Kaspersky Lab."," A propos du code d&apos;activation ","161247.htm");
Page[44]=new Array("A propos de la clé","La clé est une séquence de bits qui permet d'activer, puis d'utiliser l'application conformément aux conditions du Contrat de licence utilisateur final. La clé est créée par Kaspersky Lab.","Pour ajouter une clé à l'application, utilisez une des méthodes suivantes : appliquer un fichier clé ou saisir un code d'activation. La clé apparaît dans l'interface de l'application sous la forme d'une séquence de caractères alpha-numériques unique une fois que vous l'avez ajoutée à l'application.","Kaspersky Lab peut ajouter une clé à une liste noire en cas de non-respect du Contrat de licence utilisateur final. Si cela se produit, il faudra ajouter une autre clé pour pouvoir utiliser l'application.","Il existe deux types de clé : active et additionnelle.","La clé active est une clé utilisée actuellement pour faire fonctionner l'application. Une clé active peut être une clé de licence commerciale ou d'évaluation. L'application ne peut comporter qu'une seule clé active.","Une clé additionnelle est une clé qui confirme le droit d'utilisation de l'application, mais qui n'est pas utilisée en ce moment. La clé additionnelle s'active automatiquement lorsque la durée de validité de la licence associée à la clé active expire. La clé additionnelle ne peut être ajoutée qu'en présence d'une clé active.","La clé de la licence d'évaluation peut uniquement être ajoutée en tant que clé active. Elle ne sera pas acceptée en tant que clé additionnelle."," A propos de la cl&#xE9; ","161248.htm");
Page[45]=new Array("A propos du fichier clé","Le fichier clé est un fichier portant l'extension key et qui est fourni par Kaspersky Lab. Les fichiers clé permettent d'activer l'application via l'ajout d'une clé.","Le fichier clé est envoyé à l'adresse email que vous avez indiquée à l'achat de Kaspersky Endpoint Security ou à la commande de la version d'essai de Kaspersky Endpoint Security.","Pour activer l'application à l'aide du fichier clé, il n'est pas nécessaire de se connecter aux serveurs d'activation Kaspersky Lab.","Si le fichier clé a été supprimé par accident, vous pouvez le récupérer. Le fichier clé peut vous être utile pour vous inscrire sur Kaspersky CompanyAccount.","Afin de récupérer le fichier clé, réalisez une des opérations suivantes :","contacter le Support Technique (http://support.kaspersky.fr) ;obtenir un fichier clé via le site Internet de Kaspersky Lab () grâce à votre code d'activation."," A propos du fichier cl&#xE9; ","161249.htm");
Page[46]=new Array("A propos de l'abonnement","L'abonnement à Kaspersky Endpoint Security est un bon de commande pour l'application avec des paramètres définis (date d'expiration de l'abonnement, nombre d'appareils protégés). Vous pouvez commander un abonnement pour Kaspersky Endpoint Security auprès de votre prestataire de services (par exemple, votre FAI). Vous pouvez renouveler l'abonnement manuellement ou automatiquement. Vous pouvez également l'annuler. Vous pouvez administrer l'abonnement sur le site du prestataire de services.","L'abonnement peut être limité (à un an par exemple) ou illimité (sans date d'expiration). Pour prolonger le fonctionnement de Kaspersky Endpoint Security après la date d'expiration d'un abonnement limité, il est nécessaire de renouveler ce dernier. L'abonnement illimité se renouvelle automatiquement si le montant dû au prestataire de services est versé dans les délais.","S'agissant des abonnements limités, il se peut que vous bénéficiez d'une période de grâce pour le renouvellement. Au cours de cette période, l'application conserve ses fonctions. C'est le prestataire de services qui décide d'octroyer ou non une période de grâce et en cas d'octroi, il détermine la durée.","Pour utiliser Kaspersky Endpoint Security selon un abonnement, il faut saisir le code d'activation fourni par le prestataire de services. Après que le code d'activation a été appliqué, la clé active est installée. Celle-ci définit la licence d'utilisation de l'application selon un abonnement. Il est possible d'installer une clé additionnelle uniquement à l'aide d'un code d'activation et non pas à l'aide d'un fichier clé ou d'un abonnement.","Les fonctions de l'application disponibles sur abonnement correspondent aux fonctions de l'application sous une des licences commerciales suivantes : Standard, Kaspersky Business Space Security, Kaspersky Enterprise Space Security. Ces types de licence sont conçus pour protéger les serveurs de fichiers, les postes de travail, les appareils mobiles et permettent l'utilisation de modules de contrôle sur les postes de travail et les appareils mobiles.","Le choix des possibilités de gestion de l'abonnement varie selon les prestataires de services. Le prestataire de services peut ne pas proposer de période de grâce où l'application continue à fonctionner après la date d'expiration de l'abonnement.","Les codes d'activation achetés par abonnement ne peuvent pas être utilisés pour l'activation de versions antérieures de Kaspersky Endpoint Security."," A propos de l&apos;abonnement ","161250.htm");
Page[47]=new Array("A propos des données","En acceptant le Contrat de licence utilisateur final, vous acceptez de transférer automatiquement les informations sur votre utilisation du produit, ainsi que le type, la version et la localisation de l'application installée, l'identifiant unique du programme d'installation et le type d'installation, ainsi que les données sur les clés actives et additionnelles (y compris le type de licence, la période de validité, la date d'activation de l'application et la date d'expiration de la licence, le numéro de licence, l'état actuel de la licence, la version du protocole d'interaction du serveur d'activation).","En acceptant les conditions de la Déclaration de Kaspersky Security Network, vous acceptez également de transmettre automatiquement les informations suivantes :","L'identifiant et la version de la Déclaration de Kaspersky Security Network que vous avez accepté(e) ou rejeté(e).Informations sur l'acceptation ou le rejet de la Déclaration de Kaspersky Security Network.Date et heure où la Déclaration de Kaspersky Security Network a été acceptée ou rejetée.Informations sur Kaspersky Security Network sans le choix des options statistiques.Informations sur Kaspersky Security Network avec le choix des options statistiques.Identifiants uniques d'un ordinateur et d'un utilisateur, version complète de l'application, et type d'application.Si l'application doit être activée à l'aide d'un code d'activation, pour recevoir les informations statistiques sur la distribution et l'utilisation des produits du Titulaire de la licence, vous acceptez de fournir automatiquement la version de l'application utilisées (y compris les informations sur les mises à jour de l'application installée, l'identifiant d'installation de l'application, et des informations sur les licences), la version du système d'exploitation, et les identifiants des volets de l'application actifs au moment où les informations sont fournies.","Kaspersky Lab protègent toutes les informations ainsi reçues conformément à la loi et aux règles applicables de Kaspersky Lab.","Kaspersky Lab utilise les informations obtenues uniquement de manière impersonnelle et sous forme de statistiques. Les statistiques générales sont automatiquement à partir des informations source reçues, et ne contiennent aucune données personnelles ou autres données confidentielles. Les informations obtenues sont supprimées au fur et à mesure de leur accumulation (une fois par an). Les statistiques générales sont conservées pour une durée indéterminée.","Pour en savoir plus sur l'obtention, le traitement, la conservation et la suppression des informations relatives à l'utilisation de l'application après l'acceptation du Contrat de licence utilisateur final et l'adhésion de la Déclaration KSN, lisez le contenu de ce dernier ou rendez-vous sur le site Internet de Kaspersky Lab. Les fichiers license.<ID de la langue> et ksn_license.<ID de la langue> contiennent le Contrat de licence utilisateur final et la Déclaration de Kaspersky Security Network et font partie du paquet de distribution de l'application."," A propos des donn&#xE9;es ","161251.htm");
Page[48]=new Array("Lancement et arrêt de l'application","Par défaut, Kaspersky Endpoint Security est lancé automatiquement au démarrage du système d'exploitation (pour les niveaux d'exécution par défaut applicables à chacun des systèmes d'exploitation). Kaspersky Endpoint Security lance toutes les tâches de service ainsi que les tâches personnalisées pour lesquelles le mode de lancement PS est défini dans les paramètres de la planification.","Si vous arrêtez Kaspersky Endpoint Security, toutes les tâches en cours d'exécution sont interrompues. Sachez que les tâches personnalisées ne sont pas rétablies automatiquement après que Kaspersky Endpoint Security a été relancé. Seules les tâches personnalisées, dont les paramètres du calendrier a la valeur PS, seront relancées.","Pour lancer Kaspersky Endpoint Security, exécutez la commande suivante :","/etc/init.d/kesl-supervisor start","Pour arrêter Kaspersky Endpoint Security, exécutez la commande suivante :","/etc/init.d/kesl-supervisor stop","Pour relancer Kaspersky Endpoint Security, exécutez la commande :","/etc/init.d/kesl-supervisor restart","Pour afficher l'état de Kaspersky Endpoint Security, exécutez la commande suivante :","/etc/init.d/kesl-supervisor status","Pour lancer Kaspersky Endpoint Security dans le système systemd, exécutez la commande suivante :","systemctl start kesl-supervisor","Pour arrêter Kaspersky Endpoint Security dans le système systemd, exécutez la commande suivante :","systemctl stop kesl-supervisor","Pour relancer Kaspersky Endpoint Security dans le système systemd, exécutez la commande suivante :","systemctl restart kesl-supervisor","Pour afficher l'état de Kaspersky Endpoint Security dans le système systemd, exécutez la commande suivante :","systemctl status kesl-supervisor","Surveillance de l'état de l'application","Le service watchdog surveille l'état de l'application. Ce service est lancé automatiquement au lancement de l'application.","En cas de plantage de l'application, un fichier dump est produit et l'application redémarre automatiquement. Une copie de sauvegarde du répertoire /var/opt/kaspersky/kesl, à l'exclusion des fichiers dump, est créée."," Lancement et arr&#xEA;t de l&apos;application ","161252.htm");
Page[49]=new Array("Paramètres généraux de Kaspersky Endpoint Security","Cette section décrit les paramètres généraux de Kaspersky Endpoint Security.","Après avoir modifié les paramètres généraux de Kaspersky Endpoint Security, relancez l'application.","Les paramètres généraux du fichier de configuration ont les valeurs suivantes :","SambaConfigPath","Répertoire dans lequel se trouve le fichier de configuration Samba. Le fichier de configuration Samba est nécessaire pour garantir l'application des valeurs AllShared ou Shared:SMB de l'option Path.","Le répertoire standard du fichier de configuration Samba sur l'ordinateur est indiqué par défaut.","Valeur par défaut : /etc/samba/smb.conf","NfsExportPath","Répertoire dans lequel se trouve le fichier de configuration NFS. Le fichier de configuration Samba est nécessaire pour garantir l'application des valeurs AllShared ou Shared:NFS de l'option Path.","Le répertoire standard du fichier de configuration NFS sur l'ordinateur est indiqué par défaut.","Valeur par défaut : /etc/exports","TraceFolder","Répertoire dans lequel Kaspersky Endpoint Security enregistre les fichiers journal de trace.","Si vous indiquez un autre répertoire, veillez à ce que le compte utilisateur sous les autorisations duquel Kaspersky Endpoint Security fonctionne puisse y accéder en lecture et en écriture.","Valeur par défaut : /var/log/kaspersky/kesl","TraceLevel","Niveau de détail du journal des traces.","Valeurs possibles :","Detailed : journal de trace le plus détaillé.","NotDetailed : le journal de trace contient des notifications sur les erreurs.","None : aucun journal de trace n'est créé.","Valeur par défaut : None.","BlockFilesGreaterMaxFileNamePath","Blocage de l'accès aux fichiers dont la longueur du chemin d'accès complet dépasse la valeur du paramètre définie en octets.","Si la longueur le chemin complet d'accès au fichier analysé excède la valeur de ce paramètre, les tâches d'analyse à la demande ignorent ce fichier lors de l'analyse.","Valeurs possibles : 4096 – 33554432.","Valeur par défaut : 16384.","DetectOtherObjects","La case active/désactive la détection des applications légitimes qui pourraient être détournées par des individus malintentionnés pour nuire aux ordinateurs ou aux données de l'utilisateur.","Valeurs possibles :","Yes. Active la détection des applications légitimes qui pourraient être détournées par des individus malintentionnés pour nuire aux ordinateurs ou aux données de l'utilisateur.","No. Désactive la détection des applications légitimes qui pourraient être détournées par des individus malintentionnés pour nuire aux ordinateurs ou aux données de l'utilisateur.","Valeur du paramètres par défaut : No","UseKSN","Active/désactive la participation à Kaspersky Security Network.","Valeurs possibles :","No. Désactive la participation à Kaspersky Security Network.","Basique : active la participation à Kaspersky Security Network sans envoi de statistiques.","Extended : active la participation à Kaspersky Security Network avec envoi de statistiques.","Valeur du paramètres par défaut : No","UseProxy","Active/désactive l'utilisation d'un proxy pour Kaspersky Security Network, l'activation de l'application et les mises à jour.","Valeurs possibles :","Yes : active l'utilisation d'un proxy.","No. Désactive l'utilisation d'un proxy.","Valeur du paramètres par défaut : No","ProxyServer","Les paramètres du serveur proxy au format [utilisateur[:mot_de_passe]@]hôte[:port].","MaxEventsNumber","Quantité maximale d'événements qui sera enregistrée dans Kaspersky Endpoint Security. Quand la quantité maximale d'événements définie est atteinte, Kaspersky Endpoint Security supprime les événements les plus anciens.","Valeur par défaut : 500000.","LimitNumberOfScanFileTasks","Quantité maximale des tâches de type Scan_File que l'utilisateur privé de privilèges peut lancer simultanément sur l'ordinateur. Ce paramètre ne limite pas la quantité de tâches que l'utilisateur doté des autorisations root peut lancer. Si la valeur 0 est attribuée, l'utilisateur privé de privilèges ne peut pas lancer les tâches de type Scan_File.","Valeurs possibles : 0 à 4294967295.","Valeur par défaut : 0.","Si le paramètre USE_GUI a été défini sur yes pendant l'installation de l'application, la valeur par défaut de LimitNumberOfScanFileTasks est 5.","UseSysLog","Active/désactive l'enregistrement des informations relatives aux événements dans syslog. Dans certains cas, l'application n'est pas en mesure de créer et d'enregistrer un événement. Les informations sont ensuite enregistrées dans syslog.","Yes. Active l'enregistrement des informations relatives aux événements dans syslog.","No. Désactive l'enregistrement des informations relatives aux événements dans syslog.","Valeur du paramètres par défaut : No","UIReportsForRootOnly","Active/désactive la consultation des rapports pour les utilisateurs via l'interface utilisateur graphique.","Yes. Permet uniquement aux utilisateurs dotés des autorisations root de consulter les rapports dans l'interface utilisateur graphique.","No. Permet à n'importe quel utilisateur de consulter les rapports depuis l'interface utilisateur graphique. Ces utilisateurs pourront également créer et lancer un maximum de 5 tâches d'analyse personnalisées.","Valeur du paramètres par défaut : No.","EventsStoragePath","Fichier de la base de données dans lequel Kaspersky Endpoint Security enregistre les informations relatives aux événements.","Valeur par défaut : /var/opt/kaspersky/kesl/events.db","Dans cette sectionCommandes d'administration des paramètres de Kaspersky Endpoint Security et des tâchesAffichage de l'aide sur les commandes de Kaspersky Endpoint SecurityActivation de l'affichage des événementsConsultation des informations sur le programmeCommandes de Kaspersky Endpoint SecurityExportation et importation des paramètres de l'application"," Param&#xE8;tres g&#xE9;n&#xE9;raux de Kaspersky Endpoint Security ","161254.htm");
Page[50]=new Array("Commandes d'administration des paramètres de Kaspersky Endpoint Security et des tâches","Cette section contient des informations sur les commandes d'administration des paramètres de Kaspersky Endpoint Security et des tâches."," Commandes d&apos;administration des param&#xE8;tres de Kaspersky Endpoint Security et des t&#xE2;ches ","161255.htm");
Page[51]=new Array("Obtention des paramètres généraux de Kaspersky Endpoint Security","La commande --get-app-settings permet d'afficher les paramètres généraux de Kaspersky Endpoint Security. Cette commande permet également d'obtenir les paramètres généraux de Kaspersky Endpoint Security définis à l'aide des arguments de la commande.","Vous pouvez utiliser cette commande pour modifier les paramètres généraux de Kaspersky Endpoint Security installé sur l'ordinateur :","Enregistrez les paramètres généraux de Kaspersky Endpoint Security dans le fichier de configuration à l'aide de la commande --get-app-settings.Ouvrez le fichier de configuration créé, modifiez les paramètres voulus et enregistrez les modifications faites.Importez les paramètres depuis le fichier de configuration dans Kaspersky Endpoint Security à l'aide de la commande --set-app-settings. Kaspersky Endpoint Security utilise les nouvelles valeurs des paramètres après que vous avez arrêté, puis relancé Kaspersky Endpoint Security.Vous pouvez utiliser le fichier de configuration créé pour importer des paramètres dans Kaspersky Endpoint Security installé sur un autre ordinateur.","Syntaxe de la commande","kesl-control [-T] --get-app-settings --file <nom du fichier de configuration>","kesl-control [-T] --get-app-settings","Arguments et clés","--file <nom du fichier de configuration>","Nom du fichier de configuration dans lequel les paramètres de Kaspersky Endpoint Security vont être enregistrés. Si vous spécifiez le nom du fichier sans avoir spécifié le chemin d'accès à celui-ci, le fichier sera créé dans le répertoire en cours. Si le fichier avec le nom spécifié existe déjà dans le répertoire indiqué, il sera réenregistré. Si le répertoire indiqué n'existe pas sur le disque, le fichier de configuration ne sera pas créé.","Exemple :","Exportez les paramètres généraux de Kaspersky Endpoint Security dans un fichier nommé kesl_config.ini. Enregistrez le fichier créé dans le répertoire actif :","kesl-control --get-app-settings --file kesl_config.ini"," Obtention des param&#xE8;tres g&#xE9;n&#xE9;raux de Kaspersky Endpoint Security ","161256.htm");
Page[52]=new Array("Modification des paramètres généraux de Kaspersky Endpoint Security","La commande --set-app-settings définit les paramètres généraux de Kaspersky Endpoint Security à l'aide des clés de commande ou les importe depuis le fichier de configuration indiqué.","Vous pouvez utiliser cette commande pour modifier les paramètres généraux de Kaspersky Endpoint Security :","Enregistrez les paramètres généraux de Kaspersky Endpoint Security dans le fichier de configuration à l'aide de la commande --get-app-settings.Ouvrez le fichier de configuration créé, modifiez les paramètres voulus et enregistrez les modifications faites.Importez les paramètres depuis le fichier de configuration dans Kaspersky Endpoint Security à l'aide de la commande --set-app-settings. Kaspersky Endpoint Security applique les nouvelles valeurs des paramètres après que vous avez arrêté, puis relancé Kaspersky Endpoint Security à l'aide des commandes --stop-app et --start-app ou à l'aide de la commande --restart-app.Syntaxe de la commande","kesl-control [-T] --set-app-settings --file <nom du fichier de configuration>","kesl-control [-T] --set-app-settings <nom du paramètre>=<valeur du paramètre> <nom du paramètre>=<valeur du paramètre>","Arguments et clés","--file <nom du fichier de configuration>","Le nom du fichier de configuration dont les paramètres vont être importés dans Kaspersky Endpoint Security ; contient le chemin d'accès complet au fichier.","Exemple :","Importez dans Kaspersky Endpoint Security les paramètres généraux depuis le fichier de configuration nommé /home/test/kav_config.ini :","kesl-control --set-app-settings --file /home/test/kav_сonfig.ini","Définissez le niveau de détails faible pour le journal de trace :","kesl-control --set-app-settings TraceLevel=NotDetailed"," Modification des param&#xE8;tres g&#xE9;n&#xE9;raux de Kaspersky Endpoint Security ","161257.htm");
Page[53]=new Array("Affichage de l'aide sur les commandes de Kaspersky Endpoint Security","La commande kesl-control avec l'argument --help <ensemble de commandes de Kaspersky Endpoint Security> affiche l'aide sur les commandes de Kaspersky Endpoint Security.","Syntaxe de la commande","kesl-control --help [<ensemble des commandes de Kaspersky Endpoint Security>]","<ensemble de commandes de Kaspersky Endpoint Security>","Valeurs possibles :","[-T] :commandes d'administration des tâches et des paramètres généraux de Kaspersky Endpoint Security ;","[-L] : commandes de gestion des clés ;","[-B] : commandes d'administration du stockage ;","[-E] : commandes d'administration des événements de Kaspersky Endpoint Security.","[-F] : commandes de gestion de la tâche Pare-feu.","[-H] : commande de gestion de la tâche Protection contre le chiffrement.","[-S] : commandes statistiques.","-W : surveillance des événements."," Affichage de l&apos;aide sur les commandes de Kaspersky Endpoint Security ","161258.htm");
Page[54]=new Array("Activation de l'affichage des événements","La commande -W permet d'afficher les événements de Kaspersky Endpoint Security. Seule, cette commande permet d'afficher tous les événements. Utilisée avec --start-task, elle affiche uniquement les événements liés à la tâche en cours d'exécution. Vous pouvez utiliser --query avec l'argument -W pour afficher uniquement des événements spécifiques.","La commande reprend le nom de l'événement et les informations supplémentaires sur l'événement.","Syntaxe de la commande","kesl-control -W","Exemple :","Activer le mode d'affichage des événements de Kaspersky Endpoint Security :","kesl-control -W"," Activation de l&apos;affichage des &#xE9;v&#xE9;nements ","161259.htm");
Page[55]=new Array("Consultation des informations sur le programme","La commande --app-info affiche les informations relatives à Kaspersky Endpoint Security.","Syntaxe de la commande","kesl-control [-S] --app-info","Résultat de l'exécution de la commande","Name","Nom de l'application.","Version","Version actuelle de l'application.","Key status","Etat de la clé.","Subscription status","Etat de l'abonnement. Ce champ apparaît si l'application est exécutée sous un abonnement.","License expiration date","Date de fin de validité de la licence.","Storage state","Etat du stockage. Affiche les informations relatives aux restrictions de durée et de taille.","Storage space usage","Taille du stockage.","Last run date of the Scan_My_Computer task","Heure du dernier lancement de la tâche Scan_My_Computer.","Last release date of databases","Date et heure de la dernière publication des mises à jour.","Anti-virus databases loaded","Indique si les bases antivirus ont été téléchargées ou non.","Anti-virus databases records","Nombre d'enregistrements dans les bases antivirus.","KSN state","Etat de la participation au Kaspersky Security Network.","File monitoring","Etat du composant de surveillance des fichiers","Integrity monitoring","Etat du composant Contrôle de l'intégrité des fichiers.","Pare-feu","Etat du composant Gestionnaire du pare-feu.","Anti-Cryptor","Etat du composant Anti-Cryptor.","Application update state","Affiche la disponibilité de mises à jour de l'application."," Consultation des informations sur le programme ","161260.htm");
Page[56]=new Array("Commandes de Kaspersky Endpoint Security","Vous pouvez modifier les valeurs des paramètres de Kaspersky Endpoint Security.","Voici les règles à suivre pour utiliser les commandes de Kaspersky Endpoint Security :","Respectez la casse.Séparez les arguments par un espace.En cas d'utilisation du nom complet de la commande ou de l'argument, saisissez la valeur après le signe \"égal\" (=).","Exemple :","Indiquer la valeur du paramètre URL pour la source de mises à jour personnalisée pour la tâche de mise à jour (ID=6) via la ligne de commande :","kesl-control --set-settings 6","SourceType=Custom CustomSources.item_0000.URL=http://site.domain/path CustomSources.item_0000.Enabled=Yes","Affichage de l'aide sur les commandes de Kaspersky Endpoint Security","--help","Affiche l'aide sur les commandes de Kaspersky Endpoint Security.","Affichage des événements de Kaspersky Endpoint Security","-W","Affiche les événements de Kaspersky Endpoint Security.","Commandes d'administration des paramètres de Kaspersky Endpoint Security et des tâches","-T","Préfixe qui indique que la commande appartient au groupe des commandes d'administration des paramètres de Kaspersky Endpoint Security/d'administration des tâches (facultatif).","[-S] --app-info","Affiche les informations générales relatives à Kaspersky Endpoint Security.","[-Т] --get-app-settings --file <nom et répertoire du fichier>","Renvoie les paramètres généraux de Kaspersky Endpoint Security.","[-T] --set-app-settings --file <nom et répertoire du fichier>","Définit les paramètres généraux de Kaspersky Endpoint Security.","[-T] --get-task-list","Renvoie la liste des tâches existantes de Kaspersky Endpoint Security.","[-T] --get-task-state <ID de la tâche>|<nom de la tâche>","Affiche l'état de la tâche indiquée.","[-T] --create-task <nom de la tâche> --type <type de la tâche> --file <nom et répertoire du fichier>","Crée la tâche de type spécifié ; importe dans la tâche les paramètres depuis le fichier de configuration spécifié.","[-T] --delete-task <ID de la tâche>|<nom de la tâche>","Supprime la tâche.","[-T] --start-task <ID de la tâche>|<nom de la tâche> [-W] [--progress] [--file <nom et répertoire du fichier>]","Lance la tâche.","[-T] --stop-task <ID de la tâche>|<nom de la tâche>","Arrête la tâche.","[-T] --suspend-task <ID de la tâche>|<nom de la tâche>","Suspend la tâche.","[-T] --resume-task <ID de la tâche>|<nom de la tâche>","Reprend la tâche.","[-T] --get-settings <ID de la tâche>|<nom de la tâche> --file <nom_et_répertoire du fichier>","Renvoie paramètres de la tâche.","[-T] --set-settings <ID de la tâche>|<nom de la tâche> [<paramètres>] [--file <nom et répertoire du fichier>] [--add-path <chemin>] [--del-path <chemin>] [--add-exclusion <exclusion>] [--del-exclusion <exclusion>]","Définit les paramètres de la tâche.","[-T] --scan-file <chemin> [--action <action>]","Crée et lance une tâche temporaire Scan_File.","[-T] --import-settings <--file file>","Importe les paramètres de l'application dans le fichier de configuration.","[-T] --update-application","Met à jour l'application.","[-S] --omsinfo --file <chemin d'accès>","Crée un fichier au format JSON en vue d'une intégration à Microsoft Operations Management Suite.","Commandes de gestion des clés","-L","Préfixe qui indique que la commande appartient au groupe des commandes de gestion des clés.","[-L] --install-active-key <code d'activation>|<fichier clé>","Ajoute la clé active.","[-L] --install-additional-key <code d'activation>|<fichier clé>","Ajoute une clé additionnelle.","[-L] --revoke-active-key","Supprime la clé active.","[-L] --revoke-additional-key","Supprime la clé additionnelle.","[-L] --query","Affiche les informations relatives à la clé.","Commande pour la tâche Gestion du pare-feu","[-F] --add-rule [--name <string>] [--action <action>] [--protocol <protocol>] [--direction <directory>] [--remote <remote>] [--local <local>] [--at <index>]","Ajoute une nouvelle règle.","[-F] --del-rule [--name <string>] [--index <index>]","Supprime une règle.","[-F] --move-rule [--name <string>] [--index <index>] [--at <index>]","Modifie la priorité de la règle.","[-F] --add-zone [--zone <zone>] [--address <adresse>]","Ajoute une adresse IP à la zone.","[-F] --del-zone [--zone <zone>] [--address <adresse>] [--index <index>]","Supprime une adresse IP de la zone.","-F --query","Affiche des informations.","Commandes pour la tâche Anti-Cryptor","[-H] --get-blocked-hosts","Affiche une liste d'hôtes bloqués.","[-H] --allow-hosts","Débloque les hôtes douteux.","Commandes d'administration du stockage","-B","Préfixe qui indique que la commande appartient au groupe des commandes d'administration du stockage.","[-B] --mass-remove --query","Purge le stockage complètement ou partiellement.","[-B] --query --limit --offset","Affiche les informations sur les objets du stockage :","--limit","Quantité maximale d'objets au sujet desquels des informations sont affichées.","--offset","Nombre d'entrées représentant le décalage à partir du début de la sélection.","[-B] --restore <ID de l'objet> --file <nom et répertoire du fichier>","Restaure un objet depuis le stockage.","Instructions d'administration du journal des événements","-E","Préfixe qui indique que la commande appartient au groupe de commandes d'administration du journal des événements.","[-E] --query --limit --offset --file <nom et répertoire du fichier> --db <db file>","Quantité maximale d'événements au sujet desquels des informations sont affichées.","--query","Affiche les informations relatives aux événement filtrés du journal des événements ou du fichier de rotation indiqué.","--offset","Nombre d'entrées représentant le décalage à partir du début de la sélection.","--db","Nom du fichier de la base de données.","Commandes d'administration de la planification des tâches","[-T] --set-schedule <ID de la tâche>|<nom de la tâche> --file <nom et répertoire du fichier>","Détermine les paramètres de l'horaire de la tâche/les importe dans la tâche depuis le fichier de configuration.","[-T] --get-schedule <ID de la tâche>|<nom de la tâche> --file <nom et répertoire du fichier>","Renvoie les paramètres de planification de la tâche.","RuleType=Once|Monthly|Weekly|Daily|Hourly|Minutely|Manual|PS|BR","Planification du lancement d'une tâche.","PS : lance la tâche après le lancement de Kaspersky Endpoint Security.","BR : lance la tâche après la mise à jour des bases antivirus.","StartTime=[année/mois/jour_du_mois] [hh]:[mm]:[ss]; [<jour_du_mois>|<jour_de_la_semaine>]; [<period>]","Heure de lancement d'une tâche.","RandomInterval=<min.>","Intervalle du lancement de la tâche, si plusieurs tâches sont lancées simultanément (en minutes).","ExecuteTimeLimit=<min.>","Restriction du temps d'exécution de la tâche (en minutes).","RunMissedStartRules","Active/désactive le lancement d'une tâche ignorée après le lancement de Kaspersky Endpoint Security."," Commandes de Kaspersky Endpoint Security ","161262.htm");
Page[57]=new Array("Exportation et importation des paramètres de l'application","Kaspersky Endpoint Security vous permet d'exporter et d'importer tous les paramètres de l'application pour le dépannage, la vérification des paramètres ou pour simplifier la configuration de l'application sur les autres ordinateurs.","Dans le cadre de l'exportation des paramètres, tous les paramètres de l'application et de la tâche sont enregistrés dans un fichier de configuration. Ce fichier de configuration permet d'importer les paramètres pour configurer l'application.","Pour pouvoir importer ou exporter les paramètres, Kaspersky Endpoint Security doit être lancé. Il faut redémarrer l'application après l'importation des paramètres. ","L'importation des paramètres n'est pas disponible si l'application est administrée via Kaspersky Security Center. ","Lors de l'importation ou de l'exportation de paramètres depuis une version antérieure de l'application, les nouveaux paramètres prennent la valeur par défaut. Quand les fichiers de configuration de la nouvelle et de l'ancienne version de l'application correspondent, le code de retour est 1.","L'importation des paramètres dans une version antérieure de l'application est impossible.","Lors de l'importation des paramètres de l'application, le paramètre UseKSN est défini sur No. Pour démarrer ou reprendre la participation à Kaspersky Security Network, vvous devez préciser UseKSN=Basic ou UseKSN=Extended.","Après l'importation des paramètres de l'application, les identifiants des tâches internes peuvent être modifiés. Nous conseillons de les administrer à l'aide de noms de tâche.","Pour exporter les paramètres de l'application dans le fichier de configuration, exécutez la commande suivante :","kesl-control --export-settings [--file chemin d'accès complet aux fichier de configuration] ","Pour configurer l'application à l'aide des paramètres d'un fichier de configuration (importation de paramètres), exécutez la commande suivante :","kesl-control --import-settings --file chemin d'accès complet au fichier de configuration"," Exportation et importation des param&#xE8;tres de l&apos;application ","162401.htm");
Page[58]=new Array("Administration des tâches de Kaspersky Endpoint Security via la ligne de commande","Cette section contient des informations sur les types de tâches de Kaspersky Endpoint Security et des instructions relatives à la gestion de ces tâches.","Dans cette sectionA propos des tâches de Kaspersky Endpoint SecurityConsultation d'une liste de tâches de Kaspersky Endpoint SecurityCréation d'une tâcheModification des paramètres de la tâche via le fichier de configurationModification des paramètres de la tâche via la ligne de commandeLancement et arrêt de la tâcheAdministration des zones d'analyse via la ligne de commandeAdministration des zones d'exclusion via la ligne de commandeConsultation de l'état d'une tâcheSuspension et reprise d'une tâcheParamètres de planification d'une tâcheObtention des paramètres de l'horaire d'une tâcheModification des paramètres de l'horaire d'une tâcheSuppression d'une tâche"," Administration des t&#xE2;ches de Kaspersky Endpoint Security via la ligne de commande ","161263.htm");
Page[59]=new Array("A propos des tâches de Kaspersky Endpoint Security","Vous pouvez administrer le fonctionnement de Kaspersky Endpoint Security à l'aide de tâches aussi bien localement sur les ordinateurs (via la ligne de commande ou les fichiers de configuration) que de manière centralisée via Kaspersky Security Center.","Au niveau de l'utilisation de Kaspersky Endpoint Security, il existe deux types de tâches :","Tâche prédéfinie, à savoir une tâche créée lors de l'installation de l'application. Vous ne pouvez pas créer ou supprimer des tâches prédéfinies, mais vous pouvez en modifier les paramètres.Tâche personnalisée, à savoir une tâche que vous pouvez créer ou supprimer vous-même.Vous pouvez administrer les tâches suivantes :","File_Monitoring est une tâche de protection en temps réel (ID=1, type – OAS).Scan_My_Computer est une tâche d'analyse à la demande (ID=2, type – ODS).Scan_File est une tâche d'analyse personnalisée (ID=3, type – ODS). Les paramètres de cette tâche correspondent par défaut aux paramètres de la tâche Scan_My_Computer.Boot_Scan est une tâche d'analyse des secteurs d'amorçage (ID=4, type – BootScan).Memory_Scan est une tâche d'analyse de la mémoire des processus (ID=5, type – MemoryScan).Update est une tâche de mise à jour (ID=6, type – Update).Rollback est une tâche de recul de mise à jour des bases (ID=7, type – Rollback). Elle n'a pas de paramètres. Vous pouvez uniquement arrêter ou démarrer cette tâche.Retranslate est une tâche de copie des mises à jour (ID=8, type – Retranslate).License est une tâche de mise en œuvre du serveur de licences (ID=9, type – License).Backup est une tâche d'administration du stockage (ID=10, type – Backup).Integrity_Monitoring est une tâche de contrôle de l'intégrité des fichiers (ID=11, type – OAFIM).Firewall est une tâche de gestion du pare-feu (ID=12, type – Firewall).Anti-Cryptor est une tâche de protection contre le chiffrement (ID=13, type – AntiCryptor).ID est le numéro d'identification de la tâche attribué par Kaspersky Endpoint Security lors de la création de la tâche.","Vous pouvez réaliser les opérations suivantes sur les tâches :","lancer et arrêter des tâches ;créer et supprimer des tâches (uniquement pour les tâches personnalisées) ;modifier les paramètres des tâches."," A propos des t&#xE2;ches de Kaspersky Endpoint Security ","161264.htm");
Page[60]=new Array("Consultation d'une liste de tâches de Kaspersky Endpoint Security","Pour consulter la liste des tâches de Kaspersky Endpoint Security, exécutez la commande suivante :","kesl-control [-T] --get-task-list","Une liste des tâches de Kaspersky Endpoint Security s'affiche.","Les informations suivantes sont affichées pour chaque tâche :","Nom. Nom de la tâche.ID. Task ID.Type. Task type.State. Etat de la tâche en cours.Si un utilisateur ne dispose pas des autorisations pour voir et modifier les paramètres d'une tâche, les informations relatives aux tâches Scan_File, Backup, License, File_Monitoring, Integrity_Monitor et Anti_Cryptor sont affichées. Les informations relatives aux autres tâches ne sont pas affichées.","Si votre licence ne couvre pas la fonctionnalité Protection contre le chiffrement et Contrôle de l'intégrité des fichiers, les informations sur les tâches correspondantes ne s'affichent pas.","Pour en savoir plus, consultez la section A propos des tâches de Kaspersky Endpoint Security."," Consultation d&apos;une liste de t&#xE2;ches de Kaspersky Endpoint Security ","161267.htm");
Page[61]=new Array("Création d'une tâche","Vous pouvez créer des tâches avec les paramètres par défaut ou avec des paramètres définis dans le fichier de configuration.","Les tâches des types OAS, Pare-Feu, OAFIM, License, Sauvegarde et Protection contre le chiffrement ne peuvent pas être créées.","Pour créer une tâche avec les paramètres par défaut, exécutez la commande suivante :","kesl-control [-T] --create-task <nom de la tâche> --type <type de tâche>","Ici :","<nom de la tâche> est le nom attribué à la nouvelle tâche.<type de tâche> est un type de tâche prédéfinieLa tâche du type indiqué est créée selon les paramètres par défaut.","Pour créer une tâche selon les paramètres repris dans un fichier de configuration, exécutez la commande suivante :","kesl-control [-T] --create-task <nom de la tâche> --type <type de tâche> --file <chemin d'accès complet au fichier de configuration>","Ici :","<nom de la tâche> est le nom attribué à la nouvelle tâche.<type de tâche> est un type de tâche prédéfinie<chemin d'accès complet au fichier de configuration> est le chemin d'accès complet au fichier de configurationUne tâche du type indiqué est créée selon les paramètres indiqués dans un fichier de configuration."," Cr&#xE9;ation d&apos;une t&#xE2;che ","161268.htm");
Page[62]=new Array("Modification des paramètres de la tâche via le fichier de configuration","Pour modifier les paramètres d'une tâche en modifiant le fichier de configuration :","Enregistrez les paramètres de la tâche dans le fichier de configuration :kesl-control --get-settings <nom de la tâche>|<ID de la tâche> --file <chemin d'accès complet au fichier>","Ouvrez le fichier de configuration créé pour l'édition.Modifiez les paramètres requis dans le fichier de configuration.Enregistrez les modifications dans le fichier de configuration.Importez dans la tâche les paramètres depuis le fichier de configuration :kesl-control --set-settings <nom de la tâche>|<ID de la tâche> --file <chemin d'accès complet au fichier>","La tâche est alors exécutée selon les paramètres mis à jour."," Modification des param&#xE8;tres de la t&#xE2;che via le fichier de configuration ","162022.htm");
Page[63]=new Array("Modification des paramètres de la tâche via la ligne de commande","Pour modifier les paramètres d'une tâche via la ligne de commande :","Définissez la valeur requise pour le paramètre :kesl-control --set-settings <ID ou nom de la tâche> setting=value [setting=value]","Kaspersky Endpoint Security modifie le paramètre indiqué.","Confirmez que la valeur du paramètre est modifiée dans un fichier de configuration de tâche :kesl-control --get-settings <nom ou ID de tâche>","Si vous ajoutez une nouvelle zone d'analyse ou d'exclusion sans définir tous les paramètres, une zone configurée selon les paramètres par défaut est ajoutée au fichier de configuration.","Exemple :","Pour définir une nouvelle zone d'analyse, exécutez la commande suivante :","--set-settings 100 ScanScope.item_0001.UseScanArea=Yes ScanScope.item_0001.Path=/home","Une nouvelle section qui décrit la zone d'analyse est ajoutée au fichier de configuration pour la tâche ID=100 :","[ScanScope.item_0001]","AreaDesc=","UseScanArea=Yes","Path=/home","AreaMask.item_0000=*"," Modification des param&#xE8;tres de la t&#xE2;che via la ligne de commande ","162393.htm");
Page[64]=new Array("Lancement et arrêt de la tâche","Vous ne pouvez pas lancer et arrêter les tâches de type Backup et License.","Pour lancer la tâche, exécutez la commande :","kesl-control --start-task <ID de la tâche>|<nom de la tâche>","Pour arrêter la tâche, exécutez la commande :","kesl-control --stop-task <ID de la tâche>|<nom de la tâche>"," Lancement et arr&#xEA;t de la t&#xE2;che ","161269.htm");
Page[65]=new Array("Administration des zones d'analyse via la ligne de commande","Vous pouvez ajouter ou supprimer une zone d'analyse avec le paramètre Path indiqué pour les tâches OAS, ODS, OAFIM, ODFIM et Protection contre le chiffrement depuis la ligne de commande.","Pour ajouter une nouvelle zone d'analyse, exécutez la commande suivante :","kesl-control --set-settings <ID ou nom de la tâche> --add-path <chemin>","Une nouvelle section [ScanScope.item_#] est ajoutée au fichier de configuration de la tâche. Kaspersky Endpoint Security analyse les objet situés dans le répertoire défini par le paramètre Path. ","Si une section [ScanScope.item_#] pour le paramètre Path défini existe déjà, son double n'est pas ajouté au fichier de configuration. Si le paramètre UseScanArea a reçu la valeur No, il prend la valeur Yes après l'exécution de la commande et les objets situés dans ce répertoire sont analysés.","Pour supprimer une zone d'analyse, exécutez la commande suivante :","kesl-control --set-settings <ID ou nom de la tâche> --del-path <chemin>","Une section [ScanScope.item_#] qui contient le chemin indiqué est supprimée du fichier de configuration d'une tâche. Kaspersky Endpoint Security n'analyse pas les objets situés dans le répertoire défini par le paramètre Path. "," Administration des zones d&apos;analyse via la ligne de commande ","162407.htm");
Page[66]=new Array("Administration des zones d'exclusion via la ligne de commande","Vous pouvez ajouter ou supprimer une zone d'exclusion avec le paramètre Path indiqué pour les tâches OAS, ODS, OAFIM, ODFIM et Protection contre le chiffrement depuis la ligne de commande.","Pour ajouter une nouvelle zone d'exclusion, exécutez la commande suivante :","kesl-control --set-settings <ID ou nom de la tâche> --add-exclusion<chemin>","Une nouvelle section [ExcludedFromScanScope.item_#] est ajoutée au fichier de configuration de la tâche. Kaspersky Endpoint Security exclut les objet situés dans le répertoire défini par le paramètre Path. ","Si une section [ExcludedFromScanScope.item_#] pour le paramètre Path défini existe déjà, son double n'est pas ajouté au fichier de configuration. Si le paramètre UseScanArea a reçu la valeur No, il prend la valeur Yes après l'exécution de la commande et les objets situés dans ce répertoire sont exclus de l'analyse.","Pour supprimer une zone d'exclusion, exécutez la commande suivante :","kesl-control --set-settings <ID ou nom de la tâche> --del-exclusion<chemin>","Une section [ExcludedFromScanScope.item_#] qui contient le chemin indiqué est supprimée du fichier de configuration d'une tâche. Kaspersky Endpoint Security n'exclut pas les objets situés dans le répertoire défini par le paramètre Path. "," Administration des zones d&apos;exclusion via la ligne de commande ","162408.htm");
Page[67]=new Array("Consultation de l'état d'une tâche","Vous pouvez consulter l'état d'une tâche.","Pour consulter l'état d'une tâche, exécutez la commande suivante :","kesl-control --get-task-state <ID de la tâche>|<nom de la tâche>","Ici :","<ID tâche> est un ID de tâche que Kaspersky Endpoint Security a attribué à la tâche lors de sa création.<nom de la tâche> est le nom attribué à la nouvelle tâche.Les tâches de Kaspersky Endpoint Security peuvent se trouver dans un des états suivants :","Started : en cours d'exécution.En cours de démarrage : en cours de lancement.Arrêté : en cours d'arrêt.Stopping : en cours d'arrêt.Suspendu : en cours de suspension.Suspending : en cours de suspension.Resuming : en cours de reprise.Resuming : cours de reprise"," Consultation de l&apos;&#xE9;tat d&apos;une t&#xE2;che ","161277.htm");
Page[68]=new Array("Suspension et reprise d'une tâche","Vous pouvez suspendre et reprendre l'exécution des tâches de type ODS, BootScan, MemoryScan, Rollback, Retranslate et Update.","Pour suspendre une tâche, exécutez la commande suivante :","kesl-control --suspend-task <ID de la tâche>|<nom de la tâche>","Une fois la commande exécutée, la tâche est suspendue.","Pour reprendre une tâche, saisissez la commande suivante :","kesl-control --resume-task <ID de la tâche>|<nom de la tâche>","Une fois la commande exécutée, la tâche reprend."," Suspension et reprise d&apos;une t&#xE2;che ","161271.htm");
Page[69]=new Array("Paramètres de planification d'une tâche","Pour planifier une tâche, procédez comme suit :","Enregistrez les paramètres de planification d'une tâche dans le fichier de configuration à l'aide de la commande suivante :kesl-control --get-schedule <ID de la tâche>|<nom de la tâche>","Ouvrez le fichier de configuration afin de le modifier.Précisez les paramètres de planification.Enregistrez les modifications dans le fichier de configuration.Importez les paramètres de planification dans la tâche à l'aide de la commande suivante :kesl-control --set-schedule <ID de la tâche>|<nom de la tâche> --file <chemin d'accès complet au fichier>"," Param&#xE8;tres de planification d&apos;une t&#xE2;che ","161272.htm");
Page[70]=new Array("Obtention des paramètres de l'horaire d'une tâche","La commande --get-schedule renvoie les paramètres de l'horaire de la tâche. Cette instruction permet également d'obtenir les paramètres de planification de la tâche définis à l'aide des arguments de la commande.","Vous pouvez utiliser cette commande pour modifier l'horaire de la tâche :","Enregistrez les paramètres de planification dans un fichier de configuration à l'aide de la commande --get-schedule.Ouvrez le fichier de configuration créé, modifiez les paramètres voulus et enregistrez les modifications faites.Importez les paramètres depuis le fichier de configuration dans Kaspersky Endpoint Security à l'aide de la commande --set-schedule. Kaspersky Endpoint Security utilise les nouvelles valeurs des paramètres de planification immédiatement.Syntaxe de la commande","kesl-control [-T] --get-schedule <ID de la tâche>|<nom de la tâche> [--file <nom du fichier de configuration>]","kesl-control [-T] --get-schedule <ID de la tâche>|<nom de la tâche> <nom du paramètre>","Arguments et clés","<ID de la tâche>","Le numéro d'identification de la tâche dans Kaspersky Endpoint Security.","<nom de la tâche>","Nom de la tâche.","--file <nom du fichier de configuration>","Nom du fichier de configuration dans lequel les paramètres de planification sont enregistrés. Si vous spécifiez le nom du fichier sans avoir spécifié le chemin d'accès à celui-ci, le fichier sera créé dans le répertoire en cours. Si le fichier avec le nom spécifié existe déjà dans le répertoire indiqué, il sera réenregistré. Si le répertoire indiqué n'existe pas sur le disque, le fichier de configuration ne sera pas créé.","Exemple :","Enregistrer les paramètres de Kaspersky Endpoint Security dans un fichier nommé update_schedule.ini. Enregistrez le fichier créé dans le répertoire actif :","kesl-control --get-schedule 6 --file update_schedule.ini","Renvoyez la planification de la tâche Mise à jour :","kesl-control --get-schedule 6"," Obtention des param&#xE8;tres de l&apos;horaire d&apos;une t&#xE2;che ","161274.htm");
Page[71]=new Array("Modification des paramètres de l'horaire d'une tâche","La commande --set-schedule définit les paramètres de la planification à l'aide des clés ou les importe depuis le fichier de configuration indiqué.","Vous pouvez utiliser cette commande pour modifier les paramètres de Kaspersky Endpoint Security :","Enregistrez les paramètres de planification dans un fichier de configuration à l'aide de la commande --get-schedule.Ouvrez le fichier de configuration créé, modifiez les paramètres voulus et enregistrez les modifications faites.Importez les paramètres depuis le fichier de configuration dans Kaspersky Endpoint Security à l'aide de la commande -T --set-schedule. Kaspersky Endpoint Security utilise les nouvelles valeurs des paramètres de planification immédiatement.Syntaxes de la commande","kesl-control --set-schedule <ID de la tâche>|<nom de la tâche> --file <nom du fichier de configuration>","kesl-control --set-schedule <ID de la tâche>|<nom de la tâche> <nom du paramètre>=<valeur du paramètre> <nom du paramètre>=<valeur du paramètre>","Arguments et clés","<ID de la tâche>","Le numéro d'identification de la tâche dans Kaspersky Endpoint Security.","<nom de la tâche>","Nom de la tâche.","--file <nom du fichier de configuration>","Le nom du fichier de configuration depuis lequel les paramètres sont importés dans la tâche ; comprend le chemin d'accès complet au fichier.","Exemple :","Importer dans la tâche portant l'ID=2 les paramètres de planification depuis le fichier de configuration nommé /home/test/on_demand_schedule.ini :","kesl-control --set-schedule 2 --file /home/test/on_demand_schedule.ini"," Modification des param&#xE8;tres de l&apos;horaire d&apos;une t&#xE2;che ","161275.htm");
Page[72]=new Array("Suppression d'une tâche","Vous pouvez supprimer les tâches que vous avez créées (tâches personnalisées).","Pour supprimer une tâche, exécutez la commande suivante :","kesl-control --delete-task <ID de la tâche>|<nom de la tâche>"," Suppression d&apos;une t&#xE2;che ","161270.htm");
Page[73]=new Array("Tâche de protection en temps réel (ID File_Monitoring :1)","Cette section contient des informations sur la tâche de protection en temps réel.","Dans cette sectionA propos de la protection en temps réelA propos des fichiers infectésParticularités de l'analyse des liens symboliques et matérielsParamètres de la tâche de protection en temps réelDéfinition d'une zone d'exclusion globale"," T&#xE2;che de protection en temps r&#xE9;el (ID File_Monitoring&#xA0;:1) ","161279.htm");
Page[74]=new Array("A propos de la protection en temps réel","La protection en temps réel permet d'éviter l'infection du système de fichiers de l'ordinateur. La tâche de protection en temps réel est créée selon les paramètres par défaut lors de l'installation de Kaspersky Endpoint Security sur l'ordinateur. La tâche de protection en temps réel est lancée automatiquement par défaut au démarrage de Kaspersky Endpoint Security. La tâche demeure dans la mémoire vive de l'ordinateur et analyse tous les fichiers qui sont ouverts, enregistrés et lancés. Vous pouvez l'arrêter et la lancer.","Vous ne pouvez pas créer de tâches de protection en temps réel personnalisées. Vous pouvez modifier les paramètres de la tâche prédéfinie de la protection en temps réel.","Les paramètres de protection en temps réel figurent dans le fichier de configuration utilisé par la tâche de protection en temps réel. "," A propos de la protection en temps r&#xE9;el ","161280.htm");
Page[75]=new Array("A propos des fichiers infectés","Kaspersky Endpoint Security analyse les fichiers à l'aide de bases antivirus. Les bases contiennent des fichiers avec des fragments de code malveillant et des algorithmes de désinfection des objets qui contiennent ces menaces. Les bases antivirus permettent de détecter les menaces connues dans les fichiers analysés.","Si un fichier contient du code qui correspond parfaitement au code d'une menace connue, Kaspersky Endpoint Security attribue l'état Infecté au fichier."," A propos des fichiers infect&#xE9;s ","161281.htm");
Page[76]=new Array("Particularités de l'analyse des liens symboliques et matériels","Kaspersky Endpoint Security permet d'analyser les liens symboliques et matériels vers les fichiers.","Analyse des liens symboliques","Kaspersky Endpoint Security analyse les liens symboliques uniquement si le fichier auquel se réfère le lien symbolique entre dans la zone de protection de la tâche de protection en temps réel ou dans la zone d'analyse de la tâche d'analyse à la demande.","Si le fichier accessible via le lien symbolique n'entre pas dans la zone de protection ou dans la zone d'analyse de la tâche, l'application ne l'analyse pas. Toutefois, si un tel fichier contient un code malveillant, la sécurité de l'ordinateur est menacée.","Analyse des liens matériels","Quand Kaspersky Endpoint Security traite un fichier contenant plusieurs liens matériels, l'application choisit l'action en fonction de l'action à exécuter sur les objets définie :","Si l'action Exécuter l'action recommandée est sélectionnée, Kaspersky Endpoint Security choisit automatiquement l'action et exécute celle-ci sur l'objet sur la base des données relatives au danger de la menace détectée dans l'objet et de la possibilité de désinfection de celui-ci.Si l'action Supprimer est sélectionnée, Kaspersky Endpoint Security supprime le lien matériel traité.  Les autres liens matériels vers ce fichier ne sont pas traités.Si l'action Réparer est sélectionnée, Kaspersky Endpoint Security désinfecte le fichier source. Si la désinfection échoue, l'application supprime le lien matériel et crée à la place une copie du fichier source portant le nom du lien matériel supprimé.Quand vous restaurez un fichier avec un lien matériel depuis la Sauvegarde, Kaspersky Endpoint Security crée la copie du fichier source portant le nom du lien matériel précédemment placé dans le Stockage. Les liens avec les autres liens matériels vers le fichier source ne sont pas restaurés."," Particularit&#xE9;s de l&apos;analyse des liens symboliques et mat&#xE9;riels ","161283.htm");
Page[77]=new Array("Paramètres de la tâche de protection en temps réel","Cette section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche de protection en temps réel.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","ScanArchived","Active ou désactive l'analyse des archives (y compris les archives autoextractibles SFX). Kaspersky Endpoint Security détecte les menaces dans les archives mais ne les désinfecte pas. Les archives suivantes sont prises en charge : .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Valeurs possibles :","yes : analyse les archives ;","no : ,n'analyse pas les archives.","Valeur du paramètres par défaut : No.","ScanSfxArchived","Active ou désactive l'analyse uniquement des archives autoextractibles (archives comprenant un module d'extraction d'exécutable).","Valeurs possibles :","Yes : analyser les archives autoextractibles.","No : ne pas analyser les archives autoextractibles.","Valeur du paramètres par défaut : No.","ScanMailBases","Active ou désactive l'analyse des bases de données email des applications Microsoft Outlook®, Outlook Express, The Bat et autres clients de messagerie.","Valeurs possibles :","Yes : analyse les fichiers des bases de données email.","No : n'analyse pas les fichiers des bases de données email.","Valeur du paramètres par défaut : No","ScanPlainMail","Active ou désactive l'analyse des messages électroniques au format texte (plain text).","Valeurs possibles :","Yes : analyse les messages électroniques au format texte.","Non : n'analyse pas les messages électroniques au format texte.","Valeur du paramètres par défaut : No","SizeLimit","Définit la taille maximale de l'objet à analyser (en mégaoctets). Si la taille de l'objet à analyser dépasse la valeur indiquée, Kaspersky Endpoint Security ignore l'objet.","Ce paramètre est appliqué avec le paramètre UseSizeLimit.","Valeurs possibles :","0 – 999,999.","0 : Kaspersky Endpoint Security analyse les objets de n'importe quelle taille.","Valeur par défaut : 0.","TimeLimit","Définit la durée maximale d'analyse de l'objet (en secondes). Kaspersky Endpoint Security interrompt l'analyse de l'objet si sa durée dépasse la valeur définie pour ce paramètre.","Ce paramètre est appliqué avec le paramètre UseTimeLimit.","Valeurs possibles :","0 – 9999.","0 : la durée de l'analyse des objets n'est pas limitée.","Valeur par défaut : 60.","FirstAction","Sélection de la première action exécutée par Kaspersky Endpoint Security sur les objets infectés.","Dans les tâches de protection en temps réel, avant d'exécuter l'action que vous avez choisie, Kaspersky Endpoint Security bloque l'accès de l'application à l'objet qu'elle a sollicité.","Valeurs possibles :","Cure (désinfecter) : Kaspersky Endpoint Security tente de désinfecter un objet en enregistrant une copie dans le stockage. Si la désinfection échoue, par exemple, le type de l'objet ou le type de la menace dans l'objet ne peut être désinfecté, Kaspersky Anti-Virus garde l'objet intact. Si la valeur de la première action est Cure, il est conseillé de définir une deuxième action via le paramètre SecondAction.","Remove : Kaspersky Endpoint Security supprime l'objet infecté après avoir créé au préalable sa copie de sauvegarde.","Recommended (exécution de l'action recommandée) : Kaspersky Endpoint Security sélectionne et exécute automatiquement une action sur l'objet en fonction des informations relatives à la menace détectée dans l'objet. Par exemple, Kaspersky Endpoint Security supprime automatiquement les chevaux de Troie car ils ne s'intègrent pas à d'autres fichiers et par conséquent, ils n'ont pas besoin d'être désinfectés.","Block : Kaspersky Endpoint Security bloque l'accès à l'objet infecté. Les informations relatives à l'objet infecté sont consignées dans le journal.","Valeur par défaut : Recommended.","SecondAction","Sélection de la deuxième action exécutée par Kaspersky Endpoint Security sur les objets infectés. Kaspersky Endpoint Security exécute la deuxième action si la première échoue.","Les valeurs du paramètre SecondAction sont identiques à celles du paramètre FirstAction.","Si l'option Block ou Remove est sélectionnée en tant que première action, il n'est pas nécessaire d'en choisir une deuxième. Dans les autres cas, il est recommandé d'indiquer deux actions. Si vous n'avez pas défini une deuxième action, Kaspersky Endpoint Security utilise l'action Block en tant que deuxième action.","Valeur par défaut : Bloquer.","UseExcludeMasks","Active ou désactive l'exclusion de l'analyse des objets définis à l'aide du paramètre ExcludeMasks.","Valeurs possibles :","Yes : exclut les objets définis par le paramètre ExcludeMasks.","No : n'exclut pas les objets définis par le paramètre ExcludeMasks.","Valeur du paramètres par défaut : No","ExcludeMasks","Exclut de l'analyse les objets en fonction du nom ou du masque. Ce paramètre permet d'exclure de la zone d'analyse indiquée un fichier distinct en fonction de son nom ou plusieurs fichiers à l'aide des masques de l'interpréteur de commandes.","La valeur par défaut n'est pas définie.","Exemple :","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Active ou désactive l'exclusion de l'analyse les objets contenant les menaces indiquées par le paramètre ExcludeThreats.","Valeurs possibles :","Yes : exclut de l'analyse les objets contenant les menaces définies à l'aide du paramètre ExcludeThreats.","No : n'exclut pas de l'analyse les objets contenant les menaces désignées par le paramètre ExcludeThreats.","Valeur du paramètres par défaut : No","ExcludeThreats","Exclut de l'analyse les objets en fonction des noms des menaces détectées dans ceux-ci. Avant d'indiquer les valeurs de ce paramètre, assurez-vous que le paramètre UseExcludeThreats est activé.","Pour exclure un objet de l'analyse, indiquez le nom complet de la menace détectée dans cet objet, la chaîne de Kaspersky Security contenant le verdict d'infection de l'objet.","Par exemple, vous utilisez un utilitaire pour obtenir des informations sur le réseau. Pour que Kaspersky Endpoint Security ne le bloque pas, ajoutez le nom complet de la menace qu'il comporte à la liste des menaces exclues de l'analyse.","Le nom complet de la menace détectée dans l'objet est repris dans le journal de Kaspersky Endpoint Security. Vous pouvez également trouver le nom complet de la menace sur le site Internet de l'Encyclopédie des virus (). Pour trouver le nom d'une menace, saisissez le nom de l'application dans le champ Rechercher.","La valeur du paramètre est sensible à la casse.","La valeur par défaut n'est pas définie.","Exemple :","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Active ou désactive l'enregistrement dans le journal des informations sur les objets analysés que Kaspersky Endpoint Security a reconnus comme non infectés.","Vous pouvez activer ce paramètre par exemple pour confirmer qu'un objet en particulier a bien été analysé par Kaspersky Endpoint Security.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non infectés.","No : n'enregistre pas les informations relatives aux objets non infectés dans le journal.","Valeur du paramètres par défaut : No","ReportPackedObjects","Active ou désactive l'enregistrement dans le journal des informations relatives aux objets analysés qui font partie d'objets composés.","Vous pouvez activer ce paramètre par exemple pour confirmer qu'un objet qui se trouve dans une archive a bien été analysé par Kaspersky Endpoint Security.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives à l'analyse des objets des archives.","No : n'enregistre pas dans le journal les informations relatives à l'analyse des objets des archives.","Valeur du paramètres par défaut : No","ReportUnprocessedObjects","Active ou désactive l'enregistrement dans le journal des informations relatives aux objets non analysés.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non analysés.","No : n'enregistre pas dans le journal les informations relatives aux objets non analysés.","Valeur du paramètres par défaut : No","UseAnalyzer","Active ou désactive l'analyse heuristique.","Grâce à l'analyse heuristique, l'application peut détecter les nouvelles menaces avant leur détection par les analystes antivirus. ","Valeurs possibles :","Yes : active l'analyse heuristique.","No : désactive l'analyse heuristique.","Valeur par défaut : Yes.","HeuristicLevel","Niveau de l'analyse heuristique.","Vous pouvez définir le niveau de l'analyse heuristique. Celui-ci définit l'équilibre entre la minutie de la recherche des menaces, la charge sur les ressources du système d'exploitation et la durée de l'analyse. Plus le niveau d'analyse heuristique est élevé, plus le volume de ressources et le temps consacrés à l'analyse augmentent.","Valeurs possibles :","Light : analyse moins minutieuse, charge minimale du système ;","Medium : niveau moyen de l'analyse heuristique, charge équilibrée du système ;","Deep : analyse plus minutieuse, charge maximale du système.","Recommended : valeur recommandée.","Valeur par défaut : Recommended.","UseIChecker","Active ou désactive l'utilisation de la technologie iChecker.","Valeurs possibles :","Yes : active l'utilisation de la technologie iChecker.","No : désactive l'utilisation de la technologie iChecker.","Valeur par défaut : Yes.","ScanByAccessType","Ce paramètre permet de préciser le mode de protection en temps réel. Le paramètre ScanByAccessType s'applique seulement aux tâches de protection en temps réel.","Valeurs possibles :","SmartCheck : analyse le fichier en cas de tentative d'ouverture et l'analyse à nouveau en cas de tentative de fermeture s'il a été modifié. Si le processus lors de son fonctionnement adresse plusieurs requêtes à l'objet durant une certaine période de temps et le modifie, l'application analyse à nouveau l'objet uniquement lorsque le processus le ferme pour la dernière fois.","OpenAndModify : analyse le fichier en cas de tentative d'ouverture et l'analyse à nouveau en cas de tentative de fermeture s'il a été modifié.","Open : analyse le fichier en cas de tentative d'ouverture en lecture, ainsi qu'en exécution ou modification.","Valeur par défaut : SmartCheck.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","La description de la zone d'analyse contient des informations complémentaires sur la zone d'analyse. La longueur maximale la ligne définie par ce paramètre est de 4 096 caractères.","Valeur par défaut : All objects.","Exemple :","AreaDesc=\"Analyse des bases de messagerie\"","UseScanArea","Ce paramètre active ou désactive l'analyse de la zone indiquée. Pour exécuter la tâche, il faut inclure au moins une zone dans l'analyse.","Valeurs possibles :","Yes : analyse la zone indiquée.","No : n'analyse pas la zone indiquée.","Valeur par défaut : Yes.","AreaMask","Ce paramètre permet de limiter la zone d'analyse.","Dans la zone d'analyse, Kaspersky Endpoint Security analyse uniquement les fichiers désignés à l'aide des masques au format de l'interpréteur de commande.","Si le paramètre n'est pas défini, Kaspersky Endpoint Security analyse tous les objets de la zone d'analyse. Vous pouvez définir plusieurs valeurs de ce paramètre.","Valeur par défaut : * (analyser tous les objets).","Exemple :","AreaMask=*doc","Path","Ce paramètre permet de définir le chemin d'accès aux objets à analyser.","La valeur du paramètre Path se compose de deux éléments : <type de système de fichiers>:<protocole d'accès>. Il peut également contenir le chemin d'accès au répertoire dans le système de fichiers local.","Valeurs possibles :","<chemin d'accès au répertoire local> : analyse les objets dans le répertoire indiqué.","Shared:NFS : analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole NFS.","Shared:SMB : analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole SMB ;","AllRemoteMounted : analyse tous les répertoires distants montés sur l'ordinateur via les protocoles SMB et NFS.","AllShared :analyse toutes les ressources du système de fichiers de l'ordinateur accessibles via les protocoles SMB et NFS.","La section [ExcludedFromScanScope.item_#] contient les paramètres suivants :","AreaDesc","Description de la zone d'exclusion de l'analyse. Contient des informations complémentaires sur la zone d'exclusion.","La valeur par défaut n'est pas définie.","Exemple :","AreaDesc=\"Exclusion des fichiers SAMBA fragmentés\"","UseScanArea","Ce paramètre active ou désactive l'analyse de la zone indiquée.","Valeurs possibles :","Yes : exclut la zone indiquée.","No : n'exclut pas la zone indiquée.","Valeur par défaut : Yes.","Path","Ce paramètre permet de définir le chemin d'accès aux objets à exclure.","La valeur du paramètre Path se compose de deux éléments : <type de système de fichiers>:<protocole d'accès>. Il peut également contenir le chemin d'accès au répertoire dans le système de fichiers local.","Valeurs possibles :","<chemin d'accès au répertoire local> : exclut de l'analyse les objets du répertoire indiqué.","Shared:NFS : exclut de l'analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole NFS.","Shared:SMB : exclut de l'analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole SMB.","AllRemoteMounted : exclut de l'analyse tous les répertoires distants montés sur l'ordinateur via les protocoles SMB et NFS.","AllShared : exclut de l'analyse toutes les ressources du système de fichiers de l'ordinateur accessibles via les protocoles SMB et NFS."," Param&#xE8;tres de la t&#xE2;che de protection en temps r&#xE9;el ","161284.htm");
Page[78]=new Array("Définition d'une zone d'exclusion globale","Vous pouvez définir une zone d'exclusion globale pour la tâche de protection en temps réel. Les fichiers de la zone d'exclusion globale sont exclus des zones de protection en temps réel.","Pour créer une zone d'exclusion globale,","Enregistrez les paramètres de la tâche de protection en temps réel à l'aide de l'instruction suivante :kesl-control --get-settings <nom ou ID de la tâche> --file <chemin d'accès complet au fichier de configuration>","Ajoutez les sections [ExcludedFromScanScope.item_#] au fichier créé. Chaque section [ExcludedFromScanScope.item_#] contient les paramètres suivants :AreaMask : définit les masques de nom de fichier pour les fichiers à exclure de la zone de protection.AreaDesc : définit le nom unique de la zone d'exclusion.Path : définit le chemin d'accès aux fichiers à exclure de la zone de protection. Importez les paramètres du fichier de configuration dans la tâche de protection en temps réel à l'aide de la commande suivante :kesl-control --set-settings <nom ou ID de la tâche> --file <chemin d'accès complet au fichier de configuration>"," D&#xE9;finition d&apos;une zone d&apos;exclusion globale ","162099.htm");
Page[79]=new Array("Tâche d'analyse à la demande (Scan_My_Computer ID:2)","Cette section contient des informations sur la tâche d'analyse à la demande.","Dans cette sectionA propos de l'analyse à la demandeParamètres de la tâche d'analyse à la demande"," T&#xE2;che d&apos;analyse &#xE0; la demande (Scan_My_Computer ID:2) ","161286.htm");
Page[80]=new Array("A propos de l'analyse à la demande","L'analyse à la demande est une analyse complète ou personnalisée ponctuelle des fichiers de l'ordinateur réalisée par Kaspersky Endpoint Security. Kaspersky Endpoint Security peut exécuter simultanément plusieurs tâches d'analyse à la demande.","Kaspersky Endpoint Security crée par défaut une tâche d'analyse à la demande prédéfinie : une analyse complète. L'application analyse tous les objets sur les disques locaux de l'ordinateur, ainsi que tous les objets montés et partagés, accessibles via les protocoles Samba et NFS, selon les paramètres de sécurité recommandés.","Les utilisateurs peuvent créer des tâches personnalisées d'analyse à la demande.","Un tâche d'analyse personnalisée prédéfinie est également créée par défaut dans Kaspersky Endpoint Security.","En cas de relancement de l'application via le service watchdog ou, manuellement par l'utilisateur, lors de l'exécution d'une tâche d'analyse à la demande, la tâche est interrompue. L'application consigne l'événement OnDemandTaskInterrupted."," A propos de l&apos;analyse &#xE0; la demande ","161287.htm");
Page[81]=new Array("Paramètres de la tâche d'analyse à la demande","Cette section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche d'analyse à la demande.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","ScanArchived ","Active ou désactive l'analyse des archives (y compris les archives autoextractibles SFX). Kaspersky Endpoint Security détecte les menaces dans les archives mais ne les désinfecte pas. Les archives suivantes sont prises en charge : .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Valeurs possibles :","yes : analyse les archives ;","no : ,n'analyse pas les archives.","Valeur par défaut : Yes.","ScanSfxArchived","Active ou désactive l'analyse uniquement des archives autoextractibles (archives comprenant un module d'extraction d'exécutable).","Valeurs possibles :","Yes : analyser les archives autoextractibles.","No : ne pas analyser les archives autoextractibles.","Valeur par défaut : Yes.","ScanMailBases","Active ou désactive l'analyse des bases de données email des applications Microsoft Outlook®, Outlook Express, The Bat et autres clients de messagerie.","Valeurs possibles :","Yes : analyse les fichiers des bases de données email.","No : n'analyse pas les fichiers des bases de données email.","Valeur du paramètres par défaut : No","ScanPlainMail","Active ou désactive l'analyse des messages électroniques au format texte (plain text).","Valeurs possibles :","Yes : analyse les messages électroniques au format texte.","Non : n'analyse pas les messages électroniques au format texte.","Valeur du paramètres par défaut : No","UseSizeLimit","Active ou désactive l'application du paramètre SizeLimit (taille maximale de l'objet à analyser).","Valeurs possibles :","Yes : applique le paramètre SizeLimit.","No : n'applique pas le paramètre SizeLimit.","Valeur du paramètres par défaut : No","SizeLimit","Définit la taille maximale de l'objet à analyser (en mégaoctets). Si la taille de l'objet à analyser dépasse la valeur indiquée, Kaspersky Endpoint Security ignore l'objet.","Ce paramètre est appliqué avec le paramètre UseSizeLimit.","Valeurs possibles :","0 – 999,999.","0 : Kaspersky Endpoint Security analyse les objets de n'importe quelle taille.","Valeur par défaut : 0.","UseTimeLimit","Active ou désactive l'application du paramètre TimeLimit (durée maximale d'analyse de l'objet).","Valeurs possibles :","Yes : applique le paramètre TimeLimit.","No : n'applique pas le paramètre TimeLimit.","Valeur du paramètres par défaut : No.","TimeLimit","Définit la durée maximale d'analyse de l'objet (en secondes). Kaspersky Endpoint Security interrompt l'analyse de l'objet si sa durée dépasse la valeur définie pour ce paramètre.","Ce paramètre est appliqué avec le paramètre UseTimeLimit.","Valeurs possibles :","0 – 9999.","0 : la durée de l'analyse des objets n'est pas limitée.","Valeur par défaut : 0.","FirstAction","Sélection de la première action exécutée par Kaspersky Endpoint Security sur les objets infectés.","Valeurs possibles :","Cure (désinfecter) : Kaspersky Endpoint Security tente de désinfecter un objet en enregistrant une copie dans le stockage. Si la désinfection échoue, par exemple, le type de l'objet ou le type de la menace dans l'objet ne peut être désinfecté, Kaspersky Anti-Virus garde l'objet intact. Si la valeur de la première action est Cure, il est conseillé de définir une deuxième action via le paramètre SecondAction.","Remove : Kaspersky Endpoint Security supprime l'objet infecté après avoir créé au préalable sa copie de sauvegarde.","Recommended (exécution de l'action recommandée) : Kaspersky Endpoint Security sélectionne et exécute automatiquement une action sur l'objet en fonction des informations relatives à la menace détectée dans l'objet. Par exemple, Kaspersky Endpoint Security supprime automatiquement les chevaux de Troie car ils ne s'intègrent pas à d'autres fichiers et par conséquent, ils n'ont pas besoin d'être désinfectés.","Skip : Kaspersky Endpoint Security ne tente pas de désinfecter ou de supprimer un objet infecté. Les informations relatives à l'objet infecté sont consignées dans le journal.","Valeur par défaut : Recommended.","SecondAction","Sélection de la deuxième action exécutée par Kaspersky Endpoint Security sur les objets infectés. Kaspersky Endpoint Security exécute la deuxième action si la première échoue.","Les valeurs du paramètre SecondAction sont identiques à celles du paramètre FirstAction.","Si l'option Skip ou Remove est sélectionnée en tant que première action, il n'est pas nécessaire d'en choisir une deuxième. Dans les autres cas, il est recommandé d'indiquer deux actions. Si vous n'avez pas défini une deuxième action, Kaspersky Endpoint Security utilise l'action Skip en tant que deuxième action.","Valeur par défaut : Ignorer.","UseExcludeMasks","Active ou désactive l'exclusion de l'analyse des objets définis à l'aide du paramètre ExcludeMasks.","Valeurs possibles :","Yes : exclut les objets définis par le paramètre ExcludeMasks.","No : n'exclut pas les objets définis par le paramètre ExcludeMasks.","Valeur du paramètres par défaut : No","ExcludeMasks","Exclut de l'analyse les objets en fonction du nom ou du masque. Ce paramètre permet d'exclure de la zone d'analyse indiquée un fichier distinct en fonction de son nom ou plusieurs fichiers à l'aide des masques de l'interpréteur de commandes.","La valeur par défaut n'est pas définie.","Exemple :","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Active ou désactive l'exclusion de l'analyse les objets contenant les menaces indiquées par le paramètre ExcludeThreats.","Valeurs possibles :","Yes : exclut de l'analyse les objets contenant les menaces définies à l'aide du paramètre ExcludeThreats.","No : n'exclut pas de l'analyse les objets contenant les menaces désignées par le paramètre ExcludeThreats.","Valeur du paramètres par défaut : No","ExcludeThreats","Exclut de l'analyse les objets en fonction des noms des menaces détectées dans ceux-ci. Avant d'indiquer les valeurs de ce paramètre, assurez-vous que le paramètre UseExcludeThreats est activé.","Pour exclure un objet de l'analyse, indiquez le nom complet de la menace détectée dans cet objet, la chaîne de Kaspersky Security contenant le verdict d'infection de l'objet.","Par exemple, vous utilisez un utilitaire pour obtenir des informations sur le réseau. Pour que Kaspersky Endpoint Security ne le bloque pas, ajoutez le nom complet de la menace qu'il comporte à la liste des menaces exclues de l'analyse.","Le nom complet de la menace détectée dans l'objet est repris dans le journal de Kaspersky Endpoint Security. Vous pouvez également trouver le nom complet de la menace sur le site Internet de l'Encyclopédie des virus (). Pour trouver le nom d'une menace, saisissez le nom de l'application dans le champ Rechercher.","La valeur du paramètre est sensible à la casse.","La valeur par défaut n'est pas définie.","Exemple :","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Active ou désactive l'enregistrement dans le journal des informations sur les objets analysés que Kaspersky Endpoint Security a reconnus comme non infectés.","Vous pouvez activer ce paramètre par exemple pour confirmer qu'un objet en particulier a bien été analysé par Kaspersky Endpoint Security.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non infectés.","No : n'enregistre pas les informations relatives aux objets non infectés dans le journal.","Valeur du paramètres par défaut : No","ReportPackedObjects","Active ou désactive l'enregistrement dans le journal des informations relatives aux objets analysés qui font partie d'objets composés.","Vous pouvez activer ce paramètre par exemple pour confirmer qu'un objet qui se trouve dans une archive a bien été analysé par Kaspersky Endpoint Security.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives à l'analyse des objets des archives.","No : n'enregistre pas dans le journal les informations relatives à l'analyse des objets des archives.","Valeur du paramètres par défaut : No","ReportUnprocessedObjects","Active ou désactive l'enregistrement dans le journal des informations relatives aux objets non analysés.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non analysés.","No : n'enregistre pas dans le journal les informations relatives aux objets non analysés.","Valeur du paramètres par défaut : No","UseAnalyzer","Active ou désactive l'analyse heuristique.","Grâce à l'analyse heuristique, l'application peut détecter les nouvelles menaces avant leur détection par les analystes antivirus.","Valeurs possibles :","Yes : active l'analyse heuristique.","No : désactive l'analyse heuristique.","Valeur par défaut : Yes.","HeuristicLevel","Niveau de l'analyse heuristique.","Vous pouvez définir le niveau de l'analyse heuristique. Celui-ci définit l'équilibre entre la minutie de la recherche des menaces, la charge sur les ressources du système d'exploitation et la durée de l'analyse. Plus le niveau d'analyse heuristique est élevé, plus le volume de ressources et le temps consacrés à l'analyse augmentent.","Valeurs possibles :","Light : analyse moins minutieuse, charge minimale du système ;","Medium : niveau moyen de l'analyse heuristique, charge équilibrée du système ;","Deep : analyse plus minutieuse, charge maximale du système.","Recommended : valeur recommandée.","Valeur par défaut : Recommended.","UseIChecker","Active ou désactive l'utilisation de la technologie iChecker.","Valeurs possibles :","Yes : active l'utilisation de la technologie iChecker.","No : désactive l'utilisation de la technologie iChecker.","Valeur par défaut : Yes.","ScanByAccessType","Ce paramètre permet de préciser le mode de protection en temps réel. Le paramètre ScanByAccessType s'applique seulement aux tâches de protection en temps réel.","Valeurs possibles :","SmartCheck : analyse le fichier en cas de tentative d'ouverture et l'analyse à nouveau en cas de tentative de fermeture s'il a été modifié. Si le processus lors de son fonctionnement adresse plusieurs requêtes à l'objet durant une certaine période de temps et le modifie, l'application analyse à nouveau l'objet uniquement lorsque le processus le ferme pour la dernière fois.","OpenAndModify : analyse le fichier en cas de tentative d'ouverture et l'analyse à nouveau en cas de tentative de fermeture s'il a été modifié.","Open : analyse le fichier en cas de tentative d'ouverture en lecture, ainsi qu'en exécution ou modification.","Valeur par défaut : SmartCheck.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","La description de la zone d'analyse contient des informations complémentaires sur la zone d'analyse. La longueur maximale la ligne définie par ce paramètre est de 4 096 caractères.","Valeur par défaut : All objects.","Exemple :","AreaDesc=\"Analyse des bases de messagerie\"","UseScanArea","Ce paramètre active ou désactive l'analyse de la zone indiquée. Pour exécuter la tâche, il faut inclure au moins une zone dans l'analyse.","Valeurs possibles :","Yes : analyse la zone indiquée.","No : n'analyse pas la zone indiquée.","Valeur par défaut : Yes.","AreaMask","Ce paramètre permet de limiter la zone d'analyse.","Dans la zone d'analyse, Kaspersky Endpoint Security analyse uniquement les fichiers désignés à l'aide des masques au format de l'interpréteur de commande.","Si le paramètre n'est pas défini, Kaspersky Endpoint Security analyse tous les objets de la zone d'analyse. Vous pouvez définir plusieurs valeurs de ce paramètre.","Valeur par défaut : * (analyser tous les objets).","Exemple :","AreaMask=*doc","Path","Ce paramètre permet de définir le chemin d'accès aux objets à analyser.","La valeur du paramètre Path se compose de deux éléments : <type de système de fichiers>:<protocole d'accès>. Il peut également contenir le chemin d'accès au répertoire dans le système de fichiers local.","Valeurs possibles :","<chemin d'accès au répertoire local> : analyse les objets dans le répertoire indiqué.","Shared:NFS : analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole NFS.","Shared:SMB : analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole SMB ;","AllRemoteMounted : analyse tous les répertoires distants montés sur l'ordinateur via les protocoles SMB et NFS.","AllShared :analyse toutes les ressources du système de fichiers de l'ordinateur accessibles via les protocoles SMB et NFS.","La section [ExcludedFromScanScope.item_#] contient les paramètres suivants :","AreaDesc","Description de la zone d'exclusion de l'analyse. Contient des informations complémentaires sur la zone d'exclusion.","La valeur par défaut n'est pas définie.","Exemple :","AreaDesc=\"Exclusion des fichiers SAMBA fragmentés\"","UseScanArea","Ce paramètre active ou désactive l'analyse de la zone indiquée.","Valeurs possibles :","Yes : exclut la zone indiquée.","No : n'exclut pas la zone indiquée.","Valeur par défaut : Yes.","Path","Ce paramètre permet de définir le chemin d'accès aux objets à exclure.","La valeur du paramètre Path se compose de deux éléments : <type de système de fichiers>:<protocole d'accès>. Il peut également contenir le chemin d'accès au répertoire dans le système de fichiers local.","Valeurs possibles :","<chemin d'accès au répertoire local> : exclut de l'analyse les objets du répertoire indiqué.","Shared:NFS : exclut de l'analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole NFS.","Shared:SMB : exclut de l'analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole SMB.","AllRemoteMounted : exclut de l'analyse tous les répertoires distants montés sur l'ordinateur via les protocoles SMB et NFS.","AllShared : exclut toutes les ressources du système de fichiers de l'ordinateur accessibles via les protocoles SMB et NFS."," Param&#xE8;tres de la t&#xE2;che d&apos;analyse &#xE0; la demande ","161288.htm");
Page[82]=new Array("Tâche d'analyse personnalisée (Scan_File ID :3)","Cette section contient des informations relatives à la tâche d'analyse personnalisée.","Dans cette sectionA propos de la tâche d'analyse personnaliséeParamètres de la tâche d'analyse personnalisée"," T&#xE2;che d&apos;analyse personnalis&#xE9;e (Scan_File ID&#xA0;:3) ","161290.htm");
Page[83]=new Array("A propos de la tâche d'analyse personnalisée","Une tâche d'analyse personnalisée utilise les paramètres appliqués par la commande --scan-file.","Il est possible d'analyse un fichier ou un répertoire à l'aide de la commande suivante :","--scan-file <chemin du fichier>","L'application crée une tâche d'analyse à la demande temporaire (ODS) avec les paramètres de la tâche Scan_File. Une fois l'analyse terminée, la tâche temporaire est supprimée automatiquement.","Il est possible de modifier les paramètres d'analyse de la tâche temporaire Scan_File via la ligne de commande."," A propos de la t&#xE2;che d&apos;analyse personnalis&#xE9;e ","161291.htm");
Page[84]=new Array("Paramètres de la tâche d'analyse personnalisée","Cette section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche d'analyse personnalisée.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","ScanArchived","Active ou désactive l'analyse des archives (y compris les archives autoextractibles SFX). Kaspersky Endpoint Security détecte les menaces dans les archives, mais ne les désinfecte pas. Les archives suivantes sont prises en charge : .zip; .7z*; .7-z; .rar; .iso; .cab; .jar; .bz;.bz2;.tbz;.tbz2; .gz;.tgz; .arj.","Valeurs possibles :","yes : analyse les archives ;","no : ,n'analyse pas les archives.","Valeur par défaut : Yes.","ScanSfxArchived","Active ou désactive l'analyse uniquement des archives autoextractibles (archives comprenant un module d'extraction d'exécutable).","Valeurs possibles :","Yes : analyser les archives autoextractibles.","No : ne pas analyser les archives autoextractibles.","Valeur par défaut : Yes.","ScanMailBases","Active ou désactive l'analyse des bases de données email des applications Microsoft Outlook®, Outlook Express, The Bat et autres clients de messagerie.","Valeurs possibles :","Yes : analyse les fichiers des bases de données email.","No : n'analyse pas les fichiers des bases de données email.","Valeur du paramètres par défaut : No","ScanPlainMail","Active ou désactive l'analyse des messages électroniques au format texte (plain text).","Valeurs possibles :","Yes : analyse les messages électroniques au format texte.","Non : n'analyse pas les messages électroniques au format texte.","Valeur du paramètres par défaut : No","UseSizeLimit","Active ou désactive l'application du paramètre SizeLimit (taille maximale de l'objet à analyser).","Valeurs possibles :","Yes : applique le paramètre SizeLimit.","No : n'applique pas le paramètre SizeLimit.","Valeur du paramètres par défaut : No","SizeLimit","Définit la taille maximale de l'objet à analyser (en mégaoctets). Si la taille de l'objet à analyser dépasse la valeur indiquée, Kaspersky Endpoint Security ignore l'objet.","Ce paramètre est appliqué avec le paramètre UseSizeLimit.","Valeurs possibles :","0 – 999,999.","0 : Kaspersky Endpoint Security analyse les objets de n'importe quelle taille.","Valeur par défaut : 0.","UseTimeLimit","Active ou désactive l'application du paramètre TimeLimit (durée maximale d'analyse de l'objet).","Valeurs possibles :","Yes : applique le paramètre TimeLimit.","No : n'applique pas le paramètre TimeLimit.","Valeur du paramètres par défaut : No.","TimeLimit","Définit la durée maximale d'analyse de l'objet (en secondes). Kaspersky Endpoint Security interrompt l'analyse de l'objet si sa durée dépasse la valeur définie pour ce paramètre.","Ce paramètre est appliqué avec le paramètre UseTimeLimit.","Valeurs possibles :","0-9999.","0 : la durée de l'analyse des objets n'est pas limitée.","Valeur par défaut : 0.","FirstAction","Sélection de la première action exécutée par Kaspersky Endpoint Security sur les objets infectés.","Valeurs possibles :","Cure (désinfecter) : Kaspersky Endpoint Security tente de désinfecter un objet en enregistrant une copie dans le stockage. Si la désinfection échoue, par exemple, le type de l'objet ou le type de la menace dans l'objet ne peut être désinfecté, Kaspersky Anti-Virus garde l'objet intact. Si la valeur de la première action est Cure, il est conseillé de définir une deuxième action via le paramètre SecondAction.","Remove : Kaspersky Endpoint Security supprime l'objet infecté après avoir créé au préalable sa copie de sauvegarde.","Recommended (exécution de l'action recommandée) : Kaspersky Endpoint Security sélectionne et exécute automatiquement une action sur l'objet en fonction des informations relatives à la menace détectée dans l'objet. Par exemple, Kaspersky Endpoint Security supprime automatiquement les chevaux de Troie car ils ne s'intègrent pas à d'autres fichiers et par conséquent, ils n'ont pas besoin d'être désinfectés.","Skip : Kaspersky Endpoint Security ne tente pas de désinfecter ou de supprimer un objet infecté. Les informations relatives à l'objet infecté sont consignées dans le journal.","Valeur par défaut : Recommended.","SecondAction","Sélection de la deuxième action exécutée par Kaspersky Endpoint Security sur les objets infectés. Kaspersky Endpoint Security exécute la deuxième action si la première échoue.","Les valeurs du paramètre SecondAction sont identiques à celles du paramètre FirstAction.","Si l'option Skip ou Remove est sélectionnée en tant que première action, il n'est pas nécessaire d'en choisir une deuxième. Dans les autres cas, il est recommandé d'indiquer deux actions. Si vous n'avez pas défini une deuxième action, Kaspersky Endpoint Security utilise l'action Skip en tant que deuxième action.","Valeur par défaut : Ignorer.","UseExcludeMasks","Active ou désactive l'exclusion de l'analyse des objets définis à l'aide du paramètre ExcludeMasks.","Valeurs possibles :","Yes : exclut les objets définis par le paramètre ExcludeMasks.","No : n'exclut pas les objets définis par le paramètre ExcludeMasks.","Valeur du paramètres par défaut : No","ExcludeMasks","Exclut de l'analyse les objets en fonction du nom ou du masque. Ce paramètre permet d'exclure de la zone d'analyse indiquée un fichier distinct en fonction de son nom ou plusieurs fichiers à l'aide des masques de l'interpréteur de commandes.","La valeur par défaut n'est pas définie.","Exemple :","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","Active ou désactive l'exclusion de l'analyse les objets contenant les menaces indiquées par le paramètre ExcludeThreats.","Valeurs possibles :","Yes : exclut de l'analyse les objets contenant les menaces définies à l'aide du paramètre ExcludeThreats.","No : n'exclut pas de l'analyse les objets contenant les menaces désignées par le paramètre ExcludeThreats.","Valeur du paramètres par défaut : No","ExcludeThreats","Exclut de l'analyse les objets en fonction des noms des menaces détectées dans ceux-ci. Avant d'indiquer les valeurs de ce paramètre, assurez-vous que le paramètre UseExcludeThreats est activé.","Pour exclure un objet de l'analyse, indiquez le nom complet de la menace détectée dans cet objet, la chaîne de Kaspersky Security contenant le verdict d'infection de l'objet.","Par exemple, vous utilisez un utilitaire pour obtenir des informations sur le réseau. Pour que Kaspersky Endpoint Security ne le bloque pas, ajoutez le nom complet de la menace qu'il comporte à la liste des menaces exclues de l'analyse.","Le nom complet de la menace détectée dans l'objet est repris dans le journal de Kaspersky Endpoint Security. Vous pouvez également trouver le nom complet de la menace sur le site Internet de l'Encyclopédie des virus (). Pour trouver le nom d'une menace, saisissez le nom de l'application dans le champ Rechercher.","La valeur du paramètre est sensible à la casse.","La valeur par défaut n'est pas définie.","Exemple :","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Active ou désactive l'enregistrement dans le journal des informations sur les objets analysés que Kaspersky Endpoint Security a reconnus comme non infectés.","Vous pouvez activer ce paramètre par exemple pour confirmer qu'un objet en particulier a bien été analysé par Kaspersky Endpoint Security.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non infectés.","No : n'enregistre pas les informations relatives aux objets non infectés dans le journal.","Valeur du paramètres par défaut : No","ReportPackedObjects","Active ou désactive l'enregistrement dans le journal des informations relatives aux objets analysés qui font partie d'objets composés.","Vous pouvez activer ce paramètre par exemple pour confirmer qu'un objet qui se trouve dans une archive a bien été analysé par Kaspersky Endpoint Security.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives à l'analyse des objets des archives.","No : n'enregistre pas dans le journal les informations relatives à l'analyse des objets des archives.","Valeur du paramètres par défaut : No","ReportUnprocessedObjects","Active ou désactive l'enregistrement dans le journal des informations relatives aux objets non analysés.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non analysés.","No : n'enregistre pas dans le journal les informations relatives aux objets non analysés.","Valeur du paramètres par défaut : No","UseAnalyzer","Active ou désactive l'analyse heuristique. Grâce à l'analyse heuristique, l'application peut détecter les nouvelles menaces avant leur détection par les analystes antivirus. ","Valeurs possibles :","Yes : active l'analyse heuristique.","No : désactive l'analyse heuristique.","Valeur par défaut : Yes.","HeuristicLevel","Niveau de l'analyse heuristique.","Vous pouvez définir le niveau de l'analyse heuristique. Celui-ci définit l'équilibre entre la minutie de la recherche des menaces, la charge sur les ressources du système d'exploitation et la durée de l'analyse. Plus le niveau d'analyse heuristique est élevé, plus le volume de ressources et le temps consacrés à l'analyse augmentent.","Valeurs possibles :","Light : analyse moins minutieuse, charge minimale du système ;","Medium : niveau moyen de l'analyse heuristique, charge équilibrée du système ;","Deep : analyse plus minutieuse, charge maximale du système.","Recommended : valeur recommandée.","Valeur par défaut : Recommended.","UseIChecker","Active ou désactive l'utilisation de la technologie iChecker.","Valeurs possibles :","Yes : active l'utilisation de la technologie iChecker.","No : désactive l'utilisation de la technologie iChecker.","Valeur par défaut : Yes.","ScanByAccessType","Ce paramètre permet de préciser le mode de protection en temps réel. Le paramètre ScanByAccessType s'applique seulement aux tâches de protection en temps réel.","Valeurs possibles :","SmartCheck : analyse le fichier en cas de tentative d'ouverture et l'analyse à nouveau en cas de tentative de fermeture s'il a été modifié. Si le processus lors de son fonctionnement adresse plusieurs requêtes à l'objet durant une certaine période de temps et le modifie, l'application analyse à nouveau l'objet uniquement lorsque le processus le ferme pour la dernière fois.","OpenAndModify : analyse le fichier en cas de tentative d'ouverture et l'analyse à nouveau en cas de tentative de fermeture s'il a été modifié.","Open : analyse le fichier en cas de tentative d'ouverture en lecture, ainsi qu'en exécution ou modification.","Valeur par défaut : SmartCheck.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","La description de la zone d'analyse contient des informations complémentaires sur la zone d'analyse. La longueur maximale la ligne définie par ce paramètre est de 4 096 caractères.","Valeur par défaut : All objects.","Exemple :","AreaDesc=\"Analyse des bases de messagerie\"","UseScanArea","Ce paramètre active ou désactive l'analyse de la zone indiquée. Pour exécuter la tâche, il faut inclure au moins une zone dans l'analyse.","Valeurs possibles :","Yes : analyse la zone indiquée.","No : n'analyse pas la zone indiquée.","Valeur par défaut : Yes.","AreaMask","Ce paramètre permet de limiter la zone d'analyse.","Dans la zone d'analyse, Kaspersky Endpoint Security analyse uniquement les fichiers désignés à l'aide des masques au format de l'interpréteur de commande.","Si le paramètre n'est pas défini, Kaspersky Endpoint Security analyse tous les objets de la zone d'analyse. Vous pouvez définir plusieurs valeurs de ce paramètre.","Valeur par défaut : * (analyser tous les objets).","Exemple :","AreaMask=*doc","Path","Ce paramètre permet de définir le chemin d'accès aux objets à analyser.","La valeur du paramètre Path se compose de deux éléments : <type de système de fichiers>:<protocole d'accès>. Il peut également contenir le chemin d'accès au répertoire dans le système de fichiers local.","Valeurs possibles :","<chemin d'accès au répertoire local> : analyse les objets dans le répertoire indiqué.","Shared:NFS : analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole NFS.","Shared:SMB : analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole SMB ;","AllRemoteMounted : analyse tous les répertoires distants montés sur l'ordinateur via les protocoles SMB et NFS.","AllShared :analyse toutes les ressources du système de fichiers de l'ordinateur accessibles via les protocoles SMB et NFS.","La section [ExcludedFromScanScope.item_#] contient les paramètres suivants :","AreaDesc","Description de la zone d'exclusion de l'analyse. Contient des informations complémentaires sur la zone d'exclusion.","La valeur par défaut n'est pas définie.","Exemple :","AreaDesc=\"Exclusion des fichiers SAMBA fragmentés\"","UseScanArea","Ce paramètre active ou désactive l'analyse de la zone indiquée.","Valeurs possibles :","Yes : exclut la zone indiquée.","No : n'exclut pas la zone indiquée.","Valeur par défaut : Yes.","Path","Ce paramètre permet de définir le chemin d'accès aux objets à exclure.","La valeur du paramètre Path se compose de deux éléments : <type de système de fichiers>:<protocole d'accès>. Il peut également contenir le chemin d'accès au répertoire dans le système de fichiers local.","Valeurs possibles :","<chemin d'accès au répertoire local> : exclut de l'analyse les objets du répertoire indiqué.","Shared:NFS : exclut de l'analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole NFS.","Shared:SMB : exclut de l'analyse les ressources du système de fichiers de l'ordinateur accessibles via le protocole SMB.","AllRemoteMounted : exclut de l'analyse tous les répertoires distants montés sur l'ordinateur via les protocoles SMB et NFS.","AllShared : exclut toutes les ressources du système de fichiers de l'ordinateur accessibles via les protocoles SMB et NFS."," Param&#xE8;tres de la t&#xE2;che d&apos;analyse personnalis&#xE9;e ","161292.htm");
Page[85]=new Array("Tâche d'analyse des secteurs d'amorçage (Boot_Scan ID:4)","Cette section contient des informations sur la tâche d'analyse des secteurs d'amorçage.","Dans cette sectionA propos de la tâche d'analyse des secteurs d'amorçageParamètres de la tâche d'analyse des secteurs d'amorçage"," T&#xE2;che d&apos;analyse des secteurs d&apos;amor&#xE7;age (Boot_Scan ID:4) ","161294.htm");
Page[86]=new Array("A propos de la tâche d'analyse des secteurs d'amorçage","La tâche d'analyse des secteurs d'amorçage permet d'analyser les secteurs d'amorçage sans définir une zone d'analyse."," A propos de la t&#xE2;che d&apos;analyse des secteurs d&apos;amor&#xE7;age ","161295.htm");
Page[87]=new Array("Paramètres de la tâche d'analyse des secteurs d'amorçage","Cette section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche d'analyse des secteurs d'amorçage.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","UseExcludeMasks ","Active ou désactive l'exclusion de l'analyse des objets définis à l'aide du paramètre ExcludeMasks.","Valeurs possibles :","Yes : exclut les objets définis par le paramètre ExcludeMasks.","No : n'exclut pas les objets définis par le paramètre ExcludeMasks.","Valeur du paramètres par défaut : No","ExcludeMasks","Exclut de l'analyse les objets en fonction du nom ou du masque. Ce paramètre permet d'exclure de la zone d'analyse indiquée un fichier distinct en fonction de son nom ou plusieurs fichiers à l'aide des masques de l'interpréteur de commandes.","La valeur par défaut n'est pas définie.","UseExcludeThreats","Active ou désactive l'exclusion de l'analyse les objets contenant les menaces indiquées par le paramètre ExcludeThreats.","Valeurs possibles :","Yes : exclut de l'analyse les objets contenant les menaces définies à l'aide du paramètre ExcludeThreats.","No : n'exclut pas de l'analyse les objets contenant les menaces désignées par le paramètre ExcludeThreats.","Valeur du paramètres par défaut : No.","ExcludeThreats","Exclut de l'analyse les objets en fonction des noms des menaces détectées dans ceux-ci. Avant d'indiquer les valeurs de ce paramètre, assurez-vous que le paramètre UseExcludeThreats est activé.","Pour exclure un objet de l'analyse, indiquez le nom complet de la menace détectée dans cet objet, la chaîne de Kaspersky Security contenant le verdict d'infection de l'objet.","Par exemple, vous utilisez un utilitaire pour obtenir des informations sur le réseau. Pour que Kaspersky Endpoint Security ne le bloque pas, ajoutez le nom complet de la menace qu'il comporte à la liste des menaces exclues de l'analyse.","Le nom complet de la menace détectée dans l'objet est repris dans le journal de Kaspersky Endpoint Security. Vous pouvez également trouver le nom complet de la menace sur le site Internet de l'Encyclopédie des virus (). Pour trouver le nom d'une menace, saisissez le nom de l'application dans le champ Rechercher.","La valeur du paramètre est sensible à la casse.","La valeur par défaut n'est pas définie.","ReportCleanObjects","Active ou désactive l'enregistrement dans le journal des informations sur les objets analysés que Kaspersky Endpoint Security a reconnus comme non infectés.","Vous pouvez activer ce paramètre par exemple pour confirmer qu'un objet en particulier a bien été analysé par Kaspersky Endpoint Security.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non infectés.","No : n'enregistre pas les informations relatives aux objets non infectés dans le journal.","Valeur du paramètres par défaut : No","ReportUnprocessedObjects","Active ou désactive la consignation des informations relatives aux fichiers qui n'ont pas été traités pour une raison particulière.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non traités. Il est déconseillé d'attribuer la valeur Yes à ce paramètre pour une longue période car l'enregistrement d'un volume important d'informations pourrait réduire les performances de l'application.","No : n'enregistre pas dans le journal les informations relatives aux objets non traités.","Valeur du paramètres par défaut : No","UseAnalyzer","Active ou désactive l'analyse heuristique. Grâce à l'analyse heuristique, l'application peut détecter les nouvelles menaces avant leur détection par les analystes antivirus.","Valeurs possibles :","Yes : active l'analyse heuristique.","No : désactive l'analyse heuristique.","Valeur par défaut : Yes.","HeuristicLevel","Niveau de l'analyse heuristique.","Vous pouvez définir le niveau de l'analyse heuristique. Celui-ci définit l'équilibre entre la minutie de la recherche des menaces, la charge sur les ressources du système d'exploitation et la durée de l'analyse. Plus le niveau d'analyse heuristique est élevé, plus le volume de ressources et le temps consacrés à l'analyse augmentent.","Valeurs possibles :","Light : analyse moins minutieuse, charge minimale du système ;","Medium : niveau moyen de l'analyse heuristique, charge équilibrée du système ;","Deep : analyse plus minutieuse, charge maximale du système.","Recommended : valeur recommandée.","Valeur par défaut : Recommended.","Action","Sélection de l'action exécutée par Kaspersky Endpoint Security sur les objets infectés.","Valeurs possibles :","Cure (désinfecter) : Kaspersky Endpoint Security tente de désinfecter un objet en enregistrant une copie dans le stockage. Si la désinfection échoue, par exemple, le type de l'objet ou le type de la menace dans l'objet ne peut être désinfecté, Kaspersky Anti-Virus garde l'objet intact.","Skip : Kaspersky Endpoint Security ne tente pas de désinfecter ou de supprimer un objet infecté. Les informations relatives à l'objet infecté sont consignées dans le journal.","Valeur par défaut : Réparer."," Param&#xE8;tres de la t&#xE2;che d&apos;analyse des secteurs d&apos;amor&#xE7;age ","161296.htm");
Page[88]=new Array("Tâche d'analyse de la mémoire des processus (Memory_Scan ID:5)","Cette section contient des informations sur la tâche d'analyse de la mémoire des processus.","Dans cette sectionA propos de la tâche d'analyse de la mémoire des processusParamètres de la tâche d'analyse de la mémoire des processus"," T&#xE2;che d&apos;analyse de la m&#xE9;moire des processus (Memory_Scan ID:5) ","161297.htm");
Page[89]=new Array("A propos de la tâche d'analyse de la mémoire des processus","La tâche d'analyse de la mémoire des processus permet d'analyser la mémoire des processus sans définir une zone d'analyse."," A propos de la t&#xE2;che d&apos;analyse de la m&#xE9;moire des processus ","161298.htm");
Page[90]=new Array("Paramètres de la tâche d'analyse de la mémoire des processus","Cette section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche d'analyse de la mémoire des processus.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","UseExcludeThreats","Active ou désactive l'exclusion de l'analyse les objets contenant les menaces indiquées par le paramètre ExcludeThreats.","Valeurs possibles :","Yes : exclut de l'analyse les objets contenant les menaces définies à l'aide du paramètre ExcludeThreats.","No : n'exclut pas de l'analyse les objets contenant les menaces désignées par le paramètre ExcludeThreats.","Valeur du paramètres par défaut : No","ExcludeThreats","Exclut de l'analyse les objets en fonction des noms des menaces détectées dans ceux-ci. Avant d'indiquer les valeurs de ce paramètre, assurez-vous que le paramètre UseExcludeThreats est activé.","Pour exclure un objet de l'analyse, indiquez le nom complet de la menace détectée dans cet objet, la chaîne de Kaspersky Security contenant le verdict d'infection de l'objet.","Par exemple, vous utilisez un utilitaire pour obtenir des informations sur le réseau. Pour que Kaspersky Endpoint Security ne le bloque pas, ajoutez le nom complet de la menace qu'il comporte à la liste des menaces exclues de l'analyse.","Le nom complet de la menace détectée dans l'objet est repris dans le journal de Kaspersky Endpoint Security. Vous pouvez également trouver le nom complet de la menace sur le site Internet de l'Encyclopédie des virus (). Pour trouver le nom d'une menace, saisissez le nom de l'application dans le champ Rechercher.","La valeur du paramètre est sensible à la casse.","La valeur par défaut n'est pas définie.","ReportCleanObjects","Active ou désactive l'enregistrement dans le journal des informations sur les objets analysés que Kaspersky Endpoint Security a reconnus comme non infectés.","Vous pouvez activer ce paramètre par exemple pour confirmer qu'un objet en particulier a bien été analysé par Kaspersky Endpoint Security.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non infectés.","No : n'enregistre pas les informations relatives aux objets non infectés dans le journal.","Valeur du paramètres par défaut : No","ReportUnprocessedObjects","Active ou désactive la consignation des informations relatives aux fichiers qui n'ont pas été traités pour une raison particulière.","Valeurs possibles :","Yes : enregistre dans le journal les informations relatives aux objets non traités. Il est déconseillé d'attribuer la valeur Yes à ce paramètre pour une longue période car l'enregistrement d'un volume important d'informations pourrait réduire les performances de l'application.","No : n'enregistre pas dans le journal les informations relatives aux objets non traités.","Valeur du paramètres par défaut : No","Action","Sélection de l'action exécutée par Kaspersky Endpoint Security sur les objets infectés.","Valeurs possibles :","Cure (désinfecter) : Kaspersky Endpoint Security tente de désinfecter un objet en enregistrant une copie dans le stockage. Si la désinfection échoue, par exemple, le type de l'objet ou le type de la menace dans l'objet ne peut être désinfecté, Kaspersky Anti-Virus garde l'objet intact.","Skip : Kaspersky Endpoint Security ne tente pas de désinfecter ou de supprimer un objet infecté. Les informations relatives à l'objet infecté sont consignées dans le journal.","Valeur par défaut : Réparer."," Param&#xE8;tres de la t&#xE2;che d&apos;analyse de la m&#xE9;moire des processus ","161299.htm");
Page[91]=new Array("Tâche de mise à jour (ID de mise à jour :6)","Cette section contient des informations relatives à la tâche de mise à jour.","Dans cette sectionA propos de la mise à jour des bases de données et des modules de l'applicationA propos des sources de mises à jourParamètres des tâches de mise à jourInstallation manuelle d'une mise à jour de l'application"," T&#xE2;che de mise &#xE0; jour (ID de mise &#xE0; jour&#xA0;:6) ","161300.htm");
Page[92]=new Array("A propos de la mise à jour des bases de données et des modules de l'application","La mise à jour des bases et des modules de Kaspersky Endpoint Security garantit l'actualité de la protection de votre ordinateur. De nouveaux virus et autres applications malveillantes apparaissent chaque jour à travers le monde. Les bases de données de Kaspersky Endpoint Security contiennent des informations relatives aux menaces et aux moyens de les neutraliser. Afin de pouvoir détecter les menaces rapidement, vous êtes vivement encouragé à mettre à jour régulièrement les bases de données et les modules de l'application.","Pour pouvoir bénéficier de ces mises à jour régulières, votre licence doit être active. Sans licence, vous ne pourrez réaliser qu'une seule mise à jour.","La source principale de mises à jour pour Kaspersky Endpoint Security sont les serveurs de mise à jour de Kaspersky Lab.","Le téléchargement du paquet de mises à jour depuis les serveurs de mise à jour de Kaspersky Lab requiert une connexion à Internet pour l'ordinateur. Les paramètres de la connexion Internet sont définis automatiquement par défaut. Si vous utilisez un serveur proxy, il faut adapter les paramètres de la protection.","Lors de la réalisation d'une mise à jour, les objets suivants sont téléchargés et installés sur l'ordinateur :","Bases de données de Kaspersky Endpoint Security. Pendant l'installation, Kaspersky Endpoint Security récupère les bases les plus récentes depuis un des serveurs HTTP de mise à jour de Kaspersky Lab. Si la tâche prédéfinie avec les paramètres par défaut (ID=6) est utilisée pour la mise à jour, Kaspersky Endpoint Security met à jour les bases une fois toutes les 60 minutes. Vous pouvez modifier les paramètres de la tâche de mise à jour prédéfinie des bases et des modules de l'application et créer des tâches personnalisées de mise à jour.Kaspersky Endpoint Security continue à utiliser la version antérieure des bases installées si le chargement de la mise à jour des bases de données s'interrompt ou se solde par une erreur.","Par défaut l'application inscrit au journal l'événement Les bases sont dépassées (AVBasesAreOutOfDate), si les dernières mises à jour des bases de données installées ont été publiées sur le serveur de Kaspersky Lab il y a plus d'un jour, mais moins de sept. Si les bases n'ont pas été mises à jour depuis sept jours, Kaspersky Endpoint Security enregistre l'événement Les bases de données sont périmées (AVBasesAreTotallyOutOfDate) dans le journal. Une base de données est considérée comme étant à jour si son téléchargement remonte à moins de 24 heures.","Mises à jour de l'application. Outre les bases de données de Kaspersky Endpoint Security, vous pouvez également mettre à jour l'application elle-même. La mise à jour de l'application élimine les vulnérabilités dans Kaspersky Endpoint Security ou améliore les fonctions existantes.Il est possible d'installer une mise à jour de l'application quel que soit l'état de l'application (lancée ou arrêtée, administrée par une stratégie de Kaspersky Security Center) et la planification des mises à jour.","Kaspersky Endpoint Security continue à protéger votre ordinateur durant la mise à jour de l'application.","Kaspersky Endpoint Security migre les paramètres de l'application, ainsi que le journal, automatiquement. Les paramètres de la version antérieure de l'application sont exportés au lancement de la version mise à jour.","En cas de dysfonctionnement de Kaspersky Endpoint Security après l'installation de la mise à jour de l'application, l'application revient automatiquement à sa version antérieure. Un message relatif à cet événement s'affiche. Nous vous conseillons de contacter le Support Technique de Kaspersky Lab.","Lors de la mise à jour, l'application et les bases de données installées sur votre ordinateur sont comparées à la version à jour présente sur la source de mises à jour. Si vos bases de données et les modules de l'application diffèrent des versions respectives à jour, la portion manquante des mises à jour est installée sur l'ordinateur.","Si les bases de données sont obsolètes, le paquet de mise à jour peut être volumineux, ce qui pourrait provoquer du trafic Internet complémentaire (jusqu'à plusieurs dizaines de Mo)."," A propos de la mise &#xE0; jour des bases de donn&#xE9;es et des modules de l&apos;application ","161301.htm");
Page[93]=new Array("A propos des sources de mises à jour","Une source des mises à jour est une ressource qui contient les mises à jour des bases de données et des modules de l'application Kaspersky Endpoint Security. Les sources de mises à jour peuvent être des serveurs FTP ou HTTP (par exemple, Kaspersky Security Center, les serveurs de mise à jour de Kaspersky Lab) ou des répertoires locaux ou réseau montés au préalable par l'utilisateur.","Dans la tâche de la mise à jour prédéfinie, la source de mise à jour par défaut sont les serveurs de mise à jour de Kaspersky Lab. Les mises à jour des bases de données et des modules de l'application sont installées sur les serveurs de mise à jour pour de nombreuses applications de Kaspersky Lab. Les mises à jour sont téléchargées via les protocoles HTTP.","Si, pour une raison quelconque, vous ne pouvez pas utiliser les serveurs de mise à jour de Kaspersky Lab en tant que source des mises à jour, vous pouvez récupérer les mises à jour sur une source de mises à jour définie par l'utilisateur, à savoir un répertoire local ou réseau (SMB/NFS) qui a été monté par l'utilisateur ou un serveur FTP ou HTTP. Vous pouvez indiquer la sources des mises à jour personnalisée dans le fichier de configuration de la tâche de mise à jour."," A propos des sources de mises &#xE0; jour ","161302.htm");
Page[94]=new Array("Paramètres des tâches de mise à jour","La section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche de mise à jour.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","SourceType","Ce paramètre permet de choisir la source sur laquelle Kaspersky Endpoint Security va récupérer les mises à jour.","Valeurs possibles :","KLServers : Kaspersky Endpoint Security récupère les mises à jour depuis un des serveurs de mise à jour de Kaspersky Lab. Les mises à jour sont téléchargées via le protocole HTTP.","SCServer : Kaspersky Endpoint Security télécharge les mises à jour sur l'ordinateur protégé depuis le serveur d'administration Kaspersky Security Center installé sur le réseau local. Vous pouvez sélectionner cette source de mise à jour si vous utilisez l'application Kaspersky Security Center pour l'administration centralisée de la protection antivirus des ordinateurs au sein de votre entreprise.","Custom : Kaspersky Endpoint Security télécharge les mises à jour depuis la source personnalisée définie dans la section [CommonSettings:CustomSources]. Vous pouvez désigner les répertoires des serveurs HTTP, les répertoires sur tout appareil monté sur l'ordinateur protégé, compris les répertoires des ordinateurs distants montés via les protocoles Samba ou NFS.","Valeur par défaut : KLServers.","UseKLServersWhenUnavailable","Ce paramètre permet de configurer l'accès de Kaspersky Endpoint Security aux serveurs de mise à jour de Kaspersky Lab si toutes les sources définies par l'utilisateur sont inaccessibles.","Valeurs possibles :","Yes : Kaspersky Endpoint Security contacte les serveurs de mise à jour de Kaspersky Lab si toutes les sources de mise à jour définies par l'utilisateur sont inaccessibles.","No : Kaspersky Endpoint Security ne contacte pas les serveurs de mise à jour de Kaspersky Lab si toutes les sources de mise à jour définies par l'utilisateur sont inaccessibles.","Valeur par défaut : Yes.","IgnoreProxySettingsForKLServers","Ce paramètre permet de configurer l'utilisation du serveur proxy pour vous connecter aux serveurs de mise à jour de Kaspersky Lab.","Valeurs possibles :","Yes : Kaspersky Endpoint Security n'utilise par le serveur proxy pour se connecter aux serveurs de mise à jour de Kaspersky Lab.","No : Kaspersky Endpoint Security utilise un serveur proxy pour se connecter aux serveurs de mise à jour de Kaspersky Lab.","Valeur du paramètres par défaut : No","IgnoreProxySettingsForCustomSources","Ce paramètre permet de configurer l'utilisation d'un serveur proxy pour vous connecter aux sources utilisateur de mise à jour. Vous devez activer ce paramètre si l'accès à un serveur proxy est requis pour établir la connexion à un des serveurs de mise à jour HTTP personnalisé.","Valeurs possibles :","Yes : Kaspersky Endpoint Security n'utilise pas de serveur proxy pour se connecter aux sources de mise à jour définies par l'utilisateur.","No : Kaspersky Endpoint Security utilise un serveur proxy pour se connecter aux sources de mise à jour définies par l'utilisateur.","Valeur du paramètres par défaut : No","ApplicationUpdateMode","Définit le mode de téléchargement et d'installation des mises à jour de l'application.","Valeurs possibles :","Disable : ne télécharge et n'installe pas les mises à jour de l'application","DownloadOnly : télécharge les mises à jour de l'application mais ne les installe pas.","DownloadAndInstall : télécharge et installe automatiquement les mises à jour de l'application.","Valeur par défaut : DownloadOnly.","ConnectionTimeout","Ce paramètre permet de définir le délai d'attente (en secondes) de la réponse depuis une source de mise à jour, comme un serveur HTTP, en cas de connexion à celle-ci. Si la source de mise à jour n'a pas répondu à l'issue du délai indiqué, Kaspersky Endpoint Security contacte la source de mise à jour suivante dans la liste.","Vous pouvez indiquer uniquement des nombres entiers compris entre 0 et 120.","Valeur par défaut : 10.","La section [CustomSources.item_#] contient les paramètres suivants :","URL","Ce paramètre permet d'indiquer l'adresse de la source de mise à jour personnalisée sur le réseau local ou sur Internet.","La valeur par défaut n'est pas définie.","Exemple :","URL=http://example.com/bases/ : adresse du serveur HTTP sur lequel se trouve le répertoire contenant les mises à jour.","URL =/home/bases/ : répertoire qui contient les bases de l'application sur l'ordinateur protégé.","Enabled","Ce paramètre permet d'activer ou de désactiver l'utilisation de la source de mise à jour désignée par le paramètre URL. Pour exécuter la tâche, il faut utiliser au moins une source de mises à jour.","Valeurs possibles :","Yes : Kaspersky Endpoint Security utilise la source de mise à jour.","No : Kaspersky Endpoint Security n'utilise pas la source de mise à jour.","La valeur par défaut n'est pas définie.","Exemple :","Enabled=Yes"," Param&#xE8;tres des t&#xE2;ches de mise &#xE0; jour ","161303.htm");
Page[95]=new Array("Installation manuelle d'une mise à jour de l'application","Vous pouvez installer manuellement la mise à jour de l'application via la ligne de commande. Pour pouvoir installer la mise à jour de l'application, Kaspersky Endpoint Security doit être installé sur votre ordinateur.","Pour installer Kaspersky Endpoint Security depuis un paquet au format RPM, exécutez la commande suivante :","# rpm –U <nom du paquet rpm>.rpm","Installer une mise à jour de Kaspersky Endpoint Security installée à l'aide d'un paquet au format DEB, exécutez la commande suivante :","# dpkg -i <nom du paquet deb>.deb","Le processus de mise à jour de l'application est lancé.","Il faudra peut-être relancé l'application ou le système d'exploitation. Le message correspondant est affiché. Après le redémarrage de l'application ou du système d'exploitation, la version mise à jour de Kaspersky Endpoint Security est lancée.","Après la mise à jour de l'application, il faudra peut-être accepter à nouveau le Contrat de licence utilisateur final et/ou la Déclaration de Kaspersky Security Network. ","Pour accepter le Contrat de licence utilisateur final,","lisez le texte du Contrat de licence utilisateur final.Si vous acceptez les dispositions du Contrat de licence utilisateur final, définissez la variable d'environnement :# KESL_EULA_AGREED=Yes rpm -U <nom du paquet rpm>.rpm pour un paquet rpm.# KESL_EULA_AGREED=Yes dpkg -i <nom du paquet deb>.deb pour un paquet deb.Pour accepter la Déclaration de Kaspersky Security Network,","lisez le texte de la Déclaration de Kaspersky Security Network.Si vous acceptez le texte de la Déclaration de Kaspersky Security Network, définissez la variable d'environnement :# KESL_USE_KSN=Yes rpm -U <nom du paquet rpm>.rpm pour un paquet rpm.# KESL_ USE_KSN=Yes dpkg -i <nom du paquet deb>.deb pour un paquet deb."," Installation manuelle d&apos;une mise &#xE0; jour de l&apos;application ","162013.htm");
Page[96]=new Array("Tâche de recul de mise à jour des bases (Rollback ID:7)","Cette section contient des informations relatives à la tâche de recul de mise à jour des bases.","La tâche de recul de mise à jour des bases permet de revenir à la version antérieure à la dernière mise à jour des bases de données.","Cette tâche n'a aucun paramètre.","Pour en savoir plus sur l'administration de la tâche de recul de mise à jour des bases, consultez la section \"Administration des tâches de Kaspersky Endpoint Security via la ligne de commande\"."," T&#xE2;che de recul de mise &#xE0; jour des bases (Rollback ID:7) ","161304.htm");
Page[97]=new Array("Tâche de copie des mises à jour (Retranslate ID:8)","Cette section contient des informations sur la tâche de copie des mises à jour.","Dans cette sectionA propos de la tâche de copie des mises à jourParamètres de la tâche de copie des mises à jour"," T&#xE2;che de copie des mises &#xE0; jour (Retranslate ID:8) ","161306.htm");
Page[98]=new Array("A propos de la tâche de copie des mises à jour","La tâche de copie des mises à jour permet de télécharger les mises à jour des bases de données et de l'application dans le répertoire sélectionné. Les mises à jour ne sont pas installées.","Les bases de données mises à jour copiées peuvent être utilisée uniquement par une application portant le même numéro de version."," A propos de la t&#xE2;che de copie des mises &#xE0; jour ","161307.htm");
Page[99]=new Array("Paramètres de la tâche de copie des mises à jour","La section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche de copie des mises à jour.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","SourceType ","Ce paramètre permet de choisir la source sur laquelle Kaspersky Endpoint Security va récupérer les mises à jour.","Valeurs possibles :","KLServers : Kaspersky Endpoint Security récupère les mises à jour depuis un des serveurs de mise à jour de Kaspersky Lab. Les mises à jour sont téléchargées via le protocole HTTP.","SCServer : Kaspersky Endpoint Security télécharge les mises à jour sur l'ordinateur protégé depuis le serveur d'administration Kaspersky Security Center installé sur le réseau local. Vous pouvez sélectionner cette source de mise à jour si vous utilisez l'application Kaspersky Security Center pour l'administration centralisée de la protection antivirus des ordinateurs au sein de votre entreprise.","Custom : Kaspersky Endpoint Security télécharge les mises à jour depuis la source personnalisée définie dans la section [CommonSettings:CustomSources]. Vous pouvez désigner les répertoires des serveurs HTTP, les répertoires sur tout appareil monté sur l'ordinateur protégé, compris les répertoires des ordinateurs distants montés via les protocoles Samba ou NFS.","Valeur par défaut : KLServers.","UseKLServersWhenUnavailable","Ce paramètre permet de configurer l'accès de Kaspersky Endpoint Security aux serveurs de mise à jour de Kaspersky Lab si toutes les sources définies par l'utilisateur sont inaccessibles.","Valeurs possibles :","Yes : Kaspersky Endpoint Security contacte les serveurs de mise à jour de Kaspersky Lab si toutes les sources de mise à jour définies par l'utilisateur sont inaccessibles.","No : Kaspersky Endpoint Security ne contacte pas les serveurs de mise à jour de Kaspersky Lab si toutes les sources de mise à jour définies par l'utilisateur sont inaccessibles.","Valeur par défaut : Yes.","IgnoreProxySettingsForKLServers","Ce paramètre permet de configurer l'utilisation du serveur proxy pour vous connecter aux serveurs de mise à jour de Kaspersky Lab.","Valeurs possibles :","Yes : Kaspersky Endpoint Security n'utilise par le serveur proxy pour se connecter aux serveurs de mise à jour de Kaspersky Lab.","No : Kaspersky Endpoint Security utilise un serveur proxy pour se connecter aux serveurs de mise à jour de Kaspersky Lab.","Valeur du paramètres par défaut : No","IgnoreProxySettingsForCustomSources","Ce paramètre permet de configurer l'utilisation d'un serveur proxy pour vous connecter aux sources utilisateur de mise à jour. Vous devez activer ce paramètre si l'accès à un serveur proxy est requis pour établir la connexion à un des serveurs de mise à jour HTTP personnalisé.","Valeurs possibles :","Yes : Kaspersky Endpoint Security n'utilise pas de serveur proxy pour se connecter aux sources de mise à jour définies par l'utilisateur.","No : Kaspersky Endpoint Security utilise un serveur proxy pour se connecter aux sources de mise à jour définies par l'utilisateur.","Valeur du paramètres par défaut : No","ConnectionTimeout","Ce paramètre permet de définir le délai d'attente (en secondes) de la réponse depuis une source de mise à jour, comme un serveur HTTP, en cas de connexion à celle-ci. Si la source de mise à jour n'a pas répondu à l'issue du délai indiqué, Kaspersky Endpoint Security contacte la source de mise à jour suivante dans la liste.","Vous pouvez indiquer uniquement des nombres entiers compris entre 0 et 120.","Valeur par défaut : 10.","RetranslationFolder","Ce paramètre permet de définir le répertoire dans lequel les mises à jour vont être copiées. Si le répertoire indiqué n'existe pas, Kaspersky Endpoint Security le crée pendant l'exécution de la tâche de copie des mises à jour.","La section [CustomSources.item_#] contient les paramètres suivants :","URL","Ce paramètre permet d'indiquer l'adresse de la source de mise à jour personnalisée sur le réseau local ou sur Internet.","La valeur par défaut n'est pas définie.","Exemple :","URL=http://example.com/bases/ : adresse du serveur HTTP sur lequel se trouve le répertoire contenant les mises à jour.","URL =/home/bases/ : répertoire qui contient les bases de l'application sur l'ordinateur protégé.","Enabled","Ce paramètre permet d'activer ou de désactiver l'utilisation de la source de mise à jour désignée par le paramètre URL. Pour exécuter la tâche, il faut utiliser au moins une source de mises à jour.","Valeurs possibles :","Yes : Kaspersky Endpoint Security utilise la source de mise à jour.","No : Kaspersky Endpoint Security n'utilise pas la source de mise à jour.","La valeur par défaut n'est pas définie.","AutoPatchDownload","Active ou désactive le téléchargement automatique des mises à jour de l'application.","Valeurs possibles : ","Yes : télécharge automatiquement les mises à jour de l'application","No : ne télécharge pas automatiquement les mises à jour de l'application","Valeur par défaut : Yes."," Param&#xE8;tres de la t&#xE2;che de copie des mises &#xE0; jour ","161308.htm");
Page[100]=new Array("Tâche License (License ID:9)","Cette section contient des informations relatives à la tâche License.","Dans cette sectionA propos de la tâche LicenseAjout d'une clé activeAjout d'une clé additionnelleSuppression d'une clé activeSuppression d'une clé additionnelleSaisie d'un code d'activation supplémentaire"," T&#xE2;che License (License ID:9) ","161309.htm");
Page[101]=new Array("A propos de la tâche License","La tâche License permet d'administrer les clés et les codes d'activation de Kaspersky Endpoint Security."," A propos de la t&#xE2;che License ","161310.htm");
Page[102]=new Array("Ajout d'une clé active","La commande --install-active-key ajoute une clé active. Pour en savoir plus sur les clés, consultez la section \"A propos de la clé\".","Syntaxe de la commande","kesl-control [-L] --install-active-key <chemin d'accès au fichier clé>|<code d'activation>","Arguments et clés","<chemin d'accès au fichier clé>","Le chemin d'accès au fichier clé ; si le fichier clé se trouve dans le répertoire actif, il suffit de saisir uniquement le nom du fichier.","Exemple :","Ajouter une clé depuis le fichier /home/test/00000001.key en tant que clé active :","kesl-control --install-active-key /home/test/00000001.keу"," Ajout d&apos;une cl&#xE9; active ","161311.htm");
Page[103]=new Array("Ajout d'une clé additionnelle","La commande --install-additional-key ajoute une clé additionnelle. Pour en savoir plus sur les clés, consultez la section \"A propos de la clé\".","Si aucune clé active n'est installée, la clé additionnelle est installée comme clé principale.","Syntaxe de la commande","kesl-control [-L] --install-additional-key <chemin d'accès au fichier clé>","Arguments et clés","<chemin d'accès au fichier clé>","Le chemin d'accès au fichier clé ; si le fichier clé se trouve dans le répertoire actif, il suffit de saisir uniquement le nom du fichier.","Exemple :","Installer la clé additionnelle depuis le fichier /home/test/00000002.key :","kesl-control --install-additional-key /home/test/00000002.key"," Ajout d&apos;une cl&#xE9; additionnelle ","161312.htm");
Page[104]=new Array("Suppression d'une clé active","La commande --revoke-active-key supprime la clé active.","Syntaxe de la commande","kesl-control [-L] --revoke-active-key"," Suppression d&apos;une cl&#xE9; active ","161313.htm");
Page[105]=new Array("Suppression d'une clé additionnelle","La commande --revoke-additional-key supprime la clé additionnelle.","Syntaxe de la commande","kesl-control [-L] --revoke-additional-key"," Suppression d&apos;une cl&#xE9; additionnelle ","161314.htm");
Page[106]=new Array("Saisie d'un code d'activation supplémentaire","La commande --install-additional-key saisit le code d'activation additionnel. Pour en savoir plus sur les codes d'activation, consultez la section \"A propos du code d'activation\".","Syntaxe de la commande","kesl-control [-L] --install-additional-key <code d'activation>"," Saisie d&apos;un code d&apos;activation suppl&#xE9;mentaire ","161315.htm");
Page[107]=new Array("Tâche d'administration du stockage (Backup ID :10)","Cette section contient des informations relatives à la tâche d'administration du stockage.","Dans cette sectionA propos du stockageParamètres de la tâche d'administration du stockageConsultation des numéros d'identification des objets dans le stockageA propos de la restauration des objets depuis le stockageRestauration des objets depuis le stockageSuppression des objets du stockage"," T&#xE2;che d&apos;administration du stockage (Backup ID&#xA0;:10) ","161316.htm");
Page[108]=new Array("A propos du stockage","Le stockage est une liste de copies de sauvegarde des fichiers qui ont été supprimés ou modifiés pendant la désinfection. La copie de sauvegarde est une copie du fichier créée lors de la première tentative de désinfection ou de suppression de ce fichier. Les copies de sauvegarde des fichiers sont conservées dans un format spécial et ne représentent aucun danger.","Il n'est pas toujours possible de préserver l'intégrité des fichiers lors de la désinfection. Si le fichier désinfecté contenait des informations critiques partiellement ou complètement perdues suite à la désinfection, vous pouvez tenter de restaurer la copie désinfectée du fichier dans son répertoire d'origine."," A propos du stockage ","161317.htm");
Page[109]=new Array("Paramètres de la tâche d'administration du stockage","La section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche d'administration du stockage.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","DaysToLive","Durée de conservation des objets dans le stockage (en jours).","Pour lever la restriction sur la durée de conservation des objets dans le stockage, attribuez la valeur 0.","Valeur par défaut : 90.","BackupSizeLimit","Volume maximal du stockage.","Quand la taille du stockage atteint la valeur maximale définie, Kaspersky Endpoint Security supprime les objets les plus anciens.","Valeurs possibles :","0 – 999,999 (en mégabytes).","Pour lever la restriction sur la taille du stockage, attribuez la valeur 0.","Valeur par défaut : 0.","BackupFolder","Chemin d'accès au répertoire du stockage. Vous pouvez définir un répertoire de stockage autre que celui défini par défaut.","En guise de répertoire de stockage, vous pouvez utiliser des répertoires sur n'importe quel appareil de l'ordinateur. Il est déconseillé de désigner des répertoires qui se trouvent sur des ordinateurs distants, par exemple des répertoires montés via les protocoles Samba et NFS.","Kaspersky Endpoint Security commence à placer les objets dans le répertoire indiqué après l'importation des paramètres du fichier dans la tâche de stockage et le relancement de Kaspersky Endpoint Security.","Si le répertoire précisé n'existe pas ou n'est pas disponible, Kaspersky Endpoint Security utilise le répertoire de stockage par défaut.","Valeur par défaut : /var/opt/kaspersky/kesl/objects-backup/"," Param&#xE8;tres de la t&#xE2;che d&apos;administration du stockage ","161318.htm");
Page[110]=new Array("Consultation des numéros d'identification des objets dans le stockage","Quand Kaspersky Anti-Virus place des objets dans le stockage, il leur attribue un identifiant numérique. L'ID intervient dans l'exécution d'actions sur l'objet, comme la restauration ou la suppression de l'objet dans le stockage.","Pour consulter les numéros d'identification des objets dans le stockage,","exécutez la commande : kesl-control -B --query","L'identifiant de l'objet apparaît dans la ligne ObjectId."," Consultation des num&#xE9;ros d&apos;identification des objets dans le stockage ","161319.htm");
Page[111]=new Array("A propos de la restauration des objets depuis le stockage","Kaspersky Endpoint Security conserve les objets dans le stockage sous forme chiffrée pour protéger le serveur contre d'éventuelles actions malveillantes.","Vous pouvez restaurer les objets depuis le stockage. La restauration des objets peut être nécessaire dans les cas suivants :","Lors de la désinfection d'un fichier infecté, Kaspersky Endpoint Security n'a pas réussi à préserver son intégrité et les informations contenues dans le fichier ne sont plus accessibles.Si vous estimez que l'objet ne présente aucun danger pour le serveur et si vous souhaitez l'utiliser, vous pouvez l'exclure de l'analyse afin que l'application ne le détecte plus lors des analyses suivantes. Pour cela, vous devez exclure l'objet en fonction du nom ou du nom de la menace détectée par la tâche de protection en temps réel ainsi qu'en fonction du nom de l'objet ou du nom de la menace détectée par la tâche d'analyse à la demande.La restauration d'objets infectés peut infecter l'ordinateur.","En cas restauration depuis le stockage, vous pouvez enregistrer le fichier sous un autre nom."," A propos de la restauration des objets depuis le stockage ","161320.htm");
Page[112]=new Array("Restauration des objets depuis le stockage","Pour restaurer un objet depuis le stockage, exécutez une des actions suivantes :","Pour restaurer l'objet sous son nom d'origine dans son emplacement initial, exécutez la commande suivante :kesl-control --restore <ID objet>","où ID objet correspond au numéro d'identification de l'objet dans le stockage.","Pour restaurer un objet sous un nouveau nom dans le répertoire indiqué, exécutez la commande suivante :kesl-control --restore <ID de l'objet> --file <nom du fichier et chemin d'accès>","Si le répertoire indiqué n'existe pas, Kaspersky Endpoint Security le crée."," Restauration des objets depuis le stockage ","161321.htm");
Page[113]=new Array("Suppression des objets du stockage","Pour supprimer un objet du stockage, exécutez la commande suivante :","kesl-control -B --mass-remove --query \"ObjectId == 'object ID>'\"","Pour supprimer plusieurs objets du stockage, exécutez la commande suivante :","kesl-control -B --mass-remove --query \"<champ><opérateur de comparaison> '<valeur>' [and <champ> <opérateur de comparaison>'<valeur>' ]* ]","Pour supprimer tous les objets du stockage, exécutez une des commandes suivantes :","kesl-control -B --mass-remove","ou","kesl-control -B --mass-remove --query"," Suppression des objets du stockage ","161322.htm");
Page[114]=new Array("Tâche de contrôle de l'intégrité des fichiers (Integrity_Monitoring ID:11)","Cette section contient des informations sur la tâche de contrôle de l'intégrité des fichiers.","Dans cette sectionA propos du contrôle de l'intégrité des fichiersContrôle de l'intégrité des fichiers à l'accès (OAFIM)Contrôle de l'intégrité des fichiers à la demande (ODFIM)Paramètres de la tâche de contrôle de l'intégrité des fichiers à l'accèsParamètres de la tâche de contrôle de l'intégrité des fichiers à la demande"," T&#xE2;che de contr&#xF4;le de l&apos;int&#xE9;grit&#xE9; des fichiers (Integrity_Monitoring ID:11) ","161323.htm");
Page[115]=new Array("A propos du contrôle de l'intégrité des fichiers","La tâche Contrôle de l'intégrité des fichiers vise à assurer le suivi des actions réalisées sur les fichiers et les répertoires dans la zone d'analyse définie dans les paramètres de la tâche. Cette tâche permet de trouver les modifications dans un fichier qui pourraient indiquer une violation de la sécurité sur le serveur protégé. Vous pouvez également configurer les modifications de fichier à suivre pendant les périodes où la surveillance est interrompue.","Pour utiliser la fonction de Contrôle de l'intégrité des fichiers, vous devez acheter une licence qui couvre cette fonction. Le Contrôle de l'intégrité des fichiers est désactivé par défaut.","Le Contrôle de l'intégrité des fichiers peut avoir lieu en temps réel en exécutant la tâche Contrôle de l'intégrité des fichiers à l'accès (OAFIM). Il est également possible de créer des tâches de contrôle de l'intégrité des fichiers à la demande (ODFIM) et de les exécuter.","Les tâches OAFIM et ODFIM envoie les notifications au sujet des modifications dans une liste de contrôle de l'accès d'un objet. Pour la tâche OAFIM, les détails relatifs à la nature exacte du changement ne sont pas signalés. Pour la tâche ODFIM, les informations relatives aux modifications d'attribut et aux déplacements de fichiers/de répertoires sont signalées."," A propos du contr&#xF4;le de l&apos;int&#xE9;grit&#xE9; des fichiers ","161324.htm");
Page[116]=new Array("Contrôle de l'intégrité des fichiers à l'accès (OAFIM)","Lorsque la tâche OAFIM est en cours d'exécution, chaque modification d'objet par une interception en temps réel des opérations exécutées sur les fichiers en temps réel. Quand un objet est modifié, Kaspersky Endpoint Security envoie un événement au Serveur d'administration Kaspersky Security Center. La somme de contrôle du fichier n'est pas calculée lors de l'exécution de la tâche. La tâche OAFIM ne contrôle pas les modifications des fichiers (attributs et contenu) avec des liens matériels qui ne se trouvent pas dans une zone d'analyse.","Kaspersky Endpoint Security contrôle les opérations exécutées sur les fichiers pour des fichiers particuliers ou dans les zones définies à l'aide des paramètres de la tâche.","Zones de contrôle","Il faut toujours définir les zones de contrôle des tâches de contrôle de l'intégrité des fichiers. L'administrateur peut modifier en temps réel les zones d'analyse et de contrôle. Si aucune zone de contrôle n'est définie, les paramètres de la tâche ne peuvent pas être enregistrés dans le fichier de configuration. Quand une zone de contrôle ou d'exclusion est ajoutée, l'application ne vérifie pas si le répertoire défini existe.","Vous pouvez définir plusieurs zones de contrôle.","Zones d'exclusion du contrôle","Il est possible de créer des exclusions pour la zone de contrôle. Les exclusions sont définies pour chaque zone distincte et fonctionnent uniquement pour la zone de contrôle indiquée. Vous pouvez définir plusieurs zones d'exclusion.","La priorité des exclusions est supérieure à celle des zones de contrôle et les exclusions ne sont pas contrôlées par une tâche, même si un répertoire ou un fichier indiqué figure dans la zone de contrôle. Si les paramètres d'une des règles définissent une zone de contrôle à un niveau inférieur à celui d'un répertoire indiqué dans les exclusions, la zone de contrôle n'est pas prise en compte lors de l'exécution de la tâche.","Pour définir des exclusions, vous pouvez utiliser les mêmes masques d'interpréteur de ligne de commande que ceux utilisés pour indiquer les zones de contrôle.","Paramètres contrôlés","La tâche Contrôle de l'intégrité des fichiers est à l'affût des modifications apportées aux paramètres suivants :","contenu (write (), truncate (), etc.)métadonnées (possession rights (chmod / chown))Horodateurs (utimensat)attributs étendus (setxattr) et autresLes limites techniques du système d'exploitation Linux ne permettent pas au composant Contrôle de l'intégrité des fichiers d'identifier l'administrateur ou le processus qui a modifié un fichier."," Contr&#xF4;le de l&apos;int&#xE9;grit&#xE9; des fichiers &#xE0; l&apos;acc&#xE8;s (OAFIM) ","161948.htm");
Page[117]=new Array("Contrôle de l'intégrité des fichiers à la demande (ODFIM)","Lors de l'exécution de la tâche ODFIM, chaque modification d'objet est confirmée via la comparaison de l'état actuel des objets surveillés à l'état d'origine, défini au préalable comme référence.","Vous pouvez créer plusieurs tâches ODFIM.","Référence","La référence est établie lors de la première exécution de la tâche ODFIM sur l'ordinateur. Une référence distincte est créée pour chaque tâche ODFIM. La tâche est réalisée uniquement si la référence correspond à la zone de contrôle. Si la référence ne correspond pas à la zone de contrôle, Kaspersky Endpoint Security génère un événement à propos de la violation de l'intégrité du fichier.","Il est possible de recréer une référence pour une tâche à l'aide du paramètre correspondant. La référence est à nouveau générée après l'exécution de la tâche ODFIM.","Une référence est également à nouveau générée après la modification des paramètres d'une tâche, par exemple si une nouvelle zone de contrôle est ajoutée. La nouvelle référence est générée lors de l'exécution suivante de la tâche.","La tâche ODFIM crée un stockage pour les références sur un ordinateur doté du composant Contrôle de l'intégrité des fichiers.","Vous pouvez supprimer une référence uniquement si vous supprimez la tâche ODFIM correspondante. "," Contr&#xF4;le de l&apos;int&#xE9;grit&#xE9; des fichiers &#xE0; la demande (ODFIM) ","161949.htm");
Page[118]=new Array("Paramètres de la tâche de contrôle de l'intégrité des fichiers à l'accès","Cette section décrit les paramètres que vous pouvez définir pour la tâche de Contrôle de l'intégrité des fichiers à l'accès.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites ci-dessous.","UseExcludeMasks","Active ou désactive l'exclusion de la zone d'analyse des objets définis à l'aide du paramètre ExcludeMasks.","Le paramètre UseExcludeMasks fonctionne uniquement si le paramètre ExcludeMasks est défini.","Valeurs possibles :","Yes : exclut de la zone d'analyse les objets définis par le paramètre ExcludeMasks","No : n'exclut pas de la zone d'analyse les objets définis par le paramètre ExcludeMasks.","Valeur du paramètres par défaut : No","ExcludeMasks","Définit une liste de masques qui indiquent les objets à exclure de la zone d'analyse.","Avant de définir ce paramètre, confirmez que le paramètre UseExcludeMasks possède la valeur Yes.","Les masques sont définis dans le format de l'interpréteur de commandes. ","Si vous souhaitez définir plusieurs masques, chaque masque doit figurer sur sa propre ligne et il faut définir un nouvel index (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Valeur par défaut : non définie.","Section [ScanScope.item_#]","Les sections [ScanScope.item_#] définissent les zones que la tâche Contrôle de l'intégrité des fichiers doit surveiller. Il faut définir au moins une zone de surveillance pour la tâche.","Vous pouvez définir plusieurs sections [ScanScope.item_#] dans un fichier de configuration dans n'importe quel ordre. Kaspersky Endpoint Security traite les zones par ordre croissant d'index d'élément.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","Définit le nom de la zone de surveillance.","UseScanArea","Active ou désactive la surveillance de la zone indiquée.","Valeurs possibles :","Yes : surveille une zone indiquée.","No : ne surveille pas une zone indiquée.","Valeur par défaut : Yes.","Path","Définit le chemin d'accès complet à l'objet ou aux répertoires à contrôler.","Valeur par défaut : /opt/kaspersky/kesl/","AreaMask.item_#","Définit un masque d'interpréteur de ligne de commande qui précise les objets à contrôler.","Vous pouvez définir plusieurs éléments AreaMask.item_# dans n'importe quel ordre. Kaspersky Endpoint Security traite les éléments par ordre croissant d'index.","Valeur par défaut : * (tous les objets sont traités)","Section [ExcludedFromScanScope.item_#]","Les sections [ExcludedFromScanScope.item_#] définissent les objets à exclure de toutes les sections [ScanScope.item_#].","Les objets qui satisfont aux règles de n'importe quelle section [ExcludedFromScanScope.item_#] sont exclus du contrôle. le format d'une section [ExcludedFromScanScope.item_#] est identique au format d'une section [ScanScope.item_#].","Vous pouvez définir plusieurs sections [ExcludedFromScanScope.item_#] dans un fichier de configuration dans n'importe quel ordre. Kaspersky Endpoint Security traite les zones par ordre croissant d'index d'élément.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","Définit le nom de la zone à exclure du contrôle.","UseScanArea","Définit si la zone indiquée est exclue du contrôle.","Valeurs possibles :","Yes : exclut la zone indiquée du contrôle","No : n'exclut pas la zone indiquée du contrôle","Valeur par défaut : Yes.","Path","Définit le chemin d'accès aux objets ou aux répertoires à exclure du contrôle.","AreaMask.item_#","Définit un masque d'intepréteur de ligne de commande qui précise les objets à exclure du contrôle.","Vous pouvez définir plusieurs éléments AreaMask.item_# dans n'importe quel ordre. Kaspersky Endpoint Security traite les éléments par ordre croissant d'index.","Valeur par défaut : * (tous les objets sont contrôlés)"," Param&#xE8;tres de la t&#xE2;che de contr&#xF4;le de l&apos;int&#xE9;grit&#xE9; des fichiers &#xE0; l&apos;acc&#xE8;s ","161325.htm");
Page[119]=new Array("Paramètres de la tâche de contrôle de l'intégrité des fichiers à la demande","Cette section décrit les paramètres que vous pouvez préciser pour la tâche Contrôle de l'intégrité des fichiers à la demande.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","RebuildBaseline","Active ou désactive la reconstruction d'une référence à la fin d'une tâche ODFIM.","Valeurs possibles :","Yes : reconstruit une référence à la fin d'une tâche ODFIM","No : ne reconstruit pas une référence à la fin d'une tâche ODFIM","Valeur du paramètres par défaut : No","CheckFileHash","Active ou désactive un contrôle du hash (SHA-256).","Valeurs possibles :","Yes : active un contrôle de hash.","No : désactive un contrôle de hash.","Valeur du paramètres par défaut : No","TrackDirectoryChanges","Active ou désactive la surveillance des répertoires.","Valeurs possibles :","Yes : surveille les répertoires.","No : ne surveille pas les répertoires.","Valeur du paramètres par défaut : No","TrackLastAccessTime","Active ou désactive la vérification de la dernière fois où le fichier a été consulté. (Dans les systèmes d'exploitation Linux, c'est le paramètre noatime.)","Valeurs possibles :","Yes : vérifie la dernière fois où le fichier a été consulté","No : ne vérifie pas la dernière fois où le fichier a été consulté","Valeur du paramètres par défaut : No","UseExcludeMasks","Active ou désactive l'exclusion de la zone d'analyse des objets définis par le paramètre ExcludeMasks.","Ce paramètre fonctionne uniquement si le paramètre ExcludeMasks a été défini.","Valeurs possibles :","Yes : exclut de la zone d'analyse les objets définis par le paramètre ExcludeMasks","No : n'exclut pas de la zone d'analyse les objets définis par le paramètre ExcludeMasks.","Valeur du paramètres par défaut : No","ExcludeMasks","Définit une liste de masques qui indiquent les objets à exclure de la zone d'analyse.","Avant de définir ce paramètre, confirmez que le paramètre UseExcludeMasks possède la valeur Yes.","Les masques sont définis dans le format de l'interpréteur de commandes. ","Si vous souhaitez définir plusieurs masques, chaque masque doit figurer sur sa propre ligne et il faut définir un nouvel index (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Valeur par défaut : non définie.","Section [ScanScope.item_#]","Les sections [ScanScope.item_#] définissent les zones que la tâche Contrôle de l'intégrité des fichiers doit surveiller. Il faut définir au moins une zone de surveillance pour la tâche.","Vous pouvez définir plusieurs sections [ScanScope.item_#] dans un fichier de configuration dans n'importe quel ordre. Kaspersky Endpoint Security traite les zones par ordre croissant d'index d'élément.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","Définit le nom de la zone de surveillance.","UseScanArea","Active ou désactive la surveillance de la zone indiquée.","Valeurs possibles :","Yes : surveille une zone indiquée.","No : ne surveille pas une zone indiquée.","Valeur par défaut : Yes.","Path","Définit le chemin d'accès complet à l'objet ou aux répertoires à contrôler.","Valeur par défaut : /opt/kaspersky/kesl/","AreaMask.item_#","Définit un masque d'interpréteur de ligne de commande qui précise les objets à contrôler.","Vous pouvez définir plusieurs éléments AreaMask.item_# dans n'importe quel ordre. Kaspersky Endpoint Security traite les éléments par ordre croissant d'index.","Valeur par défaut : * (tous les objets sont traités)","Section [ExcludedFromScanScope.item_#]","Les sections [ExcludedFromScanScope.item_#] définissent les objets à exclure de toutes les sections [ScanScope.item_#].","Les objets qui satisfont aux règles de n'importe quelle section [ExcludedFromScanScope.item_#] sont exclus du contrôle. le format d'une section [ExcludedFromScanScope.item_#] est identique au format d'une section [ScanScope.item_#].","Vous pouvez définir plusieurs sections [ExcludedFromScanScope.item_#] dans un fichier de configuration dans n'importe quel ordre. Kaspersky Endpoint Security traite les zones par ordre croissant d'index d'élément.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","Définit le nom de la zone à exclure du contrôle.","UseScanArea","Définit si la zone indiquée est exclue du contrôle.","Valeurs possibles :","Yes : exclut la zone indiquée du contrôle","No : n'exclut pas la zone indiquée du contrôle","Valeur par défaut : Yes.","Path","Définit le chemin d'accès aux objets ou aux répertoires à exclure du contrôle.","AreaMask.item_#","Définit un masque d'intepréteur de ligne de commande qui précise les objets à exclure du contrôle.","Vous pouvez définir plusieurs éléments AreaMask.item_# dans n'importe quel ordre. Kaspersky Endpoint Security traite les éléments par ordre croissant d'index.","Valeur par défaut : * (tous les objets sont contrôlés)"," Param&#xE8;tres de la t&#xE2;che de contr&#xF4;le de l&apos;int&#xE9;grit&#xE9; des fichiers &#xE0; la demande ","165474.htm");
Page[120]=new Array("Tâche Gestion du pare-feu (Identifiant du Pare-feu :12)","Cette section contient des informations relatives à la tâche Gestion du pare-feu.","Dans cette sectionA propos de la Gestion du pare-feuA propos des règles pour paquet de réseauA propos des règles dynamiquesA propos des noms de zone de réseau prédéfiniesParamètres de la tâche Gestion du pare-feuAjout d'une règle pour paquet de réseauSuppression d'une règle pour paquet de réseauModification de la priorité d'exécution d'une règle pour paquet de réseauAjout d'une adresse réseau à la section zoneSuppression de l'adresse réseau de la section zone"," T&#xE2;che Gestion du pare-feu (Identifiant du Pare-feu&#xA0;:12) ","161326.htm");
Page[121]=new Array("A propos de la Gestion du pare-feu","Quand un ordinateur est connecté à des réseaux locaux (LAN) ou à Internet, il est exposé à des virus, d'autres applications malveillantes et une multitude d'attaques qui exploitent des vulnérabilités dans les systèmes d'exploitation et dans les logiciels.","Le pare-feu du système d'exploitation protège les données personnelles stockées sur l'ordinateur de l'utilisateur. Le pare-feu bloque la plupart des menaces potentielles pour le système d'exploitation lorsque l'ordinateur est connecté à Internet ou à un LAN. La Gestionnaire du pare-feu détecte toutes les connexions réseau de l'ordinateur de l'utilisateur et fournit une liste des adresses IP, avec une indication sur l'état de la connexion réseau par défaut.","Le composant Gestion du pare-feu filtre toutes les activités réseau conformément aux règles de paquet réseau. La configuration des règles pour paquet de réseau permet de définir le niveau souhaité de protection de l'ordinateur, depuis l'interdiction de l'accès Internet pour toutes les applications jusqu'à l'autorisation d'un accès illimité.","Quand la tâche Gestion du pare-feu est exécutée, Kaspersky Endpoint Security gère les paramètres et les règles du pare-feu du système d'exploitation. L'application interdit la configuration des paramètres du pare-feu du système d'exploitation de n'importe quelle manière, par exemple lorsqu'une application ou un outil ajoute ou supprime une règle. Kaspersky Endpoint Security vérifie le pare-feu du système d'exploitation toutes les 60 secondes et, le cas échéant, rétablit un ensemble de règles du pare-feu. Il est impossible de modifier la fréquence de contrôle.","Le contrôle du pare-feu du système d'exploitation continue même lorsque la tâche Gestion du pare-feu est à l'arrêt. Cela permet à l'application de rétablir les règles dynamiques.","Quand la tâche Gestion du pare-feu est à l'arrêt (lorsque le composant est supprimé ou que l'application est arrêtée ou supprimée), Kaspersky Endpoint Security ne modifie pas les règles du pare-feu du système d'exploitation et ne contrôle pas les modifications dans ses paramètres.","Toutes les connexions sortantes sont autorisées par défaut (paramètre d'action par défaut), sauf si les règles d'interdiction correspondantes ont été définies pour la tâche Gestion du pare-feu. L'action par défaut est exécutée selon la priorité la plus faible : si aucune autre règle pour paquet de réseau n'a été déclenchée ou si aucune règle pour paquet de réseau n'a été définie, la connexion est autorisée.","Avant l'activation de la tâche Gestion du pare-feu, nous vous recommandons de désactiver les autres outils de gestion du pare-feu du système d'exploitation."," A propos de la Gestion du pare-feu ","161327.htm");
Page[122]=new Array("A propos des règles pour paquet de réseau","Les règles pour les paquets réseau sont des actions autorisées ou interdites exécutées par la Gestion du pare-feu en cas de détection d'une tentative de connexion au réseau.","Les règles pour les paquets réseau imposent des restrictions sur les paquets réseau, quelle soit l'application. Ces règles limitent le trafic réseau entrant et sortant via des ports spécifiques du protocole de données sélectionnés. ","La gestion du pare-feu définit certaines règles pour les paquets réseau par défaut. Vous pouvez créer vos propres règles pour les paquets réseau et définir des priorités d'exécution pour chacune d'entre elles."," A propos des r&#xE8;gles pour paquet de r&#xE9;seau ","161953.htm");
Page[123]=new Array("A propos des règles dynamiques","Les composants de Kaspersky Endpoint Security peuvent ajouter et supprimer des règles dynamiques au pare-feu afin de garantir le fonctionnement adéquat. Par exemple, l'Agent d'administration ajoute des règles dynamiques qui autorisent les connexions à Kaspersky Security Center lancées à la fois par l'application et par Kaspersky Security Center.","La tâche Gestion du pare-feu ne contrôle pas les règles dynamiques et ne bloque pas l'accès aux ressources réseau pour les composants de l'application. Les règles dynamiques ne dépendent pas de l'état de la tâche Gestion du pare-feu (lancée ou arrêtée) ou des modifications de paramètres. Une priorité d'exécution des règles dynamiques est supérieure à une priorité de règles pour les paquets réseau. Kaspersky Endpoint Security rétablit un ensemble de règles dynamiques à l'aide de l'utilitaire iptables en cas de suppression d'une d'entre elles.","Vous pouvez consulter un ensemble de règles dynamiques (à l'aide de la commande kesl-control –F –query), mais vous ne pouvez pas en modifier les paramètres. "," A propos des r&#xE8;gles dynamiques ","161954.htm");
Page[124]=new Array("A propos des noms de zone de réseau prédéfinies","La gestion du pare-feu contrôle toutes les connexions réseau sur l'ordinateur de l'utilisateur. Vous pouvez ajouter une adresse de réseau à l'une des zones prédéfinies suivantes :","PublicsLocauxDe confiance"," A propos des noms de zone de r&#xE9;seau pr&#xE9;d&#xE9;finies ","161955.htm");
Page[125]=new Array("Paramètres de la tâche Gestion du pare-feu","Cette section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche Gestion du pare-feu.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","DefaultIncomingAction","L'action par défaut à exécuter sur une connexion entrante, si aucune règle réseau ne peut être appliquée à ce type de connexion.","Valeurs possibles :","Allow : autorise la connexion entrante.","Block : interdit la connexion entrante.","Valeur par défaut : Allow.","DefaultIncomingPacketAction","L'action par défaut à exécuter sur un paquet entrant, si aucune règle pour paquet de réseau ne peut être appliquée à ce type de connexion.","Valeurs possibles :","Allow : autoriser le paquet entrant","Block : bloquer le paquet entrant","Valeur par défaut : Allow.","Section [PacketRules.item_xxxx]","Les sections [PacketRules.item_#] définissent les règles pour paquet de réseau de la tâche Gestion du pare-feu.","Vous pouvez définir plusieurs sections [PacketRules.item_#] dans un fichier de configuration dans n'importe quel ordre. Kaspersky Endpoint Security traite les zones par ordre croissant d'index d'élément.","Chaque section [PacketRules.item_#] contient les paramètres suivants :","Name","Un nom de règle pour paquet de réseau.","Valeur par défaut : Network rule #<n>, où n est un index.","FirewallAction","Action à réaliser sur les connexions définies dans cette règle pour paquet de réseau.","Valeurs possibles :","Allow : autorise la connexion réseau","Block : interdit la connexion réseau","Valeur par défaut : Allow.","Protocol","Type de protocole pour lequel l'activité réseau doit être contrôlée.","Valeurs possibles :","Any : la Gestion du pare-feu contrôle toute l'activité réseau.","TCP","UDP","ICMP","ICMPv6","IGMP","GRE","Valeur par défaut : Any.","RemotePorts","Numéros de port des ordinateurs distants entre lesquels la connexion doit être contrôlée.","Ce paramètre peut être défini uniquement si le paramètre Protocol a la valeur TCP ou UDP.","Ce paramètre peut être un entier ou un intervalle.","Valeurs possibles :","Any : tous les ports distants sont contrôlés.","0 à 65535","Valeur par défaut : Any.","LocalPorts","Numéros de port des ordinateurs locaux entre lesquels la connexion doit être contrôlée.","Ce paramètre peut être défini uniquement si le paramètre Protocol a la valeur TCP ou UDP.","Ce paramètre peut être un entier ou un intervalle.","Valeurs possibles :","Any : tous les ports locaux sont contrôlés","0 à 65535","Valeur par défaut : Any.","ICMPType","Type de paquet ICMP.","Ce paramètre peut être défini uniquement si le paramètre Protocol a la valeur ICMP ou ICMPv6.","Valeurs possibles :","Any : tous les types de paquet ICMP sont contrôlés","Entier en fonction d'une spécification du protocole de transfert de données","Valeur par défaut : Any.","ICMPCode","Code du paquet ICMP.","Ce paramètre peut être défini uniquement si le paramètre Protocol a la valeur ICMP ou ICMPv6.","Valeurs possibles :","Any : tous les codes de paquet ICMP sont contrôlés.","Entier en fonction d'une spécification du protocole de transfert de données","Valeur par défaut : Any.","Direction","Direction de l'activité réseau contrôlée.","Valeurs possibles :","IncomingOutgoing : contrôle les connexions entrantes et sortantes.","Incoming : contrôle les connexions entrantes.","Outgoing : contrôle les connexions sortantes.","IncomingPacket : contrôle les paquets entrants.","OutgoingPacket : contrôle les paquets sortants.","IncomingOutgoingPacket : contrôle les connexions entrantes et sortantes.","Valeur par défaut : IncomingOutgoing","RemoteAddress","Adresses réseau des ordinateurs distants qui peuvent envoyer et/ou recevoir des paquets réseau.","Valeurs possibles :","Any : contrôle les paquets réseau envoyés et/ou reçus par des ordinateurs distants possédant n'importe quelle adresse IP.","Trusted : tous les réseaux de confiance.","Local : tous les réseaux locaux.","Public : tous les réseaux publics.","d.d.d.d : adresse IPv4 où d est un nombre décimal compris entre 0 et 255.","d.d.d.d/p : sous-réseau d'adresses IPv4 où p est un nombre compris entre 0 et 32.","x:x:x:x:x:x:x:x : adresses IPv6 où x est un nombre hexadécimal compris entre 0 et fffff.","x:x:x:x::0/p : sous-réseau d'adresses IPv6 où p est un nombre compris entre 0 et 64.","Valeur par défaut : Any.","LocalAddress","Adresses réseau des ordinateurs dotés de Kaspersky Endpoint Security et qui peuvent envoyer et/ou recevoir des paquets réseau.","Valeurs possibles :","Any : contrôle les paquets réseau envoyés et/ou reçus par des ordinateurs distants possédant n'importe quelle adresse IP.","d.d.d.d : adresse IPv4 où d est un nombre décimal compris entre 0 et 255.","d.d.d.d/p : sous-réseau d'adresses IPv4 où p est un nombre compris entre 0 et 32.","x:x:x:x:x:x:x:x : adresses IPv6 où x est un nombre hexadécimal compris entre 0 et fffff.","x:x:x:x::0/p : sous-réseau d'adresses IPv6 où p est un nombre compris entre 0 et 64.","Valeur par défaut : Any.","LogAttempts","Indiquez si vous souhaitez que les actions de la règle pour réseau figurent dans le rapport.","Valeurs possibles :","Yes : signale les actions.","No : ne signale pas les actions.","Valeur du paramètres par défaut : No","Section [NetworkZonesPublic]","La section [NetworkZonesPublic] renseigne les adresses réseau associées aux réseaux publics.","Vous pouvez définir plusieurs adresses IP ou des sous-réseaux d'adresses IP.","Address.item_xxxx","Valeurs possibles :","d.d.d.d : adresse IPv4 où d est un nombre décimal compris entre 0 et 255.","d.d.d.d/p : sous-réseau d'adresses IPv4 où p est un nombre compris entre 0 et 32.","x:x:x:x:x:x:x:x : adresses IPv6 où x est un nombre hexadécimal compris entre 0 et fffff.","x:x:x:x::0/p : sous-réseau d'adresses IPv6 où p est un nombre compris entre 0 et 64.","Valeur par défaut : “” (pas d'adresses IP dans cette zone)","Section [NetworkZonesLocal]","La section [NetworkZonesLocal] renseigne les adresses réseau associées aux réseaux locaux.","Vous pouvez définir plusieurs adresses IP ou des sous-réseaux d'adresses IP.","Address.item_xxxx","Valeurs possibles :","d.d.d.d : adresse IPv4 où d est un nombre décimal compris entre 0 et 255.","d.d.d.d/p : sous-réseau d'adresses IPv4 où p est un nombre compris entre 0 et 32.","x:x:x:x:x:x:x:x : adresses IPv6 où x est un nombre hexadécimal compris entre 0 et fffff.","x:x:x:x::0/p : sous-réseau d'adresses IPv6 où p est un nombre compris entre 0 et 64.","Valeur par défaut : “” (pas d'adresses IP dans cette zone)","Section [NetworkZonesTrusted]","La section [NetworkZonesTrusted] renseigne les adresses réseau associées aux réseaux de confiance.","Vous pouvez définir plusieurs adresses IP ou des sous-réseaux d'adresses IP.","Address.item_xxxx","Valeurs possibles :","d.d.d.d : adresse IPv4 où d est un nombre décimal compris entre 0 et 255.","d.d.d.d/p : sous-réseau d'adresses IPv4 où p est un nombre compris entre 0 et 32.","x:x:x:x:x:x:x:x : adresses IPv6 où x est un nombre hexadécimal compris entre 0 et fffff.","x:x:x:x::0/p : sous-réseau d'adresses IPv6 où p est un nombre compris entre 0 et 64.","Valeur par défaut : “” (pas d'adresses IP dans cette zone)"," Param&#xE8;tres de la t&#xE2;che Gestion du pare-feu ","161328.htm");
Page[126]=new Array("Ajout d'une règle pour paquet de réseau","Vous pouvez ajouter manuellement une règle pour un paquet réseau.","Vous ne pouvez ajouter qu'une règle pour un paquet réseau à la fois.","Pour ajouter une règle pour un paquet réseau, exécutez la commande suivante :","kesl-control -F --add-rule --name <nom de la règle> --action <action> --protocol <protocole> --direction <direction> --remote <adresse distante> --local <adresse locale> --at <index dans une liste de règles pour un paquet réseau>","Une section contenant le nouveau paramètre de règle pour un paquet réseau est ajoutée au fichier de configuration de la tâche Gestion du pare-feu. Si vous n'avez pas défini un certain paramètre dans la commande, la valeur par défaut est utilisée.","L'option –at vous permet de définir l'index de la règle créée dans la liste des règles pour un paquet de réseau. Si l'option –at n'est pas définie ou si sa valeur est supérieure au nombre de règles dans la liste, la nouvelle règle est ajoutée à la fin de la liste."," Ajout d&apos;une r&#xE8;gle pour paquet de r&#xE9;seau ","161956.htm");
Page[127]=new Array("Suppression d'une règle pour paquet de réseau","Vous pouvez supprimer manuellement une règle pour un paquet réseau.","Vous ne pouvez supprimer qu'une règle pour un paquet réseau à la fois.","Pour supprimer une règle pour un paquet réseau, exécutez une des commandes suivantes :","kesl-control -F --del-rule --name <nom>Une règle pour un paquet réseau est supprimée par son nom. Si la liste des règles contient plusieurs règles qui portent le même nom, Kaspersky Endpoint Security n'en supprime aucune.","kesl-control -F –del-rule --index <index>Une règle pour un paquet réseau est supprimée par son index dans la liste des règles pour paquet réseau.","Une section avec les paramètres de règles pour les paquets réseau est supprimée du fichier de configuration de la Gestion du pare-feu.","Si la liste des règles pour un paquet réseau ne contient pas de règle portant le nom ou l'index indiqué, une erreur s'affiche."," Suppression d&apos;une r&#xE8;gle pour paquet de r&#xE9;seau ","161958.htm");
Page[128]=new Array("Modification de la priorité d'exécution d'une règle pour paquet de réseau","Vous pouvez modifier manuellement une priorité d'exécution d'une règle pour un paquet réseau.","Pour modifier une priorité d'exécution d'une règle pour un paquet réseau, exécutez la commande suivante :","kesl-control -F --move-rule [--name <nom>|--index <index>] --at <index>","La priorité de la règle pour le paquet réseau est changée selon l'index indiqué."," Modification de la priorit&#xE9; d&apos;ex&#xE9;cution d&apos;une r&#xE8;gle pour paquet de r&#xE9;seau ","161960.htm");
Page[129]=new Array("Ajout d'une adresse réseau à la section zone","Vous pouvez ajouter manuellement des adresses réseau associées à un certain type de réseau au fichier de configuration de la tâche Gestion du pare-feu.","Pour ajouter une adresse réseau à la zone, exécutez la commande suivante :","kesl-control -F --add-zone <Public|Local|Trusted> --address <adresse>","Une adresse réseau est ajoutée à la section de la zone indiquée dans le fichier de configuration de la tâche."," Ajout d&apos;une adresse r&#xE9;seau &#xE0; la section zone ","161959.htm");
Page[130]=new Array("Suppression de l'adresse réseau de la section zone","Vous pouvez supprimer manuellement des adresses réseau associées à un certain type de réseau du fichier de configuration de la tâche Gestion du pare-feu.","Pour supprimer une adresse réseau de la zone dans une tâche de configuration, exécutez la commande suivante :","kesl_control -F --del-zone <zone> [--address <adresse>| --index <index de l'adresse dans la zone>]","L'adresse réseau indiquée est supprimée de la section de la zone indiquée dans un fichier de configuration.","Si une zone contient plusieurs éléments porteur de la même adresse réseau, la commande –del-zone n'est pas exécutée.","Si l'adresse réseau ou l'index indiqués n'existent pas, une erreur se produit."," Suppression de l&apos;adresse r&#xE9;seau de la section zone ","161961.htm");
Page[131]=new Array("Tâche Protection contre le chiffrement (AntiCryptor ID:13)","Cette section fournit des informations relatives à la tâche Protection contre le chiffrement.","Dans cette sectionA propos de la tâche Protection contre le chiffrementA propos du blocage des hôtes douteuxParamètres de la tâche Protection contre le chiffrementConsultation de la liste des hôtes bloquésAutorisation des hôtes bloqués"," T&#xE2;che Protection contre le chiffrement (AntiCryptor ID:13) ","161329.htm");
Page[132]=new Array("A propos de la tâche Protection contre le chiffrement","La tâche Protection contre le chiffrement permet de protéger vos fichiers dans les répertoires locaux accessibles sur le réseau via les protocoles SMB/NFS contre le chiffrement malveillant à distance.","Quand la tâche Protection contre le chiffrement est en cours d'exécution, Kaspersky Endpoint Security analyse les appels des ordinateurs distants en vue d'accéder aux fichiers qui se trouvent dans des répertoires réseau partagés de l'appareil protégé. Si l'application considère que les actions d'un ordinateur distant sur des ressources de fichier réseau correspondent à du chiffrement malveillant, cet ordinateur est ajouté à la liste des hôtes douteux et perd son accès aux répertoires réseau partagés.","Kaspersky Endpoint Security ne considère pas une activité comme du chiffrement malveillant si l'activité de chiffrement détectée a lieu dans des répertoires exclus de la zone d'application de la tâche Protection contre le chiffrement.","Par défaut, Kaspersky Endpoint Security bloque l'accès des hôtes douteux aux ressources de fichier réseau pendant 30 minutes.","La tâche Protection contre le chiffrement fonctionne sans problème avec les protocoles SMB1, SMB2, SMB3, NFS3, TCP / UDP et IP / IPv6. Les protocoles NFS2 et NFS4 ne sont pas pris en charge. Nous vous conseiller de configurer le serveur de telle sorte que les protocoles NFS2 et NFS4 ne puissent pas être utilisés pour monter des ressources.","La tâche Protection contre le chiffrement ne bloque pas l'accès aux ressources de fichiers réseau tant que l'activité de l'hôte n'a pas été considérée comme malveillante. Autrement dit, au moins un fichier doit être chiffré avant que l'application ne détecte une activité malveillante. "," A propos de la t&#xE2;che Protection contre le chiffrement ","161330.htm");
Page[133]=new Array("A propos du blocage des hôtes douteux","Quand une activité de chiffrement malveillante est détectée, Kaspersky Endpoint Security crée et active une règle pour le pare-feu du système d'exploitation afin que celui-ci interdise le trafic réseau en provenance d'un hôte compromis. L'hôte compromis est ajouté à la liste des hôtes douteux. Kaspersky Endpoint Security interdit l'accès aux répertoires réseau partagés pour tous les hôtes distants de la liste des hôtes douteux. Les informations relatives aux hôtes interdits sur un serveur protégé sont envoyées à Kaspersky Security Center.","Il est impossible d'utiliser l'utilitaire iptables pour supprimer les règles de pare-feu créées par la Protection contre le chiffrement : Kaspersky Endpoint Security rétablit l'ensemble de règles une fois par minute. Pour autoriser un hôte, utilisez l'option --allow-hosts.","Kaspersky Endpoint Security supprime par défaut les ordinateurs douteux de la liste 30 minutes après leur ajout à la liste. L'accès de l'ordinateur aux ressources de fichier réseau est automatiquement restauré une fois qu'il a été supprimé de la liste des hôtes douteux. Vous pouvez modifier la liste des hôtes bloqués et définir la période à l'issue de laquelle les ordinateurs bloqués seront automatiquement débloqués."," A propos du blocage des h&#xF4;tes douteux ","161331.htm");
Page[134]=new Array("Paramètres de la tâche Protection contre le chiffrement","Cette section fournit des informations relatives aux paramètres que vous pouvez définir pour la tâche Protection contre le chiffrement.","Toutes les valeurs disponibles et les valeurs par défaut pour chaque paramètre sont décrites.","UseHostBlocker","Active ou désactive le blocage des hôtes douteux.","Si le blocage des hôtes douteux est activé, Kaspersky Endpoint Security analyse malgré tout les actions des ordinateurs distants sur les ressources de fichiers réseau afin d'identifier d'éventuels chiffrements malveillants quand la tâche Protection contre le chiffrement est exécutée. En cas de détection d'une activité malveillante, l'événement EncryptionDetected est généré, mais l'hôte à l'origine de l'attaque n'est pas bloqué. ","Valeurs possibles :","Yes : active le blocage des hôtes douteux.","No : désactive le blocage des hôtes douteux.","Valeur par défaut : Yes.","BlockTime","Définit la durée de blocage d'un hôte douteux (en minutes).","Si un hôte compromis est bloqué et si vous modifiez la valeur du paramètre BlockTime, la durée de blocage de cet hôte ne change pas. La durée de blocage n'est pas une valeur dynamique et se calcule au moment du blocage.","Valeurs possibles :","Entier entre 1 et 4294967295","Valeur par défaut : 30.","UseExcludeMasks","Active ou désactive l'exclusion de la zone de protection des objets définis par le paramètre ExcludeMasks.","Ce paramètre fonctionne uniquement si le paramètre ExcludeMasks a été défini.","Valeurs possibles :","Yes : exclut de la zone de protection les objets définis par le paramètre ExcludeMasks.","No : n'exclut pas de la zone de protection les objets définis par le paramètre ExcludeMasks.","Valeur du paramètres par défaut : No","ExcludeMasks","Définit une liste de masques qui déterminent les objets à exclure de la zone de protection.","Avant de définir ce paramètre, confirmez que le paramètre UseExcludeMasks a la valeur Yes.","Les masques sont définis dans le format de l'interpréteur de commandes. ","Si vous souhaitez définir plusieurs masques, chaque masque doit figurer sur sa propre ligne et il faut définir un nouvel index (ExcludeMasks.item_0000, ExcludeMasks.item_0001).","Valeur par défaut : non définie.","Section [ScanScope.item_#]","Les sections [ScanScope.item_#] définissent les zones que Kaspersky Endpoint Security doit protéger. Il faut définir au moins une zone de protection pour la tâche Protection contre le chiffrement.","Seuls des répertoires partagés peuvent être définis pour la tâche Protection contre le chiffrement.","Vous pouvez définir plusieurs sections [ScanScope.item_#] dans un fichier de configuration dans n'importe quel ordre. Kaspersky Endpoint Security traite les zones par ordre croissant d'index d'élément.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","Définit le nom de la zone de protection.","Valeur par défaut : AllSharedFolders","UseScanArea","Active ou désactive la protection de la zone indiquée.","Valeurs possibles :","Yes : protège une zone définie.","No : ne protège pas une zone définie.","Valeur par défaut : Yes.","Path","Définit le chemin d'accès aux objets à protéger.","Valeurs possibles :","chemin d'accès absolu disponible via SMB / NFS (par exemple, Path=/tmp)","AllShared : protège toutes les ressources partagées via SMB / NFS.","Shared:SMB <chemin> : protège les ressources partagées via SMB.","Shared:NFS <chemin> : protège les ressources partagées via NFS.","Valeur par défaut : AllShared","AreaMask.item_#","Définit un masque de shell de ligne de commande qui précise les objets à protéger.","Vous pouvez définir plusieurs éléments AreaMask.item_# dans n'importe quel ordre. Kaspersky Endpoint Security traite les éléments par ordre croissant d'index.","Valeur par défaut : * (tous les objets sont traités)","Section [ExcludedFromScanScope.item_#]","Les sections [ExcludedFromScanScope.item_#] définissent les objets à exclure de toutes les sections [ScanScope.item_#].","Les objets qui satisfont aux règles de n'importe quelle section [ExcludedFromScanScope.item_#] ne sont pas analysés. le format d'une section [ExcludedFromScanScope.item_#] est identique au format d'une section [ScanScope.item_#].","Vous pouvez définir plusieurs sections [ExcludedFromScanScope.item_#] dans un fichier de configuration dans n'importe quel ordre. Kaspersky Endpoint Security traite les zones par ordre croissant d'index d'élément.","La section [ScanScope.item_#] contient les paramètres suivants :","AreaDesc","Définit le nom de la zone à exclure de l'analyse.","Valeur par défaut : All objects","UseScanArea","Indique si la zone définie est exclue ou non de la protection.","Valeurs possibles :","Yes : exclut une zone définie de la protection.","No : n'exclut pas la zone définie de la protection.","Valeur par défaut : Yes.","Path","Définit le chemin d'accès aux objets à exclure de la protection.","Vous pouvez définir uniquement un chemin d'accès absolu à un répertoire local (par exemple, /root /tmp/123) qui n'est pas protégé par Protection contre le chiffrement.","Valeur par défaut : non définie.","AreaMask.item_#","Définit un masque de shell de ligne de commande qui précise les objets à exclure de la protection.","Vous pouvez définir plusieurs éléments AreaMask.item_# dans n'importe quel ordre. Kaspersky Endpoint Security traite les éléments par ordre croissant d'index.","Valeur par défaut : * (tous les objets sont traités)"," Param&#xE8;tres de la t&#xE2;che Protection contre le chiffrement ","161332.htm");
Page[135]=new Array("Consultation de la liste des hôtes bloqués","Liste des hôtes douteux bloqués par la tâche Protection contre le chiffrement est affichée.","Pour consulter une liste des hôtes bloqués, exécutez la commande suivante :","kesl-control -H --get-blocked-hosts","Les hôtes bloqués par la tâche Protection contre le chiffrement sont affichés."," Consultation de la liste des h&#xF4;tes bloqu&#xE9;s ","161333.htm");
Page[136]=new Array("Autorisation des hôtes bloqués","Vous pouvez débloquer manuellement les hôtes qui ont été bloqués par la tâche Protection contre le chiffrement et restaurer ainsi l'accès réseau pour ceux-ci.","Pour débloquer des hôtes, saisissez la commande suivante :","kesl-control [-H] --allow-hosts <hôte>","où <hôte> est une liste d'adresses valides au format IPv4 / IPv6 (dont les adresses courtes) et/ou un sous-réseau. Il est possible également de définir les hôtes en tant que liste.","Les hôtes définis sont débloqués.","Exemples :","Adresses IPv4 :","dec - 192.168.0.1","dec - 192.168.0.0/24","Adresses IPv6 :","hex - FEDC:BA98:7654:3210:FEDC:BA98:7654:3210","hex - FEDC:BA98:7654:3210:FEDC:BA98:7654:3210%1","hex - 2001:db8::ae21:ad12","hex - ::ffff:255.255.255.254","hex - ::"," Autorisation des h&#xF4;tes bloqu&#xE9;s ","161334.htm");
Page[137]=new Array("Participation au Kaspersky Security Network","Cette section contient des informations relatives à la participation au Kaspersky Security Network et explique comment activer ou désactiver l'utilisation de Kaspersky Security Network.","Dans cette sectionPrésentation de la participation au Kaspersky Security NetworkActivation et désactivation de l'utilisation de Kaspersky Security NetworkVérification de la connexion à Kaspersky Security NetworkProtection complémentaire avec l'utilisation de Kaspersky Security Network"," Participation au Kaspersky Security Network ","161355.htm");
Page[138]=new Array("Présentation de la participation au Kaspersky Security Network","Pour renforcer l'efficacité de la protection de l'ordinateur de l'utilisateur, Kaspersky Endpoint Security utilise les données obtenues auprès d'utilisateurs du monde entier. Kaspersky Security Network permet de récolter ces données.","Kaspersky Security Network (KSN) est une infrastructure de service cloud qui permet d'accéder à la base de connaissances de Kaspersky Lab sur la réputation des fichiers, des ressources Internet et des logiciels. L'exploitation des données de Kaspersky Security Network garantit une réaction plus rapide de Kaspersky Endpoint Security face aux nouvelles menaces. Elle améliore également les performances de certains composants de la protection et réduit le risque de faux-positifs.","En fonction de l'emplacement de l'infrastructure, on distingue le KSN global (infrastructure implantée sur les serveurs de Kaspersky Lab) ou le KSN privé (infrastructure implantée sur des serveurs tiers, par exemple dans le réseau d'un FAI).","Après la modification de la licence, il faut transmettre les informations relatives à la nouvelle clé au fournisseur de services afin de pouvoir utiliser le KSN privé. Dans le cas contraire, il sera impossible d'échanger des informations avec le KSN privé en raison d'une erreur d'authentification.","La participation des utilisateurs à KSN permet à Kaspersky Lab de recevoir rapidement les informations sur les types et les sources de menaces, d'élaborer les moyens de neutralisation des menaces et de minimiser la quantité de faux positifs pour les composants de l'application.","Il y a deux façons de participer à KSN :","Kaspersky Security Network with statistics : vous pouvez obtenir des informations à partir de la base de connaissances. L'application envoie automatiquement à KSN les statistiques obtenues pendant l'utilisation de KSN. L'application peut également envoyer à Kaspersky Lab pour analyse complémentaire des fichiers (ou des parties de fichiers) que des individus malintentionnés pourraient utiliser pour nuire à l'ordinateur et aux données.Kaspersky Security Network without statistics : vous pouvez obtenir des informations de la base de connaissances mais l'application n'envoie pas de statistiques et d'informations anonymes sur les types et les sources des nouvelles menaces.Les données personnelles de l'utilisateur ne sont ni recueillies, ni traitées, ni enregistrées. Pour en savoir plus sur l'envoi, la conservation et la suppression des statistiques obtenues pendant l'utilisation du KSN, consultez la Déclaration de Kaspersky Security Network et le site Internet de Kaspersky Lab (http://www.kaspersky.ru/privacy). Le fichier qui reprend la Déclaration de Kaspersky Security Network figure dans le kit de distribution de l'application.","Les ordinateurs des utilisateurs administrés via le Serveur d'administration Kaspersky Security Center peuvent interagir avec KSN à l'aide du service KSN Proxy.","Le service KSN Proxy offre les possibilités suivantes :","L'ordinateur peut interroger KSN et transmettre des informations à KSN, même en l'absence d'accès direct à Internet.Le service KSN Proxy met en cache les données traitées, ce qui réduit la charge sur la connexion réseau externe et accélère la réception des informations sollicitées sur l'ordinateur de l'utilisateur.Pour en savoir plus sur le service KSN Proxy, consultez la documentation de Kaspersky Security Center.","La configuration des paramètres d'utilisation du service KSN Proxy s'opère via une stratégie Kaspersky Security Center.","La participation au Kaspersky Security Network est volontaire. L'application propose de participer au KSN pendant l'installation. Vous pouvez décider de participer au KSN ou d'interrompre votre participation à tout moment."," Pr&#xE9;sentation de la participation au Kaspersky Security Network ","161356.htm");
Page[139]=new Array("Activation et désactivation de l'utilisation de Kaspersky Security Network","Pour activer l'utilisation de Kaspersky Security Network, exécutez une des commandes suivantes :","Pour activer l'utilisation de Kaspersky Security Network avec des statistiques,kesl-control --set-app-settings UseKSN=Extended","Pour activer l'utilisation de Kaspersky Security Network sans statistiques,kesl-control --set-app-settings UseKSN=Basic","Pour désactiver l'utilisation de Kaspersky Security Network, exécutez la commande suivante :","kesl-control --set-app-settings UseKSN=No","Pour activer ou désactiver l'utilisation de Kaspersky Security Network à l'aide du fichier de configuration, exécutez la commande suivante :","kesl-control --set-app-settings --file <nom du fichier de configuration>","Si Kaspersky Endpoint Security, installé sur un ordinateur, fonctionne sous une stratégie définie dans Kaspersky Security Center, la valeur du paramètre UseKSN peut être modifiée uniquement à l'aide de Kaspersky Security Center.","Si Kaspersky Endpoint Security, installé sur l'ordinateur, n'est plus soumis à la stratégie, la valeur du paramètre devient UseKSN=No.","Le fichier contenant le texte de la Déclaration de Kaspersky Security Network se trouve dans le répertoire /opt/kaspersky/kesl/doc/ksn_license.<ID de la langue>."," Activation et d&#xE9;sactivation de l&apos;utilisation de Kaspersky Security Network ","161357.htm");
Page[140]=new Array("Vérification de la connexion à Kaspersky Security Network","Pour vérifier la connexion à Kaspersky Security Network, exécutez la commande suivante :","kesl-control --app-info","La ligne KSN state affiche l'état de la connexion à Kaspersky Security Network :","Si l'état Extended est affiché, Kaspersky Endpoint Security est connecté à Kaspersky Security Network, des informations peuvent être obtenues dans la base de connaissances, les statistiques anonymes et les informations sur les types et les sources des nouvelles menaces sont envoyées.Si l'état Basique est affiché, Kaspersky Endpoint Security est connecté à Kaspersky Security Network, des informations peuvent être obtenues dans la base de connaissances, mais les statistiques anonymes et les informations sur les types et les sources des nouvelles menaces ne sont pas envoyées.Si l'état No est affiché, Kaspersky Endpoint Security n'est pas connecté à Kaspersky Security Network.La connexion à Kaspersky Security Network peut être absente pour une des raisons suivantes :","L'ordinateur n'est pas connecté à Internet.Vous ne participez pas à Kaspersky Security Network.L'application n'est pas activée ou la licence a expiré.Des problèmes liés à la clé ont été détectés. Par exemple, la clé figure dans une liste noire."," V&#xE9;rification de la connexion &#xE0; Kaspersky Security Network ","161358.htm");
Page[141]=new Array("Protection complémentaire avec l'utilisation de Kaspersky Security Network","Kaspersky Lab offre un niveau complémentaire de protection grâce à l'utilisation de Kaspersky Security Network. Ce mode de protection permet de lutter efficacement contre les menaces persistantes avancées et les menaces du type zero-day (0jour). Les technologies cloud associées à Kaspersky Endpoint Security et les connaissances approfondies des experts de la lutte contre les virus de Kaspersky Lab assurent une protection ultra-fiable contre les menaces les plus complexes contre les réseaux.","Pour en savoir plus sur la protection complémentaire dans Kaspersky Endpoint Security, visitez le site Internet de Kaspersky Lab."," Protection compl&#xE9;mentaire avec l&apos;utilisation de Kaspersky Security Network ","161359.htm");
Page[142]=new Array("Utilisation de l'interface utilisateur graphique de Kaspersky Endpoint Security","Cette section décrit l'utilisation de Kaspersky Endpoint Security à l'aide de l'interface utilisateur graphique.","Dans cette sectionActivation et désactivation locales de l'interface utilisateur graphiqueInterface de l'applicationGestion des tâches et des composantsRapportsAffichage des objets stockésCréation d'un fichier de trace"," Utilisation de l&apos;interface utilisateur graphique de Kaspersky Endpoint Security ","161978.htm");
Page[143]=new Array("Activation et désactivation locales de l'interface utilisateur graphique","Vous pouvez activer ou désactiver localement l'interface utilisateur graphique de Kaspersky Endpoint Security depuis la ligne de commande.","Des droits root sont requis pour activer ou désactiver l'interface utilisateur graphique.","Pour activer ou désactiver l'interface utilisateur graphique :","Exécutez le script de configuration de l'application :/opt/kaspersky/kesl/bin/kesl-setup.pl –G","Dans la ligne de commande, effectuez l'une des opérations suivantes :Si vous souhaitez activer l'interface utilisateur graphique, appuyez sur la touche Y.Si vous activez l'interface utilisateur graphique, les utilisateurs sans droits root pourront exécuter des tâches d'analyse à la demande.","Si un utilisateur est connecté, une interface utilisateur graphique sera lancée pour cet utilisateur à condition que toutes les bibliothèques nécessaires soient disponibles. L'icône de l'application apparaît dans la zone de notification de la barre des tâches et des raccourcis sont créés.","Si vous souhaitez désactiver l'interface utilisateur graphique, appuyez sur la touche N.L'application empêche les utilisateurs de démarrer l'interface utilisateur graphique. L'icône de l'application et les raccourcis sont supprimés."," Activation et d&#xE9;sactivation locales de l&apos;interface utilisateur graphique ","161980.htm");
Page[144]=new Array("Interface de l'application","Cette section décrit les éléments principaux de l'interface utilisateur graphique de l'application."," Interface de l&apos;application ","161988.htm");
Page[145]=new Array("Icône de l'application dans la zone de notification","Une fois l'interface utilisateur graphique de Kaspersky Endpoint Security activée, l'icône de l'application apparaît dans la zone de notification à droite de la barre des tâches.","L'icône agit comme un raccourci vers le menu contextuel et la fenêtre principale de l'application.","Le menu contextuel de l'icône de l'application contient les éléments suivants :","Kaspersky Endpoint Security 10 SP1 for Linux. Ouvre la fenêtre principale de l'application. La fenêtre principale de l'application vous permet d'afficher l'état de protection de votre ordinateur et l'état et l'état de la tâche Analyse à la demande et de la tâche Mise à jour. Vous pouvez également accéder aux fenêtres Rapports, Stockage, Paramètres et Support.Quitter. Quitte l'interface utilisateur graphique de Kaspersky Endpoint. Vous pouvez ouvrir le menu contextuel de l'icône de l'application en cliquant-droit sur l'icône de l'application dans la zone de notification."," Ic&#xF4;ne de l&apos;application dans la zone de notification ","161990.htm");
Page[146]=new Array("Fenêtre principale de l'application","La fenêtre principale de Kaspersky Endpoint Security contient des éléments d'interface qui permettent d'accéder aux fonctions de l'application.","La fenêtre principale de l'application est divisée en plusieurs parties :","La partie centrale de la fenêtre affiche l'état de la protection de votre ordinateur. Cliquez sur cette partie de la fenêtre principale pour accéder à la fenêtre Centre de protection.L'onglet Analyse affiche l'état de la tâche d'analyse à la demande et le nombre de menaces détectées. Cliquez sur cet onglet pour accéder à la fenêtre Analyse. Dans cette fenêtre, vous pouvez démarrer ou arrêter les tâches d'analyse à la demande, d'analyse du secteur de démarrage et d'analyse de la mémoire. En outre, vous pouvez afficher des rapports pour ces tâches.L'onglet Mise à jour affiche l'état de la tâche de mise à jour et des bases antivirus. Cliquez sur cet onglet pour accéder à la fenêtre Mise à jour. Dans cette fenêtre, vous pouvez démarrer ou arrêter les tâches de mise à jour ou de diffusion des mises à jour. En outre, vous pouvez afficher des rapports pour ces tâches.La partie inférieure de la fenêtre de l'application de messagerie contient les éléments suivants :Bouton Rapports. Cliquez sur ce bouton pour accéder à la fenêtre Rapports, dans laquelle vous pouvez afficher les statistiques des tâches et divers rapports.Bouton Stockage. Cliquez sur ce bouton pour accéder à la fenêtre Stockage qui contient des informations sur les objets dans le Stockage.Bouton Paramètres. Cliquez sur ce bouton pour accéder à la fenêtre Paramètres, dans laquelle vous pouvez activer ou désactiver la participation à diverses tâches : Kaspersky Security Network, Protection en temps réel, Pare-feu, Anti-Cryptor et Contrôle de l'intégrité des fichiers.Bouton Support. Cliquez sur ce bouton pour accéder à la fenêtre Support qui contient des informations sur la version actuelle de Kaspersky Endpoint Security, sur les licences, l'état des clés, l'état des bases de données, le système d'exploitation et des liens vers les ressources d'informations de Kaspersky Lab.Pour ouvrir la fenêtre principale de Kaspersky Endpoint Security, effectuez l'une des actions suivantes :","Double-cliquez ou cliquez-droit sur l'icône de l'application dans la zone de notification de la barre des tâches.Cliquez-droit sur l'application et sélectionnez Kaspersky Endpoint Security 10 SP 1 for Linux."," Fen&#xEA;tre principale de l&apos;application ","161987.htm");
Page[147]=new Array("Gestion des tâches et des composants","Par défaut, l'interface utilisateur graphique de Kaspersky Endpoint Security vous permet de lancer et d'arrêter les tâches suivantes :","Tâche d'analyse complète (Scan_My_Computer)Tâches d'analyse à la demande (Scan_File, Boot_Scan, Memory_Scan)Mise à jour des tâches (Mise à jour, Recul de mise à jour des bases, Retranslate)L'interface utilisateur graphique de Kaspersky Endpoint Security vous permet également d'activer et de désactiver les composants suivants :","Protection en temps réel des fichiersPare-feuAnti-CryptorContrôle de l'intégrité des fichiersEn outre, vous pouvez gérer votre participation à la tâche Kaspersky Security Network."," Gestion des t&#xE2;ches et des composants ","165423.htm");
Page[148]=new Array("Démarrage et arrêt des tâches d'analyse","Vous pouvez lancer et arrêter les tâches Analyse complète, Analyse à la demande, Analyse des secteur d'amorçage et Analyse de la mémoire des processus à l'aide de l'interface utilisateur graphique de Kaspersky Endpoint Security.","Pour démarrer ou arrêter une tâche d'analyse,","Ouvrez la fenêtre principale de l'application.Dans la fenêtre principale de l'application, cliquez sur le bouton Analyse pour ouvrir la fenêtre Analyse.Exécutez une des actions suivantes :Si vous voulez démarrer une tâche, cliquez sur le bouton Démarrer sous la tâche d'analyse que vous voulez démarrer.La progression de la tâche en cours s'affiche.","Si vous souhaitez arrêter une tâche, cliquez sur le bouton Arrêter sous la tâche d'analyse que vous souhaitez arrêter.La tâche d'analyse s'arrête et des informations sur les objets analysés et les menaces détectées s'affichent.","Si nécessaire, vous pouvez cliquer sur le bouton Afficher le rapport pour afficher le rapport relatif à la tâche.La fenêtre Rapports est disponible pour les utilisateurs non root uniquement lorsque le paramètre général de l'application UIReportsForRootOnly est défini sur No. Sinon, la fenêtre Rapports est disponible uniquement pour un utilisateur root."," D&#xE9;marrage et arr&#xEA;t des t&#xE2;ches d&apos;analyse ","161997.htm");
Page[149]=new Array("Démarrage et arrêt des tâches de mise à jour","Vous pouvez lancer et arrêter les tâches de mise à jour, de recul de mise à jour des bases et de diffusion des mises à jour à l'aide de l'interface utilisateur graphique de Kaspersky Endpoint Security.","Pour démarrer ou arrêter une tâche de mise à jour ou de diffusion des mises à jour :","Ouvrez la fenêtre principale de l'application.Dans la fenêtre principale de l'application, cliquez sur le bouton Mise à jour pour ouvrir la fenêtre Mise à jour.Exécutez une des actions suivantes :Si vous voulez démarrer une tâche, cliquez sur le bouton Démarrer sous la tâche que vous souhaitez démarrer.La progression de la tâche en cours s'affiche. ","Si la tâche de mise à jour aboutit, le lien Annuler la mise à jour est disponible et vous pouvez restaurer la dernière mise à jour.","Si vous souhaitez arrêter une tâche, cliquez sur le bouton Arrêter sous la tâche que vous souhaitez arrêter.La tâche s'arrête.","Si nécessaire, vous pouvez cliquer sur le bouton Afficher le rapport pour afficher le rapport relatif à la tâche.La fenêtre Rapports est disponible pour les utilisateurs non root uniquement lorsque le paramètre général de l'application UIReportsForRootOnly est défini sur No. Sinon, la fenêtre Rapports est disponible uniquement pour un utilisateur root.","Pour exécuter une tâche de recul de mise à jour des bases :","Ouvrez la fenêtre principale de l'application.Dans la fenêtre principale de l'application, cliquez sur le bouton Mise à jour pour ouvrir la fenêtre Mise à jour.Dans la section Mise à jour, cliquez sur le lien Recul de mise à jour des bases pour annuler la dernière mise à jour réussie de la base de données."," D&#xE9;marrage et arr&#xEA;t des t&#xE2;ches de mise &#xE0; jour ","165426.htm");
Page[150]=new Array("Activation et désactivation de composants de l'application","À l'aide de l'interface utilisateur graphique de Kaspersky Endpoint Security, vous pouvez à tout moment activer et désactiver les composants suivants : Protection en temps réel, Gestion du pare-feu, Protection contre le chiffrement et Contrôle de l'intégrité des fichiers. .","Si un composant est activé, le bouton Désactiver est disponible. Par défaut, seule la protection en temps réel est activée.","Si un composant est désactivé, le bouton Activer est disponible.","Pour activer ou désactiver un composant :","Ouvrez la fenêtre principale de l'application.Dans la partie inférieure de la fenêtre principale de l'application, cliquez sur bouton Paramètres.La fenêtre Paramètres s'ouvre.","Dans la fenêtre Paramètres, effectuez les actions suivantes par rapport au composant requis :Si vous souhaitez activer un composant, cliquez sur le bouton Activer.Si vous souhaitez désactiver un composant, cliquez sur le bouton Désactiver."," Activation et d&#xE9;sactivation de composants de l&apos;application ","162000.htm");
Page[151]=new Array("Gestion de la participation à la tâche Kaspersky Security Network","Vous pouvez gérer votre participation à Kaspersky Security Network à tout moment.","Pour activer Kaspersky Security Network :","Ouvrez la fenêtre principale de l'application.Dans la partie inférieure de la fenêtre principale de l'application, cliquez sur bouton Paramètres.La fenêtre Paramètres s'ouvre.","Dans la fenêtre Paramètres, sélectionnez l'une des options suivantes :Kaspersky Security Network with statistics : pour activer Kaspersky Security Network, obtenir des informations dans la base de connaissance, et envoyer des statistiques anonymes et des informations sur les types et les sources de nouvelles menaces.Kaspersky Security Network without statistics : pour obtenir des informations dans la base de connaissances sans envoyer des statistiques anonymes et des informations sur les types et les sources de nouvelles menaces.Cliquez sur le bouton Activer.Dans la fenêtre Participation à Kaspersky Security Network, lisez attentivement la Déclaration de Kaspersky Security Network, et sélectionnez l'une des options suivantes :Je confirme avoir bien lu, compris et j'accepte les conditions de la présente Déclaration KSN : active Kaspersky Security Network.Je n'accepte pas les conditions de la présente Déclaration KSN : désactive l'utilisation de Kaspersky Security Network.Cliquez sur OK.Le bouton OK est indisponible si l'option Not selected est sélectionnée.","Pour désactiver Kaspersky Security Network :","Ouvrez la fenêtre principale de l'application.Dans la partie inférieure de la fenêtre principale de l'application, cliquez sur bouton Paramètres.La fenêtre Paramètres s'ouvre.","Dans la fenêtre Paramètres, cliquez sur le bouton Désactiver.Dans la fenêtre qui s'ouvre, effectuez l'une des opérations suivantes :Cliquez sur Oui pour confirmer la désactivation de Kaspersky Security Network.Cliquez sur Annuler pour continuer à participer à Kaspersky Security Network."," Gestion de la participation &#xE0; la t&#xE2;che Kaspersky&#xA0;Security&#xA0;Network ","165428.htm");
Page[152]=new Array("Rapports","Cette section décrit comment afficher les rapports dans l'interface utilisateur graphique de Kaspersky Endpoint Security."," Rapports ","161993.htm");
Page[153]=new Array("Principes de gestion des rapports","La fenêtre Rapports est disponible pour les utilisateurs non root uniquement lorsque le paramètre général de l'application UIReportsForRootOnly est défini sur No. Sinon, la fenêtre Rapports est disponible uniquement pour un utilisateur root.","Les informations sur les performances des tâches de Kaspersky Endpoint Security sont enregistrées dans des rapports.","Les données des rapports sont présentées dans un tableau qui contient une liste d'événements. Chaque ligne du tableau contient des informations sur un événement distinct. Les attributs d'événement sont situés dans les colonnes du tableau. Les événements consignés lors de l'exécution de diverses tâches ont des jeux d'attributs différents.","Les rapports suivants figurant dans le menu sur la gauche sont disponibles :","Statistiques. Contient des informations statistiques sur la Tâche de protection en temps réel et les tâches d'analyse à la demande. Vous pouvez mettre à jour le rapport affiché en cliquant sur le bouton Recharger.Une réinitialisation des statistiques pour la Tâche de protection en temps réel se produit lorsque la tâche est arrêtée. Aucune réinitialisation des tâche d'analyse à la demande ne se produit. Au contraire, les statistiques sont incrémentées lors de l'installation de l'application sur l'ordinateur.","Audit du système. Ce rapport contient des informations sur les événements qui se produisent lors de l'interaction de l'utilisateur avec l'application. Il contient également des informations sur les événements qui se produisent pendant le fonctionnement général de l'application.Protection contre les menaces. Ces rapports contiennent des informations sur les événements qui sont enregistrés alors que les composants Kaspersky Endpoint Security suivants sont en cours d'exécution :Anti-CryptorContrôle de l'intégrité des fichiersPare-feuAntivirus FichiersTâches à la demande. Ces rapports contiennent des informations sur les événements qui sont enregistrés alors que les tâches de Kaspersky Endpoint Security suivants sont en cours d'exécution :Tâches d'analyseMise à jourVérification de l'intégritéLes rapports utilisent les niveaux d'importance d'événement suivants :","Événements d'information. Événements formels qui ne contiennent généralement aucune information importante.Evénements importants. Evénements qui nécessitent une attention particulière car ils témoignent de situations importantes dans le fonctionnement de Kaspersky Endpoint Security.Evénements critiques. Événements d'importance critique qui indiquent des problèmes dans le fonctionnement de Kaspersky Endpoint Security ou des vulnérabilités dans la protection de l'ordinateur de l'utilisateur.Pour faciliter le traitement des rapports, vous pouvez modifier la présentation des données à l'écran de la manière suivante :","Filtrez la liste des événements par période.Utilisez la fonction de recherche pour trouver un événement spécifique.Affichez l'événement sélectionné dans une section distincte."," Principes de gestion des rapports ","161992.htm");
Page[154]=new Array("Affichage des rapports","La fenêtre Rapports est disponible pour les utilisateurs non root uniquement lorsque le paramètre général de l'application UIReportsForRootOnly est défini sur No. Sinon, la fenêtre Rapports est disponible uniquement pour un utilisateur root.","Pour afficher les rapports :","Ouvrez la fenêtre principale de l'application.Dans la partie inférieure de la fenêtre principale de l'application, cliquez sur bouton Rapports.La fenêtre Rapports s'ouvre.","Pour afficher un rapport spécifique, dans la partie gauche de la fenêtre Rapports, dans la liste des tâches, sélectionnez la tâche requise.Un rapport est affiché dans la partie droite de la fenêtre et contient une liste d'événements dans l'exécution de la tâche de Kaspersky Endpoint Security sélectionnée.","Par défaut, les événements sont triés par ordre croissant de valeurs dans la colonne Date. Vous pouvez choisir un ordre différent en cliquant sur l'en-tête de colonne souhaitée.","Pour afficher un résumé détaillé de chaque événement dans un rapport, sélectionnez l'événement en question dans le rapport.La partie inférieure de la fenêtre affiche un résumé de l'événement."," Affichage des rapports ","161994.htm");
Page[155]=new Array("Affichage des objets stockés","Pour voir les objets que Kaspersky Endpoint Security a déplacé dans le stockage,","Ouvrez la fenêtre principale de l'application.Cliquez sur le bouton Stockage.La fenêtre qui s'ouvre affiche les informations sur les objets dans le Stockage.","Vous pouvez afficher les informations suivantes sur les objets dans le Stockage :","Nom de la menace.Chemin complet vers un objet.Date à laquelle un objet a été déplacé vers le Stockage.Date à laquelle un objet sera supprimé du Stockage. Ce champ s'affiche si le paramètre DaysToLive a été spécifié.Taille de l'objet.Vous pouvez restaurer les objets depuis le Stockage vers leurs répertoires d'origine. Vous pouvez également supprimer des objets du Stockage. Les objets supprimés ne peuvent être restaurés à l'avenir. Les informations sur ces actions sont enregistrées dans le journal des événements. "," Affichage des objets stock&#xE9;s ","161999.htm");
Page[156]=new Array("Création d'un fichier de trace","Pour créer un fichier de trace :","Ouvrez la fenêtre principale de l'application.Cliquez sur le bouton Support.Dans la fenêtre Support, cliquez sur le lien Traces.Dans la liste déroulante Niveau, sélectionnez le niveau de trace.Il est conseillé de préciser le niveau de trace auprès d'un spécialiste du Support technique. Par défaut, le niveau de trace est réglé sur Diagnostic (300).","Pour démarrer le processus de traçage, cliquez sur bouton Activer.Pour arrêter le processus de traçage, cliquez sur le bouton Désactiver.Les fichiers de trace créés sont stockés dans le répertoire /var/log/kaspersky/kesl/."," Cr&#xE9;ation d&apos;un fichier de trace ","166209.htm");
Page[157]=new Array("Contacter le Support Technique","Cette section contient des informations sur les modes et les conditions d'obtention de l'assistance technique.","Dans cette sectionModes d'obtention du Support TechniqueBénéficiez d'une assistance technique par téléphoneSupport Technique via le Kaspersky CompanyAccountUtilisation d'un fichier de trace et d'un script AVZ"," Contacter le Support Technique ","70331.htm");
Page[158]=new Array("Modes d'obtention du Support Technique","Si la solution à votre problème ne figure pas dans la documentation de l'application ou dans une des sources d'informations consacrées à l'application, nous vous conseillons de contacter le Support Technique de Kaspersky Lab. Les experts du Support Technique répondront à toutes vos questions sur l'installation et l'utilisation de l'application.","Avant de contacter le Support Technique, veuillez prendre connaissances des Conditions d'accès au Support Technique.","Vous pouvez contacter les experts du Support Technique d'une des manières suivantes :","Par téléphone. Cette méthode vous permet de consulter des experts du Support Technique russophone ou international.Envoyer des demandes via le portail My Kaspersky. Cette méthode vous permet de contacter nos experts via un formulaire de demande.Le Support Technique est accessible uniquement aux utilisateurs qui ont acheté une licence pour l'application. Les utilisateurs de la version d'essai n'ont pas droit à l'assistance technique."," Modes d&apos;obtention du Support Technique ","85903.htm");
Page[159]=new Array("Bénéficiez d'une assistance technique par téléphone","Vous pouvez appeler les spécialistes du Support Technique à partir de la plupart des régions du monde. Les informations sur les moyens de bénéficier de l'assistance technique dans votre région ainsi que les coordonnées du Support Technique figurent sur le site Internet du Support Technique de Kaspersky Lab.","Avant de contacter le Support Technique, veuillez prendre connaissances des Conditions d'accès au Support Technique."," B&#xE9;n&#xE9;ficiez d&apos;une assistance technique par t&#xE9;l&#xE9;phone ","70152.htm");
Page[160]=new Array("Support Technique via le Kaspersky CompanyAccount","Kaspersky CompanyAccount est un portail à disposition des entreprises qui utilisent les applications de Kaspersky Lab. Le portail Kaspersky CompanyAccount vise à permettre l'interaction entre les utilisateurs et les experts de Kaspersky Lab via des requêtes électroniques. Kaspersky CompanyAccount vous permet de suivre l'état de vos demandes en ligne et d'en conserver l'historique.","Vous pouvez inscrire tous les employés de votre entreprise sous un seul compte dans Kaspersky CompanyAccount. Ce compte unique permet de gérer centralement les demandes électroniques envoyées à Kaspersky Lab par les employés enregistrés et de gérer les autorisations de ces employés via Kaspersky CompanyAccount.","Le portail Kaspersky CompanyAccount est disponible dans les langues suivantes :","AnglaisEspagnolItalienAllemandPolonaisPortugaisRusseFrançaisJaponaisPour en savoir plus sur Kaspersky CompanyAccount, veuillez consulter le site Internet du Support technique."," Support Technique via le Kaspersky CompanyAccount ","68417.htm");
Page[161]=new Array("Utilisation d'un fichier de trace et d'un script AVZ","Après que vous avez signalé un problème aux spécialistes du Support Technique de Kaspersky Lab, ils peuvent vous demander de générer un rapport sur le fonctionnement de Kaspersky Endpoint Security et de l'envoyer au Support Technique de Kaspersky Lab. Les spécialistes du Support Technique peuvent également vous demander de créer un fichier de trace. Le fichier de trace permet met de procéder à un examen détaillé de l'exécution des commandes de l'application et de déterminer quand les erreurs se produisent.","Après avoir analysé les données que vous leur avez envoyées, les spécialistes du Support Technique peuvent créer un script AVZ et vous l'envoyer. En exécutant des scripts AVZ, il est possible d'analyser les processus actifs pour y détecter des menaces, d'analyser les ordinateurs pour y détecter des menaces, de désinfecter ou de supprimer les fichiers infectés et de créer des rapports d'analyse système."," Utilisation d&apos;un fichier de trace et d&apos;un script AVZ ","73375.htm");
Page[162]=new Array("Appendices","Cette section contient des renseignements qui viennent compléter le contenu principal du document.","Dans cette sectionFichiers de configuration de tâche par défautConfiguration de la collaboration : Kaspersky Antivirus for Linux Mail ServerCodes de retour de la ligne de commande"," Appendices ","161364.htm");
Page[163]=new Array("Fichiers de configuration de tâche par défaut","Cette section contient les fichiers de configuration par défaut des tâches de Kaspersky Endpoint Security.","Vous pouvez modifier ces fichiers de configuration à tout moment. Il est possible également de modifier les valeurs des paramètres via la ligne de commande."," Fichiers de configuration de t&#xE2;che par d&#xE9;faut ","161365.htm");
Page[164]=new Array("Règles de mise au point des fichiers de configuration de Kaspersky Endpoint Security","Lors de la modification d'un fichier de configuration, veuillez respecter les règles suivantes :","Il faut définir une valeur pour tous les paramètres obligatoires du fichier de configuration. Pour définir des paramètres distincts d'une tâche, vous pouvez opter pour la ligne de commande qui permet de réaliser l'opération sans fichier.Si le paramètre fait partie d'une section, ne le placez que dans cette section. Au sein d'une section, vous pouvez placer les paramètres dans n'importe quel ordre.Mettez les noms des sections entre crochets [ ].Saisissez les valeurs au format nom du paramètre=valeur (les espaces entre le nom du paramètre et sa valeur ne sont pas traités).","Exemple :","[ScanScope.item_0000]","AreaDesc=Home","AreaMask.item_0000=*doc","Path=/home","Les caractères \"espace\" et \"tabulation\" sont ignorés avant le premier guillemet et après le dernier guillemet d'une valeur de ligne, ainsi qu'au début et à la fin d'une valeur de ligne ne figurant pas entre guillemets.","S'il s'avère nécessaire de définir plusieurs valeurs, répétez le paramètre autant de fois que le nombre de valeurs que vous voulez définir.","Exemple :","AreaMask.item_0000=*xml","AreaMask.item_0001=*doc","Respectez la casse lors de la saisie des valeurs des paramètres des types suivants :noms (masques) des objets analysés et des objets d'exclusion ;noms (masque) des menaces.Les autres valeurs de paramètres ne sont pas sensibles à la casse.","Indiquez les valeurs des paramètres de type booléen comme suit : Yes – No.Les chaînes de valeur contenant un \"espace\" doivent être saisies entre guillemets (par exemple, les noms de fichiers ou les répertoires et les chemins d'accès à ceux ci, les expressions contenant la date et l'heure au format AAAA-MM-DD HH:MM:SS).Les autres valeurs peuvent être saisies entre guillemets et sans guillemets.","Exemple :","AreaDesc=\"Analyse des bases de messagerie\"","Un guillemet solitaire en début ou en fin de ligne est une erreur."," R&#xE8;gles de mise au point des fichiers de configuration de Kaspersky Endpoint Security ","161266.htm");
Page[165]=new Array("Fichier de configuration de la tâche de protection en temps réel","ScanArchived=No","ScanSfxArchived=No","ScanMailBases=No","ScanPlainMail=No","TimeLimit=60","SizeLimit=0","FirstAction=Recommended","SecondAction=Block","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","ScanByAccessType=SmartCheck","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," Fichier de configuration de la t&#xE2;che de protection en temps r&#xE9;el ","161366.htm");
Page[166]=new Array("Fichier de configuration de la tâche d'analyse à la demande","ScanArchived=Yes","ScanSfxArchived=Yes","ScanMailBases=No","ScanPlainMail=No","TimeLimit=0","SizeLimit=0","FirstAction=Recommended","SecondAction=Skip","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," Fichier de configuration de la t&#xE2;che d&apos;analyse &#xE0; la demande ","161367.htm");
Page[167]=new Array("Fichier de configuration de la tâche d'analyse personnalisée","ScanArchived=Yes","ScanSfxArchived=Yes","ScanMailBases=No","ScanPlainMail=No","TimeLimit=0","SizeLimit=0","FirstAction=Recommended","SecondAction=Skip","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," Fichier de configuration de la t&#xE2;che d&apos;analyse personnalis&#xE9;e ","161368.htm");
Page[168]=new Array("Fichier de configuration de la tâche d'analyse des secteurs d'amorçage","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","Action=Cure"," Fichier de configuration de la t&#xE2;che d&apos;analyse des secteurs d&apos;amor&#xE7;age ","161369.htm");
Page[169]=new Array("Fichier de configuration de la tâche d'analyse de la mémoire des processus","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportUnprocessedObjects=No","Action=Cure"," Fichier de configuration de la t&#xE2;che d&apos;analyse de la m&#xE9;moire des processus ","161370.htm");
Page[170]=new Array("Fichier de configuration de la tâche de mise à jour","SourceType=\"KLServers\"","UseKLServersWhenUnavailable=Yes","IgnoreProxySettingsForKLServers=No","IgnoreProxySettingsForCustomSources=No","ApplicationUpdateMode=DownloadOnly","ConnectionTimeout=10"," Fichier de configuration de la t&#xE2;che de mise &#xE0; jour ","161371.htm");
Page[171]=new Array("Fichier de configuration de la tâche de copie des mises à jour","SourceType=KLServers","UseKLServersWhenUnavailable=Yes","ConnectionTimeout=10","ApplicationUpdateMode=DownloadOnly"," Fichier de configuration de la t&#xE2;che de copie des mises &#xE0; jour ","161372.htm");
Page[172]=new Array("Fichier de configuration de la tâche d'administration du stockage","DaysToLive=90","BackupSizeLimit=0","BackupFolder=/var/opt/kaspersky/kesl/common/objects-backup/"," Fichier de configuration de la t&#xE2;che d&apos;administration du stockage ","161373.htm");
Page[173]=new Array("Fichier de configuration de la tâche de gestion du pare-feu","DefaultIncomingAction=Allow","DefaultIncomingPacketAction=Allow","[NetworkZonesTrusted]","[NetworkZonesLocal]","[NetworkZonesPublic]"," Fichier de configuration de la t&#xE2;che de gestion du pare-feu ","161374.htm");
Page[174]=new Array("Fichier de configuration de la tâche de contrôle de l'intégrité des fichiers","UseExcludeMasks=No","[ScanScope.item_0000]","AreaDesc=Kaspersky internal objects","UseScanArea=Yes","Path=/opt/kaspersky/kesl/","AreaMask.item_0000=*"," Fichier de configuration de la t&#xE2;che de contr&#xF4;le de l&apos;int&#xE9;grit&#xE9; des fichiers ","161375.htm");
Page[175]=new Array("Fichier de configuration de la tâche Protection contre le chiffrement","UseHostBlocker=yes","BlockTime=30","UseExcludeMasks=no","[ScanScope.item_0000]","AreaDesc=AllSharedFolders","UseScanArea=yes","Path=AllShared","AreaMask.item_0000=*"," Fichier de configuration de la t&#xE2;che Protection contre le chiffrement ","161376.htm");
Page[176]=new Array("Configuration de la collaboration : Kaspersky Antivirus for Linux Mail Server","Pour configurer la compatibilité entre Kaspersky Endpoint Security 10 et Kaspersky Anti-Virus for Linux Mail Server, procédez comme suit :","Enregistrez les paramètres de la tâche de protection en temps réel dans le fichier de configuration à l'aide de la commande suivante :kesl-control --get-settings 1 --file <chemin d'accès au fichier>","Ouvrez le fichier de configuration créé afin d'en modifier le contenu.Ajoutez la section suivante dans le fichier créé :[ExcludedFromScanScope.item_#]","Path=</var/opt/kaspersky/klms>","Répéter la section indiquée ci-dessus pour tous les agents de messagerie intégrés à Kaspersky Anti-Virus for Linux Mail Server.Pour exclure le répertoire temporaire des filtres et des services de Kaspersky Anti-Virus for Linux Mail Server de l'analyse, ajoutez la section suivante dans le fichier créé la section :[ExcludedFromScanScope.item_#]","Path=/tmp/klmstmp","Enregistrez les modifications dans le fichier de configuration.Importez les paramètres du fichier de configuration dans la tâche de protection en temps réel à l'aide de la commande suivante :kesl-control --set-settings 1 --file <chemin d'accès complet au fichier>"," Configuration de la collaboration : Kaspersky Antivirus for Linux Mail Server ","161377.htm");
Page[177]=new Array("Codes de retour de la ligne de commande","Cette section décrit les codes de retour de la ligne de commande.","0 : réussite de l'exécution de la commande/de la tâche ;","1 : erreur générale dans les arguments de la commande ;","2 : erreur dans les configurations de l'application transmises ;","64 : Kaspersky Endpoint Security n'est pas lancé ;","66 : les bases antivirus ne sont pas chargées (utilisé uniquement par la commande --app-info) ;","67 : échec de l'activation 2.0 suite à des problèmes de réseau ;","68 : impossible d'exécuter la commande car l'application est soumise à une stratégie ;","128 : erreur inconnue ;","65 : toutes les autres erreurs."," Codes de retour de la ligne de commande ","161378.htm");
Page[178]=new Array("AO Kaspersky Lab","Kaspersky Lab est un société de renommée mondiale qui fournit des systèmes de protection des ordinateurs contre les menaces numériques, y compris les virus et autres applications malveillantes, les emails non sollicités (spam) ainsi que les attaques réseau et de piratage.","En 2008, Kaspersky Lab a fait son entrée dans le Top 4 des leaders mondiaux du marché des solutions de sécurité informatique pour les utilisateurs finaux (classement « IDC Worldwide Endpoint Security Revenue by Vendor »). Kaspersky Lab est le fournisseur privilégié des systèmes de protection informatique pour les particuliers en Russie (IDC Endpoint Tracker 2014).","Kaspersky Lab a vu le jour en Russie en 1997. Il est depuis devenu un groupe international d'entreprises disposant de 38 bureaux dans 33 pays. La société emploie plus de 3 000 experts qualifiés.","Produits. Les produits développés par Kaspersky Lab protègent aussi bien les ordinateurs des particuliers que les ordinateurs des réseaux d'entreprise.","La gamme de logiciels pour particuliers reprend des applications de sécurité pour ordinateurs de bureau et ordinateurs portables, ainsi pour ordinateurs de poche, smartphones et d'autres appareils nomades.","La société propose des solutions et des technologies de protection et de contrôle pour les postes de travail et les appareils mobiles, les machines virtuelles, les serveurs de fichiers et Internet, les passerelles de messagerie et les pare-feu. Le portefeuille de la société propose également des produits spécialisés assurant une protection contre les attaques DDoS, une protection pour les systèmes de contrôle industriel et la prévention de la fraude financière. Utilisées conjointement avec les outils de gestion centralisée, ces solutions garantissent une protection automatisée efficace contre toutes les tailles de menaces informatiques pour les entreprises et les organisations. Les produits de Kaspersky Lab sont certifiés par les grands laboratoires d'essai, compatibles avec les logiciels de divers éditeurs et optimisés pour fonctionner sur de nombreuses plateformes matérielles.","Les experts antivirus de Kaspersky Lab travaillent 24h/24. Chaque jour, ils trouvent des centaines de milliers de nouvelles menaces informatiques, créent les outils de détection et de désinfection de ces menaces et ajoutent leurs signatures aux bases utilisées par les applications de Kaspersky Lab.","Technologies. Kaspersky Lab est à l’origine de nombreuses technologies sans lesquelles il est impossible d’imaginer un logiciel antivirus moderne. Ce n'est pas un hasard si beaucoup d'autres développeurs utilisent le moteur de Kaspersky Antivirus dans leurs produits, notamment : Alcatel-Lucent, Alt-N, Asus, BAE Systems, Blue Coat, Check Point, Cisco Meraki, Clearswift, D-Link, Facebook, General Dynamics, H3C, Juniper Networks, Lenovo, Microsoft, NETGEAR, Openwave Messaging, Parallels, Qualcomm, Samsung, Stormshield, Toshiba, Trustwave, Vertu et ZyXEL. De nombreuses technologies novatrices développées par la société sont brevetées.","Réalisations. Au fil des années, Kaspersky Lab a remporté des centaines de récompenses pour ces efforts en matière de lutte contre les menaces informatiques. Suite aux essais et aux recherches menés par le célèbre laboratoire autrichien AV-Comparatives en 2014, Kaspersky Lab est classé parmi les deux premiers fournisseurs par le nombre de certificats Advanced+ et a finalement obtenu le certificat Top Rated. Mais la plus grande réalisation de Kaspersky Lab est la fidélité de ses clients à travers le monde. Les produits et les technologies de la société protègent plus de 400 millions d'utilisateurs et plus de 270 000 entreprises leur confient leur protection."," ","Site Internet de Kaspersky Lab :","https://www.kaspersky.fr ","Encyclopédie des virus :","https://securelist.com ","Laboratoire de virus :","https://virusdesk.kaspersky.com (pour l'analyse des fichiers et sites Internet suspects)","Forum de Kaspersky Lab :","https://forum.kaspersky.com "," "," AO Kaspersky Lab ","34744.htm");
Page[179]=new Array("Informations sur le code tiers","Les informations sur le code tiers se trouvent dans le fichier legal_notices.txt, situé dans le répertoire d'installation de l'application."," Informations sur le code tiers ","161380.htm");
Page[180]=new Array("Notice sur les marques de commerce","Les marques déposées et les marques de services appartiennent à leurs propriétaires respectifs.","Core est une marque commerciale d'Intel Corporation déposée aux Etats-Unis et dans d'autres pays.","Linux est une marque de Linus Torvalds déposée aux Etats-Unis et d'autres pays.","Microsoft, Outlook, Outlook Express et Windows sont des marques déposées de Microsoft Corporation aux États-Unis et dans d'autres pays.","Novell une marque de Novell Inc. déposée aux États-Unis et dans d'autres pays.","Oracle est une marque déposée d'Oracle et / ou de ses filiales.","Red Hat, Red Hat Enterprise Linux et CentOS sont des marques de Red Hat Inc., déposées aux Etats-Unis et dans d'autres pays.","Debian est une marque déposée de Software in the Public Interest, Inc.","SUSE est une marque de SUSE LLC déposée aux Etats-Unis et dans d'autres pays."," Notice sur les marques de commerce ","161381.htm");
Page[181]=new Array("Code qui vous est communiqué lors de l'achat d'une licence pour Kaspersky Endpoint Security. Ce code est nécessaire pour l'activation de l'application.","Le code d'activation est une séquence unique de vingts caractères lettres et chiffres au format xxxxx-xxxxx-xxxxx-xxxxx.","Code d'activation","95897.htm#o112627");
Page[182]=new Array("Clé que l'application utilise actuellement.","Clé active","95897.htm#o111595");
Page[183]=new Array("Une clé qui confirme le droit d'utilisation de l'application, mais qui n'est pas utilisée en ce moment.","Clé additionnelle","95897.htm#o111599");
Page[184]=new Array("Ensemble d'ordinateurs qui partagent des fonctions communes et un groupe d'applications Kaspersky Lab installées dessus. Le regroupement des ordinateurs de la sorte vise à permettre l'administration de ces ordinateurs comme une seule entité. Un groupe peut inclure d'autres groupes. Il est possible de créer des stratégies de groupe et des tâches de groupe pour chaque application installée dans le groupe.","Groupe d'administration","95897.htm#o112575");
Page[185]=new Array("Composant de Kaspersky Security Center qui stocke centralement les informations relatives à toutes les applications de Kaspersky Lab installées dans le réseau de l'entreprise. Il peut également intervenir dans l'administration de ces applications.","Serveur d'administration","95897.htm#o112576");
Page[186]=new Array("Bases de données qui contiennent des informations sur les menaces contre la sécurité des ordinateurs connues de Kaspersky Lab à la date de publication des bases antivirus. Les entrées dans les bases antivirus permettent de détecter le code malveillant dans les objets analysés. Les bases antivirus sont créées par les experts de Kaspersky Lab et mises à jour toutes les heures.","Bases antivirus","95897.htm#o111582");
Page[187]=new Array("Un composant spécialisé qui fournit l'interface de gestion des applications via la Console d'administration. Chaque application comporte son propre plug-in. Il est inclus dans toutes les applications de Kaspersky Lab qui peuvent être gérées via Kaspersky Endpoint Security.","Plug-in d'administration de l'application","95897.htm#o112588");
Page[188]=new Array("Stockage spécial des copies de sauvegarde des fichiers qui sont créés avant la tentative de désinfection ou de suppression.","Sauvegarde","95897.htm#o112592");
Page[189]=new Array("Méthode de traitement des objets infectés qui débouche sur une récupération complète ou partielle des données. La désinfection n'est pas applicable à tous les fichiers infectés.","Désinfection","95897.htm#o112629");
Page[190]=new Array("Une Exclusion est un objet exclu de l'analyse par une application Kaspersky Lab. Vous pouvez exclure de l'analyse certains formats de fichiers, des masques de fichiers, une zone en particulier (par exemple, un dossier ou une application), des processus d'application ou des objets par type de menace, d'après le classement de l'Encyclopédie des virus. Chaque tâche peut se voir attribuer un ensemble d'exclusions.","Exclusion","95897.htm#o112624");
Page[191]=new Array("Situation qui se produit lorsqu'une application de Kaspersky Lab considère qu'un objet non infecté est infecté car son code est similaire à celui d'un virus.","Faux positif","95897.htm#o112631");
Page[192]=new Array("Représentation d'un nom de fichier à l'aide de caractères génériques. Les caractères génériques standard utilisés dans les masques de fichiers sont * et ?, où * représente n'importe quel nombre de caractères et ? remplace un caractère unique.","Masque de fichier","95897.htm#o111603");
Page[193]=new Array("Tâche définie pour un groupe d'administration et exécutée sur tous les ordinateurs clients inclus dans ce groupe d'administration.","Tâche de groupe","95897.htm#o112572");
Page[194]=new Array("Objet qui, en raison de sa structure ou de son format, peut être exploité par des individus malintentionnés en tant que \"conteneur\" pour stocker et propager du code malveillant. En général, il s'agit de fichiers exécutables portant des extensions telles que .com, .exe et .dll. Le risque de pénétration de code malveillant dans ces fichiers est assez élevé.","Objet infectable","95897.htm#o112644");
Page[195]=new Array("Objet dont une partie de code correspond entièrement à une partie de code d'une application malveillante connue. Kaspersky Lab ne recommande pas l'accès à ces objets.","Objet infecté","95897.htm#o112621");
Page[196]=new Array("Liste de serveurs HTTP et FTP Kaspersky Lab sur lesquels l'application télécharge les mises à jour des bases de données vers les appareils mobiles.","Serveurs de mise à jour Kaspersky Lab","95897.htm#o112658");
Page[197]=new Array("Droit d'utilisation de l'application, limité dans le temps et octroyé dans le cadre du Contrat de licence utilisateur final.","Licence","95897.htm#o135751");
Page[198]=new Array("Document livré par Kaspersky Lab avec un fichier clé ou un code d'activation. Ce document contient des informations relatives à la licence fournie.","Certificat de licence","95897.htm#o166042");
Page[199]=new Array("Une stratégie détermine les paramètres d'une application et administre l'accès à la configuration d'une application installée sur des ordinateurs au sein d'un groupe d'administration. Il faut créer une stratégie individuelle pour chaque application. Vous pouvez créer un nombre illimité de stratégies différentes pour des applications installées sur les ordinateurs de chaque groupe d'administration, mais seule une stratégie peut être appliquée à chaque application à la fois au sein d'un groupe d'administration.","Stratégie","95897.htm#o111585");
Page[200]=new Array("Paramètres de l'application communs à tous les types de tâches. Ils régissent le fonctionnement global de l'application, comme ses performances, les rapports et les paramètres de sauvegarde.","Paramètres de l'application","95897.htm#o112587");
Page[201]=new Array("Service réseau de l'ordinateur qui permet aux utilisateurs de lancer des requêtes indirectes vers d'autres services du réseau. Tout d'abord, un utilisateur se connecte à un serveur proxy et demande une ressource (par exemple, un fichier) située sur un autre serveur. Ensuite, le serveur proxy se connecte au serveur spécifié et obtient la ressource depuis ce dernier ou renvoie la ressource depuis son propre cache (si le proxy dispose de son propre cache). Dans certains cas, le serveur proxy peut modifier la requête de l'utilisateur ou la réponse du serveur pour certains objectifs.","Serveur Proxy","95897.htm#o112649");
Page[202]=new Array("Mode de fonctionnement de l'application dans lequel les objets sont analysés en temps réel à la recherche de code malveillant.","L'application intercepte toutes les tentatives d'ouverture d'un objet (en lecture, écriture ou exécution) et y recherche la présence éventuelle de menaces. Les objets non infectés sont transmis à l'utilisateur ; les objets contenant des menaces ou des objets probablement infectés sont traités selon les paramètres de la tâche (désinfectés, supprimés ou mis en quarantaine).","Protection en temps réel des fichiers ","95897.htm#o112643");
Page[203]=new Array("Permet l'utilisation de l'application d'après les paramètres sélectionnés (date d'expiration et nombre d'appareils). Vous pouvez suspendre ou reprendre votre abonnement, le renouveler automatiquement ou l'annuler.","Abonnement","95897.htm#o142586");
Page[204]=new Array("Les fonctions exécutées par l'application Kaspersky Lab sont mises en œuvre sous forme de tâches telles que : Protection en temps réel, Analyse complète et Mise à jour des bases de données.","Tâche","95897.htm#o112579");
Page[205]=new Array("Tâche assignée à un ensemble d'ordinateurs clients par des groupes d'administration arbitraires et effectuée sur ces hôtes.","Tâche pour des ordinateurs particuliers","95897.htm#o112571");
Page[206]=new Array("Les paramètres de l'application sont propres à chaque type de tâche.","Paramètres des tâches","95897.htm#o112586");
Page[207]=new Array("Fonction exécutée par une application Kaspersky Lab qui lui permet de maintenir à jour la protection de l'ordinateur. Au cours de la mise à jour, une application les mises à jour de ses bases de données et modules sur les serveurs de mise à jour Kaspersky Lab, les installe et les applique automatiquement.","Mise à jour","95897.htm#o111604");
var PageCount=208;
var parsedMainTitle = 'Kaspersky Endpoint Security 10 Service Pack 1 for Linux ';
(function () {
    var maxTextLength = 0;
    var fakeDiv = $('<div/>');
    var text;
    var pageSearch = _.map(Page, function (page) {
        return {
            link: page[page.length - 1],
            title: page[page.length - 2],
            text: _.map(page.slice(0, page.length - 2), function(item) {
                text = fakeDiv.html(item).text();
                maxTextLength = Math.max(maxTextLength, text.length);

                return text;
            })
        };
    });

    fakeDiv.remove();

    window.search = function (searchWord, searchWordMinLength) {
        //console.time('search');
        var result = {
            found: false,
            isInit: false,
            results: [],
            resultsCount: 0
        };

        if (searchWord !== '') {
            result.searchWord = searchWord;

            var searchLength = searchWord.length > 5 ? searchWord.length - 2 : searchWordMinLength;

            var fuseOptions = {
                //verbose: true,
                shouldSort: true,
                includeScore: true,
                includeMatches: true,
                minMatchCharLength: searchLength,
                tokenize: true,
                matchAllTokens: true,
                findAllMatches: true,
                threshold: 0.2,
                location: 0,
                distance: maxTextLength,
                keys: ['text', 'title']
            };

            var fuse = new Fuse(pageSearch, fuseOptions);
            var currentResults = fuse.search(searchWord);
            var searchRegExp = new RegExp(searchWord, 'gi');

            if (currentResults.length) {
                result.found = true;
                result.results = _.chain(currentResults)
                    // .filter(function(result) {
                    //     return result.matches.length;
                    // })
                    .map(function (result) {
                        var item = result.item;

                        return {
                            title: item.title.replace(searchRegExp, '<mark>$&</mark>'),
                            link: item.link,
                            texts: _.reduce(result.matches, function(previous, searchResult) {
                                if (searchResult.key === 'text') {
                                    previous.push(searchResult.value.replace(searchRegExp, '<mark>$&</mark>'));
                                }

                                return previous;
                            }, [])
                        }
                    })
                    .value();

                result.resultsCount = result.results.length;
            }
        }

        //console.timeEnd('search');
        return result;
    };

    /*
    #    result = {
    #        found: true
    #        isInit: false
    #        results: {
    #            "12345.htm": {
    #                {
    #                    title: 'Страница 1'
    #                    texts: [
    #                               "В этом тексте было найдено <mark>#{searchWord}</mark>",
    #                               "В этом тексте тоже было найдено <mark>#{searchWord}</mark>"
    #                           ]
    #                    link: '#'
    #                }
    #                {
    #                    title: 'Страница 8962'
    #                    texts: [
    #                               "Здесь текст, а в нём встречается <mark>#{searchWord}</mark>",
    #                               "Здесь тоже текст, и в нём тоже встречается <mark>#{searchWord}</mark>"
    #                           ]
    #                    link: '#'
    #                }
    #            }
    #        }
    #    }
    */
})();

if (typeof String.prototype.trim !== 'function') {
    String.prototype.trim = function () {
        return this.replace(/^\s+|\s+$/g, '');
    };
}

window.loadParent = function () {};

// hide content to avoid blink
window.document.documentElement.style.display = 'none';

$(function () {
    var $aside, $container, $content, $header, $modalContent, $modalHeader, $overlay, $pageTitle,
        $tooltip, $tooltipContent, tooltipButton;

    $.support.cors = true;
    $.fx.speeds._default = 200;

    var options = {
        helpers: {
            media_hv_min: 568,
            media_hv_middle: 874,
            media_mobile: 768
        },
        isMac: Boolean(window['IsMacVersion']),
        isMacProject: Boolean(window['isMacProject']),
        isIE7: Boolean(navigator.appVersion.match('MSIE 7.')),
        isIE8: Boolean(navigator.appVersion.match('MSIE 8.')),
        isIE9: Boolean(navigator.appVersion.match('MSIE 9.')),
        isIE10: Boolean(navigator.appVersion.match('MSIE 10.')),
        isOperaMini: Object.prototype.toString.call(window["operamini"]) === "[object OperaMini]",
        isFileProtocol: window.location.protocol === 'file:',
        isAllInOne: window.location.pathname.match(/(all-in-one\.htm)[l]?$/),
        searchWord: getParam('searchWord', true),
        searchWordMinLength: 3
    };

    if (window.Customization) {
        _.each(window.Localization, function(item, key) {
            if (_.isObject(window.Customization[key])) {
                window.Localization[key] = window.Customization[key].value;
            }
        });
    }

    setParam('searchWord', null, true);

    var HELP = window.HELP = $.extend(true, window.HELP, options);
    var $window = $(window);
    var html = document.documentElement;
    var $html = $(html);
    var $head = $(document.head);
    var $body = $(document.body);
    var title = $html.find('title').text();

    $body.removeClass("no-js");

    var ContainerTemplateFunction = _.template(ContainerTemplate);
    var HeaderTemplateFunction = _.template(HeaderTemplate);
    var FooterTemplateFunction = _.template(FooterTemplate);
    var AsideTemplateFunction = _.template(AsideTemplate);
    var SearchResultsTemplateFunction = _.template(SearchResultsTemplate);
    var MobileSearchResultsTemplateFunction = _.template(MobileSearchResultsTemplate);
    var LangListTemplateFunction = _.template(LangListTemplate);
    var VersionsTemplateFunction = _.template(VersionsTemplate);
    var IndexLiteralsTemplateFunction = _.template(IndexLiteralsTemplate);
    var MenuTemplateFunction = _.template(MenuTemplate);
    var AllInOneMenuTemplateFunction = _.template(AllInOneMenuTemplate);
    var CustomStylesTemplateFunction = _.template(CustomStylesTemplate);

    window.parsedMainTitle = window.parsedMainTitle || "Kaspersky Online Help";
    window.toggleBlock = toggleBlock;
    window.showAll = showAll;
    window.hideAll = hideAll;
    window.togglePopup = togglePopup;
    window.showPopup = showTooltip;
    window.hidePopup = hideTooltip;

    function getParam(param, inSession) {
        if (localStorageChecker()) {
            if (inSession && window.sessionStorage) {
                return window.sessionStorage.getItem(param);
            }

            return store(param);
        }

        return null;
    }

    function setParam(param, value, inSession) {
        if (localStorageChecker()) {
            if (value === void 0) {
                value = null;
            }

            if (inSession && window.sessionStorage) {
                if (value === null) {
                    window.sessionStorage.removeItem(param);
                } else {
                    window.sessionStorage.setItem(param, value);
                }
            } else {
                store(param, value);
            }
        }
    }

    function toggleBlock(id) {
        if (!HELP.isAllInOne) {
            var $block = $('#d' + id);
            var $toggler = $('#h' + id);

            if ($block.length > 0 && $toggler.length > 0) {
                $block.slideToggle();
                $toggler.toggleClass('is-expanded');
                $window.resize();
            }
        }
    }

    function showAll() {
        $('.expandingblock').slideDown();
        $('.expandingblocktemplate').addClass('is-expanded');
        $window.resize();
    }

    function hideAll() {
        $('.expandingblock').slideUp();
        $('.expandingblocktemplate').removeClass('is-expanded');
        $window.resize();
    }

    function togglePopup(id, legacyblockname, show) {
        switch (show) {
            case true:
                showTooltip(id, legacyblockname);
                break;
            case false:
                hideTooltip();
                break;
            default:
                toggleTooltip(id, legacyblockname);
        }
    }

    function calcTooltipPosition() {
        if (tooltipButton) {
            var body = document.body;
            var delta = 30;
            var offset = 10;

            if (options.isIE7 || options.isIE8) {
                offset = 0;
            }

            var bodyHeight = body.clientHeight;
            var bodyWidth = body.clientWidth;
            var linkRect = tooltipButton.getBoundingClientRect();
            var tooltip = $tooltip[0];
            var isToTop = linkRect.top > bodyHeight - linkRect.bottom;
            var isToLeft = linkRect.left > bodyWidth - linkRect.right;
            var coords = {
                top: isToTop ? "" : linkRect.bottom + offset,
                bottom: isToTop ? bodyHeight - linkRect.top + offset : "",
                left: isToLeft ? "" : linkRect.left - delta,
                right: isToLeft ? bodyWidth - linkRect.right - delta : ""
            };

            $tooltip.toggleClass("is-to-top", isToTop).toggleClass("is-to-left", isToLeft).css(coords);

            var tooltipRect = tooltip.getBoundingClientRect();
            coords = {};

            var isOverlapLeft = tooltipRect.left < delta;
            var isOverlapRight = tooltipRect.right > bodyWidth - delta;

            if (isOverlapLeft) {
                coords.left = delta;
            }

            if (isOverlapRight) {
                coords.right = delta;
            }

            if (isOverlapLeft || isOverlapRight) {
                coords.width = "auto";
            } else {
                coords.width = "";
            }

            $tooltip.css(coords);
            tooltipRect = tooltip.getBoundingClientRect();
            coords = {};

            var isOverlapTop = tooltipRect.top < delta;
            var isOverlapBottom = tooltipRect.bottom > bodyHeight - delta;

            if (isOverlapTop) {
                coords.top = delta;
            }

            if (isOverlapBottom) {
                coords.bottom = delta;
            }

            $tooltip.css(coords);
            if (options.isIE7 || options.isIE8) {
                return $tooltip.height(Math.min($tooltipContent[0] != null ? $tooltipContent[0].scrollHeight : void 0, 200));
            }
        }
    }

    function calcHomeBtnVisibility($viewport) {
        return setTimeout(function () {
            var $homeBtn = $viewport.find('.bt-home');

            var calcHeight;
            if ($homeBtn.hasClass('is-shown')) {
                var btn = $homeBtn[0];
                var style = btn.currentStyle || window.getComputedStyle(btn);
                calcHeight = btn.offsetHeight + parseInt(style.marginTop) + parseInt(style.marginBottom);
            } else {
                calcHeight = 0;
            }

            var showBtn = $viewport[0].offsetHeight < $viewport[0].scrollHeight - calcHeight;

            $homeBtn.toggleClass('is-shown', showBtn);
        }, 400);
    }

    function verifyMenuVisiblity($asidePlaceholder) {
        if (window.matchMedia) {
            var mq = window.matchMedia('screen and (max-width: 767px)');

            if (!mq.matches) {
                //$asidePlaceholder.removeClass('is-hidden');
            } else {
                $('.js-tab-link').eq(0).click();
            }
        }
    }

    function showTooltip(id, btnId) {
        if ($tooltip.data("id") !== id) {
            var content = document.getElementById("d" + id).innerHTML;
            $tooltip.data("id", id);
            $tooltipContent.html(content);
        }

        tooltipButton = document.getElementById(btnId);
        $tooltip.show();

        calcTooltipPosition();
    }

    function hideTooltip() {
        return $tooltip.hide();
    }

    function toggleTooltip(id, btnId) {
        if ($tooltip.data("id") !== id || $tooltip.css("display") === "none") {
            showTooltip(id, btnId);
        } else {
            hideTooltip();
        }
    }

    function bindEvents() {
        var $asidePlaceholder = $('.js_aside_placeholder');
        var $menuItems = $('.js_menu_item');
        var $mobileSearch = $('.js_mobile_search_result');
        var $viewport = $('.js_main');
        var mobileMenuToggle = function (button) {
            if (!$mobileSearch.hasClass('is-hidden')) {
                $mobileSearch.addClass('is-hidden');
            }

            $asidePlaceholder.toggleClass('is-active');
            $(button).toggleClass('is-active');
        };

        $('.js_burger').on('click', function (event) {
            event.preventDefault();
            mobileMenuToggle(this);
        });

        $body.on('click', '.js_mobile_menu_deeper', function (event) {
            event.preventDefault();
            mobileMenuShowItem($(this).data('id'));
        });

        $body.on('click', '.bt-home', function (event) {
            event.preventDefault();

            $(".js_content, .js_main").animate({
                scrollTop: 0
            }, '500', 'swing');
        });

        $body.on('click', '.js-tab-link', function () {
            if (!$(this).hasClass('js_search_tab')) {
                delete HELP.searchWord;
                setParam('searchWord', null, true);
            }
        });

        $window.on('resize', function () {
            calcTooltipPosition();
            calcHomeBtnVisibility($('.js_main'));
            verifyMenuVisiblity($asidePlaceholder);
            calcAsideWidth($asidePlaceholder);
        });

        $viewport.on("scroll", calcTooltipPosition);

        $body.on('click', 'a', function (event) {
            var $self = $(this);
            var url = $self.attr('href');

            if (HELP.isAllInOne) {
                if (url) {
                    var hash = url.match( /(.*)\.html?$/ );
                    if (hash && hash[1]) {
                        scrollToHash(hash[1]);

                        if (window.history && window.history.pushState) {
                            window.history.pushState({
                                url: url,
                                hash: hash[1]
                            }, document.title, location.pathname + '#' + hash[1]);
                        }

                        event.stopPropagation();
                        event.preventDefault();

                        trackPage();

                        return;
                    }
                }
            }

            if (window.matchMedia) {
                var mq = window.matchMedia('screen and (max-width: 767px)');
                if (mq.matches) {
                    var toggleSiblings = $self.siblings('.js_contents_toggle');
                    if (toggleSiblings.length > 0 && !$self.hasClass('js_menu_link_direct')) {
                        toggleSiblings.trigger('click');
                        event.preventDefault();
                        return;
                    }
                }
            }

            if (url && url !== '#') {
                var localUrlRegExp = /([\w_]+\.htm)[l]?(#[\w]+(.htm))?/i;
                var urlMatches = url.match(localUrlRegExp);
                var isLocalUrl = Boolean(urlMatches && urlMatches[2] && urlMatches[3]);
                var isLocalAnchor = urlMatches && urlMatches[2] && !urlMatches[3];

                if ($self.closest('.js_search_result_wrapper')) {
                    setParam('searchWord', HELP.searchWord, true);
                }

                if (localStorageChecker()) {
                    var $view = $('.js_tabs_viewport');

                    if ($view.length) {
                        window['localStorage']['asideScrollPosition'] = $view[0].scrollTop;
                    }

                    var $opened_menus = $('.js_contents_toggle.is-toggled+.js_menu_link');

                    if ($opened_menus.length) {
                        window['localStorage']['openedMenus'] = _.map($opened_menus, function (a) {
                            return $(a).attr('href');
                        });
                    }
                }

                if (isLocalUrl) {
                    if ($tooltip) {
                        $tooltip.hide();
                    }

                    var targetUrl = url;
                    var titlePageMatch = location.pathname.match(/(title\.htm)[l]?$/);

                    //if (titlePageMatch && titlePageMatch[1] === "title.htm") {
                    if (HELP.isMacProject) {
                        targetUrl = "./pgs/" + urlMatches[2].slice(1);
                        if (HELP.isFileProtocol) {
                            $self.attr('href', targetUrl);
                        }
                    }

                    if (!HELP.isFileProtocol) {
                        event.preventDefault();

                        setNavigation(HELP.isMacProject ? urlMatches[2].slice(1) : url);

                        loadContent(targetUrl, true, null, url);

                        if (window.matchMedia && mq && mq.matches) {
                            $('.js_aside_placeholder').removeClass('is-active');
                            $('.js_burger').removeClass('is-active');
                            $('.js_mobile_aside').addClass('is-hidden');
                        }

                        $('.js_home').toggleClass('is-active', HELP.nav.home.url === HELP.nav.currentPage.url);
                    }
                } else if (isLocalAnchor) {
                    if (window.matchMedia && mq && mq.matches) {
                        $('.js_aside_placeholder').removeClass('is-active');
                        $('.js_burger').removeClass('is-active');
                        $('.js_mobile_aside').addClass('is-hidden');
                    }
                } else if ($self.hasClass('hyperlinktemplate') && url.indexOf('mailto') !== 0) {
                    if (window.confirm(HELP.localization.ExternalLinkText)) {
                        return;
                    }

                    event.preventDefault();
                }
            } else {
                event.preventDefault();
            }
        });

        $body.on('click', '.js_menu_link, .js_menu_link_direct', function () {
            var $self = $(this);
            delete HELP.searchWord;
            setParam('searchWord', null, true);

            if (!$self.prev().hasClass('js_contents_toggle')) {
                $menuItems.removeClass('is-active');
            }

            $self.children('.js_contents_toggle').addClass('is-toggled').siblings('.js_contents_level').slideDown();
            $self.closest('.js_menu_item').addClass('is-active');

            var href = $self.attr('href');
            var topicRegExp = /[\w_]+\.htm/;
            var hashRegExp = /#([\w_]+)/;

            if (href.indexOf('#') > -1) {
                var locationMatch = location.pathname.match(topicRegExp);
                var hrefMatch = href.match(topicRegExp);
                var hash = href.match(hashRegExp)[1];
                event.preventDefault();

                if (!(locationMatch.length && hrefMatch.length && locationMatch[0] === hrefMatch[0])) {
                    loadContent(href, true, function() {
                        if (hash) {
                            scrollToHash(hash);
                        }
                    });
                }

                if (hash) {
                    scrollToHash(hash);

                    if (!HELP.isMacProject && window.history && window.history.pushState) {
                        window.history.pushState({
                            url: href,
                            hash: hash
                        }, document.title, href);
                    }
                }
            }
        });

        $body.on('click', '.js_home_link', function () {
            $('.js-tab-link').eq(0).trigger('click');
        });

        $(window).on('popstate', function (event) {
            var state = event.originalEvent.state;

            if (state && state.url) {
                if (!HELP.isAllInOne) {
                    loadContent(state.url, false, scroll, state.originalUrl);
                    setNavigation(state.url);
                } else {
                    scroll();
                    trackPage();
                }
            }

            function scroll() {
                if (state.hash) {
                    $(".js_menu_item").removeClass('is-active');
                    var $menuItem = $(".js_menu_link[href='" + state.hash + ".htm']").closest('.js_menu_item');
                    autoScrollContents($menuItem);

                    scrollToHash(state.hash);
                }
            }
        });

        $body.on('click', '.js_modal_close', function () {
            $overlay.removeClass('is-visible');
        }).on('click', '.js_overlay', function (event) {
            if (!$(event.target).closest('.js_modal').length) {
                $overlay.removeClass('is-visible');
            }
        });

        $body.on('click', '.js_print_section', function() {
            var currentUrl = window.location.pathname.match(/\/(\w+\.\w+)$/)[1];
            //window.location.href = 'all-in-one.htm?sectionUrl=' + currentUrl;
            window.open('all-in-one.htm?sectionUrl=' + currentUrl);
        });

        if (!HELP.isAllInOne) {
            var xStart = null;
            var yStart = null;

            $body.on('touchstart', '.js_content', function(event) {

                var tableInTopic = $(event.target).closest('.tableintopic');
                if (tableInTopic.length && tableInTopic.width() > tableInTopic.parent().width()) {
                    return;
                }

                var touch = event.originalEvent.touches[0];
                if (touch) {
                    xStart = touch.clientX;
                    yStart = touch.clientY;
                }
            });

            $body.on('touchmove', '.js_content', function(event) {
                if (!xStart || !yStart) {
                    return;
                }

                var touch = event.originalEvent.touches[0];
                var xEnd = touch.clientX;
                var yEnd = touch.clientY;
                var xDiff = xStart - xEnd ;
                var yDiff = yStart - yEnd;

                if (Math.abs(xDiff) > Math.abs(yDiff) && Math.abs(xDiff) > 50) {
                    if (xDiff > 0 && HELP.nav.nextPage) {
                        $('.js_container').addClass('is-loading');
                        $('.js_main').addClass('swipe-left');
                        setTimeout(function () {
                            $('.js_next_link').click();
                        }, 350);
                    } else if(xDiff < 0 && HELP.nav.prevPage) {
                        $('.js_container').addClass('is-loading');
                        $('.js_main').addClass('swipe-right');
                        setTimeout(function () {
                            $('.js_prev_link').click();
                        }, 350);
                    }

                    xStart = null;
                    yStart = null;
                }
            });
        }
    }

    /*
    #* Языки в хэдере --------------------------------------------------------------------------------------------------
     */
    function loadLangs() {
        if (!window.Langs) {
            $('.js_selector_mobile_langs').remove();
            return;
        }

        var currentId = 'no id';
        var currentName = 'no name';
        var locLangs = window.LangsLocalization;

        window.Langs.forEach(function(item) {
            if (locLangs && locLangs[item.id]) {
                item.name = locLangs[item.id];
            }

            if (item.id === document.documentElement.lang) {
                HELP.currentLangId = currentId = item.id;
                HELP.currentLangCode = currentName = item.name;

                if (~['ja-JP', 'ko-KR', 'zh-Hans', 'zh-Hant'].indexOf(HELP.currentLangId)) {
                    HELP.searchWordMinLength = 2;
                }
            }
        });

        if (window.Langs.length < 2) {
            $('.js_selector_mobile_langs').remove();
            return;
        }

        var isMac = Boolean(window.location.pathname.match(/pgs\/[\w_\.]+/));
        var isMacTitle = Boolean(window.location.pathname.match(/title\.html?$/));
        var LangListHtml = LangListTemplateFunction({
            langs: window.Langs,
            currentLang: {
                name: currentName,
                id: currentId
            },
            localization: HELP.localization,
            isMac: isMac,
            isMacTitle: isMacTitle
        });

        $header.find('.js_header_lang_list').html(LangListHtml);
        $('.js_selector_mobile_langs').html(LangListHtml).find('.js_dropdown').addClass('dropdown_large');

        $body.on('click', '.js_lang_item', function (event) {
            event.preventDefault();

            var $element = $(this);
            var langId = $element.data('lang-id');
            var path = window.location.pathname;
            var currentFolder = window.location.pathname.match(/([\w]+|[\w\.-]+)(\/pgs)?\/[\w_]+.html?/)[1];

            window.location.href  = path.replace("/" + currentFolder + "/", "/" + langId + "/");
        });
    }

    function triggerSearch() {
        if (HELP.helpers.searchTimeout) {
            clearTimeout(HELP.helpers.searchTimeout);
        }

        HELP.helpers.searchTimeout = setTimeout(function () {
            var searchWord = $('.js_search_text').val().trim();

            if (searchWord.length < HELP.searchWordMinLength) {
                delete HELP.searchWord;
                setParam('searchWord', null, true);

                searchWord = null;

                $('.js-menu-content, .js_search').show();
                $('.js-search-content, .js_search_clear').hide();
            } else {
                HELP.searchWord = searchWord;
                setParam('searchWord', searchWord, true);

                var resultObj = search(searchWord, HELP.searchWordMinLength);
                resultObj.localization = HELP.localization;
                resultObj.isMacProject = HELP.isMacProject;

                var searchResultsHtml = SearchResultsTemplateFunction(resultObj);

                $('.js-menu-content, .js_search').hide();
                $('.js-search-content, .js_search_clear').show();
                //$('.js_search_tab').trigger('click');

                $('.js_search_result_wrapper').html(searchResultsHtml);
            }
        }, 300);
    }

    /*
    #* Левое меню ------------------------------------------------------------------------------------------------------
     */
    function loadMenu(menu) {
        if (!window['Toc']) {
            return;
        }

        var flatMenu = [];
        var currentUrl = HELP.isAllInOne || HELP.isMacProject ?
            /#([\w_]+)/.exec(location.hash) : /\/([\w_]+\.\w+$)/.exec(location.pathname);
        var currentPage = {};
        var currentLevel, parentPage;

        if (currentUrl && currentUrl[1]) {
            currentUrl = currentUrl[1];
        }

        function buildMenu(menu, level, parentId) {
            var isCurrentMenuLevelActive;
            level = level || 0;

            _.each(menu, function (item) {
                item.level = level;
                if (item.url && item.url.match(/#|(title\.html?)/)) {
                    return;
                }

                if (item.hidden) {
                    return;
                }

                flatMenu.push(item);

                if (item.url === currentUrl || item.url === currentUrl + '.htm') {
                    item.isActive = true;
                    currentPage = item;
                    currentLevel = level;
                }

                if (item.children) {
                    item.childIsActive = buildMenu(item.children, level + 1, item.id);
                }

                if (item.isActive || item.childIsActive) {
                    isCurrentMenuLevelActive = true;
                }

                if (level > 0 && parentId) {
                    return item.parentId = parentId;
                }
            });

            return isCurrentMenuLevelActive;
        }

        buildMenu(menu);

        var i, j, ref, item, prevSection, nextSection;
        for (i = j = 0, ref = flatMenu.length - 1; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
            item = flatMenu[i];
            if (item.url === currentUrl || item.url === currentUrl + '.htm') {
                if (i > 0) {
                    prevSection = flatMenu[i - 1];
                }

                if (i !== flatMenu.length - 1) {
                    nextSection = flatMenu[i + 1];
                }
            }
        }

        if (!currentPage.url) {
            nextSection = flatMenu[0];
        }

        window.HELP = $.extend(true, window.HELP, {
            nav: {
                menu: menu,
                flatMenu: flatMenu,
                home: flatMenu[0],
                currentPage: currentPage,
                currentLevel: currentLevel,
                parentPage: parentPage,
                prevPage: prevSection,
                nextPage: nextSection
            }
        });

        var $homeBtn = $body.find('.js_home');
        var $homeBtnLink = $homeBtn.find('.js_home_link');

        if (HELP.nav.home) {
            $homeBtnLink.attr('href', HELP.nav.home.url);
        }

        if (HELP.isAllInOne) {
            $(window).on('load', function() {
                setTimeout(function() {
                    scrollToHash(currentUrl);
                });
            });
        }

        buildLinks($container);

        var MenuHtml = MenuTemplateFunction({
            menu: menu,
            localization: HELP.localization,
            isMacProject: HELP.isMacProject
        });

        $aside.find('.js_menu').html(MenuHtml);

        $('.js_search_text').on('keyup', function (event) {
            if (event.keyCode === 27) {
                $('.js-tab-link').eq(0).click();
                $(this).val('');
            } else {

            }
            triggerSearch();
        });

        $('.js_search_clear').on('click', function () {
            $('.js_search_text').val('');
            triggerSearch();
        });

        $('.js_mobile_search_button').on('click', function () {
            var $this = $(this);
            var $result = $('.js_mobile_search_result');
            var $input = $('.js_mobile_search_input');
            var $clearBtn = $('.js_mobile_search_clear');
            var isShow = !$input.hasClass('is-hidden');

            if (isShow) {
                if ($input.val().length > 0) {
                    var searchWord = $input.val().trim();
                    var resultObj = search(searchWord, HELP.searchWordMinLength);

                    resultObj.localization = HELP.localization;
                    resultObj.isMacProject = HELP.isMacProject;
                    var mobileSearchResultsHtml = MobileSearchResultsTemplateFunction(resultObj);

                    $result.html(mobileSearchResultsHtml).removeClass('is-hidden').addClass('is-active');

                    setTimeout(function () {
                        $('.js_aside_placeholder').removeClass('is-active');
                        $('.js_burger').removeClass('is-active');
                    });
                } else {
                    $result.removeClass('is-active').addClass('is-hidden');
                }

                /*$this.removeClass('is-active');
                $input.addClass('is-hidden');
                $clearBtn.addClass('is-hidden');*/
            } else {
                $input.removeClass('is-hidden');
                $clearBtn.removeClass('is-hidden');
                $this.addClass('is-active');

                if (!$result.is(':empty')) {
                    $result.removeClass('is-hidden').addClass('is-active');
                }

                setTimeout(function () {
                    $input.focus();
                }, 100);
            }
        });

        $('.js_mobile_search_clear').on('click', function () {
            var $searchBtn = $('.js_mobile_search_button');
            var $result = $('.js_mobile_search_result');
            var $input = $('.js_mobile_search_input');

            if ($input.val().length > 0) {
                $input.val('');
                HELP.searchWord = null;
                setParam('searchWord', null, true);

                $result.empty();
            }

            $searchBtn.removeClass('is-active');
            $result.addClass('is-hidden');
            $input.addClass('is-hidden');
            $(this).addClass('is-hidden');
        });

        var triggerMobileSearch = _.debounce(function() {
            $('.js_mobile_search_button').trigger('click');
        }, 350);

        $('.js_mobile_search_input').on('keyup', function (event) {
            if (event.keyCode === 13) {
                $('.js_mobile_search_button').trigger('click');
            // } else {
            //     triggerMobileSearch();
            }
        });

        $('.js_contents_toggle').on('click', function (event) {
            event.preventDefault();

            var $toggler = $(this);
            $toggler.toggleClass('is-toggled');

            if ($toggler.hasClass('is-toggled')) {
                $toggler.siblings('.contents').slideDown();
            } else {
                $toggler.siblings('.contents').slideUp();
            }
        });

        $('.js_dropdown_btn').on('click', function (event) {
            event.preventDefault();

            var $list = $(this).siblings('.js_dropdown_list');

            $list.css({
                maxHeight: html.clientHeight - $list.offset().top - this.clientHeight
            }).toggleClass('dropdown__list--opened');

            $body.on('click.dropdown', function (event) {
                if (!$(event.target).closest('.js_dropdown').length) {
                    $list.toggleClass('dropdown__list--opened');
                    $body.off('click.dropdown');
                }
            });
        });

        bindEvents();
    }

    function loadContent(url, saveToHistory, callback, originalUrl) {
        if (saveToHistory == null) {
            saveToHistory = true;
        }

        var loadingTimeout = setTimeout(function () {
            $('.js_container').addClass('is-loading');
        }, 300);

        $.ajax(url, {
            crossDomain: true,
            dataType: "html",
            success: function (response) {
                if (saveToHistory && window.history && window.history.pushState) {
                    window.history.pushState({
                        url: url,
                        originalUrl: originalUrl
                    }, null, originalUrl || url);
                }

                var frameHtml = processHtml(response);
                var langMatches = frameHtml.match(/\slang="(.+?)"/);

                if ((langMatches != null ? langMatches.length : void 0) > 1 && langMatches[1] !== HELP.currentLangId) {
                    window.location = HELP.isMacProject ? originalUrl : url;
                    return;
                }

                var $cont = $(frameHtml).filter('.cont');
                $content.html($cont);

                $(".js_content, .js_main").animate({
                    scrollTop: 0
                }, '200', 'swing');

                title = $cont.find('.heading1, .heading2, .heading3, .heading4').first().text();
                document.title = title;
                $(".js_menu_item").removeClass('is-active');

                var scrollToUrl = HELP.isMacProject ? originalUrl : url || HELP.nav.currentPage.url;
                var $menuItem = $(".js_menu_link[href='" + scrollToUrl + "']").closest('.js_menu_item');
                var $index = $('.js_index_literals');
                var $indexLinks = $index.find('.indexlink > a');
                $indexLinks.removeClass('is-active').filter("[href='" + url + "']").addClass('is-active');

                autoScrollContents($menuItem);
                processContent($container);

                if (loadingTimeout) {
                    clearTimeout(loadingTimeout);
                }

                if (callback && typeof callback === 'function') {
                    callback();
                }

                $('.js_container').removeClass('is-loading');
                $('.js_main').removeClass('swipe-left swipe-right');

                trackPage();
            },
            error: function () {
                window.history.back();
                return window.location = url;
            }
        });
    }

    function processHtml(content, menu) {
        if (menu) {
            var AllInOneMenuHtml = AllInOneMenuTemplateFunction({
                menu: menu,
                localization: HELP.localization
            });
            var resultContent = $();

            menu.forEach(getContent);

            function getContent(item) {
                resultContent = resultContent.add('#' + item.o + ', [name=' + item.o + ']');

                if (item.children) {
                    item.children.forEach(getContent);
                }
            }

            content = AllInOneMenuHtml + $('<div/>').html(resultContent).html();
        }

        if (typeof content === 'string') {
            content = content.replace(/[™®]|&reg;|&#8482;|&#174;/g, '');

            if (HELP.isMacProject) {
                content = content.replace(/"title.htm#([\w]+.htm)"/gi,'"index.htm#$1"');
            }

            if (HELP.searchWord) {
                var searchRegExp = new RegExp(escapeRegExp(HELP.searchWord) + '(?!([^<]+)?>)', "ig");
                content = content.replace(searchRegExp, "<mark>$&</mark>");
            }
        }

        return content;
    }

    function processContent($container) {
        $container.find('.links').remove();
        buildLinks($container);

        $container.find('.cont').toggleClass('mactitlepage', Boolean(location.pathname.match(/title\.htm/)));
        $container.find('style').remove();

        if (!HELP.isAllInOne) {
            $container.find('.popuponclick, .expandingblock').each(function () {
                var $self = $(this);
                var $toggler = $($self.attr('id').replace('d', '#h'));

                if ($toggler.length > 0) {
                    var $wrapper = $toggler.closest(".settingdescr");

                    if ($wrapper.length === 0) {
                        $wrapper = $toggler.parent();
                    }

                    $wrapper.append($self);

                    if ($self.hasClass('expandingblock')) {
                        $wrapper.addClass('expandingblock-wrapper');

                        var img = $toggler.next('img');

                        if (img.length) {
                            $toggler.append(img);
                        }
                    }
                }
            });
        }

        $container.find('.cont [title]').each(function(index, item) {
            var classes = item.className;
            var $item = $(item);

            if (!$item.is('img') &&
                classes.indexOf('hyperlinktemplate') === -1 &&
                classes.indexOf('crossreferencetemplate') === -1) {
                $item.removeAttr('title');
            }
        });

        $container.find('.hyperlinktemplate').each(function() {
            var $self = $(this);
            var $siblingLink = $self.next('span').find('.hyperlinktemplate');

            if ($siblingLink.length) {
                var text = $siblingLink.text();
                $self.append($siblingLink.parent().text(text));
            }
        });

        var $tables = $container.find(".tableintopic");
        $tables.wrap("<div class='tableintopic-wrapper'/>");
        var $tableRows = $tables.find('tr');
        $tableRows.filter(':nth-child(2n)').addClass('is-even');
        $tableRows.filter(':nth-child(2n+1)').addClass('is-odd');

        $container.find('.popuponhover, .popuponclick').each(function () {
            var $self = $(this);
            var $toggler = $($self.attr('id').replace('d', '#h'));

            if ($toggler.length > 0) {
                return $toggler.wrap("<div class='link-wrapper'/>").after($self);
            }
        });

        $container.find('.js_feedback_link').attr('href', getMailtoLink());

        $container.find('.program').each(function(index, item) {
            var $item = $(item);
            if (!$item.parent().hasClass('js_code')) {
                var siblings = $(item).nextUntil(':not(.program)').addBack();

                if (siblings.length > 1) {
                    siblings.wrapAll('<div class="js_code"></div>');
                    siblings.after('\n');
                }
            }
        });

        $container.find('.exampleheading, .examplebodytext, .exampleheadingblue2015, .examplebodytextblue2015')
            .parent().each(function(index, item) {
                $(item).addClass('example-wrapper');
            });

        setTimeout(function() {
            $container.find('.js_code').each(function(index, item) {
                window.hljs.highlightBlock(item);
            });
        });

        $window.resize();
    }

    function buildLinks($container) {
        $pageTitle = $container.find('.heading1, .heading2, .heading3, .heading4').first();
        var $homeBtn = $container.find('.bt-home');
        var $prevBtnPlaceholder = $container.find('.js_prev_btn_placeholder');
        var $nextBtnPlaceholder = $container.find('.js_next_btn_placeholder');
        var PageTitleTemplateFunction = _.template(PageTitleTemplate);
        var BottomLinksTemlateFunctions = _.template(BottomLinksTemplate);
        var NextLinkTemplateTemlateFunctions = _.template(NextLinkTemplate);
        var PrevLinkTemplateTemlateFunctions = _.template(PrevLinkTemplate);

        if (HELP.nav) {
            var PageTitleHtml = PageTitleTemplateFunction({
                titleHtml: $pageTitle.html(),
                localization: HELP.localization
            });

            $pageTitle.html(PageTitleHtml);

            if (!HELP.isAllInOne) {
                var NextLinkHtml = NextLinkTemplateTemlateFunctions({
                    nextPage: HELP.nav.nextPage,
                    isMacProject: HELP.isMacProject
                });

                var PrevLinkHtml = PrevLinkTemplateTemlateFunctions({
                    prevPage: HELP.nav.prevPage,
                    isMacProject: HELP.isMacProject
                });

                $prevBtnPlaceholder.html(PrevLinkHtml);
                $nextBtnPlaceholder.html(NextLinkHtml);

                if ($homeBtn.length === 1) {
                    $homeBtn = $homeBtn.first();

                    var BottomLinksHtmls = BottomLinksTemlateFunctions({
                        homeBtnHtml: $homeBtn[0].outerHTML,
                        localization: HELP.localization,
                        serviceInfo: {
                            id:  HELP.isMacProject ? window.location.hash.slice(1) : window.location.pathname.match(/\/(\w+)\.htm/)[1],
                            reviewDate: window.reviewDate ? (new Date(window.reviewDate)).toLocaleString(HELP.currentLangId, {
                                year: 'numeric',
                                month: 'short',
                                day: 'numeric'
                            }) : null
                        }
                    });

                    $homeBtn.replaceWith(BottomLinksHtmls);
                }
            } else {
                $('.js_all_in_one_header').text(HELP.localization.TableOfContents);
            }
        }
    }

    function autoScrollContents($target, animateSpeed) {
        if (animateSpeed == null) {
            animateSpeed = 2;
        }

        if (!$target || !$target.length) {
            return;
        }

        var $view = $('.js_tabs_viewport');
        var $menuItem = $view.find('.js-menu-content:not(.is-hidden)').find($target);

        if (!$menuItem.length || !$view.length) {
            return;
        }

        var targetTop;
        if (localStorageChecker() && window['localStorage']['asideScrollPosition'] !== void 0) {
            targetTop = window['localStorage']['asideScrollPosition'];
            setParam('asideScrollPosition', null);
            var isFromLocalStorage = true;
        } else {
            var view = $view[0];
            var delta1 = view.clientHeight / 5;
            var delta2 = view.clientHeight / 4;
            var isOverBottom = $menuItem.offset().top > view.clientHeight + $view.offset().top - delta1;
            var isOverTop = $menuItem.offset().top < $view.offset().top + delta1 + $menuItem[0].offsetHeight;
            var targetDelta;
            if (isOverBottom) {
                targetDelta = $menuItem.offset().top - $view.offset().top - view.clientHeight + delta2;
            } else if (isOverTop) {
                targetDelta = $menuItem.offset().top - $view.offset().top - delta2 - $menuItem[0].offsetHeight;
            }
            targetTop = view.scrollTop + targetDelta;
        }

        var scrollingDuration = Math.min(animateSpeed * Math.abs(targetDelta), 1500);
        if (isFromLocalStorage || isOverTop || isOverBottom) {
            $view.animate({
                scrollTop: targetTop
            }, scrollingDuration, 'swing');
        }

        $menuItem
            .addClass('is-active')
            .parents('.js_contents_level')
            .add($menuItem.children('.js_contents_level'))
            .slideDown()
            .siblings('.js_contents_toggle')
            .addClass('is-toggled');
    }

    function loadVersions() {
        var url = window.location.pathname.split('/');
        var productKey = url[1];
        var currentVersionUrl = url[2];
        var product =
            _.findWhere(HELP.localization.products_b2c, {url: productKey}) ||
            _.findWhere(HELP.localization.products_b2b, {url: productKey});
        var $productLogo = $('.js_product_logo');

        if (!product) {
            return;
        }

        $productLogo.addClass('top-bar__product_' + product.icon);

        var currentVersion;
        _.some(product.versions, function(item) {
            if (item.url.split('/')[0] === currentVersionUrl) {
                currentVersion = item;
                return true;
            }
            return false;
        });

        if (currentVersion && product.versions.length > 1) {
            var VersionsResultsHtml = VersionsTemplateFunction({
                currentVersion: currentVersion,
                versions: product.versions
            });

            $header.find('.js_header_versions_list').html(VersionsResultsHtml);
            $('.js_selector_mobile_versions')
                .html(VersionsResultsHtml).find('.js_dropdown').addClass('dropdown_large');

            $header.on('click', '.js_version_item', function (event) {
                event.preventDefault();

                var versionUrl = $(this).data('version-url');
                /*var path = window.location.pathname.split('/');
                var currentPage = path[path.length - 1];

                window.location.href  = '/' + productKey + '/' + versionUrl + '/' + currentPage;*/
                window.location.href = '/' + productKey + '/' + versionUrl;
            });
        } else {
            $('.js_selector_mobile_versions').remove();
        }
    }

    function calcAsideWidth(aside) {
        aside.children().width(aside.width());
    }

    function getMailtoLink() {
        return 'mailto://?subject=Shared from Kaspersky Online Help: "' +
            window.parsedMainTitle + ' - ' + window.document.title + '"&body=' + window.parsedMainTitle +
            ' - ' + window.document.title + '%0A' + window.location.href;
    }

    function findSection(menuList, sectionUrl) {
        var result =[];

        menuList.forEach(function(item) {
            if (item.url === sectionUrl) {
                result.push(item);
            } else if (item.children) {
                result = result.concat(findSection(item.children, sectionUrl));
            }
        });

        return result;
    }

    function scrollToHash(hash) {
        var $target = $("[name='" + hash + "'], #" + hash);
        var $main = $('.js_main');

        if ($target.length) {
            $main.animate({
                scrollTop: $target[0].offsetTop - $main[0].offsetTop
            }, '500', 'swing');

            document.documentElement.scrollTop = 0;
        }
    }

    function escapeRegExp(text) {
        return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    }

    function localStorageChecker() {
        // localstorage & sessionstorage falls with error in EDGE for local files
        try {
            return Boolean(window.localStorage);
        } catch (e) {
            return false;
        }
    }

    function trackPage() {
        if (window._gaq) {
            window._gaq.push(['_trackPageview', location.pathname + location.search + location.hash]);
        }
    }

    function setNavigation(url) {
        _.each(HELP.nav.flatMenu, function (item, index) {
            if (item.url === url) {
                HELP.nav.currentPage = item;

                if (index > 0) {
                    HELP.nav.prevPage = HELP.nav.flatMenu[index - 1];
                } else {
                    HELP.nav.prevPage = null;
                }

                if (index !== HELP.nav.flatMenu.length - 1) {
                    HELP.nav.nextPage = HELP.nav.flatMenu[index + 1];
                } else {
                    HELP.nav.nextPage = null;
                }
            }
        });
    }

    /*
    #* Первичный рендеринг --------------------------------------------------------------------------------------------------
     */
    function firstRender() {
        var $footer, $menuItem, arrOpenedMenus, i, j;
        var sectionUrl = location.search.split('sectionUrl=')[1];
        var menu = window['Toc'];

        if (sectionUrl) {
            menu = findSection(menu, sectionUrl);
        }

        HELP.localization = window.Localization || {};
        HELP.customization = window.Customization || {};
                
        $html.toggleClass('ie7', HELP.isIE7).toggleClass('ie8', HELP.isIE8)
             .toggleClass('ie9', HELP.isIE9).toggleClass('ie10', HELP.isIE10)
             .toggleClass('is-opera-mini', HELP.isOperaMini)
             .toggleClass('is-offline', HELP.isFileProtocol);

        if (window['HelpViewer'] !== void 0 && window.sessionStorage && JSON.parse && window.sessionStorage.getItem('isTOCHidden') && JSON.parse(window.sessionStorage.getItem('isTOCHidden'))) {
            $html.removeClass('is-menu-shown');
        }

        if (location.hostname === 'localhost' || location.hostname === 'stage.help.kaspersky.com') {
            $html.addClass('is-test-mode');
        }

        var containerHtml = ContainerTemplateFunction({
            localization: HELP.localization
        });

        var parsedMainTitle = window.parsedMainTitle;
        if (parsedMainTitle.indexOf('Kaspersky') === 0) {
            var titlePreffix = parsedMainTitle.slice(0, 9);
            parsedMainTitle = parsedMainTitle.slice(10, parsedMainTitle.length);
        }

        var headerHtml = HeaderTemplateFunction({
            titlePreffix: titlePreffix || '',
            title: parsedMainTitle,
            localization: HELP.localization,
            customization: HELP.customization,
            isAllInOne: HELP.isAllInOne,
            isOffline: HELP.isFileProtocol
        });

        var footerHtml = FooterTemplateFunction({
            localization: HELP.localization,
            customization: HELP.customization
        });

        var asideHtml = AsideTemplateFunction({
            localization: HELP.localization
        });

        if (window.Customization) {
            var customStyles = CustomStylesTemplateFunction({
                customization: HELP.customization
            });

            $head.append(customStyles);
        }

        $container = $(containerHtml);
        $header = $(headerHtml);
        $footer = $(footerHtml);
        $aside = $(asideHtml);

        var $headerPlaceholder = $container.find('.js_header_placeholder');
        var $asidePlaceholder = $container.find('.js_aside_placeholder');
        var $footerPlaceholder = $container.find('.js_footer_placeholder');

        $headerPlaceholder.append($header);
        $asidePlaceholder.append($aside);
        $footerPlaceholder.append($footer);
        $content = $container.find('.js_content');
        $content.append(processHtml($body.html(), sectionUrl ? menu : null));
        $body.html($container);
        processContent($container);
        $body.addClass('js_tabs');

        var $viewport = $('<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">');
        $head.append($viewport);
        $html.find('base').remove();

        if ($.inArray($html.attr('lang'), ['ar-AE', 'fa-IR']) > -1) {
            $html.attr('dir', 'rtl');
        } else {
            $html.attr('dir', 'ltr');
        }

        FastClick.attach(document.body);

        $overlay = $body.find('.js_overlay');
        loadLangs();
        loadVersions();
        loadMenu(menu);

        if (HELP.searchWord) {
            $body.find('.js_search_text').val(HELP.searchWord);
            triggerSearch();
        }

        if (HELP.nav.currentPage && HELP.nav.currentPage.url) {
            $menuItem = $(".js_menu_link[href='" + HELP.nav.currentPage.url + "']").closest('.js_menu_item');
            autoScrollContents($menuItem, 0);
        }

        var localUrlRegExp = /([\w_]+\.htm)[l]?(#[\w]+(.htm))?/i;
        var urlMatches = window.location.href.match(localUrlRegExp);
        if (HELP.isMacProject && urlMatches[2] && urlMatches[3]) {
            loadContent("./pgs/" + urlMatches[2].slice(1), false, null, urlMatches[0]);
        } else if (window.history && window.history.replaceState && !HELP.isAllInOne) {
            var initialUrl = /\/([\w_-]+\.\w+$)/.exec(location.pathname)[1];
            window.history.replaceState({
                url: initialUrl
            }, null, initialUrl);
        }

        $modalContent = $overlay.find('.js_modal_content');
        $modalHeader = $overlay.find('.js_modal_header');
        $tooltip = $body.find('.js_tooltip');
        $tooltipContent = $body.find('.js_tooltip_content');

        setTimeout(function () {
            $html.show();
            $window.resize();
        }, 100);

        if (HELP.isIE7 || HELP.isIE8) {
            setTimeout(function () {
                calcAsideWidth($asidePlaceholder);
            }, 500);
        }

        $(".downloadhyperlinktemplate").attr("download", "").addClass("hyperlinktemplate");
    }

    firstRender();
});