/*!
 * https://github.com/es-shims/es5-shim
 * @license es5-shim Copyright 2009-2015 by contributors, MIT License
 * see https://github.com/es-shims/es5-shim/blob/master/LICENSE
 */

// vim: ts=4 sts=4 sw=4 expandtab

// Add semicolon to prevent IIFE from being passed as argument to concatenated code.
;

// UMD (Universal Module Definition)
// see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
(function (root, factory) {
    'use strict';

    /* global define, exports, module */
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals (root is window)
        root.returnExports = factory();
    }
}(this, function () {

/**
 * Brings an environment as close to ECMAScript 5 compliance
 * as is possible with the facilities of erstwhile engines.
 *
 * Annotated ES5: http://es5.github.com/ (specific links below)
 * ES5 Spec: http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf
 * Required reading: http://javascriptweblog.wordpress.com/2011/12/05/extending-javascript-natives/
 */

// Shortcut to an often accessed properties, in order to avoid multiple
// dereference that costs universally. This also holds a reference to known-good
// functions.
var $Array = Array;
var ArrayPrototype = $Array.prototype;
var $Object = Object;
var ObjectPrototype = $Object.prototype;
var $Function = Function;
var FunctionPrototype = $Function.prototype;
var $String = String;
var StringPrototype = $String.prototype;
var $Number = Number;
var NumberPrototype = $Number.prototype;
var array_slice = ArrayPrototype.slice;
var array_splice = ArrayPrototype.splice;
var array_push = ArrayPrototype.push;
var array_unshift = ArrayPrototype.unshift;
var array_concat = ArrayPrototype.concat;
var array_join = ArrayPrototype.join;
var call = FunctionPrototype.call;
var apply = FunctionPrototype.apply;
var max = Math.max;
var min = Math.min;

// Having a toString local variable name breaks in Opera so use to_string.
var to_string = ObjectPrototype.toString;

/* global Symbol */
/* eslint-disable one-var-declaration-per-line, no-redeclare */
var hasToStringTag = typeof Symbol === 'function' && typeof Symbol.toStringTag === 'symbol';
var isCallable; /* inlined from https://npmjs.com/is-callable */ var fnToStr = Function.prototype.toString, constructorRegex = /^\s*class /, isES6ClassFn = function isES6ClassFn(value) { try { var fnStr = fnToStr.call(value); var singleStripped = fnStr.replace(/\/\/.*\n/g, ''); var multiStripped = singleStripped.replace(/\/\*[.\s\S]*\*\//g, ''); var spaceStripped = multiStripped.replace(/\n/mg, ' ').replace(/ {2}/g, ' '); return constructorRegex.test(spaceStripped); } catch (e) { return false; /* not a function */ } }, tryFunctionObject = function tryFunctionObject(value) { try { if (isES6ClassFn(value)) { return false; } fnToStr.call(value); return true; } catch (e) { return false; } }, fnClass = '[object Function]', genClass = '[object GeneratorFunction]', isCallable = function isCallable(value) { if (!value) { return false; } if (typeof value !== 'function' && typeof value !== 'object') { return false; } if (hasToStringTag) { return tryFunctionObject(value); } if (isES6ClassFn(value)) { return false; } var strClass = to_string.call(value); return strClass === fnClass || strClass === genClass; };

var isRegex; /* inlined from https://npmjs.com/is-regex */ var regexExec = RegExp.prototype.exec, tryRegexExec = function tryRegexExec(value) { try { regexExec.call(value); return true; } catch (e) { return false; } }, regexClass = '[object RegExp]'; isRegex = function isRegex(value) { if (typeof value !== 'object') { return false; } return hasToStringTag ? tryRegexExec(value) : to_string.call(value) === regexClass; };
var isString; /* inlined from https://npmjs.com/is-string */ var strValue = String.prototype.valueOf, tryStringObject = function tryStringObject(value) { try { strValue.call(value); return true; } catch (e) { return false; } }, stringClass = '[object String]'; isString = function isString(value) { if (typeof value === 'string') { return true; } if (typeof value !== 'object') { return false; } return hasToStringTag ? tryStringObject(value) : to_string.call(value) === stringClass; };
/* eslint-enable one-var-declaration-per-line, no-redeclare */

/* inlined from http://npmjs.com/define-properties */
var supportsDescriptors = $Object.defineProperty && (function () {
    try {
        var obj = {};
        $Object.defineProperty(obj, 'x', { enumerable: false, value: obj });
        for (var _ in obj) { return false; }
        return obj.x === obj;
    } catch (e) { /* this is ES3 */
        return false;
    }
}());
var defineProperties = (function (has) {
  // Define configurable, writable, and non-enumerable props
  // if they don't exist.
  var defineProperty;
  if (supportsDescriptors) {
      defineProperty = function (object, name, method, forceAssign) {
          if (!forceAssign && (name in object)) { return; }
          $Object.defineProperty(object, name, {
              configurable: true,
              enumerable: false,
              writable: true,
              value: method
          });
      };
  } else {
      defineProperty = function (object, name, method, forceAssign) {
          if (!forceAssign && (name in object)) { return; }
          object[name] = method;
      };
  }
  return function defineProperties(object, map, forceAssign) {
      for (var name in map) {
          if (has.call(map, name)) {
            defineProperty(object, name, map[name], forceAssign);
          }
      }
  };
}(ObjectPrototype.hasOwnProperty));

//
// Util
// ======
//

/* replaceable with https://npmjs.com/package/es-abstract /helpers/isPrimitive */
var isPrimitive = function isPrimitive(input) {
    var type = typeof input;
    return input === null || (type !== 'object' && type !== 'function');
};

var isActualNaN = $Number.isNaN || function (x) { return x !== x; };

var ES = {
    // ES5 9.4
    // http://es5.github.com/#x9.4
    // http://jsperf.com/to-integer
    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToInteger */
    ToInteger: function ToInteger(num) {
        var n = +num;
        if (isActualNaN(n)) {
            n = 0;
        } else if (n !== 0 && n !== (1 / 0) && n !== -(1 / 0)) {
            n = (n > 0 || -1) * Math.floor(Math.abs(n));
        }
        return n;
    },

    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToPrimitive */
    ToPrimitive: function ToPrimitive(input) {
        var val, valueOf, toStr;
        if (isPrimitive(input)) {
            return input;
        }
        valueOf = input.valueOf;
        if (isCallable(valueOf)) {
            val = valueOf.call(input);
            if (isPrimitive(val)) {
                return val;
            }
        }
        toStr = input.toString;
        if (isCallable(toStr)) {
            val = toStr.call(input);
            if (isPrimitive(val)) {
                return val;
            }
        }
        throw new TypeError();
    },

    // ES5 9.9
    // http://es5.github.com/#x9.9
    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToObject */
    ToObject: function (o) {
        if (o == null) { // this matches both null and undefined
            throw new TypeError("can't convert " + o + ' to object');
        }
        return $Object(o);
    },

    /* replaceable with https://npmjs.com/package/es-abstract ES5.ToUint32 */
    ToUint32: function ToUint32(x) {
        return x >>> 0;
    }
};

//
// Function
// ========
//

// ES-5 15.3.4.5
// http://es5.github.com/#x15.3.4.5

var Empty = function Empty() {};

defineProperties(FunctionPrototype, {
    bind: function bind(that) { // .length is 1
        // 1. Let Target be the this value.
        var target = this;
        // 2. If IsCallable(Target) is false, throw a TypeError exception.
        if (!isCallable(target)) {
            throw new TypeError('Function.prototype.bind called on incompatible ' + target);
        }
        // 3. Let A be a new (possibly empty) internal list of all of the
        //   argument values provided after thisArg (arg1, arg2 etc), in order.
        // XXX slicedArgs will stand in for "A" if used
        var args = array_slice.call(arguments, 1); // for normal call
        // 4. Let F be a new native ECMAScript object.
        // 11. Set the [[Prototype]] internal property of F to the standard
        //   built-in Function prototype object as specified in 15.3.3.1.
        // 12. Set the [[Call]] internal property of F as described in
        //   15.3.4.5.1.
        // 13. Set the [[Construct]] internal property of F as described in
        //   15.3.4.5.2.
        // 14. Set the [[HasInstance]] internal property of F as described in
        //   15.3.4.5.3.
        var bound;
        var binder = function () {

            if (this instanceof bound) {
                // 15.3.4.5.2 [[Construct]]
                // When the [[Construct]] internal method of a function object,
                // F that was created using the bind function is called with a
                // list of arguments ExtraArgs, the following steps are taken:
                // 1. Let target be the value of F's [[TargetFunction]]
                //   internal property.
                // 2. If target has no [[Construct]] internal method, a
                //   TypeError exception is thrown.
                // 3. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Construct]] internal
                //   method of target providing args as the arguments.

                var result = apply.call(
                    target,
                    this,
                    array_concat.call(args, array_slice.call(arguments))
                );
                if ($Object(result) === result) {
                    return result;
                }
                return this;

            } else {
                // 15.3.4.5.1 [[Call]]
                // When the [[Call]] internal method of a function object, F,
                // which was created using the bind function is called with a
                // this value and a list of arguments ExtraArgs, the following
                // steps are taken:
                // 1. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 2. Let boundThis be the value of F's [[BoundThis]] internal
                //   property.
                // 3. Let target be the value of F's [[TargetFunction]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Call]] internal method
                //   of target providing boundThis as the this value and
                //   providing args as the arguments.

                // equiv: target.call(this, ...boundArgs, ...args)
                return apply.call(
                    target,
                    that,
                    array_concat.call(args, array_slice.call(arguments))
                );

            }

        };

        // 15. If the [[Class]] internal property of Target is "Function", then
        //     a. Let L be the length property of Target minus the length of A.
        //     b. Set the length own property of F to either 0 or L, whichever is
        //       larger.
        // 16. Else set the length own property of F to 0.

        var boundLength = max(0, target.length - args.length);

        // 17. Set the attributes of the length own property of F to the values
        //   specified in 15.3.5.1.
        var boundArgs = [];
        for (var i = 0; i < boundLength; i++) {
            array_push.call(boundArgs, '$' + i);
        }

        // XXX Build a dynamic function with desired amount of arguments is the only
        // way to set the length property of a function.
        // In environments where Content Security Policies enabled (Chrome extensions,
        // for ex.) all use of eval or Function costructor throws an exception.
        // However in all of these environments Function.prototype.bind exists
        // and so this code will never be executed.
        bound = $Function('binder', 'return function (' + array_join.call(boundArgs, ',') + '){ return binder.apply(this, arguments); }')(binder);

        if (target.prototype) {
            Empty.prototype = target.prototype;
            bound.prototype = new Empty();
            // Clean up dangling references.
            Empty.prototype = null;
        }

        // TODO
        // 18. Set the [[Extensible]] internal property of F to true.

        // TODO
        // 19. Let thrower be the [[ThrowTypeError]] function Object (13.2.3).
        // 20. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "caller", PropertyDescriptor {[[Get]]: thrower, [[Set]]:
        //   thrower, [[Enumerable]]: false, [[Configurable]]: false}, and
        //   false.
        // 21. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "arguments", PropertyDescriptor {[[Get]]: thrower,
        //   [[Set]]: thrower, [[Enumerable]]: false, [[Configurable]]: false},
        //   and false.

        // TODO
        // NOTE Function objects created using Function.prototype.bind do not
        // have a prototype property or the [[Code]], [[FormalParameters]], and
        // [[Scope]] internal properties.
        // XXX can't delete prototype in pure-js.

        // 22. Return F.
        return bound;
    }
});

// _Please note: Shortcuts are defined after `Function.prototype.bind` as we
// use it in defining shortcuts.
var owns = call.bind(ObjectPrototype.hasOwnProperty);
var toStr = call.bind(ObjectPrototype.toString);
var arraySlice = call.bind(array_slice);
var arraySliceApply = apply.bind(array_slice);
var strSlice = call.bind(StringPrototype.slice);
var strSplit = call.bind(StringPrototype.split);
var strIndexOf = call.bind(StringPrototype.indexOf);
var pushCall = call.bind(array_push);
var isEnum = call.bind(ObjectPrototype.propertyIsEnumerable);
var arraySort = call.bind(ArrayPrototype.sort);

//
// Array
// =====
//

var isArray = $Array.isArray || function isArray(obj) {
    return toStr(obj) === '[object Array]';
};

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.13
// Return len+argCount.
// [bugfix, ielt8]
// IE < 8 bug: [].unshift(0) === undefined but should be "1"
var hasUnshiftReturnValueBug = [].unshift(0) !== 1;
defineProperties(ArrayPrototype, {
    unshift: function () {
        array_unshift.apply(this, arguments);
        return this.length;
    }
}, hasUnshiftReturnValueBug);

// ES5 15.4.3.2
// http://es5.github.com/#x15.4.3.2
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/isArray
defineProperties($Array, { isArray: isArray });

// The IsCallable() check in the Array functions
// has been replaced with a strict check on the
// internal class of the object to trap cases where
// the provided function was actually a regular
// expression literal, which in V8 and
// JavaScriptCore is a typeof "function".  Only in
// V8 are regular expression literals permitted as
// reduce parameters, so it is desirable in the
// general case for the shim to match the more
// strict and common behavior of rejecting regular
// expressions.

// ES5 15.4.4.18
// http://es5.github.com/#x15.4.4.18
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/array/forEach

// Check failure of by-index access of string characters (IE < 9)
// and failure of `0 in boxedString` (Rhino)
var boxedString = $Object('a');
var splitString = boxedString[0] !== 'a' || !(0 in boxedString);

var properlyBoxesContext = function properlyBoxed(method) {
    // Check node 0.6.21 bug where third parameter is not boxed
    var properlyBoxesNonStrict = true;
    var properlyBoxesStrict = true;
    var threwException = false;
    if (method) {
        try {
            method.call('foo', function (_, __, context) {
                if (typeof context !== 'object') { properlyBoxesNonStrict = false; }
            });

            method.call([1], function () {
                'use strict';

                properlyBoxesStrict = typeof this === 'string';
            }, 'x');
        } catch (e) {
            threwException = true;
        }
    }
    return !!method && !threwException && properlyBoxesNonStrict && properlyBoxesStrict;
};

defineProperties(ArrayPrototype, {
    forEach: function forEach(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var i = -1;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
          T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.forEach callback must be a function');
        }

        while (++i < length) {
            if (i in self) {
                // Invoke the callback function with call, passing arguments:
                // context, property value, property key, thisArg object
                if (typeof T === 'undefined') {
                    callbackfn(self[i], i, object);
                } else {
                    callbackfn.call(T, self[i], i, object);
                }
            }
        }
    }
}, !properlyBoxesContext(ArrayPrototype.forEach));

// ES5 15.4.4.19
// http://es5.github.com/#x15.4.4.19
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/map
defineProperties(ArrayPrototype, {
    map: function map(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var result = $Array(length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.map callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                if (typeof T === 'undefined') {
                    result[i] = callbackfn(self[i], i, object);
                } else {
                    result[i] = callbackfn.call(T, self[i], i, object);
                }
            }
        }
        return result;
    }
}, !properlyBoxesContext(ArrayPrototype.map));

// ES5 15.4.4.20
// http://es5.github.com/#x15.4.4.20
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/filter
defineProperties(ArrayPrototype, {
    filter: function filter(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var result = [];
        var value;
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.filter callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                value = self[i];
                if (typeof T === 'undefined' ? callbackfn(value, i, object) : callbackfn.call(T, value, i, object)) {
                    pushCall(result, value);
                }
            }
        }
        return result;
    }
}, !properlyBoxesContext(ArrayPrototype.filter));

// ES5 15.4.4.16
// http://es5.github.com/#x15.4.4.16
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/every
defineProperties(ArrayPrototype, {
    every: function every(callbackfn/*, thisArg*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.every callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self && !(typeof T === 'undefined' ? callbackfn(self[i], i, object) : callbackfn.call(T, self[i], i, object))) {
                return false;
            }
        }
        return true;
    }
}, !properlyBoxesContext(ArrayPrototype.every));

// ES5 15.4.4.17
// http://es5.github.com/#x15.4.4.17
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/some
defineProperties(ArrayPrototype, {
    some: function some(callbackfn/*, thisArg */) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);
        var T;
        if (arguments.length > 1) {
            T = arguments[1];
        }

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.some callback must be a function');
        }

        for (var i = 0; i < length; i++) {
            if (i in self && (typeof T === 'undefined' ? callbackfn(self[i], i, object) : callbackfn.call(T, self[i], i, object))) {
                return true;
            }
        }
        return false;
    }
}, !properlyBoxesContext(ArrayPrototype.some));

// ES5 15.4.4.21
// http://es5.github.com/#x15.4.4.21
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduce
var reduceCoercesToObject = false;
if (ArrayPrototype.reduce) {
    reduceCoercesToObject = typeof ArrayPrototype.reduce.call('es5', function (_, __, ___, list) { return list; }) === 'object';
}
defineProperties(ArrayPrototype, {
    reduce: function reduce(callbackfn/*, initialValue*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.reduce callback must be a function');
        }

        // no value to return if no initial value and an empty array
        if (length === 0 && arguments.length === 1) {
            throw new TypeError('reduce of empty array with no initial value');
        }

        var i = 0;
        var result;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i++];
                    break;
                }

                // if array contains no values, no initial value to return
                if (++i >= length) {
                    throw new TypeError('reduce of empty array with no initial value');
                }
            } while (true);
        }

        for (; i < length; i++) {
            if (i in self) {
                result = callbackfn(result, self[i], i, object);
            }
        }

        return result;
    }
}, !reduceCoercesToObject);

// ES5 15.4.4.22
// http://es5.github.com/#x15.4.4.22
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduceRight
var reduceRightCoercesToObject = false;
if (ArrayPrototype.reduceRight) {
    reduceRightCoercesToObject = typeof ArrayPrototype.reduceRight.call('es5', function (_, __, ___, list) { return list; }) === 'object';
}
defineProperties(ArrayPrototype, {
    reduceRight: function reduceRight(callbackfn/*, initial*/) {
        var object = ES.ToObject(this);
        var self = splitString && isString(this) ? strSplit(this, '') : object;
        var length = ES.ToUint32(self.length);

        // If no callback function or if callback is not a callable function
        if (!isCallable(callbackfn)) {
            throw new TypeError('Array.prototype.reduceRight callback must be a function');
        }

        // no value to return if no initial value, empty array
        if (length === 0 && arguments.length === 1) {
            throw new TypeError('reduceRight of empty array with no initial value');
        }

        var result;
        var i = length - 1;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i--];
                    break;
                }

                // if array contains no values, no initial value to return
                if (--i < 0) {
                    throw new TypeError('reduceRight of empty array with no initial value');
                }
            } while (true);
        }

        if (i < 0) {
            return result;
        }

        do {
            if (i in self) {
                result = callbackfn(result, self[i], i, object);
            }
        } while (i--);

        return result;
    }
}, !reduceRightCoercesToObject);

// ES5 15.4.4.14
// http://es5.github.com/#x15.4.4.14
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/indexOf
var hasFirefox2IndexOfBug = ArrayPrototype.indexOf && [0, 1].indexOf(1, 2) !== -1;
defineProperties(ArrayPrototype, {
    indexOf: function indexOf(searchElement/*, fromIndex */) {
        var self = splitString && isString(this) ? strSplit(this, '') : ES.ToObject(this);
        var length = ES.ToUint32(self.length);

        if (length === 0) {
            return -1;
        }

        var i = 0;
        if (arguments.length > 1) {
            i = ES.ToInteger(arguments[1]);
        }

        // handle negative indices
        i = i >= 0 ? i : max(0, length + i);
        for (; i < length; i++) {
            if (i in self && self[i] === searchElement) {
                return i;
            }
        }
        return -1;
    }
}, hasFirefox2IndexOfBug);

// ES5 15.4.4.15
// http://es5.github.com/#x15.4.4.15
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/lastIndexOf
var hasFirefox2LastIndexOfBug = ArrayPrototype.lastIndexOf && [0, 1].lastIndexOf(0, -3) !== -1;
defineProperties(ArrayPrototype, {
    lastIndexOf: function lastIndexOf(searchElement/*, fromIndex */) {
        var self = splitString && isString(this) ? strSplit(this, '') : ES.ToObject(this);
        var length = ES.ToUint32(self.length);

        if (length === 0) {
            return -1;
        }
        var i = length - 1;
        if (arguments.length > 1) {
            i = min(i, ES.ToInteger(arguments[1]));
        }
        // handle negative indices
        i = i >= 0 ? i : length - Math.abs(i);
        for (; i >= 0; i--) {
            if (i in self && searchElement === self[i]) {
                return i;
            }
        }
        return -1;
    }
}, hasFirefox2LastIndexOfBug);

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.12
var spliceNoopReturnsEmptyArray = (function () {
    var a = [1, 2];
    var result = a.splice();
    return a.length === 2 && isArray(result) && result.length === 0;
}());
defineProperties(ArrayPrototype, {
    // Safari 5.0 bug where .splice() returns undefined
    splice: function splice(start, deleteCount) {
        if (arguments.length === 0) {
            return [];
        } else {
            return array_splice.apply(this, arguments);
        }
    }
}, !spliceNoopReturnsEmptyArray);

var spliceWorksWithEmptyObject = (function () {
    var obj = {};
    ArrayPrototype.splice.call(obj, 0, 0, 1);
    return obj.length === 1;
}());
defineProperties(ArrayPrototype, {
    splice: function splice(start, deleteCount) {
        if (arguments.length === 0) { return []; }
        var args = arguments;
        this.length = max(ES.ToInteger(this.length), 0);
        if (arguments.length > 0 && typeof deleteCount !== 'number') {
            args = arraySlice(arguments);
            if (args.length < 2) {
                pushCall(args, this.length - start);
            } else {
                args[1] = ES.ToInteger(deleteCount);
            }
        }
        return array_splice.apply(this, args);
    }
}, !spliceWorksWithEmptyObject);
var spliceWorksWithLargeSparseArrays = (function () {
    // Per https://github.com/es-shims/es5-shim/issues/295
    // Safari 7/8 breaks with sparse arrays of size 1e5 or greater
    var arr = new $Array(1e5);
    // note: the index MUST be 8 or larger or the test will false pass
    arr[8] = 'x';
    arr.splice(1, 1);
    // note: this test must be defined *after* the indexOf shim
    // per https://github.com/es-shims/es5-shim/issues/313
    return arr.indexOf('x') === 7;
}());
var spliceWorksWithSmallSparseArrays = (function () {
    // Per https://github.com/es-shims/es5-shim/issues/295
    // Opera 12.15 breaks on this, no idea why.
    var n = 256;
    var arr = [];
    arr[n] = 'a';
    arr.splice(n + 1, 0, 'b');
    return arr[n] === 'a';
}());
defineProperties(ArrayPrototype, {
    splice: function splice(start, deleteCount) {
        var O = ES.ToObject(this);
        var A = [];
        var len = ES.ToUint32(O.length);
        var relativeStart = ES.ToInteger(start);
        var actualStart = relativeStart < 0 ? max((len + relativeStart), 0) : min(relativeStart, len);
        var actualDeleteCount = min(max(ES.ToInteger(deleteCount), 0), len - actualStart);

        var k = 0;
        var from;
        while (k < actualDeleteCount) {
            from = $String(actualStart + k);
            if (owns(O, from)) {
                A[k] = O[from];
            }
            k += 1;
        }

        var items = arraySlice(arguments, 2);
        var itemCount = items.length;
        var to;
        if (itemCount < actualDeleteCount) {
            k = actualStart;
            var maxK = len - actualDeleteCount;
            while (k < maxK) {
                from = $String(k + actualDeleteCount);
                to = $String(k + itemCount);
                if (owns(O, from)) {
                    O[to] = O[from];
                } else {
                    delete O[to];
                }
                k += 1;
            }
            k = len;
            var minK = len - actualDeleteCount + itemCount;
            while (k > minK) {
                delete O[k - 1];
                k -= 1;
            }
        } else if (itemCount > actualDeleteCount) {
            k = len - actualDeleteCount;
            while (k > actualStart) {
                from = $String(k + actualDeleteCount - 1);
                to = $String(k + itemCount - 1);
                if (owns(O, from)) {
                    O[to] = O[from];
                } else {
                    delete O[to];
                }
                k -= 1;
            }
        }
        k = actualStart;
        for (var i = 0; i < items.length; ++i) {
            O[k] = items[i];
            k += 1;
        }
        O.length = len - actualDeleteCount + itemCount;

        return A;
    }
}, !spliceWorksWithLargeSparseArrays || !spliceWorksWithSmallSparseArrays);

var originalJoin = ArrayPrototype.join;
var hasStringJoinBug;
try {
    hasStringJoinBug = Array.prototype.join.call('123', ',') !== '1,2,3';
} catch (e) {
    hasStringJoinBug = true;
}
if (hasStringJoinBug) {
    defineProperties(ArrayPrototype, {
        join: function join(separator) {
            var sep = typeof separator === 'undefined' ? ',' : separator;
            return originalJoin.call(isString(this) ? strSplit(this, '') : this, sep);
        }
    }, hasStringJoinBug);
}

var hasJoinUndefinedBug = [1, 2].join(undefined) !== '1,2';
if (hasJoinUndefinedBug) {
    defineProperties(ArrayPrototype, {
        join: function join(separator) {
            var sep = typeof separator === 'undefined' ? ',' : separator;
            return originalJoin.call(this, sep);
        }
    }, hasJoinUndefinedBug);
}

var pushShim = function push(item) {
    var O = ES.ToObject(this);
    var n = ES.ToUint32(O.length);
    var i = 0;
    while (i < arguments.length) {
        O[n + i] = arguments[i];
        i += 1;
    }
    O.length = n + i;
    return n + i;
};

var pushIsNotGeneric = (function () {
    var obj = {};
    var result = Array.prototype.push.call(obj, undefined);
    return result !== 1 || obj.length !== 1 || typeof obj[0] !== 'undefined' || !owns(obj, 0);
}());
defineProperties(ArrayPrototype, {
    push: function push(item) {
        if (isArray(this)) {
            return array_push.apply(this, arguments);
        }
        return pushShim.apply(this, arguments);
    }
}, pushIsNotGeneric);

// This fixes a very weird bug in Opera 10.6 when pushing `undefined
var pushUndefinedIsWeird = (function () {
    var arr = [];
    var result = arr.push(undefined);
    return result !== 1 || arr.length !== 1 || typeof arr[0] !== 'undefined' || !owns(arr, 0);
}());
defineProperties(ArrayPrototype, { push: pushShim }, pushUndefinedIsWeird);

// ES5 15.2.3.14
// http://es5.github.io/#x15.4.4.10
// Fix boxed string bug
defineProperties(ArrayPrototype, {
    slice: function (start, end) {
        var arr = isString(this) ? strSplit(this, '') : this;
        return arraySliceApply(arr, arguments);
    }
}, splitString);

var sortIgnoresNonFunctions = (function () {
    try {
        [1, 2].sort(null);
        [1, 2].sort({});
        return true;
    } catch (e) { /**/ }
    return false;
}());
var sortThrowsOnRegex = (function () {
    // this is a problem in Firefox 4, in which `typeof /a/ === 'function'`
    try {
        [1, 2].sort(/a/);
        return false;
    } catch (e) { /**/ }
    return true;
}());
var sortIgnoresUndefined = (function () {
    // applies in IE 8, for one.
    try {
        [1, 2].sort(undefined);
        return true;
    } catch (e) { /**/ }
    return false;
}());
defineProperties(ArrayPrototype, {
    sort: function sort(compareFn) {
        if (typeof compareFn === 'undefined') {
            return arraySort(this);
        }
        if (!isCallable(compareFn)) {
            throw new TypeError('Array.prototype.sort callback must be a function');
        }
        return arraySort(this, compareFn);
    }
}, sortIgnoresNonFunctions || !sortIgnoresUndefined || !sortThrowsOnRegex);

//
// Object
// ======
//

// ES5 15.2.3.14
// http://es5.github.com/#x15.2.3.14

// http://whattheheadsaid.com/2010/10/a-safer-object-keys-compatibility-implementation
var hasDontEnumBug = !({ 'toString': null }).propertyIsEnumerable('toString');
var hasProtoEnumBug = function () {}.propertyIsEnumerable('prototype');
var hasStringEnumBug = !owns('x', '0');
var equalsConstructorPrototype = function (o) {
    var ctor = o.constructor;
    return ctor && ctor.prototype === o;
};
var blacklistedKeys = {
    $window: true,
    $console: true,
    $parent: true,
    $self: true,
    $frame: true,
    $frames: true,
    $frameElement: true,
    $webkitIndexedDB: true,
    $webkitStorageInfo: true,
    $external: true
};
var hasAutomationEqualityBug = (function () {
    /* globals window */
    if (typeof window === 'undefined') { return false; }
    for (var k in window) {
        try {
            if (!blacklistedKeys['$' + k] && owns(window, k) && window[k] !== null && typeof window[k] === 'object') {
                equalsConstructorPrototype(window[k]);
            }
        } catch (e) {
            return true;
        }
    }
    return false;
}());
var equalsConstructorPrototypeIfNotBuggy = function (object) {
    if (typeof window === 'undefined' || !hasAutomationEqualityBug) { return equalsConstructorPrototype(object); }
    try {
        return equalsConstructorPrototype(object);
    } catch (e) {
        return false;
    }
};
var dontEnums = [
    'toString',
    'toLocaleString',
    'valueOf',
    'hasOwnProperty',
    'isPrototypeOf',
    'propertyIsEnumerable',
    'constructor'
];
var dontEnumsLength = dontEnums.length;

// taken directly from https://github.com/ljharb/is-arguments/blob/master/index.js
// can be replaced with require('is-arguments') if we ever use a build process instead
var isStandardArguments = function isArguments(value) {
    return toStr(value) === '[object Arguments]';
};
var isLegacyArguments = function isArguments(value) {
    return value !== null &&
        typeof value === 'object' &&
        typeof value.length === 'number' &&
        value.length >= 0 &&
        !isArray(value) &&
        isCallable(value.callee);
};
var isArguments = isStandardArguments(arguments) ? isStandardArguments : isLegacyArguments;

defineProperties($Object, {
    keys: function keys(object) {
        var isFn = isCallable(object);
        var isArgs = isArguments(object);
        var isObject = object !== null && typeof object === 'object';
        var isStr = isObject && isString(object);

        if (!isObject && !isFn && !isArgs) {
            throw new TypeError('Object.keys called on a non-object');
        }

        var theKeys = [];
        var skipProto = hasProtoEnumBug && isFn;
        if ((isStr && hasStringEnumBug) || isArgs) {
            for (var i = 0; i < object.length; ++i) {
                pushCall(theKeys, $String(i));
            }
        }

        if (!isArgs) {
            for (var name in object) {
                if (!(skipProto && name === 'prototype') && owns(object, name)) {
                    pushCall(theKeys, $String(name));
                }
            }
        }

        if (hasDontEnumBug) {
            var skipConstructor = equalsConstructorPrototypeIfNotBuggy(object);
            for (var j = 0; j < dontEnumsLength; j++) {
                var dontEnum = dontEnums[j];
                if (!(skipConstructor && dontEnum === 'constructor') && owns(object, dontEnum)) {
                    pushCall(theKeys, dontEnum);
                }
            }
        }
        return theKeys;
    }
});

var keysWorksWithArguments = $Object.keys && (function () {
    // Safari 5.0 bug
    return $Object.keys(arguments).length === 2;
}(1, 2));
var keysHasArgumentsLengthBug = $Object.keys && (function () {
    var argKeys = $Object.keys(arguments);
    return arguments.length !== 1 || argKeys.length !== 1 || argKeys[0] !== 1;
}(1));
var originalKeys = $Object.keys;
defineProperties($Object, {
    keys: function keys(object) {
        if (isArguments(object)) {
            return originalKeys(arraySlice(object));
        } else {
            return originalKeys(object);
        }
    }
}, !keysWorksWithArguments || keysHasArgumentsLengthBug);

//
// Date
// ====
//

var hasNegativeMonthYearBug = new Date(-3509827329600292).getUTCMonth() !== 0;
var aNegativeTestDate = new Date(-1509842289600292);
var aPositiveTestDate = new Date(1449662400000);
var hasToUTCStringFormatBug = aNegativeTestDate.toUTCString() !== 'Mon, 01 Jan -45875 11:59:59 GMT';
var hasToDateStringFormatBug;
var hasToStringFormatBug;
var timeZoneOffset = aNegativeTestDate.getTimezoneOffset();
if (timeZoneOffset < -720) {
    hasToDateStringFormatBug = aNegativeTestDate.toDateString() !== 'Tue Jan 02 -45875';
    hasToStringFormatBug = !(/^Thu Dec 10 2015 \d\d:\d\d:\d\d GMT[-\+]\d\d\d\d(?: |$)/).test(aPositiveTestDate.toString());
} else {
    hasToDateStringFormatBug = aNegativeTestDate.toDateString() !== 'Mon Jan 01 -45875';
    hasToStringFormatBug = !(/^Wed Dec 09 2015 \d\d:\d\d:\d\d GMT[-\+]\d\d\d\d(?: |$)/).test(aPositiveTestDate.toString());
}

var originalGetFullYear = call.bind(Date.prototype.getFullYear);
var originalGetMonth = call.bind(Date.prototype.getMonth);
var originalGetDate = call.bind(Date.prototype.getDate);
var originalGetUTCFullYear = call.bind(Date.prototype.getUTCFullYear);
var originalGetUTCMonth = call.bind(Date.prototype.getUTCMonth);
var originalGetUTCDate = call.bind(Date.prototype.getUTCDate);
var originalGetUTCDay = call.bind(Date.prototype.getUTCDay);
var originalGetUTCHours = call.bind(Date.prototype.getUTCHours);
var originalGetUTCMinutes = call.bind(Date.prototype.getUTCMinutes);
var originalGetUTCSeconds = call.bind(Date.prototype.getUTCSeconds);
var originalGetUTCMilliseconds = call.bind(Date.prototype.getUTCMilliseconds);
var dayName = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
var monthName = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
var daysInMonth = function daysInMonth(month, year) {
    return originalGetDate(new Date(year, month, 0));
};

defineProperties(Date.prototype, {
    getFullYear: function getFullYear() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        if (year < 0 && originalGetMonth(this) > 11) {
            return year + 1;
        }
        return year;
    },
    getMonth: function getMonth() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        var month = originalGetMonth(this);
        if (year < 0 && month > 11) {
            return 0;
        }
        return month;
    },
    getDate: function getDate() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetFullYear(this);
        var month = originalGetMonth(this);
        var date = originalGetDate(this);
        if (year < 0 && month > 11) {
            if (month === 12) {
                return date;
            }
            var days = daysInMonth(0, year + 1);
            return (days - date) + 1;
        }
        return date;
    },
    getUTCFullYear: function getUTCFullYear() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        if (year < 0 && originalGetUTCMonth(this) > 11) {
            return year + 1;
        }
        return year;
    },
    getUTCMonth: function getUTCMonth() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        var month = originalGetUTCMonth(this);
        if (year < 0 && month > 11) {
            return 0;
        }
        return month;
    },
    getUTCDate: function getUTCDate() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var year = originalGetUTCFullYear(this);
        var month = originalGetUTCMonth(this);
        var date = originalGetUTCDate(this);
        if (year < 0 && month > 11) {
            if (month === 12) {
                return date;
            }
            var days = daysInMonth(0, year + 1);
            return (days - date) + 1;
        }
        return date;
    }
}, hasNegativeMonthYearBug);

defineProperties(Date.prototype, {
    toUTCString: function toUTCString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = originalGetUTCDay(this);
        var date = originalGetUTCDate(this);
        var month = originalGetUTCMonth(this);
        var year = originalGetUTCFullYear(this);
        var hour = originalGetUTCHours(this);
        var minute = originalGetUTCMinutes(this);
        var second = originalGetUTCSeconds(this);
        return dayName[day] + ', ' +
            (date < 10 ? '0' + date : date) + ' ' +
            monthName[month] + ' ' +
            year + ' ' +
            (hour < 10 ? '0' + hour : hour) + ':' +
            (minute < 10 ? '0' + minute : minute) + ':' +
            (second < 10 ? '0' + second : second) + ' GMT';
    }
}, hasNegativeMonthYearBug || hasToUTCStringFormatBug);

// Opera 12 has `,`
defineProperties(Date.prototype, {
    toDateString: function toDateString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = this.getDay();
        var date = this.getDate();
        var month = this.getMonth();
        var year = this.getFullYear();
        return dayName[day] + ' ' +
            monthName[month] + ' ' +
            (date < 10 ? '0' + date : date) + ' ' +
            year;
    }
}, hasNegativeMonthYearBug || hasToDateStringFormatBug);

// can't use defineProperties here because of toString enumeration issue in IE <= 8
if (hasNegativeMonthYearBug || hasToStringFormatBug) {
    Date.prototype.toString = function toString() {
        if (!this || !(this instanceof Date)) {
            throw new TypeError('this is not a Date object.');
        }
        var day = this.getDay();
        var date = this.getDate();
        var month = this.getMonth();
        var year = this.getFullYear();
        var hour = this.getHours();
        var minute = this.getMinutes();
        var second = this.getSeconds();
        var timezoneOffset = this.getTimezoneOffset();
        var hoursOffset = Math.floor(Math.abs(timezoneOffset) / 60);
        var minutesOffset = Math.floor(Math.abs(timezoneOffset) % 60);
        return dayName[day] + ' ' +
            monthName[month] + ' ' +
            (date < 10 ? '0' + date : date) + ' ' +
            year + ' ' +
            (hour < 10 ? '0' + hour : hour) + ':' +
            (minute < 10 ? '0' + minute : minute) + ':' +
            (second < 10 ? '0' + second : second) + ' GMT' +
            (timezoneOffset > 0 ? '-' : '+') +
            (hoursOffset < 10 ? '0' + hoursOffset : hoursOffset) +
            (minutesOffset < 10 ? '0' + minutesOffset : minutesOffset);
    };
    if (supportsDescriptors) {
        $Object.defineProperty(Date.prototype, 'toString', {
            configurable: true,
            enumerable: false,
            writable: true
        });
    }
}

// ES5 15.9.5.43
// http://es5.github.com/#x15.9.5.43
// This function returns a String value represent the instance in time
// represented by this Date object. The format of the String is the Date Time
// string format defined in 15.9.1.15. All fields are present in the String.
// The time zone is always UTC, denoted by the suffix Z. If the time value of
// this object is not a finite Number a RangeError exception is thrown.
var negativeDate = -62198755200000;
var negativeYearString = '-000001';
var hasNegativeDateBug = Date.prototype.toISOString && new Date(negativeDate).toISOString().indexOf(negativeYearString) === -1;
var hasSafari51DateBug = Date.prototype.toISOString && new Date(-1).toISOString() !== '1969-12-31T23:59:59.999Z';

var getTime = call.bind(Date.prototype.getTime);

defineProperties(Date.prototype, {
    toISOString: function toISOString() {
        if (!isFinite(this) || !isFinite(getTime(this))) {
            // Adope Photoshop requires the second check.
            throw new RangeError('Date.prototype.toISOString called on non-finite value.');
        }

        var year = originalGetUTCFullYear(this);

        var month = originalGetUTCMonth(this);
        // see https://github.com/es-shims/es5-shim/issues/111
        year += Math.floor(month / 12);
        month = (month % 12 + 12) % 12;

        // the date time string format is specified in 15.9.1.15.
        var result = [month + 1, originalGetUTCDate(this), originalGetUTCHours(this), originalGetUTCMinutes(this), originalGetUTCSeconds(this)];
        year = (
            (year < 0 ? '-' : (year > 9999 ? '+' : '')) +
            strSlice('00000' + Math.abs(year), (0 <= year && year <= 9999) ? -4 : -6)
        );

        for (var i = 0; i < result.length; ++i) {
          // pad months, days, hours, minutes, and seconds to have two digits.
          result[i] = strSlice('00' + result[i], -2);
        }
        // pad milliseconds to have three digits.
        return (
            year + '-' + arraySlice(result, 0, 2).join('-') +
            'T' + arraySlice(result, 2).join(':') + '.' +
            strSlice('000' + originalGetUTCMilliseconds(this), -3) + 'Z'
        );
    }
}, hasNegativeDateBug || hasSafari51DateBug);

// ES5 15.9.5.44
// http://es5.github.com/#x15.9.5.44
// This function provides a String representation of a Date object for use by
// JSON.stringify (15.12.3).
var dateToJSONIsSupported = (function () {
    try {
        return Date.prototype.toJSON &&
            new Date(NaN).toJSON() === null &&
            new Date(negativeDate).toJSON().indexOf(negativeYearString) !== -1 &&
            Date.prototype.toJSON.call({ // generic
                toISOString: function () { return true; }
            });
    } catch (e) {
        return false;
    }
}());
if (!dateToJSONIsSupported) {
    Date.prototype.toJSON = function toJSON(key) {
        // When the toJSON method is called with argument key, the following
        // steps are taken:

        // 1.  Let O be the result of calling ToObject, giving it the this
        // value as its argument.
        // 2. Let tv be ES.ToPrimitive(O, hint Number).
        var O = $Object(this);
        var tv = ES.ToPrimitive(O);
        // 3. If tv is a Number and is not finite, return null.
        if (typeof tv === 'number' && !isFinite(tv)) {
            return null;
        }
        // 4. Let toISO be the result of calling the [[Get]] internal method of
        // O with argument "toISOString".
        var toISO = O.toISOString;
        // 5. If IsCallable(toISO) is false, throw a TypeError exception.
        if (!isCallable(toISO)) {
            throw new TypeError('toISOString property is not callable');
        }
        // 6. Return the result of calling the [[Call]] internal method of
        //  toISO with O as the this value and an empty argument list.
        return toISO.call(O);

        // NOTE 1 The argument is ignored.

        // NOTE 2 The toJSON function is intentionally generic; it does not
        // require that its this value be a Date object. Therefore, it can be
        // transferred to other kinds of objects for use as a method. However,
        // it does require that any such object have a toISOString method. An
        // object is free to use the argument key to filter its
        // stringification.
    };
}

// ES5 15.9.4.2
// http://es5.github.com/#x15.9.4.2
// based on work shared by Daniel Friesen (dantman)
// http://gist.github.com/303249
var supportsExtendedYears = Date.parse('+033658-09-27T01:46:40.000Z') === 1e15;
var acceptsInvalidDates = !isNaN(Date.parse('2012-04-04T24:00:00.500Z')) || !isNaN(Date.parse('2012-11-31T23:59:59.000Z')) || !isNaN(Date.parse('2012-12-31T23:59:60.000Z'));
var doesNotParseY2KNewYear = isNaN(Date.parse('2000-01-01T00:00:00.000Z'));
if (doesNotParseY2KNewYear || acceptsInvalidDates || !supportsExtendedYears) {
    // XXX global assignment won't work in embeddings that use
    // an alternate object for the context.
    /* global Date: true */
    /* eslint-disable no-undef */
    var maxSafeUnsigned32Bit = Math.pow(2, 31) - 1;
    var hasSafariSignedIntBug = isActualNaN(new Date(1970, 0, 1, 0, 0, 0, maxSafeUnsigned32Bit + 1).getTime());
    /* eslint-disable no-implicit-globals */
    Date = (function (NativeDate) {
    /* eslint-enable no-implicit-globals */
    /* eslint-enable no-undef */
        // Date.length === 7
        var DateShim = function Date(Y, M, D, h, m, s, ms) {
            var length = arguments.length;
            var date;
            if (this instanceof NativeDate) {
                var seconds = s;
                var millis = ms;
                if (hasSafariSignedIntBug && length >= 7 && ms > maxSafeUnsigned32Bit) {
                    // work around a Safari 8/9 bug where it treats the seconds as signed
                    var msToShift = Math.floor(ms / maxSafeUnsigned32Bit) * maxSafeUnsigned32Bit;
                    var sToShift = Math.floor(msToShift / 1e3);
                    seconds += sToShift;
                    millis -= sToShift * 1e3;
                }
                date = length === 1 && $String(Y) === Y ? // isString(Y)
                    // We explicitly pass it through parse:
                    new NativeDate(DateShim.parse(Y)) :
                    // We have to manually make calls depending on argument
                    // length here
                    length >= 7 ? new NativeDate(Y, M, D, h, m, seconds, millis) :
                    length >= 6 ? new NativeDate(Y, M, D, h, m, seconds) :
                    length >= 5 ? new NativeDate(Y, M, D, h, m) :
                    length >= 4 ? new NativeDate(Y, M, D, h) :
                    length >= 3 ? new NativeDate(Y, M, D) :
                    length >= 2 ? new NativeDate(Y, M) :
                    length >= 1 ? new NativeDate(Y instanceof NativeDate ? +Y : Y) :
                                  new NativeDate();
            } else {
                date = NativeDate.apply(this, arguments);
            }
            if (!isPrimitive(date)) {
              // Prevent mixups with unfixed Date object
              defineProperties(date, { constructor: DateShim }, true);
            }
            return date;
        };

        // 15.9.1.15 Date Time String Format.
        var isoDateExpression = new RegExp('^' +
            '(\\d{4}|[+-]\\d{6})' + // four-digit year capture or sign +
                                      // 6-digit extended year
            '(?:-(\\d{2})' + // optional month capture
            '(?:-(\\d{2})' + // optional day capture
            '(?:' + // capture hours:minutes:seconds.milliseconds
                'T(\\d{2})' + // hours capture
                ':(\\d{2})' + // minutes capture
                '(?:' + // optional :seconds.milliseconds
                    ':(\\d{2})' + // seconds capture
                    '(?:(\\.\\d{1,}))?' + // milliseconds capture
                ')?' +
            '(' + // capture UTC offset component
                'Z|' + // UTC capture
                '(?:' + // offset specifier +/-hours:minutes
                    '([-+])' + // sign capture
                    '(\\d{2})' + // hours offset capture
                    ':(\\d{2})' + // minutes offset capture
                ')' +
            ')?)?)?)?' +
        '$');

        var months = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365];

        var dayFromMonth = function dayFromMonth(year, month) {
            var t = month > 1 ? 1 : 0;
            return (
                months[month] +
                Math.floor((year - 1969 + t) / 4) -
                Math.floor((year - 1901 + t) / 100) +
                Math.floor((year - 1601 + t) / 400) +
                365 * (year - 1970)
            );
        };

        var toUTC = function toUTC(t) {
            var s = 0;
            var ms = t;
            if (hasSafariSignedIntBug && ms > maxSafeUnsigned32Bit) {
                // work around a Safari 8/9 bug where it treats the seconds as signed
                var msToShift = Math.floor(ms / maxSafeUnsigned32Bit) * maxSafeUnsigned32Bit;
                var sToShift = Math.floor(msToShift / 1e3);
                s += sToShift;
                ms -= sToShift * 1e3;
            }
            return $Number(new NativeDate(1970, 0, 1, 0, 0, s, ms));
        };

        // Copy any custom methods a 3rd party library may have added
        for (var key in NativeDate) {
            if (owns(NativeDate, key)) {
                DateShim[key] = NativeDate[key];
            }
        }

        // Copy "native" methods explicitly; they may be non-enumerable
        defineProperties(DateShim, {
            now: NativeDate.now,
            UTC: NativeDate.UTC
        }, true);
        DateShim.prototype = NativeDate.prototype;
        defineProperties(DateShim.prototype, {
            constructor: DateShim
        }, true);

        // Upgrade Date.parse to handle simplified ISO 8601 strings
        var parseShim = function parse(string) {
            var match = isoDateExpression.exec(string);
            if (match) {
                // parse months, days, hours, minutes, seconds, and milliseconds
                // provide default values if necessary
                // parse the UTC offset component
                var year = $Number(match[1]),
                    month = $Number(match[2] || 1) - 1,
                    day = $Number(match[3] || 1) - 1,
                    hour = $Number(match[4] || 0),
                    minute = $Number(match[5] || 0),
                    second = $Number(match[6] || 0),
                    millisecond = Math.floor($Number(match[7] || 0) * 1000),
                    // When time zone is missed, local offset should be used
                    // (ES 5.1 bug)
                    // see https://bugs.ecmascript.org/show_bug.cgi?id=112
                    isLocalTime = Boolean(match[4] && !match[8]),
                    signOffset = match[9] === '-' ? 1 : -1,
                    hourOffset = $Number(match[10] || 0),
                    minuteOffset = $Number(match[11] || 0),
                    result;
                var hasMinutesOrSecondsOrMilliseconds = minute > 0 || second > 0 || millisecond > 0;
                if (
                    hour < (hasMinutesOrSecondsOrMilliseconds ? 24 : 25) &&
                    minute < 60 && second < 60 && millisecond < 1000 &&
                    month > -1 && month < 12 && hourOffset < 24 &&
                    minuteOffset < 60 && // detect invalid offsets
                    day > -1 &&
                    day < (dayFromMonth(year, month + 1) - dayFromMonth(year, month))
                ) {
                    result = (
                        (dayFromMonth(year, month) + day) * 24 +
                        hour +
                        hourOffset * signOffset
                    ) * 60;
                    result = (
                        (result + minute + minuteOffset * signOffset) * 60 +
                        second
                    ) * 1000 + millisecond;
                    if (isLocalTime) {
                        result = toUTC(result);
                    }
                    if (-8.64e15 <= result && result <= 8.64e15) {
                        return result;
                    }
                }
                return NaN;
            }
            return NativeDate.parse.apply(this, arguments);
        };
        defineProperties(DateShim, { parse: parseShim });

        return DateShim;
    }(Date));
    /* global Date: false */
}

// ES5 15.9.4.4
// http://es5.github.com/#x15.9.4.4
if (!Date.now) {
    Date.now = function now() {
        return new Date().getTime();
    };
}

//
// Number
// ======
//

// ES5.1 15.7.4.5
// http://es5.github.com/#x15.7.4.5
var hasToFixedBugs = NumberPrototype.toFixed && (
  (0.00008).toFixed(3) !== '0.000' ||
  (0.9).toFixed(0) !== '1' ||
  (1.255).toFixed(2) !== '1.25' ||
  (1000000000000000128).toFixed(0) !== '1000000000000000128'
);

var toFixedHelpers = {
  base: 1e7,
  size: 6,
  data: [0, 0, 0, 0, 0, 0],
  multiply: function multiply(n, c) {
      var i = -1;
      var c2 = c;
      while (++i < toFixedHelpers.size) {
          c2 += n * toFixedHelpers.data[i];
          toFixedHelpers.data[i] = c2 % toFixedHelpers.base;
          c2 = Math.floor(c2 / toFixedHelpers.base);
      }
  },
  divide: function divide(n) {
      var i = toFixedHelpers.size;
      var c = 0;
      while (--i >= 0) {
          c += toFixedHelpers.data[i];
          toFixedHelpers.data[i] = Math.floor(c / n);
          c = (c % n) * toFixedHelpers.base;
      }
  },
  numToString: function numToString() {
      var i = toFixedHelpers.size;
      var s = '';
      while (--i >= 0) {
          if (s !== '' || i === 0 || toFixedHelpers.data[i] !== 0) {
              var t = $String(toFixedHelpers.data[i]);
              if (s === '') {
                  s = t;
              } else {
                  s += strSlice('0000000', 0, 7 - t.length) + t;
              }
          }
      }
      return s;
  },
  pow: function pow(x, n, acc) {
      return (n === 0 ? acc : (n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc)));
  },
  log: function log(x) {
      var n = 0;
      var x2 = x;
      while (x2 >= 4096) {
          n += 12;
          x2 /= 4096;
      }
      while (x2 >= 2) {
          n += 1;
          x2 /= 2;
      }
      return n;
  }
};

var toFixedShim = function toFixed(fractionDigits) {
    var f, x, s, m, e, z, j, k;

    // Test for NaN and round fractionDigits down
    f = $Number(fractionDigits);
    f = isActualNaN(f) ? 0 : Math.floor(f);

    if (f < 0 || f > 20) {
        throw new RangeError('Number.toFixed called with invalid number of decimals');
    }

    x = $Number(this);

    if (isActualNaN(x)) {
        return 'NaN';
    }

    // If it is too big or small, return the string value of the number
    if (x <= -1e21 || x >= 1e21) {
        return $String(x);
    }

    s = '';

    if (x < 0) {
        s = '-';
        x = -x;
    }

    m = '0';

    if (x > 1e-21) {
        // 1e-21 < x < 1e21
        // -70 < log2(x) < 70
        e = toFixedHelpers.log(x * toFixedHelpers.pow(2, 69, 1)) - 69;
        z = (e < 0 ? x * toFixedHelpers.pow(2, -e, 1) : x / toFixedHelpers.pow(2, e, 1));
        z *= 0x10000000000000; // Math.pow(2, 52);
        e = 52 - e;

        // -18 < e < 122
        // x = z / 2 ^ e
        if (e > 0) {
            toFixedHelpers.multiply(0, z);
            j = f;

            while (j >= 7) {
                toFixedHelpers.multiply(1e7, 0);
                j -= 7;
            }

            toFixedHelpers.multiply(toFixedHelpers.pow(10, j, 1), 0);
            j = e - 1;

            while (j >= 23) {
                toFixedHelpers.divide(1 << 23);
                j -= 23;
            }

            toFixedHelpers.divide(1 << j);
            toFixedHelpers.multiply(1, 1);
            toFixedHelpers.divide(2);
            m = toFixedHelpers.numToString();
        } else {
            toFixedHelpers.multiply(0, z);
            toFixedHelpers.multiply(1 << (-e), 0);
            m = toFixedHelpers.numToString() + strSlice('0.00000000000000000000', 2, 2 + f);
        }
    }

    if (f > 0) {
        k = m.length;

        if (k <= f) {
            m = s + strSlice('0.0000000000000000000', 0, f - k + 2) + m;
        } else {
            m = s + strSlice(m, 0, k - f) + '.' + strSlice(m, k - f);
        }
    } else {
        m = s + m;
    }

    return m;
};
defineProperties(NumberPrototype, { toFixed: toFixedShim }, hasToFixedBugs);

var hasToPrecisionUndefinedBug = (function () {
    try {
        return 1.0.toPrecision(undefined) === '1';
    } catch (e) {
        return true;
    }
}());
var originalToPrecision = NumberPrototype.toPrecision;
defineProperties(NumberPrototype, {
    toPrecision: function toPrecision(precision) {
        return typeof precision === 'undefined' ? originalToPrecision.call(this) : originalToPrecision.call(this, precision);
    }
}, hasToPrecisionUndefinedBug);

//
// String
// ======
//

// ES5 15.5.4.14
// http://es5.github.com/#x15.5.4.14

// [bugfix, IE lt 9, firefox 4, Konqueror, Opera, obscure browsers]
// Many browsers do not split properly with regular expressions or they
// do not perform the split correctly under obscure conditions.
// See http://blog.stevenlevithan.com/archives/cross-browser-split
// I've tested in many browsers and this seems to cover the deviant ones:
//    'ab'.split(/(?:ab)*/) should be ["", ""], not [""]
//    '.'.split(/(.?)(.?)/) should be ["", ".", "", ""], not ["", ""]
//    'tesst'.split(/(s)*/) should be ["t", undefined, "e", "s", "t"], not
//       [undefined, "t", undefined, "e", ...]
//    ''.split(/.?/) should be [], not [""]
//    '.'.split(/()()/) should be ["."], not ["", "", "."]

if (
    'ab'.split(/(?:ab)*/).length !== 2 ||
    '.'.split(/(.?)(.?)/).length !== 4 ||
    'tesst'.split(/(s)*/)[1] === 't' ||
    'test'.split(/(?:)/, -1).length !== 4 ||
    ''.split(/.?/).length ||
    '.'.split(/()()/).length > 1
) {
    (function () {
        var compliantExecNpcg = typeof (/()??/).exec('')[1] === 'undefined'; // NPCG: nonparticipating capturing group
        var maxSafe32BitInt = Math.pow(2, 32) - 1;

        StringPrototype.split = function (separator, limit) {
            var string = String(this);
            if (typeof separator === 'undefined' && limit === 0) {
                return [];
            }

            // If `separator` is not a regex, use native split
            if (!isRegex(separator)) {
                return strSplit(this, separator, limit);
            }

            var output = [];
            var flags = (separator.ignoreCase ? 'i' : '') +
                        (separator.multiline ? 'm' : '') +
                        (separator.unicode ? 'u' : '') + // in ES6
                        (separator.sticky ? 'y' : ''), // Firefox 3+ and ES6
                lastLastIndex = 0,
                // Make `global` and avoid `lastIndex` issues by working with a copy
                separator2, match, lastIndex, lastLength;
            var separatorCopy = new RegExp(separator.source, flags + 'g');
            if (!compliantExecNpcg) {
                // Doesn't need flags gy, but they don't hurt
                separator2 = new RegExp('^' + separatorCopy.source + '$(?!\\s)', flags);
            }
            /* Values for `limit`, per the spec:
             * If undefined: 4294967295 // maxSafe32BitInt
             * If 0, Infinity, or NaN: 0
             * If positive number: limit = Math.floor(limit); if (limit > 4294967295) limit -= 4294967296;
             * If negative number: 4294967296 - Math.floor(Math.abs(limit))
             * If other: Type-convert, then use the above rules
             */
            var splitLimit = typeof limit === 'undefined' ? maxSafe32BitInt : ES.ToUint32(limit);
            match = separatorCopy.exec(string);
            while (match) {
                // `separatorCopy.lastIndex` is not reliable cross-browser
                lastIndex = match.index + match[0].length;
                if (lastIndex > lastLastIndex) {
                    pushCall(output, strSlice(string, lastLastIndex, match.index));
                    // Fix browsers whose `exec` methods don't consistently return `undefined` for
                    // nonparticipating capturing groups
                    if (!compliantExecNpcg && match.length > 1) {
                        /* eslint-disable no-loop-func */
                        match[0].replace(separator2, function () {
                            for (var i = 1; i < arguments.length - 2; i++) {
                                if (typeof arguments[i] === 'undefined') {
                                    match[i] = void 0;
                                }
                            }
                        });
                        /* eslint-enable no-loop-func */
                    }
                    if (match.length > 1 && match.index < string.length) {
                        array_push.apply(output, arraySlice(match, 1));
                    }
                    lastLength = match[0].length;
                    lastLastIndex = lastIndex;
                    if (output.length >= splitLimit) {
                        break;
                    }
                }
                if (separatorCopy.lastIndex === match.index) {
                    separatorCopy.lastIndex++; // Avoid an infinite loop
                }
                match = separatorCopy.exec(string);
            }
            if (lastLastIndex === string.length) {
                if (lastLength || !separatorCopy.test('')) {
                    pushCall(output, '');
                }
            } else {
                pushCall(output, strSlice(string, lastLastIndex));
            }
            return output.length > splitLimit ? arraySlice(output, 0, splitLimit) : output;
        };
    }());

// [bugfix, chrome]
// If separator is undefined, then the result array contains just one String,
// which is the this value (converted to a String). If limit is not undefined,
// then the output array is truncated so that it contains no more than limit
// elements.
// "0".split(undefined, 0) -> []
} else if ('0'.split(void 0, 0).length) {
    StringPrototype.split = function split(separator, limit) {
        if (typeof separator === 'undefined' && limit === 0) { return []; }
        return strSplit(this, separator, limit);
    };
}

var str_replace = StringPrototype.replace;
var replaceReportsGroupsCorrectly = (function () {
    var groups = [];
    'x'.replace(/x(.)?/g, function (match, group) {
        pushCall(groups, group);
    });
    return groups.length === 1 && typeof groups[0] === 'undefined';
}());

if (!replaceReportsGroupsCorrectly) {
    StringPrototype.replace = function replace(searchValue, replaceValue) {
        var isFn = isCallable(replaceValue);
        var hasCapturingGroups = isRegex(searchValue) && (/\)[*?]/).test(searchValue.source);
        if (!isFn || !hasCapturingGroups) {
            return str_replace.call(this, searchValue, replaceValue);
        } else {
            var wrappedReplaceValue = function (match) {
                var length = arguments.length;
                var originalLastIndex = searchValue.lastIndex;
                searchValue.lastIndex = 0;
                var args = searchValue.exec(match) || [];
                searchValue.lastIndex = originalLastIndex;
                pushCall(args, arguments[length - 2], arguments[length - 1]);
                return replaceValue.apply(this, args);
            };
            return str_replace.call(this, searchValue, wrappedReplaceValue);
        }
    };
}

// ECMA-262, 3rd B.2.3
// Not an ECMAScript standard, although ECMAScript 3rd Edition has a
// non-normative section suggesting uniform semantics and it should be
// normalized across all browsers
// [bugfix, IE lt 9] IE < 9 substr() with negative value not working in IE
var string_substr = StringPrototype.substr;
var hasNegativeSubstrBug = ''.substr && '0b'.substr(-1) !== 'b';
defineProperties(StringPrototype, {
    substr: function substr(start, length) {
        var normalizedStart = start;
        if (start < 0) {
            normalizedStart = max(this.length + start, 0);
        }
        return string_substr.call(this, normalizedStart, length);
    }
}, hasNegativeSubstrBug);

// ES5 15.5.4.20
// whitespace from: http://es5.github.io/#x15.5.4.20
var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003' +
    '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028' +
    '\u2029\uFEFF';
var zeroWidth = '\u200b';
var wsRegexChars = '[' + ws + ']';
var trimBeginRegexp = new RegExp('^' + wsRegexChars + wsRegexChars + '*');
var trimEndRegexp = new RegExp(wsRegexChars + wsRegexChars + '*$');
var hasTrimWhitespaceBug = StringPrototype.trim && (ws.trim() || !zeroWidth.trim());
defineProperties(StringPrototype, {
    // http://blog.stevenlevithan.com/archives/faster-trim-javascript
    // http://perfectionkills.com/whitespace-deviations/
    trim: function trim() {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        return $String(this).replace(trimBeginRegexp, '').replace(trimEndRegexp, '');
    }
}, hasTrimWhitespaceBug);
var trim = call.bind(String.prototype.trim);

var hasLastIndexBug = StringPrototype.lastIndexOf && 'abcあい'.lastIndexOf('あい', 2) !== -1;
defineProperties(StringPrototype, {
    lastIndexOf: function lastIndexOf(searchString) {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        var S = $String(this);
        var searchStr = $String(searchString);
        var numPos = arguments.length > 1 ? $Number(arguments[1]) : NaN;
        var pos = isActualNaN(numPos) ? Infinity : ES.ToInteger(numPos);
        var start = min(max(pos, 0), S.length);
        var searchLen = searchStr.length;
        var k = start + searchLen;
        while (k > 0) {
            k = max(0, k - searchLen);
            var index = strIndexOf(strSlice(S, k, start + searchLen), searchStr);
            if (index !== -1) {
                return k + index;
            }
        }
        return -1;
    }
}, hasLastIndexBug);

var originalLastIndexOf = StringPrototype.lastIndexOf;
defineProperties(StringPrototype, {
    lastIndexOf: function lastIndexOf(searchString) {
        return originalLastIndexOf.apply(this, arguments);
    }
}, StringPrototype.lastIndexOf.length !== 1);

// ES-5 15.1.2.2
/* eslint-disable radix */
if (parseInt(ws + '08') !== 8 || parseInt(ws + '0x16') !== 22) {
/* eslint-enable radix */
    /* global parseInt: true */
    parseInt = (function (origParseInt) {
        var hexRegex = /^[\-+]?0[xX]/;
        return function parseInt(str, radix) {
            var string = trim(str);
            var defaultedRadix = $Number(radix) || (hexRegex.test(string) ? 16 : 10);
            return origParseInt(string, defaultedRadix);
        };
    }(parseInt));
}

// https://es5.github.io/#x15.1.2.3
if (1 / parseFloat('-0') !== -Infinity) {
    /* global parseFloat: true */
    parseFloat = (function (origParseFloat) {
        return function parseFloat(string) {
            var inputString = trim(string);
            var result = origParseFloat(inputString);
            return result === 0 && strSlice(inputString, 0, 1) === '-' ? -0 : result;
        };
    }(parseFloat));
}

if (String(new RangeError('test')) !== 'RangeError: test') {
    var errorToStringShim = function toString() {
        if (typeof this === 'undefined' || this === null) {
            throw new TypeError("can't convert " + this + ' to object');
        }
        var name = this.name;
        if (typeof name === 'undefined') {
            name = 'Error';
        } else if (typeof name !== 'string') {
            name = $String(name);
        }
        var msg = this.message;
        if (typeof msg === 'undefined') {
            msg = '';
        } else if (typeof msg !== 'string') {
            msg = $String(msg);
        }
        if (!name) {
            return msg;
        }
        if (!msg) {
            return name;
        }
        return name + ': ' + msg;
    };
    // can't use defineProperties here because of toString enumeration issue in IE <= 8
    Error.prototype.toString = errorToStringShim;
}

if (supportsDescriptors) {
    var ensureNonEnumerable = function (obj, prop) {
        if (isEnum(obj, prop)) {
            var desc = Object.getOwnPropertyDescriptor(obj, prop);
            desc.enumerable = false;
            Object.defineProperty(obj, prop, desc);
        }
    };
    ensureNonEnumerable(Error.prototype, 'message');
    if (Error.prototype.message !== '') {
      Error.prototype.message = '';
    }
    ensureNonEnumerable(Error.prototype, 'name');
}

if (String(/a/mig) !== '/a/gim') {
    var regexToString = function toString() {
        var str = '/' + this.source + '/';
        if (this.global) {
            str += 'g';
        }
        if (this.ignoreCase) {
            str += 'i';
        }
        if (this.multiline) {
            str += 'm';
        }
        return str;
    };
    // can't use defineProperties here because of toString enumeration issue in IE <= 8
    RegExp.prototype.toString = regexToString;
}

}));

/*!
 * https://github.com/es-shims/es5-shim
 * @license es5-shim Copyright 2009-2015 by contributors, MIT License
 * see https://github.com/es-shims/es5-shim/blob/master/LICENSE
 */

// vim: ts=4 sts=4 sw=4 expandtab

// Add semicolon to prevent IIFE from being passed as argument to concatenated code.
;

// UMD (Universal Module Definition)
// see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
(function (root, factory) {
    'use strict';

    /* global define, exports, module */
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals (root is window)
        root.returnExports = factory();
    }
}(this, function () {

    var call = Function.call;
    var prototypeOfObject = Object.prototype;
    var owns = call.bind(prototypeOfObject.hasOwnProperty);
    var isEnumerable = call.bind(prototypeOfObject.propertyIsEnumerable);
    var toStr = call.bind(prototypeOfObject.toString);

    // If JS engine supports accessors creating shortcuts.
    var defineGetter;
    var defineSetter;
    var lookupGetter;
    var lookupSetter;
    var supportsAccessors = owns(prototypeOfObject, '__defineGetter__');
    if (supportsAccessors) {
        /* eslint-disable no-underscore-dangle, no-restricted-properties */
        defineGetter = call.bind(prototypeOfObject.__defineGetter__);
        defineSetter = call.bind(prototypeOfObject.__defineSetter__);
        lookupGetter = call.bind(prototypeOfObject.__lookupGetter__);
        lookupSetter = call.bind(prototypeOfObject.__lookupSetter__);
        /* eslint-enable no-underscore-dangle, no-restricted-properties */
    }

    var isPrimitive = function isPrimitive(o) {
        return o == null || (typeof o !== 'object' && typeof o !== 'function');
    };

    // ES5 15.2.3.2
    // http://es5.github.com/#x15.2.3.2
    if (!Object.getPrototypeOf) {
        // https://github.com/es-shims/es5-shim/issues#issue/2
        // http://ejohn.org/blog/objectgetprototypeof/
        // recommended by fschaefer on github
        //
        // sure, and webreflection says ^_^
        // ... this will nerever possibly return null
        // ... Opera Mini breaks here with infinite loops
        Object.getPrototypeOf = function getPrototypeOf(object) {
            // eslint-disable-next-line no-proto
            var proto = object.__proto__;
            if (proto || proto === null) {
                return proto;
            } else if (toStr(object.constructor) === '[object Function]') {
                return object.constructor.prototype;
            } else if (object instanceof Object) {
                return prototypeOfObject;
            } else {
                // Correctly return null for Objects created with `Object.create(null)`
                // (shammed or native) or `{ __proto__: null}`.  Also returns null for
                // cross-realm objects on browsers that lack `__proto__` support (like
                // IE <11), but that's the best we can do.
                return null;
            }
        };
    }

    // ES5 15.2.3.3
    // http://es5.github.com/#x15.2.3.3

    var doesGetOwnPropertyDescriptorWork = function doesGetOwnPropertyDescriptorWork(object) {
        try {
            object.sentinel = 0;
            return Object.getOwnPropertyDescriptor(object, 'sentinel').value === 0;
        } catch (exception) {
            return false;
        }
    };

    // check whether getOwnPropertyDescriptor works if it's given. Otherwise, shim partially.
    if (Object.defineProperty) {
        var getOwnPropertyDescriptorWorksOnObject = doesGetOwnPropertyDescriptorWork({});
        var getOwnPropertyDescriptorWorksOnDom = typeof document === 'undefined' ||
            doesGetOwnPropertyDescriptorWork(document.createElement('div'));
        if (!getOwnPropertyDescriptorWorksOnDom || !getOwnPropertyDescriptorWorksOnObject) {
            var getOwnPropertyDescriptorFallback = Object.getOwnPropertyDescriptor;
        }
    }

    if (!Object.getOwnPropertyDescriptor || getOwnPropertyDescriptorFallback) {
        var ERR_NON_OBJECT = 'Object.getOwnPropertyDescriptor called on a non-object: ';

        /* eslint-disable no-proto */
        Object.getOwnPropertyDescriptor = function getOwnPropertyDescriptor(object, property) {
            if (isPrimitive(object)) {
                throw new TypeError(ERR_NON_OBJECT + object);
            }

            // make a valiant attempt to use the real getOwnPropertyDescriptor
            // for I8's DOM elements.
            if (getOwnPropertyDescriptorFallback) {
                try {
                    return getOwnPropertyDescriptorFallback.call(Object, object, property);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            var descriptor;

            // If object does not owns property return undefined immediately.
            if (!owns(object, property)) {
                return descriptor;
            }

            // If object has a property then it's for sure `configurable`, and
            // probably `enumerable`. Detect enumerability though.
            descriptor = {
                enumerable: isEnumerable(object, property),
                configurable: true
            };

            // If JS engine supports accessor properties then property may be a
            // getter or setter.
            if (supportsAccessors) {
                // Unfortunately `__lookupGetter__` will return a getter even
                // if object has own non getter property along with a same named
                // inherited getter. To avoid misbehavior we temporary remove
                // `__proto__` so that `__lookupGetter__` will return getter only
                // if it's owned by an object.
                var prototype = object.__proto__;
                var notPrototypeOfObject = object !== prototypeOfObject;
                // avoid recursion problem, breaking in Opera Mini when
                // Object.getOwnPropertyDescriptor(Object.prototype, 'toString')
                // or any other Object.prototype accessor
                if (notPrototypeOfObject) {
                    object.__proto__ = prototypeOfObject;
                }

                var getter = lookupGetter(object, property);
                var setter = lookupSetter(object, property);

                if (notPrototypeOfObject) {
                    // Once we have getter and setter we can put values back.
                    object.__proto__ = prototype;
                }

                if (getter || setter) {
                    if (getter) {
                        descriptor.get = getter;
                    }
                    if (setter) {
                        descriptor.set = setter;
                    }
                    // If it was accessor property we're done and return here
                    // in order to avoid adding `value` to the descriptor.
                    return descriptor;
                }
            }

            // If we got this far we know that object has an own property that is
            // not an accessor so we set it as a value and return descriptor.
            descriptor.value = object[property];
            descriptor.writable = true;
            return descriptor;
        };
        /* eslint-enable no-proto */
    }

    // ES5 15.2.3.4
    // http://es5.github.com/#x15.2.3.4
    if (!Object.getOwnPropertyNames) {
        Object.getOwnPropertyNames = function getOwnPropertyNames(object) {
            return Object.keys(object);
        };
    }

    // ES5 15.2.3.5
    // http://es5.github.com/#x15.2.3.5
    if (!Object.create) {

        // Contributed by Brandon Benvie, October, 2012
        var createEmpty;
        var supportsProto = !({ __proto__: null } instanceof Object);
        // the following produces false positives
        // in Opera Mini => not a reliable check
        // Object.prototype.__proto__ === null

        // Check for document.domain and active x support
        // No need to use active x approach when document.domain is not set
        // see https://github.com/es-shims/es5-shim/issues/150
        // variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
        /* global ActiveXObject */
        var shouldUseActiveX = function shouldUseActiveX() {
            // return early if document.domain not set
            if (!document.domain) {
                return false;
            }

            try {
                return !!new ActiveXObject('htmlfile');
            } catch (exception) {
                return false;
            }
        };

        // This supports IE8 when document.domain is used
        // see https://github.com/es-shims/es5-shim/issues/150
        // variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
        var getEmptyViaActiveX = function getEmptyViaActiveX() {
            var empty;
            var xDoc;

            xDoc = new ActiveXObject('htmlfile');

            var script = 'script';
            xDoc.write('<' + script + '></' + script + '>');
            xDoc.close();

            empty = xDoc.parentWindow.Object.prototype;
            xDoc = null;

            return empty;
        };

        // The original implementation using an iframe
        // before the activex approach was added
        // see https://github.com/es-shims/es5-shim/issues/150
        var getEmptyViaIFrame = function getEmptyViaIFrame() {
            var iframe = document.createElement('iframe');
            var parent = document.body || document.documentElement;
            var empty;

            iframe.style.display = 'none';
            parent.appendChild(iframe);
            // eslint-disable-next-line no-script-url
            iframe.src = 'javascript:';

            empty = iframe.contentWindow.Object.prototype;
            parent.removeChild(iframe);
            iframe = null;

            return empty;
        };

        /* global document */
        if (supportsProto || typeof document === 'undefined') {
            createEmpty = function () {
                return { __proto__: null };
            };
        } else {
            // In old IE __proto__ can't be used to manually set `null`, nor does
            // any other method exist to make an object that inherits from nothing,
            // aside from Object.prototype itself. Instead, create a new global
            // object and *steal* its Object.prototype and strip it bare. This is
            // used as the prototype to create nullary objects.
            createEmpty = function () {
                // Determine which approach to use
                // see https://github.com/es-shims/es5-shim/issues/150
                var empty = shouldUseActiveX() ? getEmptyViaActiveX() : getEmptyViaIFrame();

                delete empty.constructor;
                delete empty.hasOwnProperty;
                delete empty.propertyIsEnumerable;
                delete empty.isPrototypeOf;
                delete empty.toLocaleString;
                delete empty.toString;
                delete empty.valueOf;

                var Empty = function Empty() {};
                Empty.prototype = empty;
                // short-circuit future calls
                createEmpty = function () {
                    return new Empty();
                };
                return new Empty();
            };
        }

        Object.create = function create(prototype, properties) {

            var object;
            var Type = function Type() {}; // An empty constructor.

            if (prototype === null) {
                object = createEmpty();
            } else {
                if (prototype !== null && isPrimitive(prototype)) {
                    // In the native implementation `parent` can be `null`
                    // OR *any* `instanceof Object`  (Object|Function|Array|RegExp|etc)
                    // Use `typeof` tho, b/c in old IE, DOM elements are not `instanceof Object`
                    // like they are in modern browsers. Using `Object.create` on DOM elements
                    // is...err...probably inappropriate, but the native version allows for it.
                    throw new TypeError('Object prototype may only be an Object or null'); // same msg as Chrome
                }
                Type.prototype = prototype;
                object = new Type();
                // IE has no built-in implementation of `Object.getPrototypeOf`
                // neither `__proto__`, but this manually setting `__proto__` will
                // guarantee that `Object.getPrototypeOf` will work as expected with
                // objects created using `Object.create`
                // eslint-disable-next-line no-proto
                object.__proto__ = prototype;
            }

            if (properties !== void 0) {
                Object.defineProperties(object, properties);
            }

            return object;
        };
    }

    // ES5 15.2.3.6
    // http://es5.github.com/#x15.2.3.6

    // Patch for WebKit and IE8 standard mode
    // Designed by hax <hax.github.com>
    // related issue: https://github.com/es-shims/es5-shim/issues#issue/5
    // IE8 Reference:
    //     http://msdn.microsoft.com/en-us/library/dd282900.aspx
    //     http://msdn.microsoft.com/en-us/library/dd229916.aspx
    // WebKit Bugs:
    //     https://bugs.webkit.org/show_bug.cgi?id=36423

    var doesDefinePropertyWork = function doesDefinePropertyWork(object) {
        try {
            Object.defineProperty(object, 'sentinel', {});
            return 'sentinel' in object;
        } catch (exception) {
            return false;
        }
    };

    // check whether defineProperty works if it's given. Otherwise,
    // shim partially.
    if (Object.defineProperty) {
        var definePropertyWorksOnObject = doesDefinePropertyWork({});
        var definePropertyWorksOnDom = typeof document === 'undefined' ||
            doesDefinePropertyWork(document.createElement('div'));
        if (!definePropertyWorksOnObject || !definePropertyWorksOnDom) {
            var definePropertyFallback = Object.defineProperty,
                definePropertiesFallback = Object.defineProperties;
        }
    }

    if (!Object.defineProperty || definePropertyFallback) {
        var ERR_NON_OBJECT_DESCRIPTOR = 'Property description must be an object: ';
        var ERR_NON_OBJECT_TARGET = 'Object.defineProperty called on non-object: ';
        var ERR_ACCESSORS_NOT_SUPPORTED = 'getters & setters can not be defined on this javascript engine';

        Object.defineProperty = function defineProperty(object, property, descriptor) {
            if (isPrimitive(object)) {
                throw new TypeError(ERR_NON_OBJECT_TARGET + object);
            }
            if (isPrimitive(descriptor)) {
                throw new TypeError(ERR_NON_OBJECT_DESCRIPTOR + descriptor);
            }
            // make a valiant attempt to use the real defineProperty
            // for I8's DOM elements.
            if (definePropertyFallback) {
                try {
                    return definePropertyFallback.call(Object, object, property, descriptor);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            // If it's a data property.
            if ('value' in descriptor) {
                // fail silently if 'writable', 'enumerable', or 'configurable'
                // are requested but not supported
                /*
                // alternate approach:
                if ( // can't implement these features; allow false but not true
                    ('writable' in descriptor && !descriptor.writable) ||
                    ('enumerable' in descriptor && !descriptor.enumerable) ||
                    ('configurable' in descriptor && !descriptor.configurable)
                ))
                    throw new RangeError(
                        'This implementation of Object.defineProperty does not support configurable, enumerable, or writable.'
                    );
                */

                if (supportsAccessors && (lookupGetter(object, property) || lookupSetter(object, property))) {
                    // As accessors are supported only on engines implementing
                    // `__proto__` we can safely override `__proto__` while defining
                    // a property to make sure that we don't hit an inherited
                    // accessor.
                    /* eslint-disable no-proto */
                    var prototype = object.__proto__;
                    object.__proto__ = prototypeOfObject;
                    // Deleting a property anyway since getter / setter may be
                    // defined on object itself.
                    delete object[property];
                    object[property] = descriptor.value;
                    // Setting original `__proto__` back now.
                    object.__proto__ = prototype;
                    /* eslint-enable no-proto */
                } else {
                    object[property] = descriptor.value;
                }
            } else {
                var hasGetter = 'get' in descriptor;
                var hasSetter = 'set' in descriptor;
                if (!supportsAccessors && (hasGetter || hasSetter)) {
                    throw new TypeError(ERR_ACCESSORS_NOT_SUPPORTED);
                }
                // If we got that far then getters and setters can be defined !!
                if (hasGetter) {
                    defineGetter(object, property, descriptor.get);
                }
                if (hasSetter) {
                    defineSetter(object, property, descriptor.set);
                }
            }
            return object;
        };
    }

    // ES5 15.2.3.7
    // http://es5.github.com/#x15.2.3.7
    if (!Object.defineProperties || definePropertiesFallback) {
        Object.defineProperties = function defineProperties(object, properties) {
            // make a valiant attempt to use the real defineProperties
            if (definePropertiesFallback) {
                try {
                    return definePropertiesFallback.call(Object, object, properties);
                } catch (exception) {
                    // try the shim if the real one doesn't work
                }
            }

            Object.keys(properties).forEach(function (property) {
                if (property !== '__proto__') {
                    Object.defineProperty(object, property, properties[property]);
                }
            });
            return object;
        };
    }

    // ES5 15.2.3.8
    // http://es5.github.com/#x15.2.3.8
    if (!Object.seal) {
        Object.seal = function seal(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.seal can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // ES5 15.2.3.9
    // http://es5.github.com/#x15.2.3.9
    if (!Object.freeze) {
        Object.freeze = function freeze(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.freeze can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // detect a Rhino bug and patch it
    try {
        Object.freeze(function () {});
    } catch (exception) {
        Object.freeze = (function (freezeObject) {
            return function freeze(object) {
                if (typeof object === 'function') {
                    return object;
                } else {
                    return freezeObject(object);
                }
            };
        }(Object.freeze));
    }

    // ES5 15.2.3.10
    // http://es5.github.com/#x15.2.3.10
    if (!Object.preventExtensions) {
        Object.preventExtensions = function preventExtensions(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.preventExtensions can only be called on Objects.');
            }
            // this is misleading and breaks feature-detection, but
            // allows "securable" code to "gracefully" degrade to working
            // but insecure code.
            return object;
        };
    }

    // ES5 15.2.3.11
    // http://es5.github.com/#x15.2.3.11
    if (!Object.isSealed) {
        Object.isSealed = function isSealed(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.isSealed can only be called on Objects.');
            }
            return false;
        };
    }

    // ES5 15.2.3.12
    // http://es5.github.com/#x15.2.3.12
    if (!Object.isFrozen) {
        Object.isFrozen = function isFrozen(object) {
            if (Object(object) !== object) {
                throw new TypeError('Object.isFrozen can only be called on Objects.');
            }
            return false;
        };
    }

    // ES5 15.2.3.13
    // http://es5.github.com/#x15.2.3.13
    if (!Object.isExtensible) {
        Object.isExtensible = function isExtensible(object) {
            // 1. If Type(O) is not Object throw a TypeError exception.
            if (Object(object) !== object) {
                throw new TypeError('Object.isExtensible can only be called on Objects.');
            }
            // 2. Return the Boolean value of the [[Extensible]] internal property of O.
            var name = '';
            while (owns(object, name)) {
                name += '?';
            }
            object[name] = true;
            var returnValue = owns(object, name);
            delete object[name];
            return returnValue;
        };
    }

}));
/*!
 * jQuery JavaScript Library v1.11.3
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2015-04-28T16:19Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper window is present,
		// execute the factory and get jQuery
		// For environments that do not inherently posses a window with a document
		// (such as Node.js), expose a jQuery-making factory as module.exports
		// This accentuates the need for the creation of a real window
		// e.g. var jQuery = require("jquery")(window);
		// See ticket #14549 for more info
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Can't do this because several apps including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
// Support: Firefox 18+
//

var deletedIds = [];

var slice = deletedIds.slice;

var concat = deletedIds.concat;

var push = deletedIds.push;

var indexOf = deletedIds.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	version = "1.11.3",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1, IE<9
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: deletedIds.sort,
	splice: deletedIds.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var src, copyIsArray, copy, name, options, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		/* jshint eqeqeq: false */
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		// adding 1 corrects loss of precision from parseFloat (#15100)
		return !jQuery.isArray( obj ) && (obj - parseFloat( obj ) + 1) >= 0;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	isPlainObject: function( obj ) {
		var key;

		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!hasOwn.call(obj, "constructor") &&
				!hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Support: IE<9
		// Handle iteration over inherited properties before own properties.
		if ( support.ownLast ) {
			for ( key in obj ) {
				return hasOwn.call( obj, key );
			}
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.
		for ( key in obj ) {}

		return key === undefined || hasOwn.call( obj, key );
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && jQuery.trim( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1, IE<9
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		var len;

		if ( arr ) {
			if ( indexOf ) {
				return indexOf.call( arr, elem, i );
			}

			len = arr.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in arr && arr[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		while ( j < len ) {
			first[ i++ ] = second[ j++ ];
		}

		// Support: IE<9
		// Workaround casting of .length to NaN on otherwise arraylike objects (e.g., NodeLists)
		if ( len !== len ) {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var args, proxy, tmp;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: function() {
		return +( new Date() );
	},

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {

	// Support: iOS 8.2 (not reproducible in simulator)
	// `in` check used to prevent JIT error (gh-2145)
	// hasOwn isn't used here due to false negatives
	// regarding Nodelist length in IE
	var length = "length" in obj && obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v2.2.0-pre
 * http://sizzlejs.com/
 *
 * Copyright 2008, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-12-16
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + 1 * new Date(),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf as it's faster than native
	// http://jsperf.com/thor-indexof-vs-for/5
	indexOf = function( list, elem ) {
		var i = 0,
			len = list.length;
		for ( ; i < len; i++ ) {
			if ( list[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rwhitespace = new RegExp( whitespace + "+", "g" ),
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	},

	// Used for iframes
	// See setDocument()
	// Removing the function wrapper causes a "Permission Denied"
	// error in IE
	unloadHandler = function() {
		setDocument();
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];
	nodeType = context.nodeType;

	if ( typeof selector !== "string" || !selector ||
		nodeType !== 1 && nodeType !== 9 && nodeType !== 11 ) {

		return results;
	}

	if ( !seed && documentIsHTML ) {

		// Try to shortcut find operations when possible (e.g., not under DocumentFragment)
		if ( nodeType !== 11 && (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType !== 1 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== "undefined" && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare, parent,
		doc = node ? node.ownerDocument || node : preferredDoc;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;
	parent = doc.defaultView;

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", unloadHandler, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", unloadHandler );
		}
	}

	/* Support tests
	---------------------------------------------------------------------- */
	documentIsHTML = !isXML( doc );

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties
	// (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Support: IE<9
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName );

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== "undefined" && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( tag );

			// DocumentFragment nodes don't have gEBTN
			} else if ( support.qsa ) {
				return context.querySelectorAll( tag );
			}
		} :

		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				// By happy coincidence, a (broken) gEBTN appears on DocumentFragment nodes too
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			docElem.appendChild( div ).innerHTML = "<a id='" + expando + "'></a>" +
				"<select id='" + expando + "-\f]' msallowcapture=''>" +
				"<option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowcapture^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Support: Chrome<29, Android<4.2+, Safari<7.0+, iOS<7.0+, PhantomJS<1.9.7+
			if ( !div.querySelectorAll( "[id~=" + expando + "-]" ).length ) {
				rbuggyQSA.push("~=");
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}

			// Support: Safari 8+, iOS 8+
			// https://bugs.webkit.org/show_bug.cgi?id=136851
			// In-page `selector#id sibing-combinator selector` fails
			if ( !div.querySelectorAll( "a#" + expando + "+*" ).length ) {
				rbuggyQSA.push(".#.+[+~]");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch (e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== "undefined" && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result.replace( rwhitespace, " " ) + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					// Don't keep the element (issue #299)
					input[0] = null;
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			text = text.replace( runescape, funescape );
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			var ret = ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
			// Avoid hanging onto element (issue #299)
			checkContext = null;
			return ret;
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome 14-35+
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			ret = [],
			self = this,
			len = self.length;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var i,
			targets = jQuery( target, this ),
			len = targets.length;

		return this.filter(function() {
			for ( i = 0; i < len; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.first().prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	do {
		cur = cur[ dir ];
	} while ( cur && cur.nodeType !== 1 );

	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				ret = jQuery.unique( ret );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				ret = ret.reverse();
			}
		}

		return this.pushStack( ret );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Flag to know if list is currently firing
		firing,
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );

					} else if ( !(--remaining) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// if we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( !document.body ) {
			return setTimeout( jQuery.ready );
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * Clean-up method for dom ready events
 */
function detach() {
	if ( document.addEventListener ) {
		document.removeEventListener( "DOMContentLoaded", completed, false );
		window.removeEventListener( "load", completed, false );

	} else {
		document.detachEvent( "onreadystatechange", completed );
		window.detachEvent( "onload", completed );
	}
}

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	// readyState === "complete" is good enough for us to call the dom ready in oldIE
	if ( document.addEventListener || event.type === "load" || document.readyState === "complete" ) {
		detach();
		jQuery.ready();
	}
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// we once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		// Standards-based browsers support DOMContentLoaded
		} else if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );

		// If IE event model is used
		} else {
			// Ensure firing before onload, maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", completed );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", completed );

			// If IE and not a frame
			// continually check to see if the document is ready
			var top = false;

			try {
				top = window.frameElement == null && document.documentElement;
			} catch(e) {}

			if ( top && top.doScroll ) {
				(function doScrollCheck() {
					if ( !jQuery.isReady ) {

						try {
							// Use the trick by Diego Perini
							// http://javascript.nwbox.com/IEContentLoaded/
							top.doScroll("left");
						} catch(e) {
							return setTimeout( doScrollCheck, 50 );
						}

						// detach all dom ready events
						detach();

						// and execute any waiting functions
						jQuery.ready();
					}
				})();
			}
		}
	}
	return readyList.promise( obj );
};


var strundefined = typeof undefined;



// Support: IE<9
// Iteration over object's inherited properties before its own
var i;
for ( i in jQuery( support ) ) {
	break;
}
support.ownLast = i !== "0";

// Note: most support tests are defined in their respective modules.
// false until the test is run
support.inlineBlockNeedsLayout = false;

// Execute ASAP in case we need to set body.style.zoom
jQuery(function() {
	// Minified: var a,b,c,d
	var val, div, body, container;

	body = document.getElementsByTagName( "body" )[ 0 ];
	if ( !body || !body.style ) {
		// Return for frameset docs that don't have a body
		return;
	}

	// Setup
	div = document.createElement( "div" );
	container = document.createElement( "div" );
	container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
	body.appendChild( container ).appendChild( div );

	if ( typeof div.style.zoom !== strundefined ) {
		// Support: IE<8
		// Check if natively block-level elements act like inline-block
		// elements when setting their display to 'inline' and giving
		// them layout
		div.style.cssText = "display:inline;margin:0;border:0;padding:1px;width:1px;zoom:1";

		support.inlineBlockNeedsLayout = val = div.offsetWidth === 3;
		if ( val ) {
			// Prevent IE 6 from affecting layout for positioned elements #11048
			// Prevent IE from shrinking the body in IE 7 mode #12869
			// Support: IE<8
			body.style.zoom = 1;
		}
	}

	body.removeChild( container );
});




(function() {
	var div = document.createElement( "div" );

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( elem ) {
	var noData = jQuery.noData[ (elem.nodeName + " ").toLowerCase() ],
		nodeType = +elem.nodeType || 1;

	// Do not set data on non-element DOM nodes because it will not be cleared (#8335).
	return nodeType !== 1 && nodeType !== 9 ?
		false :

		// Nodes accept data unless otherwise specified; rejection can be conditional
		!noData || noData !== true && elem.getAttribute("classid") === noData;
};


var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	var name;
	for ( name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}

function internalData( elem, name, data, pvt /* Internal Use Only */ ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var ret, thisCache,
		internalKey = jQuery.expando,

		// We have to handle DOM nodes and JS objects differently because IE6-7
		// can't GC object references properly across the DOM-JS boundary
		isNode = elem.nodeType,

		// Only DOM nodes need the global jQuery cache; JS object data is
		// attached directly to the object so GC can occur automatically
		cache = isNode ? jQuery.cache : elem,

		// Only defining an ID for JS objects if its cache already exists allows
		// the code to shortcut on the same path as a DOM node with no cache
		id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey;

	// Avoid doing any more work than we need to when trying to get data on an
	// object that has no data at all
	if ( (!id || !cache[id] || (!pvt && !cache[id].data)) && data === undefined && typeof name === "string" ) {
		return;
	}

	if ( !id ) {
		// Only DOM nodes need a new unique ID for each element since their data
		// ends up in the global cache
		if ( isNode ) {
			id = elem[ internalKey ] = deletedIds.pop() || jQuery.guid++;
		} else {
			id = internalKey;
		}
	}

	if ( !cache[ id ] ) {
		// Avoid exposing jQuery metadata on plain JS objects when the object
		// is serialized using JSON.stringify
		cache[ id ] = isNode ? {} : { toJSON: jQuery.noop };
	}

	// An object can be passed to jQuery.data instead of a key/value pair; this gets
	// shallow copied over onto the existing cache
	if ( typeof name === "object" || typeof name === "function" ) {
		if ( pvt ) {
			cache[ id ] = jQuery.extend( cache[ id ], name );
		} else {
			cache[ id ].data = jQuery.extend( cache[ id ].data, name );
		}
	}

	thisCache = cache[ id ];

	// jQuery data() is stored in a separate object inside the object's internal data
	// cache in order to avoid key collisions between internal data and user-defined
	// data.
	if ( !pvt ) {
		if ( !thisCache.data ) {
			thisCache.data = {};
		}

		thisCache = thisCache.data;
	}

	if ( data !== undefined ) {
		thisCache[ jQuery.camelCase( name ) ] = data;
	}

	// Check for both converted-to-camel and non-converted data property names
	// If a data property was specified
	if ( typeof name === "string" ) {

		// First Try to find as-is property data
		ret = thisCache[ name ];

		// Test for null|undefined property data
		if ( ret == null ) {

			// Try to find the camelCased property
			ret = thisCache[ jQuery.camelCase( name ) ];
		}
	} else {
		ret = thisCache;
	}

	return ret;
}

function internalRemoveData( elem, name, pvt ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var thisCache, i,
		isNode = elem.nodeType,

		// See jQuery.data for more information
		cache = isNode ? jQuery.cache : elem,
		id = isNode ? elem[ jQuery.expando ] : jQuery.expando;

	// If there is already no cache entry for this object, there is no
	// purpose in continuing
	if ( !cache[ id ] ) {
		return;
	}

	if ( name ) {

		thisCache = pvt ? cache[ id ] : cache[ id ].data;

		if ( thisCache ) {

			// Support array or space separated string names for data keys
			if ( !jQuery.isArray( name ) ) {

				// try the string as a key before any manipulation
				if ( name in thisCache ) {
					name = [ name ];
				} else {

					// split the camel cased version by spaces unless a key with the spaces exists
					name = jQuery.camelCase( name );
					if ( name in thisCache ) {
						name = [ name ];
					} else {
						name = name.split(" ");
					}
				}
			} else {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = name.concat( jQuery.map( name, jQuery.camelCase ) );
			}

			i = name.length;
			while ( i-- ) {
				delete thisCache[ name[i] ];
			}

			// If there is no data left in the cache, we want to continue
			// and let the cache object itself get destroyed
			if ( pvt ? !isEmptyDataObject(thisCache) : !jQuery.isEmptyObject(thisCache) ) {
				return;
			}
		}
	}

	// See jQuery.data for more information
	if ( !pvt ) {
		delete cache[ id ].data;

		// Don't destroy the parent cache unless the internal data object
		// had been the only thing left in it
		if ( !isEmptyDataObject( cache[ id ] ) ) {
			return;
		}
	}

	// Destroy the cache
	if ( isNode ) {
		jQuery.cleanData( [ elem ], true );

	// Use delete when supported for expandos or `cache` is not a window per isWindow (#10080)
	/* jshint eqeqeq: false */
	} else if ( support.deleteExpando || cache != cache.window ) {
		/* jshint eqeqeq: true */
		delete cache[ id ];

	// When all else fails, null
	} else {
		cache[ id ] = null;
	}
}

jQuery.extend({
	cache: {},

	// The following elements (space-suffixed to avoid Object.prototype collisions)
	// throw uncatchable exceptions if you attempt to set expando properties
	noData: {
		"applet ": true,
		"embed ": true,
		// ...but Flash objects (which have this classid) *can* handle expandos
		"object ": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data ) {
		return internalData( elem, name, data );
	},

	removeData: function( elem, name ) {
		return internalRemoveData( elem, name );
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return internalData( elem, name, data, true );
	},

	_removeData: function( elem, name ) {
		return internalRemoveData( elem, name, true );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[0],
			attrs = elem && elem.attributes;

		// Special expections of .data basically thwart jQuery.access,
		// so implement the relevant behavior ourselves

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		return arguments.length > 1 ?

			// Sets one value
			this.each(function() {
				jQuery.data( this, key, value );
			}) :

			// Gets one value
			// Try to fetch any internally stored data first
			elem ? dataAttr( elem, key, jQuery.data( elem, key ) ) : undefined;
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray(data) ) {
					queue = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// not intended for public consumption - generates a queueHooks object, or returns the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return jQuery._data( elem, key ) || jQuery._data( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				jQuery._removeData( elem, type + "queue" );
				jQuery._removeData( elem, key );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = jQuery._data( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};



// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		length = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < length; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			length ? fn( elems[0], key ) : emptyGet;
};
var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	// Minified: var a,b,c
	var input = document.createElement( "input" ),
		div = document.createElement( "div" ),
		fragment = document.createDocumentFragment();

	// Setup
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";

	// IE strips leading whitespace when .innerHTML is used
	support.leadingWhitespace = div.firstChild.nodeType === 3;

	// Make sure that tbody elements aren't automatically inserted
	// IE will insert them into empty tables
	support.tbody = !div.getElementsByTagName( "tbody" ).length;

	// Make sure that link elements get serialized correctly by innerHTML
	// This requires a wrapper element in IE
	support.htmlSerialize = !!div.getElementsByTagName( "link" ).length;

	// Makes sure cloning an html5 element does not cause problems
	// Where outerHTML is undefined, this still works
	support.html5Clone =
		document.createElement( "nav" ).cloneNode( true ).outerHTML !== "<:nav></:nav>";

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	input.type = "checkbox";
	input.checked = true;
	fragment.appendChild( input );
	support.appendChecked = input.checked;

	// Make sure textarea (and checkbox) defaultValue is properly cloned
	// Support: IE6-IE11+
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;

	// #11217 - WebKit loses check when the name is after the checked attribute
	fragment.appendChild( div );
	div.innerHTML = "<input type='radio' checked='checked' name='t'/>";

	// Support: Safari 5.1, iOS 5.1, Android 4.x, Android 2.3
	// old WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<9
	// Opera does not clone events (and typeof div.attachEvent === undefined).
	// IE9-10 clones events bound via attachEvent, but they don't trigger with .click()
	support.noCloneEvent = true;
	if ( div.attachEvent ) {
		div.attachEvent( "onclick", function() {
			support.noCloneEvent = false;
		});

		div.cloneNode( true ).click();
	}

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}
})();


(function() {
	var i, eventName,
		div = document.createElement( "div" );

	// Support: IE<9 (lack submit/change bubble), Firefox 23+ (lack focusin event)
	for ( i in { submit: true, change: true, focusin: true }) {
		eventName = "on" + i;

		if ( !(support[ i + "Bubbles" ] = eventName in window) ) {
			// Beware of CSP restrictions (https://developer.mozilla.org/en/Security/CSP)
			div.setAttribute( eventName, "t" );
			support[ i + "Bubbles" ] = div.attributes[ eventName ].expando === false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


var rformElems = /^(?:input|select|textarea)$/i,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {
		var tmp, events, t, handleObjIn,
			special, eventHandle, handleObj,
			handlers, type, namespaces, origType,
			elemData = jQuery._data( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {
		var j, handleObj, tmp,
			origCount, t, events,
			special, handlers, type,
			namespaces, origType,
			elemData = jQuery.hasData( elem ) && jQuery._data( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery._removeData( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		var handle, ontype, cur,
			bubbleType, special, tmp, i,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && elem[ type ] && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					try {
						elem[ type ]();
					} catch ( e ) {
						// IE<9 dies on focus/blur to hidden element (#1486,#12518)
						// only reproducible on winXP IE8 native, not IE9 in IE8 mode
					}
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, ret, handleObj, matched, j,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( jQuery._data( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var sel, handleObj, matches, i,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			/* jshint eqeqeq: false */
			for ( ; cur != this; cur = cur.parentNode || this ) {
				/* jshint eqeqeq: true */

				// Don't check non-elements (#13208)
				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.nodeType === 1 && (cur.disabled !== true || event.type !== "click") ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: IE<9
		// Fix target property (#1925)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Support: Chrome 23+, Safari?
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// Support: IE<9
		// For mouse/key events, metaKey==false if it's undefined (#3368, #11328)
		event.metaKey = !!event.metaKey;

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var body, eventDoc, doc,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					try {
						this.focus();
						return false;
					} catch ( e ) {
						// Support: IE<9
						// If we error on focus to hidden element (#1486, #12518),
						// let .trigger() run the handlers
					}
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( jQuery.nodeName( this, "input" ) && this.type === "checkbox" && this.click ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		var name = "on" + type;

		if ( elem.detachEvent ) {

			// #8545, #7054, preventing memory leaks for custom events in IE6-8
			// detachEvent needed property on element, by name of that event, to properly expose it to GC
			if ( typeof elem[ name ] === strundefined ) {
				elem[ name ] = null;
			}

			elem.detachEvent( name, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: IE < 9, Android < 4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;
		if ( !e ) {
			return;
		}

		// If preventDefault exists, run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// Support: IE
		// Otherwise set the returnValue property of the original event to false
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;
		if ( !e ) {
			return;
		}
		// If stopPropagation exists, run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}

		// Support: IE
		// Set the cancelBubble property of the original event to true
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !jQuery._data( form, "submitBubbles" ) ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					jQuery._data( form, "submitBubbles", true );
				}
			});
			// return undefined since we don't need an event listener
		},

		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
						}
						// Allow triggered, simulated change events (#11500)
						jQuery.event.simulate( "change", this, event, true );
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !jQuery._data( elem, "changeBubbles" ) ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					jQuery._data( elem, "changeBubbles", true );
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return !rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				jQuery._data( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					jQuery._removeData( doc, fix );
				} else {
					jQuery._data( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var type, origFn;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
		safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:null|\d+)"/g,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		area: [ 1, "<map>", "</map>" ],
		param: [ 1, "<object>", "</object>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		// IE6-8 can't serialize link, script, style, or any html5 (NoScope) tags,
		// unless wrapped in a div with non-breaking characters in front of it.
		_default: support.htmlSerialize ? [ 0, "", "" ] : [ 1, "X<div>", "</div>"  ]
	},
	safeFragment = createSafeFragment( document ),
	fragmentDiv = safeFragment.appendChild( document.createElement("div") );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

function getAll( context, tag ) {
	var elems, elem,
		i = 0,
		found = typeof context.getElementsByTagName !== strundefined ? context.getElementsByTagName( tag || "*" ) :
			typeof context.querySelectorAll !== strundefined ? context.querySelectorAll( tag || "*" ) :
			undefined;

	if ( !found ) {
		for ( found = [], elems = context.childNodes || context; (elem = elems[i]) != null; i++ ) {
			if ( !tag || jQuery.nodeName( elem, tag ) ) {
				found.push( elem );
			} else {
				jQuery.merge( found, getAll( elem, tag ) );
			}
		}
	}

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], found ) :
		found;
}

// Used in buildFragment, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( rcheckableType.test( elem.type ) ) {
		elem.defaultChecked = elem.checked;
	}
}

// Support: IE<8
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (jQuery.find.attr( elem, "type" ) !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );
	if ( match ) {
		elem.type = match[1];
	} else {
		elem.removeAttribute("type");
	}
	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var elem,
		i = 0;
	for ( ; (elem = elems[i]) != null; i++ ) {
		jQuery._data( elem, "globalEval", !refElements || jQuery._data( refElements[i], "globalEval" ) );
	}
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function fixCloneNodeIssues( src, dest ) {
	var nodeName, e, data;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 copies events bound via attachEvent when using cloneNode.
	if ( !support.noCloneEvent && dest[ jQuery.expando ] ) {
		data = jQuery._data( dest );

		for ( e in data.events ) {
			jQuery.removeEvent( dest, e, data.handle );
		}

		// Event data gets referenced instead of copied if the expando gets copied too
		dest.removeAttribute( jQuery.expando );
	}

	// IE blanks contents when cloning scripts, and tries to evaluate newly-set text
	if ( nodeName === "script" && dest.text !== src.text ) {
		disableScript( dest ).text = src.text;
		restoreScript( dest );

	// IE6-10 improperly clones children of object elements using classid.
	// IE10 throws NoModificationAllowedError if parent is null, #12132.
	} else if ( nodeName === "object" ) {
		if ( dest.parentNode ) {
			dest.outerHTML = src.outerHTML;
		}

		// This path appears unavoidable for IE9. When cloning an object
		// element in IE9, the outerHTML strategy above is not sufficient.
		// If the src has innerHTML and the destination does not,
		// copy the src.innerHTML into the dest.innerHTML. #10324
		if ( support.html5Clone && ( src.innerHTML && !jQuery.trim(dest.innerHTML) ) ) {
			dest.innerHTML = src.innerHTML;
		}

	} else if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set

		dest.defaultChecked = dest.checked = src.checked;

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.defaultSelected = dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var destElements, node, clone, i, srcElements,
			inPage = jQuery.contains( elem.ownerDocument, elem );

		if ( support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ) {
			clone = elem.cloneNode( true );

		// IE<=8 does not properly clone detached, unknown element nodes
		} else {
			fragmentDiv.innerHTML = elem.outerHTML;
			fragmentDiv.removeChild( clone = fragmentDiv.firstChild );
		}

		if ( (!support.noCloneEvent || !support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			// Fix all IE cloning issues
			for ( i = 0; (node = srcElements[i]) != null; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					fixCloneNodeIssues( node, destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0; (node = srcElements[i]) != null; i++ ) {
					cloneCopyEvent( node, destElements[i] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		destElements = srcElements = node = null;

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var j, elem, contains,
			tmp, tag, tbody, wrap,
			l = elems.length,

			// Ensure a safe fragment
			safe = createSafeFragment( context ),

			nodes = [],
			i = 0;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || safe.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = (rtagName.exec( elem ) || [ "", "" ])[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;

					tmp.innerHTML = wrap[1] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[2];

					// Descend through wrappers to the right content
					j = wrap[0];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Manually add leading whitespace removed by IE
					if ( !support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						nodes.push( context.createTextNode( rleadingWhitespace.exec( elem )[0] ) );
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						elem = tag === "table" && !rtbody.test( elem ) ?
							tmp.firstChild :

							// String was a bare <thead> or <tfoot>
							wrap[1] === "<table>" && !rtbody.test( elem ) ?
								tmp :
								0;

						j = elem && elem.childNodes.length;
						while ( j-- ) {
							if ( jQuery.nodeName( (tbody = elem.childNodes[j]), "tbody" ) && !tbody.childNodes.length ) {
								elem.removeChild( tbody );
							}
						}
					}

					jQuery.merge( nodes, tmp.childNodes );

					// Fix #12392 for WebKit and IE > 9
					tmp.textContent = "";

					// Fix #12392 for oldIE
					while ( tmp.firstChild ) {
						tmp.removeChild( tmp.firstChild );
					}

					// Remember the top-level container for proper cleanup
					tmp = safe.lastChild;
				}
			}
		}

		// Fix #11356: Clear elements from fragment
		if ( tmp ) {
			safe.removeChild( tmp );
		}

		// Reset defaultChecked for any radios and checkboxes
		// about to be appended to the DOM in IE 6/7 (#8060)
		if ( !support.appendChecked ) {
			jQuery.grep( getAll( nodes, "input" ), fixDefaultChecked );
		}

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( safe.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		tmp = null;

		return safe;
	},

	cleanData: function( elems, /* internal */ acceptData ) {
		var elem, type, id, data,
			i = 0,
			internalKey = jQuery.expando,
			cache = jQuery.cache,
			deleteExpando = support.deleteExpando,
			special = jQuery.event.special;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( acceptData || jQuery.acceptData( elem ) ) {

				id = elem[ internalKey ];
				data = id && cache[ id ];

				if ( data ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}

					// Remove cache only if it was not already removed by jQuery.event.remove
					if ( cache[ id ] ) {

						delete cache[ id ];

						// IE does not allow us to delete expando properties from nodes,
						// nor does it have a removeAttribute function on Document nodes;
						// we must handle all of these cases
						if ( deleteExpando ) {
							delete elem[ internalKey ];

						} else if ( typeof elem.removeAttribute !== strundefined ) {
							elem.removeAttribute( internalKey );

						} else {
							elem[ internalKey ] = null;
						}

						deletedIds.push( id );
					}
				}
			}
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {

			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem, false ) );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}

			// If this is a select, ensure that it displays empty (#12336)
			// Support: IE<9
			if ( elem.options && jQuery.nodeName( elem, "select" ) ) {
				elem.options.length = 0;
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					undefined;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( support.htmlSerialize || !rnoshimcache.test( value )  ) &&
				( support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ (rtagName.exec( value ) || [ "", "" ])[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var first, node, hasScripts,
			scripts, doc, fragment,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[0],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[0] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[i], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!jQuery._data( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( ( node.text || node.textContent || node.innerHTML || "" ).replace( rcleanScript, "" ) );
							}
						}
					}
				}

				// Fix #11809: Avoid leaking memory
				fragment = first = null;
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			i = 0,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone(true);
			jQuery( insert[i] )[ original ]( elems );

			// Modern browsers can apply jQuery collections as arrays, but oldIE needs a .get()
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optmization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = ( iframe[ 0 ].contentWindow || iframe[ 0 ].contentDocument ).document;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}


(function() {
	var shrinkWrapBlocksVal;

	support.shrinkWrapBlocks = function() {
		if ( shrinkWrapBlocksVal != null ) {
			return shrinkWrapBlocksVal;
		}

		// Will be changed later if needed.
		shrinkWrapBlocksVal = false;

		// Minified: var b,c,d
		var div, body, container;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		// Support: IE6
		// Check if elements with layout shrink-wrap their children
		if ( typeof div.style.zoom !== strundefined ) {
			// Reset CSS: box-sizing; display; margin; border
			div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;" +
				"padding:1px;width:1px;zoom:1";
			div.appendChild( document.createElement( "div" ) ).style.width = "5px";
			shrinkWrapBlocksVal = div.offsetWidth !== 3;
		}

		body.removeChild( container );

		return shrinkWrapBlocksVal;
	};

})();
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );



var getStyles, curCSS,
	rposition = /^(top|right|bottom|left)$/;

if ( window.getComputedStyle ) {
	getStyles = function( elem ) {
		// Support: IE<=11+, Firefox<=30+ (#15098, #14150)
		// IE throws on elements created in popups
		// FF meanwhile throws on frame elements through "defaultView.getComputedStyle"
		if ( elem.ownerDocument.defaultView.opener ) {
			return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
		}

		return window.getComputedStyle( elem, null );
	};

	curCSS = function( elem, name, computed ) {
		var width, minWidth, maxWidth, ret,
			style = elem.style;

		computed = computed || getStyles( elem );

		// getPropertyValue is only needed for .css('filter') in IE9, see #12537
		ret = computed ? computed.getPropertyValue( name ) || computed[ name ] : undefined;

		if ( computed ) {

			if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
				ret = jQuery.style( elem, name );
			}

			// A tribute to the "awesome hack by Dean Edwards"
			// Chrome < 17 and Safari 5.0 uses "computed value" instead of "used value" for margin-right
			// Safari 5.1.7 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
			// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
			if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

				// Remember the original values
				width = style.width;
				minWidth = style.minWidth;
				maxWidth = style.maxWidth;

				// Put in the new values to get a computed value out
				style.minWidth = style.maxWidth = style.width = ret;
				ret = computed.width;

				// Revert the changed values
				style.width = width;
				style.minWidth = minWidth;
				style.maxWidth = maxWidth;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "";
	};
} else if ( document.documentElement.currentStyle ) {
	getStyles = function( elem ) {
		return elem.currentStyle;
	};

	curCSS = function( elem, name, computed ) {
		var left, rs, rsLeft, ret,
			style = elem.style;

		computed = computed || getStyles( elem );
		ret = computed ? computed[ name ] : undefined;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && style[ name ] ) {
			ret = style[ name ];
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		// but not position css attributes, as those are proportional to the parent element instead
		// and we can't measure the parent instead because it might trigger a "stacking dolls" problem
		if ( rnumnonpx.test( ret ) && !rposition.test( name ) ) {

			// Remember the original values
			left = style.left;
			rs = elem.runtimeStyle;
			rsLeft = rs && rs.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				rs.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				rs.left = rsLeft;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "" || "auto";
	};
}




function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			var condition = conditionFn();

			if ( condition == null ) {
				// The test was not ready at this point; screw the hook this time
				// but check again when needed next time.
				return;
			}

			if ( condition ) {
				// Hook not needed (or it's not possible to use it due to missing dependency),
				// remove it.
				// Since there are no other hooks for marginRight, remove the whole object.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.

			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	// Minified: var b,c,d,e,f,g, h,i
	var div, style, a, pixelPositionVal, boxSizingReliableVal,
		reliableHiddenOffsetsVal, reliableMarginRightVal;

	// Setup
	div = document.createElement( "div" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName( "a" )[ 0 ];
	style = a && a.style;

	// Finish early in limited (non-browser) environments
	if ( !style ) {
		return;
	}

	style.cssText = "float:left;opacity:.5";

	// Support: IE<9
	// Make sure that element opacity exists (as opposed to filter)
	support.opacity = style.opacity === "0.5";

	// Verify style float existence
	// (IE uses styleFloat instead of cssFloat)
	support.cssFloat = !!style.cssFloat;

	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	// Support: Firefox<29, Android 2.3
	// Vendor-prefix box-sizing
	support.boxSizing = style.boxSizing === "" || style.MozBoxSizing === "" ||
		style.WebkitBoxSizing === "";

	jQuery.extend(support, {
		reliableHiddenOffsets: function() {
			if ( reliableHiddenOffsetsVal == null ) {
				computeStyleTests();
			}
			return reliableHiddenOffsetsVal;
		},

		boxSizingReliable: function() {
			if ( boxSizingReliableVal == null ) {
				computeStyleTests();
			}
			return boxSizingReliableVal;
		},

		pixelPosition: function() {
			if ( pixelPositionVal == null ) {
				computeStyleTests();
			}
			return pixelPositionVal;
		},

		// Support: Android 2.3
		reliableMarginRight: function() {
			if ( reliableMarginRightVal == null ) {
				computeStyleTests();
			}
			return reliableMarginRightVal;
		}
	});

	function computeStyleTests() {
		// Minified: var b,c,d,j
		var div, body, container, contents;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";

		// Support: IE<9
		// Assume reasonable values in the absence of getComputedStyle
		pixelPositionVal = boxSizingReliableVal = false;
		reliableMarginRightVal = true;

		// Check for getComputedStyle so that this code is not run in IE<9.
		if ( window.getComputedStyle ) {
			pixelPositionVal = ( window.getComputedStyle( div, null ) || {} ).top !== "1%";
			boxSizingReliableVal =
				( window.getComputedStyle( div, null ) || { width: "4px" } ).width === "4px";

			// Support: Android 2.3
			// Div with explicit width and no margin-right incorrectly
			// gets computed margin-right based on width of container (#3333)
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			contents = div.appendChild( document.createElement( "div" ) );

			// Reset CSS: box-sizing; display; margin; border; padding
			contents.style.cssText = div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
			contents.style.marginRight = contents.style.width = "0";
			div.style.width = "1px";

			reliableMarginRightVal =
				!parseFloat( ( window.getComputedStyle( contents, null ) || {} ).marginRight );

			div.removeChild( contents );
		}

		// Support: IE8
		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		div.innerHTML = "<table><tr><td></td><td>t</td></tr></table>";
		contents = div.getElementsByTagName( "td" );
		contents[ 0 ].style.cssText = "margin:0;border:0;padding:0;display:none";
		reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		if ( reliableHiddenOffsetsVal ) {
			contents[ 0 ].style.display = "";
			contents[ 1 ].style.display = "none";
			reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		}

		body.removeChild( container );
	}

})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
		ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity\s*=\s*([^)]*)/,

	// swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// see here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];


// return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// check for vendor prefixed names
	var capName = name.charAt(0).toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = jQuery._data( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = jQuery._data( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display && display !== "none" || !hidden ) {
				jQuery._data( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// at this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// at this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// at this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// we need the check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox && ( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set. See: #7116
			if ( value == null || value !== value ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Fixes #8908, it can be done more correctly by specifing setters in cssHooks,
			// but it would mean to define eight (for every problematic property) identical functions
			if ( !support.clearCloneStyle && value === "" && name.indexOf("background") === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {

				// Support: IE
				// Swallow errors from 'invalid' CSS values (#5509)
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var num, val, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		//convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Return, converting to number if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				// certain elements can have dimension info if we invisibly show them
				// however, it must have a current display style that would benefit from this
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

if ( !support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( 0.01 * parseFloat( RegExp.$1 ) ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			// if value === "", then remove inline opacity #12685
			if ( ( value >= 1 || value === "" ) &&
					jQuery.trim( filter.replace( ralpha, "" ) ) === "" &&
					style.removeAttribute ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there is no filter style applied in a css rule or unset inline opacity, we are done
				if ( value === "" || currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			// Work around by temporarily setting element display to inline-block
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails
			// so, simple values such as "10px" are parsed to Float.
			// complex values such as "rotate(1rad)" are returned as is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// use step hook for back compat - use cssHook if its there - use .style if its
			// available and use plain properties where available
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE <=9
// Panic based approach to setting things on disconnected nodes

Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*
					// Use a string for doubling factor so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur()
				// And breaking the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		attrs = { height: type },
		i = 0;

	// if we include width, step value is 1 to do all cssExpand values,
	// if we don't include width, step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// we're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = jQuery._data( elem, "fxshow" );

	// handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// doing this makes sure that the complete handler will be called
			// before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE does not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			jQuery._data( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {

			// inline-level elements accept inline-block;
			// block-level elements need to be inline with layout
			if ( !support.inlineBlockNeedsLayout || defaultDisplay( elem.nodeName ) === "inline" ) {
				style.display = "inline-block";
			} else {
				style.zoom = 1;
			}
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		if ( !support.shrinkWrapBlocks() ) {
			anim.always(function() {
				style.overflow = opts.overflow[ 0 ];
				style.overflowX = opts.overflow[ 1 ];
				style.overflowY = opts.overflow[ 2 ];
			});
		}
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = jQuery._data( elem, "fxshow", {} );
		}

		// store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;
			jQuery._removeData( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// not quite $.extend, this wont overwrite keys already present.
			// also - reusing 'index' from above because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// archaic crash bug won't allow us to use 1 - ( 0.5 || 0 ) (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// if we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// resolve when we played the last frame
				// otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {
	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || jQuery._data( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = jQuery._data( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = jQuery._data( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// enable finishing flag on private data
			data.finish = true;

			// empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		timers = jQuery.timers,
		i = 0;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	// Minified: var a,b,c,d,e
	var input, div, select, a, opt;

	// Setup
	div = document.createElement( "div" );
	div.setAttribute( "className", "t" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName("a")[ 0 ];

	// First batch of tests.
	select = document.createElement("select");
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName("input")[ 0 ];

	a.style.cssText = "top:1px";

	// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
	support.getSetAttribute = div.className !== "t";

	// Get the style information from getAttribute
	// (IE uses .cssText instead)
	support.style = /top/.test( a.getAttribute("style") );

	// Make sure that URLs aren't manipulated
	// (IE normalizes it by default)
	support.hrefNormalized = a.getAttribute("href") === "/a";

	// Check the default checkbox/radio value ("" on WebKit; "on" elsewhere)
	support.checkOn = !!input.value;

	// Make sure that a selected-by-default option has a working selected property.
	// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
	support.optSelected = opt.selected;

	// Tests for enctype support on a form (#6743)
	support.enctype = !!document.createElement("form").enctype;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE8 only
	// Check if we can trust getAttribute("value")
	input = document.createElement( "input" );
	input.setAttribute( "value", "" );
	support.input = input.getAttribute( "value" ) === "";

	// Check if an input maintains its value after becoming a radio
	input.value = "t";
	input.setAttribute( "type", "radio" );
	support.radioValue = input.value === "t";
})();


var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// oldIE doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];

					if ( jQuery.inArray( jQuery.valHooks.option.get( option ), values ) >= 0 ) {

						// Support: IE6
						// When new option element is added to select box we need to
						// force reflow of newly added node in order to workaround delay
						// of initialization properties
						try {
							option.selected = optionSet = true;

						} catch ( _ ) {

							// Will be executed only in IE6
							option.scrollHeight;
						}

					} else {
						option.selected = false;
					}
				}

				// Force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}

				return options;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			// Support: Webkit
			// "" is returned instead of "on" if a value isn't specified
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle,
	ruseDefault = /^(?:checked|selected)$/i,
	getSetAttribute = support.getSetAttribute,
	getSetInput = support.input;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
						elem[ propName ] = false;
					// Support: IE<9
					// Also clear defaultChecked/defaultSelected (if appropriate)
					} else {
						elem[ jQuery.camelCase( "default-" + name ) ] =
							elem[ propName ] = false;
					}

				// See #9699 for explanation of this approach (setting first, then removal)
				} else {
					jQuery.attr( elem, name, "" );
				}

				elem.removeAttribute( getSetAttribute ? name : propName );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to default in case type is set after value during creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hook for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
			// IE<8 needs the *property* name
			elem.setAttribute( !getSetAttribute && jQuery.propFix[ name ] || name, name );

		// Use defaultChecked and defaultSelected for oldIE
		} else {
			elem[ jQuery.camelCase( "default-" + name ) ] = elem[ name ] = true;
		}

		return name;
	}
};

// Retrieve booleans specially
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {

	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = getSetInput && getSetAttribute || !ruseDefault.test( name ) ?
		function( elem, name, isXML ) {
			var ret, handle;
			if ( !isXML ) {
				// Avoid an infinite loop by temporarily removing this function from the getter
				handle = attrHandle[ name ];
				attrHandle[ name ] = ret;
				ret = getter( elem, name, isXML ) != null ?
					name.toLowerCase() :
					null;
				attrHandle[ name ] = handle;
			}
			return ret;
		} :
		function( elem, name, isXML ) {
			if ( !isXML ) {
				return elem[ jQuery.camelCase( "default-" + name ) ] ?
					name.toLowerCase() :
					null;
			}
		};
});

// fix oldIE attroperties
if ( !getSetInput || !getSetAttribute ) {
	jQuery.attrHooks.value = {
		set: function( elem, value, name ) {
			if ( jQuery.nodeName( elem, "input" ) ) {
				// Does not return so that setAttribute is also used
				elem.defaultValue = value;
			} else {
				// Use nodeHook if defined (#1954); otherwise setAttribute is fine
				return nodeHook && nodeHook.set( elem, value, name );
			}
		}
	};
}

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = {
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				elem.setAttributeNode(
					(ret = elem.ownerDocument.createAttribute( name ))
				);
			}

			ret.value = value += "";

			// Break association with cloned elements by also using setAttribute (#9646)
			if ( name === "value" || value === elem.getAttribute( name ) ) {
				return value;
			}
		}
	};

	// Some attributes are constructed with empty-string values when not defined
	attrHandle.id = attrHandle.name = attrHandle.coords =
		function( elem, name, isXML ) {
			var ret;
			if ( !isXML ) {
				return (ret = elem.getAttributeNode( name )) && ret.value !== "" ?
					ret.value :
					null;
			}
		};

	// Fixing value retrieval on a button requires this module
	jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret = elem.getAttributeNode( name );
			if ( ret && ret.specified ) {
				return ret.value;
			}
		},
		set: nodeHook.set
	};

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		set: function( elem, value, name ) {
			nodeHook.set( elem, value === "" ? false : value, name );
		}
	};

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		};
	});
}

if ( !support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Note: IE uppercases css property names, but if we were to .toLowerCase()
			// .cssText, that would destroy case senstitivity in URL's, like in "background"
			return elem.style.cssText || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = value + "" );
		}
	};
}




var rfocusable = /^(?:input|select|textarea|button|object)$/i,
	rclickable = /^(?:a|area)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				// Use proper attribute retrieval(#12072)
				var tabindex = jQuery.find.attr( elem, "tabindex" );

				return tabindex ?
					parseInt( tabindex, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						-1;
			}
		}
	}
});

// Some attributes require a special call on IE
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !support.hrefNormalized ) {
	// href/src property should get the full normalized URL (#10299/#12915)
	jQuery.each([ "href", "src" ], function( i, name ) {
		jQuery.propHooks[ name ] = {
			get: function( elem ) {
				return elem.getAttribute( name, 4 );
			}
		};
	});
}

// Support: Safari, IE9+
// mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});

// IE6/7 call enctype encoding
if ( !support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = arguments.length === 0 || typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed "false",
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



var rvalidtokens = /(,)|(\[|{)|(}|])|"(?:[^"\\\r\n]|\\["\\\/bfnrt]|\\u[\da-fA-F]{4})*"\s*:?|true|false|null|-?(?!0\d)\d+(?:\.\d+|)(?:[eE][+-]?\d+|)/g;

jQuery.parseJSON = function( data ) {
	// Attempt to parse using the native JSON parser first
	if ( window.JSON && window.JSON.parse ) {
		// Support: Android 2.3
		// Workaround failure to string-cast null input
		return window.JSON.parse( data + "" );
	}

	var requireNonComma,
		depth = null,
		str = jQuery.trim( data + "" );

	// Guard against invalid (and possibly dangerous) input by ensuring that nothing remains
	// after removing valid tokens
	return str && !jQuery.trim( str.replace( rvalidtokens, function( token, comma, open, close ) {

		// Force termination if we see a misplaced comma
		if ( requireNonComma && comma ) {
			depth = 0;
		}

		// Perform no more replacements after returning to outermost depth
		if ( depth === 0 ) {
			return token;
		}

		// Commas must not follow "[", "{", or ","
		requireNonComma = open || comma;

		// Determine new depth
		// array/object open ("[" or "{"): depth += true - false (increment)
		// array/object close ("]" or "}"): depth += false - true (decrement)
		// other cases ("," or primitive): depth += true - true (numeric cast)
		depth += !close - !open;

		// Remove this token
		return "";
	}) ) ?
		( Function( "return " + str ) )() :
		jQuery.error( "Invalid JSON: " + data );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	try {
		if ( window.DOMParser ) { // Standard
			tmp = new DOMParser();
			xml = tmp.parseFromString( data, "text/xml" );
		} else { // IE
			xml = new ActiveXObject( "Microsoft.XMLDOM" );
			xml.async = "false";
			xml.loadXML( data );
		}
	} catch( e ) {
		xml = undefined;
	}
	if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	// Document location
	ajaxLocParts,
	ajaxLocation,

	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat("*");

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType.charAt( 0 ) === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var deep, key,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {
	var firstDataType, ct, finalDataType, type,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

			// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Cross-domain detection vars
			parts,
			// Loop variable
			i,
			// URL without anti-cache param
			cacheURL,
			// Response headers as string
			responseHeadersString,
			// timeout handle
			timeoutTimer,

			// To know if global events are to be dispatched
			fireGlobals,

			transport,
			// Response headers
			responseHeaders,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		// Don't fire events if jQuery.event is undefined in an AMD-usage scenario (#15118)
		fireGlobals = jQuery.event && s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0 ||
		(!support.reliableHiddenOffsets() &&
			((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
};

jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;
			// Use .is(":disabled") so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject !== undefined ?
	// Support: IE6+
	function() {

		// XHR cannot access local files, always use ActiveX for that case
		return !this.isLocal &&

			// Support: IE7-8
			// oldIE XHR does not support non-RFC2616 methods (#13240)
			// See http://msdn.microsoft.com/en-us/library/ie/ms536648(v=vs.85).aspx
			// and http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html#sec9
			// Although this check for six methods instead of eight
			// since IE also does not support "trace" and "connect"
			/^(get|post|head|put|delete|options)$/i.test( this.type ) &&

			createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

var xhrId = 0,
	xhrCallbacks = {},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE<10
// Open requests must be manually aborted on unload (#5280)
// See https://support.microsoft.com/kb/2856746 for more info
if ( window.attachEvent ) {
	window.attachEvent( "onunload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]( undefined, true );
		}
	});
}

// Determine support properties
support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
xhrSupported = support.ajax = !!xhrSupported;

// Create transport if the browser can provide an xhr
if ( xhrSupported ) {

	jQuery.ajaxTransport(function( options ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !options.crossDomain || support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {
					var i,
						xhr = options.xhr(),
						id = ++xhrId;

					// Open the socket
					xhr.open( options.type, options.url, options.async, options.username, options.password );

					// Apply custom fields if provided
					if ( options.xhrFields ) {
						for ( i in options.xhrFields ) {
							xhr[ i ] = options.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( options.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( options.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !options.crossDomain && !headers["X-Requested-With"] ) {
						headers["X-Requested-With"] = "XMLHttpRequest";
					}

					// Set headers
					for ( i in headers ) {
						// Support: IE<9
						// IE's ActiveXObject throws a 'Type Mismatch' exception when setting
						// request header to a null-value.
						//
						// To keep consistent with other XHR implementations, cast the value
						// to string and ignore `undefined`.
						if ( headers[ i ] !== undefined ) {
							xhr.setRequestHeader( i, headers[ i ] + "" );
						}
					}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( options.hasContent && options.data ) || null );

					// Listener
					callback = function( _, isAbort ) {
						var status, statusText, responses;

						// Was never called and is aborted or complete
						if ( callback && ( isAbort || xhr.readyState === 4 ) ) {
							// Clean up
							delete xhrCallbacks[ id ];
							callback = undefined;
							xhr.onreadystatechange = jQuery.noop;

							// Abort manually if needed
							if ( isAbort ) {
								if ( xhr.readyState !== 4 ) {
									xhr.abort();
								}
							} else {
								responses = {};
								status = xhr.status;

								// Support: IE<10
								// Accessing binary-data responseText throws an exception
								// (#11426)
								if ( typeof xhr.responseText === "string" ) {
									responses.text = xhr.responseText;
								}

								// Firefox throws an exception when accessing
								// statusText for faulty cross-domain requests
								try {
									statusText = xhr.statusText;
								} catch( e ) {
									// We normalize with Webkit giving an empty statusText
									statusText = "";
								}

								// Filter status for non standard behaviors

								// If the request is local and we have data: assume a success
								// (success with no data won't get notified, that's the best we
								// can do given current implementations)
								if ( !status && options.isLocal && !options.crossDomain ) {
									status = responses.text ? 200 : 404;
								// IE - #1450: sometimes returns 1223 when it should be 204
								} else if ( status === 1223 ) {
									status = 204;
								}
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, xhr.getAllResponseHeaders() );
						}
					};

					if ( !options.async ) {
						// if we're in sync mode we fire the callback
						callback();
					} else if ( xhr.readyState === 4 ) {
						// (IE6 & IE7) if it's in cache and has been
						// retrieved directly we need to fire the callback
						setTimeout( callback );
					} else {
						// Add to the list of active xhr callbacks
						xhr.onreadystatechange = xhrCallbacks[ id ] = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback( undefined, true );
					}
				}
			};
		}
	});
}

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject( "Microsoft.XMLHTTP" );
	} catch( e ) {}
}




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || jQuery("head")[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement("script");

				script.async = true;

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( script.parentNode ) {
							script.parentNode.removeChild( script );
						}

						// Dereference the script
						script = null;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};

				// Circumvent IE6 bugs with base elements (#2709 and #4378) by prepending
				// Use native DOM manipulation to avoid our domManip AJAX trickery
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( undefined, true );
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, response, type,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off, url.length ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};





var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			jQuery.inArray("auto", [ curCSSTop, curCSSLeft ] ) > -1;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			box = { top: 0, left: 0 },
			elem = this[ 0 ],
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// If we don't have gBCR, just use 0,0 rather than error
		// BlackBerry 5, iOS 3 (original iPhone)
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top  + ( win.pageYOffset || docElem.scrollTop )  - ( docElem.clientTop  || 0 ),
			left: box.left + ( win.pageXOffset || docElem.scrollLeft ) - ( docElem.clientLeft || 0 )
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			parentOffset = { top: 0, left: 0 },
			elem = this[ 0 ];

		// fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// we assume that getBoundingClientRect is available when computed position is fixed
			offset = elem.getBoundingClientRect();
		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top  += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		return {
			top:  offset.top  - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true)
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					win.document.documentElement[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// getComputedStyle returns percent when specified for top/left/bottom/right
// rather than make the css module depend on the offset module, we just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// if curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height], whichever is greatest
					// unfortunately, this causes bug #3838 in IE6/8 only, but there is currently no good, small way to fix it.
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in
// AMD (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));

//     Underscore.js 1.8.3
//     http://underscorejs.org
//     (c) 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
//     Underscore may be freely distributed under the MIT license.

(function() {

  // Baseline setup
  // --------------

  // Establish the root object, `window` (`self`) in the browser, or `global` on the server.
  // We use `self` instead of `window` for `WebWorker` support.
  var root = typeof self === 'object' && self.self === self && self ||
            typeof global === 'object' && global.global === global && global;

  // Save the previous value of the `_` variable.
  var previousUnderscore = root._;

  // Save bytes in the minified (but not gzipped) version:
  var ArrayProto = Array.prototype, ObjProto = Object.prototype;

  // Create quick reference variables for speed access to core prototypes.
  var
    push = ArrayProto.push,
    slice = ArrayProto.slice,
    toString = ObjProto.toString,
    hasOwnProperty = ObjProto.hasOwnProperty;

  // All **ECMAScript 5** native function implementations that we hope to use
  // are declared here.
  var
    nativeIsArray = Array.isArray,
    nativeKeys = Object.keys,
    nativeCreate = Object.create;

  // Naked function reference for surrogate-prototype-swapping.
  var Ctor = function(){};

  // Create a safe reference to the Underscore object for use below.
  var _ = function(obj) {
    if (obj instanceof _) return obj;
    if (!(this instanceof _)) return new _(obj);
    this._wrapped = obj;
  };

  // Export the Underscore object for **Node.js**, with
  // backwards-compatibility for their old module API. If we're in
  // the browser, add `_` as a global object.
  if (typeof exports !== 'undefined') {
    if (typeof module !== 'undefined' && module.exports) {
      exports = module.exports = _;
    }
    exports._ = _;
  } else {
    root._ = _;
  }

  // Current version.
  _.VERSION = '1.8.3';

  // Internal function that returns an efficient (for current engines) version
  // of the passed-in callback, to be repeatedly applied in other Underscore
  // functions.
  var optimizeCb = function(func, context, argCount) {
    if (context === void 0) return func;
    switch (argCount == null ? 3 : argCount) {
      case 1: return function(value) {
        return func.call(context, value);
      };
      case 2: return function(value, other) {
        return func.call(context, value, other);
      };
      case 3: return function(value, index, collection) {
        return func.call(context, value, index, collection);
      };
      case 4: return function(accumulator, value, index, collection) {
        return func.call(context, accumulator, value, index, collection);
      };
    }
    return function() {
      return func.apply(context, arguments);
    };
  };

  // A mostly-internal function to generate callbacks that can be applied
  // to each element in a collection, returning the desired result — either
  // identity, an arbitrary callback, a property matcher, or a property accessor.
  var cb = function(value, context, argCount) {
    if (value == null) return _.identity;
    if (_.isFunction(value)) return optimizeCb(value, context, argCount);
    if (_.isObject(value)) return _.matcher(value);
    return _.property(value);
  };
  _.iteratee = function(value, context) {
    return cb(value, context, Infinity);
  };

  // Similar to ES6's rest param (http://ariya.ofilabs.com/2013/03/es6-and-rest-parameter.html)
  // This accumulates the arguments passed into an array, after a given index.
  var restArgs = function(func, startIndex) {
    startIndex = startIndex == null ? func.length - 1 : +startIndex;
    return function() {
      var length = Math.max(arguments.length - startIndex, 0);
      var rest = Array(length);
      var index;
      for (index = 0; index < length; index++) {
        rest[index] = arguments[index + startIndex];
      }
      switch (startIndex) {
        case 0: return func.call(this, rest);
        case 1: return func.call(this, arguments[0], rest);
        case 2: return func.call(this, arguments[0], arguments[1], rest);
      }
      var args = Array(startIndex + 1);
      for (index = 0; index < startIndex; index++) {
        args[index] = arguments[index];
      }
      args[startIndex] = rest;
      return func.apply(this, args);
    };
  };

  // An internal function for creating a new object that inherits from another.
  var baseCreate = function(prototype) {
    if (!_.isObject(prototype)) return {};
    if (nativeCreate) return nativeCreate(prototype);
    Ctor.prototype = prototype;
    var result = new Ctor;
    Ctor.prototype = null;
    return result;
  };

  var property = function(key) {
    return function(obj) {
      return obj == null ? void 0 : obj[key];
    };
  };

  // Helper for collection methods to determine whether a collection
  // should be iterated as an array or as an object
  // Related: http://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength
  // Avoids a very nasty iOS 8 JIT bug on ARM-64. #2094
  var MAX_ARRAY_INDEX = Math.pow(2, 53) - 1;
  var getLength = property('length');
  var isArrayLike = function(collection) {
    var length = getLength(collection);
    return typeof length == 'number' && length >= 0 && length <= MAX_ARRAY_INDEX;
  };

  // Collection Functions
  // --------------------

  // The cornerstone, an `each` implementation, aka `forEach`.
  // Handles raw objects in addition to array-likes. Treats all
  // sparse array-likes as if they were dense.
  _.each = _.forEach = function(obj, iteratee, context) {
    iteratee = optimizeCb(iteratee, context);
    var i, length;
    if (isArrayLike(obj)) {
      for (i = 0, length = obj.length; i < length; i++) {
        iteratee(obj[i], i, obj);
      }
    } else {
      var keys = _.keys(obj);
      for (i = 0, length = keys.length; i < length; i++) {
        iteratee(obj[keys[i]], keys[i], obj);
      }
    }
    return obj;
  };

  // Return the results of applying the iteratee to each element.
  _.map = _.collect = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length,
        results = Array(length);
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      results[index] = iteratee(obj[currentKey], currentKey, obj);
    }
    return results;
  };

  // Create a reducing function iterating left or right.
  var createReduce = function(dir) {
    // Optimized iterator function as using arguments.length
    // in the main function will deoptimize the, see #1991.
    var reducer = function(obj, iteratee, memo, initial) {
      var keys = !isArrayLike(obj) && _.keys(obj),
          length = (keys || obj).length,
          index = dir > 0 ? 0 : length - 1;
      if (!initial) {
        memo = obj[keys ? keys[index] : index];
        index += dir;
      }
      for (; index >= 0 && index < length; index += dir) {
        var currentKey = keys ? keys[index] : index;
        memo = iteratee(memo, obj[currentKey], currentKey, obj);
      }
      return memo;
    };

    return function(obj, iteratee, memo, context) {
      var initial = arguments.length >= 3;
      return reducer(obj, optimizeCb(iteratee, context, 4), memo, initial);
    };
  };

  // **Reduce** builds up a single result from a list of values, aka `inject`,
  // or `foldl`.
  _.reduce = _.foldl = _.inject = createReduce(1);

  // The right-associative version of reduce, also known as `foldr`.
  _.reduceRight = _.foldr = createReduce(-1);

  // Return the first value which passes a truth test. Aliased as `detect`.
  _.find = _.detect = function(obj, predicate, context) {
    var key;
    if (isArrayLike(obj)) {
      key = _.findIndex(obj, predicate, context);
    } else {
      key = _.findKey(obj, predicate, context);
    }
    if (key !== void 0 && key !== -1) return obj[key];
  };

  // Return all the elements that pass a truth test.
  // Aliased as `select`.
  _.filter = _.select = function(obj, predicate, context) {
    var results = [];
    predicate = cb(predicate, context);
    _.each(obj, function(value, index, list) {
      if (predicate(value, index, list)) results.push(value);
    });
    return results;
  };

  // Return all the elements for which a truth test fails.
  _.reject = function(obj, predicate, context) {
    return _.filter(obj, _.negate(cb(predicate)), context);
  };

  // Determine whether all of the elements match a truth test.
  // Aliased as `all`.
  _.every = _.all = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length;
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      if (!predicate(obj[currentKey], currentKey, obj)) return false;
    }
    return true;
  };

  // Determine if at least one element in the object matches a truth test.
  // Aliased as `any`.
  _.some = _.any = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = !isArrayLike(obj) && _.keys(obj),
        length = (keys || obj).length;
    for (var index = 0; index < length; index++) {
      var currentKey = keys ? keys[index] : index;
      if (predicate(obj[currentKey], currentKey, obj)) return true;
    }
    return false;
  };

  // Determine if the array or object contains a given item (using `===`).
  // Aliased as `includes` and `include`.
  _.contains = _.includes = _.include = function(obj, item, fromIndex, guard) {
    if (!isArrayLike(obj)) obj = _.values(obj);
    if (typeof fromIndex != 'number' || guard) fromIndex = 0;
    return _.indexOf(obj, item, fromIndex) >= 0;
  };

  // Invoke a method (with arguments) on every item in a collection.
  _.invoke = restArgs(function(obj, method, args) {
    var isFunc = _.isFunction(method);
    return _.map(obj, function(value) {
      var func = isFunc ? method : value[method];
      return func == null ? func : func.apply(value, args);
    });
  });

  // Convenience version of a common use case of `map`: fetching a property.
  _.pluck = function(obj, key) {
    return _.map(obj, _.property(key));
  };

  // Convenience version of a common use case of `filter`: selecting only objects
  // containing specific `key:value` pairs.
  _.where = function(obj, attrs) {
    return _.filter(obj, _.matcher(attrs));
  };

  // Convenience version of a common use case of `find`: getting the first object
  // containing specific `key:value` pairs.
  _.findWhere = function(obj, attrs) {
    return _.find(obj, _.matcher(attrs));
  };

  // Return the maximum element (or element-based computation).
  _.max = function(obj, iteratee, context) {
    var result = -Infinity, lastComputed = -Infinity,
        value, computed;
    if (iteratee == null && obj != null) {
      obj = isArrayLike(obj) ? obj : _.values(obj);
      for (var i = 0, length = obj.length; i < length; i++) {
        value = obj[i];
        if (value > result) {
          result = value;
        }
      }
    } else {
      iteratee = cb(iteratee, context);
      _.each(obj, function(v, index, list) {
        computed = iteratee(v, index, list);
        if (computed > lastComputed || computed === -Infinity && result === -Infinity) {
          result = v;
          lastComputed = computed;
        }
      });
    }
    return result;
  };

  // Return the minimum element (or element-based computation).
  _.min = function(obj, iteratee, context) {
    var result = Infinity, lastComputed = Infinity,
        value, computed;
    if (iteratee == null && obj != null) {
      obj = isArrayLike(obj) ? obj : _.values(obj);
      for (var i = 0, length = obj.length; i < length; i++) {
        value = obj[i];
        if (value < result) {
          result = value;
        }
      }
    } else {
      iteratee = cb(iteratee, context);
      _.each(obj, function(v, index, list) {
        computed = iteratee(v, index, list);
        if (computed < lastComputed || computed === Infinity && result === Infinity) {
          result = v;
          lastComputed = computed;
        }
      });
    }
    return result;
  };

  // Shuffle a collection.
  _.shuffle = function(obj) {
    return _.sample(obj, Infinity);
  };

  // Sample **n** random values from a collection using the modern version of the
  // [Fisher-Yates shuffle](http://en.wikipedia.org/wiki/Fisher–Yates_shuffle).
  // If **n** is not specified, returns a single random element.
  // The internal `guard` argument allows it to work with `map`.
  _.sample = function(obj, n, guard) {
    if (n == null || guard) {
      if (!isArrayLike(obj)) obj = _.values(obj);
      return obj[_.random(obj.length - 1)];
    }
    var sample = isArrayLike(obj) ? _.clone(obj) : _.values(obj);
    var length = getLength(sample);
    n = Math.max(Math.min(n, length), 0);
    var last = length - 1;
    for (var index = 0; index < n; index++) {
      var rand = _.random(index, last);
      var temp = sample[index];
      sample[index] = sample[rand];
      sample[rand] = temp;
    }
    return sample.slice(0, n);
  };

  // Sort the object's values by a criterion produced by an iteratee.
  _.sortBy = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    return _.pluck(_.map(obj, function(value, index, list) {
      return {
        value: value,
        index: index,
        criteria: iteratee(value, index, list)
      };
    }).sort(function(left, right) {
      var a = left.criteria;
      var b = right.criteria;
      if (a !== b) {
        if (a > b || a === void 0) return 1;
        if (a < b || b === void 0) return -1;
      }
      return left.index - right.index;
    }), 'value');
  };

  // An internal function used for aggregate "group by" operations.
  var group = function(behavior, partition) {
    return function(obj, iteratee, context) {
      var result = partition ? [[], []] : {};
      iteratee = cb(iteratee, context);
      _.each(obj, function(value, index) {
        var key = iteratee(value, index, obj);
        behavior(result, value, key);
      });
      return result;
    };
  };

  // Groups the object's values by a criterion. Pass either a string attribute
  // to group by, or a function that returns the criterion.
  _.groupBy = group(function(result, value, key) {
    if (_.has(result, key)) result[key].push(value); else result[key] = [value];
  });

  // Indexes the object's values by a criterion, similar to `groupBy`, but for
  // when you know that your index values will be unique.
  _.indexBy = group(function(result, value, key) {
    result[key] = value;
  });

  // Counts instances of an object that group by a certain criterion. Pass
  // either a string attribute to count by, or a function that returns the
  // criterion.
  _.countBy = group(function(result, value, key) {
    if (_.has(result, key)) result[key]++; else result[key] = 1;
  });

  // Safely create a real, live array from anything iterable.
  _.toArray = function(obj) {
    if (!obj) return [];
    if (_.isArray(obj)) return slice.call(obj);
    if (isArrayLike(obj)) return _.map(obj, _.identity);
    return _.values(obj);
  };

  // Return the number of elements in an object.
  _.size = function(obj) {
    if (obj == null) return 0;
    return isArrayLike(obj) ? obj.length : _.keys(obj).length;
  };

  // Split a collection into two arrays: one whose elements all satisfy the given
  // predicate, and one whose elements all do not satisfy the predicate.
  _.partition = group(function(result, value, pass) {
    result[pass ? 0 : 1].push(value);
  }, true);

  // Array Functions
  // ---------------

  // Get the first element of an array. Passing **n** will return the first N
  // values in the array. Aliased as `head` and `take`. The **guard** check
  // allows it to work with `_.map`.
  _.first = _.head = _.take = function(array, n, guard) {
    if (array == null) return void 0;
    if (n == null || guard) return array[0];
    return _.initial(array, array.length - n);
  };

  // Returns everything but the last entry of the array. Especially useful on
  // the arguments object. Passing **n** will return all the values in
  // the array, excluding the last N.
  _.initial = function(array, n, guard) {
    return slice.call(array, 0, Math.max(0, array.length - (n == null || guard ? 1 : n)));
  };

  // Get the last element of an array. Passing **n** will return the last N
  // values in the array.
  _.last = function(array, n, guard) {
    if (array == null) return void 0;
    if (n == null || guard) return array[array.length - 1];
    return _.rest(array, Math.max(0, array.length - n));
  };

  // Returns everything but the first entry of the array. Aliased as `tail` and `drop`.
  // Especially useful on the arguments object. Passing an **n** will return
  // the rest N values in the array.
  _.rest = _.tail = _.drop = function(array, n, guard) {
    return slice.call(array, n == null || guard ? 1 : n);
  };

  // Trim out all falsy values from an array.
  _.compact = function(array) {
    return _.filter(array, _.identity);
  };

  // Internal implementation of a recursive `flatten` function.
  var flatten = function(input, shallow, strict, output) {
    output = output || [];
    var idx = output.length;
    for (var i = 0, length = getLength(input); i < length; i++) {
      var value = input[i];
      if (isArrayLike(value) && (_.isArray(value) || _.isArguments(value))) {
        //flatten current level of array or arguments object
        if (shallow) {
          var j = 0, len = value.length;
          while (j < len) output[idx++] = value[j++];
        } else {
          flatten(value, shallow, strict, output);
          idx = output.length;
        }
      } else if (!strict) {
        output[idx++] = value;
      }
    }
    return output;
  };

  // Flatten out an array, either recursively (by default), or just one level.
  _.flatten = function(array, shallow) {
    return flatten(array, shallow, false);
  };

  // Return a version of the array that does not contain the specified value(s).
  _.without = restArgs(function(array, otherArrays) {
    return _.difference(array, otherArrays);
  });

  // Produce a duplicate-free version of the array. If the array has already
  // been sorted, you have the option of using a faster algorithm.
  // Aliased as `unique`.
  _.uniq = _.unique = function(array, isSorted, iteratee, context) {
    if (!_.isBoolean(isSorted)) {
      context = iteratee;
      iteratee = isSorted;
      isSorted = false;
    }
    if (iteratee != null) iteratee = cb(iteratee, context);
    var result = [];
    var seen = [];
    for (var i = 0, length = getLength(array); i < length; i++) {
      var value = array[i],
          computed = iteratee ? iteratee(value, i, array) : value;
      if (isSorted) {
        if (!i || seen !== computed) result.push(value);
        seen = computed;
      } else if (iteratee) {
        if (!_.contains(seen, computed)) {
          seen.push(computed);
          result.push(value);
        }
      } else if (!_.contains(result, value)) {
        result.push(value);
      }
    }
    return result;
  };

  // Produce an array that contains the union: each distinct element from all of
  // the passed-in arrays.
  _.union = restArgs(function(arrays) {
    return _.uniq(flatten(arrays, true, true));
  });

  // Produce an array that contains every item shared between all the
  // passed-in arrays.
  _.intersection = function(array) {
    var result = [];
    var argsLength = arguments.length;
    for (var i = 0, length = getLength(array); i < length; i++) {
      var item = array[i];
      if (_.contains(result, item)) continue;
      var j;
      for (j = 1; j < argsLength; j++) {
        if (!_.contains(arguments[j], item)) break;
      }
      if (j === argsLength) result.push(item);
    }
    return result;
  };

  // Take the difference between one array and a number of other arrays.
  // Only the elements present in just the first array will remain.
  _.difference = restArgs(function(array, rest) {
    rest = flatten(rest, true, true);
    return _.filter(array, function(value){
      return !_.contains(rest, value);
    });
  });

  // Complement of _.zip. Unzip accepts an array of arrays and groups
  // each array's elements on shared indices
  _.unzip = function(array) {
    var length = array && _.max(array, getLength).length || 0;
    var result = Array(length);

    for (var index = 0; index < length; index++) {
      result[index] = _.pluck(array, index);
    }
    return result;
  };

  // Zip together multiple lists into a single array -- elements that share
  // an index go together.
  _.zip = restArgs(_.unzip);

  // Converts lists into objects. Pass either a single array of `[key, value]`
  // pairs, or two parallel arrays of the same length -- one of keys, and one of
  // the corresponding values.
  _.object = function(list, values) {
    var result = {};
    for (var i = 0, length = getLength(list); i < length; i++) {
      if (values) {
        result[list[i]] = values[i];
      } else {
        result[list[i][0]] = list[i][1];
      }
    }
    return result;
  };

  // Generator function to create the findIndex and findLastIndex functions
  var createPredicateIndexFinder = function(dir) {
    return function(array, predicate, context) {
      predicate = cb(predicate, context);
      var length = getLength(array);
      var index = dir > 0 ? 0 : length - 1;
      for (; index >= 0 && index < length; index += dir) {
        if (predicate(array[index], index, array)) return index;
      }
      return -1;
    };
  };

  // Returns the first index on an array-like that passes a predicate test
  _.findIndex = createPredicateIndexFinder(1);
  _.findLastIndex = createPredicateIndexFinder(-1);

  // Use a comparator function to figure out the smallest index at which
  // an object should be inserted so as to maintain order. Uses binary search.
  _.sortedIndex = function(array, obj, iteratee, context) {
    iteratee = cb(iteratee, context, 1);
    var value = iteratee(obj);
    var low = 0, high = getLength(array);
    while (low < high) {
      var mid = Math.floor((low + high) / 2);
      if (iteratee(array[mid]) < value) low = mid + 1; else high = mid;
    }
    return low;
  };

  // Generator function to create the indexOf and lastIndexOf functions
  var createIndexFinder = function(dir, predicateFind, sortedIndex) {
    return function(array, item, idx) {
      var i = 0, length = getLength(array);
      if (typeof idx == 'number') {
        if (dir > 0) {
          i = idx >= 0 ? idx : Math.max(idx + length, i);
        } else {
          length = idx >= 0 ? Math.min(idx + 1, length) : idx + length + 1;
        }
      } else if (sortedIndex && idx && length) {
        idx = sortedIndex(array, item);
        return array[idx] === item ? idx : -1;
      }
      if (item !== item) {
        idx = predicateFind(slice.call(array, i, length), _.isNaN);
        return idx >= 0 ? idx + i : -1;
      }
      for (idx = dir > 0 ? i : length - 1; idx >= 0 && idx < length; idx += dir) {
        if (array[idx] === item) return idx;
      }
      return -1;
    };
  };

  // Return the position of the first occurrence of an item in an array,
  // or -1 if the item is not included in the array.
  // If the array is large and already in sort order, pass `true`
  // for **isSorted** to use binary search.
  _.indexOf = createIndexFinder(1, _.findIndex, _.sortedIndex);
  _.lastIndexOf = createIndexFinder(-1, _.findLastIndex);

  // Generate an integer Array containing an arithmetic progression. A port of
  // the native Python `range()` function. See
  // [the Python documentation](http://docs.python.org/library/functions.html#range).
  _.range = function(start, stop, step) {
    if (stop == null) {
      stop = start || 0;
      start = 0;
    }
    step = step || 1;

    var length = Math.max(Math.ceil((stop - start) / step), 0);
    var range = Array(length);

    for (var idx = 0; idx < length; idx++, start += step) {
      range[idx] = start;
    }

    return range;
  };

  // Function (ahem) Functions
  // ------------------

  // Determines whether to execute a function as a constructor
  // or a normal function with the provided arguments
  var executeBound = function(sourceFunc, boundFunc, context, callingContext, args) {
    if (!(callingContext instanceof boundFunc)) return sourceFunc.apply(context, args);
    var self = baseCreate(sourceFunc.prototype);
    var result = sourceFunc.apply(self, args);
    if (_.isObject(result)) return result;
    return self;
  };

  // Create a function bound to a given object (assigning `this`, and arguments,
  // optionally). Delegates to **ECMAScript 5**'s native `Function.bind` if
  // available.
  _.bind = restArgs(function(func, context, args) {
    if (!_.isFunction(func)) throw new TypeError('Bind must be called on a function');
    var bound = restArgs(function(callArgs) {
      return executeBound(func, bound, context, this, args.concat(callArgs));
    });
    return bound;
  });

  // Partially apply a function by creating a version that has had some of its
  // arguments pre-filled, without changing its dynamic `this` context. _ acts
  // as a placeholder by default, allowing any combination of arguments to be
  // pre-filled. Set `_.partial.placeholder` for a custom placeholder argument.
  _.partial = restArgs(function(func, boundArgs) {
    var placeholder = _.partial.placeholder;
    var bound = function() {
      var position = 0, length = boundArgs.length;
      var args = Array(length);
      for (var i = 0; i < length; i++) {
        args[i] = boundArgs[i] === placeholder ? arguments[position++] : boundArgs[i];
      }
      while (position < arguments.length) args.push(arguments[position++]);
      return executeBound(func, bound, this, this, args);
    };
    return bound;
  });

  _.partial.placeholder = _;

  // Bind a number of an object's methods to that object. Remaining arguments
  // are the method names to be bound. Useful for ensuring that all callbacks
  // defined on an object belong to it.
  _.bindAll = restArgs(function(obj, keys) {
    keys = flatten(keys, false, false);
    var index = keys.length;
    if (index < 1) throw new Error('bindAll must be passed function names');
    while (index--) {
      var key = keys[index];
      obj[key] = _.bind(obj[key], obj);
    }
  });

  // Memoize an expensive function by storing its results.
  _.memoize = function(func, hasher) {
    var memoize = function(key) {
      var cache = memoize.cache;
      var address = '' + (hasher ? hasher.apply(this, arguments) : key);
      if (!_.has(cache, address)) cache[address] = func.apply(this, arguments);
      return cache[address];
    };
    memoize.cache = {};
    return memoize;
  };

  // Delays a function for the given number of milliseconds, and then calls
  // it with the arguments supplied.
  _.delay = restArgs(function(func, wait, args) {
    return setTimeout(function(){
      return func.apply(null, args);
    }, wait);
  });

  // Defers a function, scheduling it to run after the current call stack has
  // cleared.
  _.defer = _.partial(_.delay, _, 1);

  // Returns a function, that, when invoked, will only be triggered at most once
  // during a given window of time. Normally, the throttled function will run
  // as much as it can, without ever going more than once per `wait` duration;
  // but if you'd like to disable the execution on the leading edge, pass
  // `{leading: false}`. To disable execution on the trailing edge, ditto.
  _.throttle = function(func, wait, options) {
    var context, args, result;
    var timeout = null;
    var previous = 0;
    if (!options) options = {};
    var later = function() {
      previous = options.leading === false ? 0 : _.now();
      timeout = null;
      result = func.apply(context, args);
      if (!timeout) context = args = null;
    };
    return function() {
      var now = _.now();
      if (!previous && options.leading === false) previous = now;
      var remaining = wait - (now - previous);
      context = this;
      args = arguments;
      if (remaining <= 0 || remaining > wait) {
        if (timeout) {
          clearTimeout(timeout);
          timeout = null;
        }
        previous = now;
        result = func.apply(context, args);
        if (!timeout) context = args = null;
      } else if (!timeout && options.trailing !== false) {
        timeout = setTimeout(later, remaining);
      }
      return result;
    };
  };

  // Returns a function, that, as long as it continues to be invoked, will not
  // be triggered. The function will be called after it stops being called for
  // N milliseconds. If `immediate` is passed, trigger the function on the
  // leading edge, instead of the trailing.
  _.debounce = function(func, wait, immediate) {
    var timeout, args, context, timestamp, result;

    var later = function() {
      var last = _.now() - timestamp;

      if (last < wait && last >= 0) {
        timeout = setTimeout(later, wait - last);
      } else {
        timeout = null;
        if (!immediate) {
          result = func.apply(context, args);
          if (!timeout) context = args = null;
        }
      }
    };

    return function() {
      context = this;
      args = arguments;
      timestamp = _.now();
      var callNow = immediate && !timeout;
      if (!timeout) timeout = setTimeout(later, wait);
      if (callNow) {
        result = func.apply(context, args);
        context = args = null;
      }

      return result;
    };
  };

  // Returns the first function passed as an argument to the second,
  // allowing you to adjust arguments, run code before and after, and
  // conditionally execute the original function.
  _.wrap = function(func, wrapper) {
    return _.partial(wrapper, func);
  };

  // Returns a negated version of the passed-in predicate.
  _.negate = function(predicate) {
    return function() {
      return !predicate.apply(this, arguments);
    };
  };

  // Returns a function that is the composition of a list of functions, each
  // consuming the return value of the function that follows.
  _.compose = function() {
    var args = arguments;
    var start = args.length - 1;
    return function() {
      var i = start;
      var result = args[start].apply(this, arguments);
      while (i--) result = args[i].call(this, result);
      return result;
    };
  };

  // Returns a function that will only be executed on and after the Nth call.
  _.after = function(times, func) {
    return function() {
      if (--times < 1) {
        return func.apply(this, arguments);
      }
    };
  };

  // Returns a function that will only be executed up to (but not including) the Nth call.
  _.before = function(times, func) {
    var memo;
    return function() {
      if (--times > 0) {
        memo = func.apply(this, arguments);
      }
      if (times <= 1) func = null;
      return memo;
    };
  };

  // Returns a function that will be executed at most one time, no matter how
  // often you call it. Useful for lazy initialization.
  _.once = _.partial(_.before, 2);

  _.restArgs = restArgs;

  // Object Functions
  // ----------------

  // Keys in IE < 9 that won't be iterated by `for key in ...` and thus missed.
  var hasEnumBug = !{toString: null}.propertyIsEnumerable('toString');
  var nonEnumerableProps = ['valueOf', 'isPrototypeOf', 'toString',
                      'propertyIsEnumerable', 'hasOwnProperty', 'toLocaleString'];

  var collectNonEnumProps = function(obj, keys) {
    var nonEnumIdx = nonEnumerableProps.length;
    var constructor = obj.constructor;
    var proto = _.isFunction(constructor) && constructor.prototype || ObjProto;

    // Constructor is a special case.
    var prop = 'constructor';
    if (_.has(obj, prop) && !_.contains(keys, prop)) keys.push(prop);

    while (nonEnumIdx--) {
      prop = nonEnumerableProps[nonEnumIdx];
      if (prop in obj && obj[prop] !== proto[prop] && !_.contains(keys, prop)) {
        keys.push(prop);
      }
    }
  };

  // Retrieve the names of an object's own properties.
  // Delegates to **ECMAScript 5**'s native `Object.keys`
  _.keys = function(obj) {
    if (!_.isObject(obj)) return [];
    if (nativeKeys) return nativeKeys(obj);
    var keys = [];
    for (var key in obj) if (_.has(obj, key)) keys.push(key);
    // Ahem, IE < 9.
    if (hasEnumBug) collectNonEnumProps(obj, keys);
    return keys;
  };

  // Retrieve all the property names of an object.
  _.allKeys = function(obj) {
    if (!_.isObject(obj)) return [];
    var keys = [];
    for (var key in obj) keys.push(key);
    // Ahem, IE < 9.
    if (hasEnumBug) collectNonEnumProps(obj, keys);
    return keys;
  };

  // Retrieve the values of an object's properties.
  _.values = function(obj) {
    var keys = _.keys(obj);
    var length = keys.length;
    var values = Array(length);
    for (var i = 0; i < length; i++) {
      values[i] = obj[keys[i]];
    }
    return values;
  };

  // Returns the results of applying the iteratee to each element of the object
  // In contrast to _.map it returns an object
  _.mapObject = function(obj, iteratee, context) {
    iteratee = cb(iteratee, context);
    var keys = _.keys(obj),
      length = keys.length,
      results = {};
    for (var index = 0; index < length; index++) {
      var currentKey = keys[index];
      results[currentKey] = iteratee(obj[currentKey], currentKey, obj);
    }
    return results;
  };

  // Convert an object into a list of `[key, value]` pairs.
  _.pairs = function(obj) {
    var keys = _.keys(obj);
    var length = keys.length;
    var pairs = Array(length);
    for (var i = 0; i < length; i++) {
      pairs[i] = [keys[i], obj[keys[i]]];
    }
    return pairs;
  };

  // Invert the keys and values of an object. The values must be serializable.
  _.invert = function(obj) {
    var result = {};
    var keys = _.keys(obj);
    for (var i = 0, length = keys.length; i < length; i++) {
      result[obj[keys[i]]] = keys[i];
    }
    return result;
  };

  // Return a sorted list of the function names available on the object.
  // Aliased as `methods`
  _.functions = _.methods = function(obj) {
    var names = [];
    for (var key in obj) {
      if (_.isFunction(obj[key])) names.push(key);
    }
    return names.sort();
  };

  // An internal function for creating assigner functions.
  var createAssigner = function(keysFunc, undefinedOnly) {
    return function(obj) {
      var length = arguments.length;
      if (length < 2 || obj == null) return obj;
      for (var index = 1; index < length; index++) {
        var source = arguments[index],
            keys = keysFunc(source),
            l = keys.length;
        for (var i = 0; i < l; i++) {
          var key = keys[i];
          if (!undefinedOnly || obj[key] === void 0) obj[key] = source[key];
        }
      }
      return obj;
    };
  };

  // Extend a given object with all the properties in passed-in object(s).
  _.extend = createAssigner(_.allKeys);

  // Assigns a given object with all the own properties in the passed-in object(s)
  // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
  _.extendOwn = _.assign = createAssigner(_.keys);

  // Returns the first key on an object that passes a predicate test
  _.findKey = function(obj, predicate, context) {
    predicate = cb(predicate, context);
    var keys = _.keys(obj), key;
    for (var i = 0, length = keys.length; i < length; i++) {
      key = keys[i];
      if (predicate(obj[key], key, obj)) return key;
    }
  };

  // Internal pick helper function to determine if `obj` has key `key`.
  var keyInObj = function(value, key, obj) {
    return key in obj;
  };

  // Return a copy of the object only containing the whitelisted properties.
  _.pick = restArgs(function(obj, keys) {
    var result = {}, iteratee = keys[0];
    if (obj == null) return result;
    if (_.isFunction(iteratee)) {
      if (keys.length > 1) iteratee = optimizeCb(iteratee, keys[1]);
      keys = _.allKeys(obj);
    } else {
      iteratee = keyInObj;
      keys = flatten(keys, false, false);
      obj = Object(obj);
    }
    for (var i = 0, length = keys.length; i < length; i++) {
      var key = keys[i];
      var value = obj[key];
      if (iteratee(value, key, obj)) result[key] = value;
    }
    return result;
  });

   // Return a copy of the object without the blacklisted properties.
  _.omit = restArgs(function(obj, keys) {
    var iteratee = keys[0], context;
    if (_.isFunction(iteratee)) {
      iteratee = _.negate(iteratee);
      if (keys.length > 1) context = keys[1];
    } else {
      keys = _.map(flatten(keys, false, false), String);
      iteratee = function(value, key) {
        return !_.contains(keys, key);
      };
    }
    return _.pick(obj, iteratee, context);
  });

  // Fill in a given object with default properties.
  _.defaults = createAssigner(_.allKeys, true);

  // Creates an object that inherits from the given prototype object.
  // If additional properties are provided then they will be added to the
  // created object.
  _.create = function(prototype, props) {
    var result = baseCreate(prototype);
    if (props) _.extendOwn(result, props);
    return result;
  };

  // Create a (shallow-cloned) duplicate of an object.
  _.clone = function(obj) {
    if (!_.isObject(obj)) return obj;
    return _.isArray(obj) ? obj.slice() : _.extend({}, obj);
  };

  // Invokes interceptor with the obj, and then returns obj.
  // The primary purpose of this method is to "tap into" a method chain, in
  // order to perform operations on intermediate results within the chain.
  _.tap = function(obj, interceptor) {
    interceptor(obj);
    return obj;
  };

  // Returns whether an object has a given set of `key:value` pairs.
  _.isMatch = function(object, attrs) {
    var keys = _.keys(attrs), length = keys.length;
    if (object == null) return !length;
    var obj = Object(object);
    for (var i = 0; i < length; i++) {
      var key = keys[i];
      if (attrs[key] !== obj[key] || !(key in obj)) return false;
    }
    return true;
  };


  // Internal recursive comparison function for `isEqual`.
  var eq, deepEq;
  eq = function(a, b, aStack, bStack) {
    // Identical objects are equal. `0 === -0`, but they aren't identical.
    // See the [Harmony `egal` proposal](http://wiki.ecmascript.org/doku.php?id=harmony:egal).
    if (a === b) return a !== 0 || 1 / a === 1 / b;
    // A strict comparison is necessary because `null == undefined`.
    if (a == null || b == null) return a === b;
    // `NaN`s are equivalent, but non-reflexive.
    if (a !== a) return b !== b;
    // Exhaust primitive checks
    var type = typeof a;
    if (type !== 'function' && type !== 'object' && typeof b !== 'object') return false;
    return deepEq(a, b, aStack, bStack);
  };

  // Internal recursive comparison function for `isEqual`.
  deepEq = function(a, b, aStack, bStack) {
    // Unwrap any wrapped objects.
    if (a instanceof _) a = a._wrapped;
    if (b instanceof _) b = b._wrapped;
    // Compare `[[Class]]` names.
    var className = toString.call(a);
    if (className !== toString.call(b)) return false;
    switch (className) {
      // Strings, numbers, regular expressions, dates, and booleans are compared by value.
      case '[object RegExp]':
      // RegExps are coerced to strings for comparison (Note: '' + /a/i === '/a/i')
      case '[object String]':
        // Primitives and their corresponding object wrappers are equivalent; thus, `"5"` is
        // equivalent to `new String("5")`.
        return '' + a === '' + b;
      case '[object Number]':
        // `NaN`s are equivalent, but non-reflexive.
        // Object(NaN) is equivalent to NaN
        if (+a !== +a) return +b !== +b;
        // An `egal` comparison is performed for other numeric values.
        return +a === 0 ? 1 / +a === 1 / b : +a === +b;
      case '[object Date]':
      case '[object Boolean]':
        // Coerce dates and booleans to numeric primitive values. Dates are compared by their
        // millisecond representations. Note that invalid dates with millisecond representations
        // of `NaN` are not equivalent.
        return +a === +b;
    }

    var areArrays = className === '[object Array]';
    if (!areArrays) {
      if (typeof a != 'object' || typeof b != 'object') return false;

      // Objects with different constructors are not equivalent, but `Object`s or `Array`s
      // from different frames are.
      var aCtor = a.constructor, bCtor = b.constructor;
      if (aCtor !== bCtor && !(_.isFunction(aCtor) && aCtor instanceof aCtor &&
                               _.isFunction(bCtor) && bCtor instanceof bCtor)
                          && ('constructor' in a && 'constructor' in b)) {
        return false;
      }
    }
    // Assume equality for cyclic structures. The algorithm for detecting cyclic
    // structures is adapted from ES 5.1 section 15.12.3, abstract operation `JO`.

    // Initializing stack of traversed objects.
    // It's done here since we only need them for objects and arrays comparison.
    aStack = aStack || [];
    bStack = bStack || [];
    var length = aStack.length;
    while (length--) {
      // Linear search. Performance is inversely proportional to the number of
      // unique nested structures.
      if (aStack[length] === a) return bStack[length] === b;
    }

    // Add the first object to the stack of traversed objects.
    aStack.push(a);
    bStack.push(b);

    // Recursively compare objects and arrays.
    if (areArrays) {
      // Compare array lengths to determine if a deep comparison is necessary.
      length = a.length;
      if (length !== b.length) return false;
      // Deep compare the contents, ignoring non-numeric properties.
      while (length--) {
        if (!eq(a[length], b[length], aStack, bStack)) return false;
      }
    } else {
      // Deep compare objects.
      var keys = _.keys(a), key;
      length = keys.length;
      // Ensure that both objects contain the same number of properties before comparing deep equality.
      if (_.keys(b).length !== length) return false;
      while (length--) {
        // Deep compare each member
        key = keys[length];
        if (!(_.has(b, key) && eq(a[key], b[key], aStack, bStack))) return false;
      }
    }
    // Remove the first object from the stack of traversed objects.
    aStack.pop();
    bStack.pop();
    return true;
  };

  // Perform a deep comparison to check if two objects are equal.
  _.isEqual = function(a, b) {
    return eq(a, b);
  };

  // Is a given array, string, or object empty?
  // An "empty" object has no enumerable own-properties.
  _.isEmpty = function(obj) {
    if (obj == null) return true;
    if (isArrayLike(obj) && (_.isArray(obj) || _.isString(obj) || _.isArguments(obj))) return obj.length === 0;
    return _.keys(obj).length === 0;
  };

  // Is a given value a DOM element?
  _.isElement = function(obj) {
    return !!(obj && obj.nodeType === 1);
  };

  // Is a given value an array?
  // Delegates to ECMA5's native Array.isArray
  _.isArray = nativeIsArray || function(obj) {
    return toString.call(obj) === '[object Array]';
  };

  // Is a given variable an object?
  _.isObject = function(obj) {
    var type = typeof obj;
    return type === 'function' || type === 'object' && !!obj;
  };

  // Add some isType methods: isArguments, isFunction, isString, isNumber, isDate, isRegExp, isError.
  _.each(['Arguments', 'Function', 'String', 'Number', 'Date', 'RegExp', 'Error'], function(name) {
    _['is' + name] = function(obj) {
      return toString.call(obj) === '[object ' + name + ']';
    };
  });

  // Define a fallback version of the method in browsers (ahem, IE < 9), where
  // there isn't any inspectable "Arguments" type.
  if (!_.isArguments(arguments)) {
    _.isArguments = function(obj) {
      return _.has(obj, 'callee');
    };
  }

  // Optimize `isFunction` if appropriate. Work around some typeof bugs in old v8,
  // IE 11 (#1621), and in Safari 8 (#1929).
  if (typeof /./ != 'function' && typeof Int8Array != 'object') {
    _.isFunction = function(obj) {
      return typeof obj == 'function' || false;
    };
  }

  // Is a given object a finite number?
  _.isFinite = function(obj) {
    return isFinite(obj) && !isNaN(parseFloat(obj));
  };

  // Is the given value `NaN`? (NaN is the only number which does not equal itself).
  _.isNaN = function(obj) {
    return _.isNumber(obj) && obj !== +obj;
  };

  // Is a given value a boolean?
  _.isBoolean = function(obj) {
    return obj === true || obj === false || toString.call(obj) === '[object Boolean]';
  };

  // Is a given value equal to null?
  _.isNull = function(obj) {
    return obj === null;
  };

  // Is a given variable undefined?
  _.isUndefined = function(obj) {
    return obj === void 0;
  };

  // Shortcut function for checking if an object has a given property directly
  // on itself (in other words, not on a prototype).
  _.has = function(obj, key) {
    return obj != null && hasOwnProperty.call(obj, key);
  };

  // Utility Functions
  // -----------------

  // Run Underscore.js in *noConflict* mode, returning the `_` variable to its
  // previous owner. Returns a reference to the Underscore object.
  _.noConflict = function() {
    root._ = previousUnderscore;
    return this;
  };

  // Keep the identity function around for default iteratees.
  _.identity = function(value) {
    return value;
  };

  // Predicate-generating functions. Often useful outside of Underscore.
  _.constant = function(value) {
    return function() {
      return value;
    };
  };

  _.noop = function(){};

  _.property = property;

  // Generates a function for a given object that returns a given property.
  _.propertyOf = function(obj) {
    return obj == null ? function(){} : function(key) {
      return obj[key];
    };
  };

  // Returns a predicate for checking whether an object has a given set of
  // `key:value` pairs.
  _.matcher = _.matches = function(attrs) {
    attrs = _.extendOwn({}, attrs);
    return function(obj) {
      return _.isMatch(obj, attrs);
    };
  };

  // Run a function **n** times.
  _.times = function(n, iteratee, context) {
    var accum = Array(Math.max(0, n));
    iteratee = optimizeCb(iteratee, context, 1);
    for (var i = 0; i < n; i++) accum[i] = iteratee(i);
    return accum;
  };

  // Return a random integer between min and max (inclusive).
  _.random = function(min, max) {
    if (max == null) {
      max = min;
      min = 0;
    }
    return min + Math.floor(Math.random() * (max - min + 1));
  };

  // A (possibly faster) way to get the current timestamp as an integer.
  _.now = Date.now || function() {
    return new Date().getTime();
  };

   // List of HTML entities for escaping.
  var escapeMap = {
    '&': '&amp;',
    '<': '&lt;',
    '>': '&gt;',
    '"': '&quot;',
    "'": '&#x27;',
    '`': '&#x60;'
  };
  var unescapeMap = _.invert(escapeMap);

  // Functions for escaping and unescaping strings to/from HTML interpolation.
  var createEscaper = function(map) {
    var escaper = function(match) {
      return map[match];
    };
    // Regexes for identifying a key that needs to be escaped
    var source = '(?:' + _.keys(map).join('|') + ')';
    var testRegexp = RegExp(source);
    var replaceRegexp = RegExp(source, 'g');
    return function(string) {
      string = string == null ? '' : '' + string;
      return testRegexp.test(string) ? string.replace(replaceRegexp, escaper) : string;
    };
  };
  _.escape = createEscaper(escapeMap);
  _.unescape = createEscaper(unescapeMap);

  // If the value of the named `property` is a function then invoke it with the
  // `object` as context; otherwise, return it.
  _.result = function(object, prop, fallback) {
    var value = object == null ? void 0 : object[prop];
    if (value === void 0) {
      value = fallback;
    }
    return _.isFunction(value) ? value.call(object) : value;
  };

  // Generate a unique integer id (unique within the entire client session).
  // Useful for temporary DOM ids.
  var idCounter = 0;
  _.uniqueId = function(prefix) {
    var id = ++idCounter + '';
    return prefix ? prefix + id : id;
  };

  // By default, Underscore uses ERB-style template delimiters, change the
  // following template settings to use alternative delimiters.
  _.templateSettings = {
    evaluate: /<%([\s\S]+?)%>/g,
    interpolate: /<%=([\s\S]+?)%>/g,
    escape: /<%-([\s\S]+?)%>/g
  };

  // When customizing `templateSettings`, if you don't want to define an
  // interpolation, evaluation or escaping regex, we need one that is
  // guaranteed not to match.
  var noMatch = /(.)^/;

  // Certain characters need to be escaped so that they can be put into a
  // string literal.
  var escapes = {
    "'": "'",
    '\\': '\\',
    '\r': 'r',
    '\n': 'n',
    '\u2028': 'u2028',
    '\u2029': 'u2029'
  };

  var escapeRegExp = /\\|'|\r|\n|\u2028|\u2029/g;

  var escapeChar = function(match) {
    return '\\' + escapes[match];
  };

  // JavaScript micro-templating, similar to John Resig's implementation.
  // Underscore templating handles arbitrary delimiters, preserves whitespace,
  // and correctly escapes quotes within interpolated code.
  // NB: `oldSettings` only exists for backwards compatibility.
  _.template = function(text, settings, oldSettings) {
    if (!settings && oldSettings) settings = oldSettings;
    settings = _.defaults({}, settings, _.templateSettings);

    // Combine delimiters into one regular expression via alternation.
    var matcher = RegExp([
      (settings.escape || noMatch).source,
      (settings.interpolate || noMatch).source,
      (settings.evaluate || noMatch).source
    ].join('|') + '|$', 'g');

    // Compile the template source, escaping string literals appropriately.
    var index = 0;
    var source = "__p+='";
    text.replace(matcher, function(match, escape, interpolate, evaluate, offset) {
      source += text.slice(index, offset).replace(escapeRegExp, escapeChar);
      index = offset + match.length;

      if (escape) {
        source += "'+\n((__t=(" + escape + "))==null?'':_.escape(__t))+\n'";
      } else if (interpolate) {
        source += "'+\n((__t=(" + interpolate + "))==null?'':__t)+\n'";
      } else if (evaluate) {
        source += "';\n" + evaluate + "\n__p+='";
      }

      // Adobe VMs need the match returned to produce the correct offest.
      return match;
    });
    source += "';\n";

    // If a variable is not specified, place data values in local scope.
    if (!settings.variable) source = 'with(obj||{}){\n' + source + '}\n';

    source = "var __t,__p='',__j=Array.prototype.join," +
      "print=function(){__p+=__j.call(arguments,'');};\n" +
      source + 'return __p;\n';

    var render;
    try {
      render = new Function(settings.variable || 'obj', '_', source);
    } catch (e) {
      e.source = source;
      throw e;
    }

    var template = function(data) {
      return render.call(this, data, _);
    };

    // Provide the compiled source as a convenience for precompilation.
    var argument = settings.variable || 'obj';
    template.source = 'function(' + argument + '){\n' + source + '}';

    return template;
  };

  // Add a "chain" function. Start chaining a wrapped Underscore object.
  _.chain = function(obj) {
    var instance = _(obj);
    instance._chain = true;
    return instance;
  };

  // OOP
  // ---------------
  // If Underscore is called as a function, it returns a wrapped object that
  // can be used OO-style. This wrapper holds altered versions of all the
  // underscore functions. Wrapped objects may be chained.

  // Helper function to continue chaining intermediate results.
  var chainResult = function(instance, obj) {
    return instance._chain ? _(obj).chain() : obj;
  };

  // Add your own custom functions to the Underscore object.
  _.mixin = function(obj) {
    _.each(_.functions(obj), function(name) {
      var func = _[name] = obj[name];
      _.prototype[name] = function() {
        var args = [this._wrapped];
        push.apply(args, arguments);
        return chainResult(this, func.apply(_, args));
      };
    });
  };

  // Add all of the Underscore functions to the wrapper object.
  _.mixin(_);

  // Add all mutator Array functions to the wrapper.
  _.each(['pop', 'push', 'reverse', 'shift', 'sort', 'splice', 'unshift'], function(name) {
    var method = ArrayProto[name];
    _.prototype[name] = function() {
      var obj = this._wrapped;
      method.apply(obj, arguments);
      if ((name === 'shift' || name === 'splice') && obj.length === 0) delete obj[0];
      return chainResult(this, obj);
    };
  });

  // Add all accessor Array functions to the wrapper.
  _.each(['concat', 'join', 'slice'], function(name) {
    var method = ArrayProto[name];
    _.prototype[name] = function() {
      return chainResult(this, method.apply(this._wrapped, arguments));
    };
  });

  // Extracts the result from a wrapped and chained object.
  _.prototype.value = function() {
    return this._wrapped;
  };

  // Provide unwrapping proxy for some methods used in engine operations
  // such as arithmetic and JSON stringification.
  _.prototype.valueOf = _.prototype.toJSON = _.prototype.value;

  _.prototype.toString = function() {
    return '' + this._wrapped;
  };

  // AMD registration happens at the end for compatibility with AMD loaders
  // that may not enforce next-turn semantics on modules. Even though general
  // practice for AMD registration is to be anonymous, underscore registers
  // as a named module because, like jQuery, it is a base library that is
  // popular enough to be bundled in a third party lib, but not be part of
  // an AMD load request. Those cases could generate an error when an
  // anonymous define() is called outside of a loader request.
  if (typeof define === 'function' && define.amd) {
    define('underscore', [], function() {
      return _;
    });
  }
}());

;(function () {
	'use strict';

	/**
	 * @preserve FastClick: polyfill to remove click delays on browsers with touch UIs.
	 *
	 * @codingstandard ftlabs-jsv2
	 * @copyright The Financial Times Limited [All Rights Reserved]
	 * @license MIT License (see LICENSE.txt)
	 */

	/*jslint browser:true, node:true*/
	/*global define, Event, Node*/


	/**
	 * Instantiate fast-clicking listeners on the specified layer.
	 *
	 * @constructor
	 * @param {Element} layer The layer to listen on
	 * @param {Object} [options={}] The options to override the defaults
	 */
	function FastClick(layer, options) {
		var oldOnClick;

		options = options || {};

		/**
		 * Whether a click is currently being tracked.
		 *
		 * @type boolean
		 */
		this.trackingClick = false;


		/**
		 * Timestamp for when click tracking started.
		 *
		 * @type number
		 */
		this.trackingClickStart = 0;


		/**
		 * The element being tracked for a click.
		 *
		 * @type EventTarget
		 */
		this.targetElement = null;


		/**
		 * X-coordinate of touch start event.
		 *
		 * @type number
		 */
		this.touchStartX = 0;


		/**
		 * Y-coordinate of touch start event.
		 *
		 * @type number
		 */
		this.touchStartY = 0;


		/**
		 * ID of the last touch, retrieved from Touch.identifier.
		 *
		 * @type number
		 */
		this.lastTouchIdentifier = 0;


		/**
		 * Touchmove boundary, beyond which a click will be cancelled.
		 *
		 * @type number
		 */
		this.touchBoundary = options.touchBoundary || 10;


		/**
		 * The FastClick layer.
		 *
		 * @type Element
		 */
		this.layer = layer;

		/**
		 * The minimum time between tap(touchstart and touchend) events
		 *
		 * @type number
		 */
		this.tapDelay = options.tapDelay || 200;

		/**
		 * The maximum time for a tap
		 *
		 * @type number
		 */
		this.tapTimeout = options.tapTimeout || 700;

		if (FastClick.notNeeded(layer)) {
			return;
		}

		// Some old versions of Android don't have Function.prototype.bind
		function bind(method, context) {
			return function() { return method.apply(context, arguments); };
		}


		var methods = ['onMouse', 'onClick', 'onTouchStart', 'onTouchMove', 'onTouchEnd', 'onTouchCancel'];
		var context = this;
		for (var i = 0, l = methods.length; i < l; i++) {
			context[methods[i]] = bind(context[methods[i]], context);
		}

		// Set up event handlers as required
		if (deviceIsAndroid) {
			layer.addEventListener('mouseover', this.onMouse, true);
			layer.addEventListener('mousedown', this.onMouse, true);
			layer.addEventListener('mouseup', this.onMouse, true);
		}

		layer.addEventListener('click', this.onClick, true);
		layer.addEventListener('touchstart', this.onTouchStart, false);
		layer.addEventListener('touchmove', this.onTouchMove, false);
		layer.addEventListener('touchend', this.onTouchEnd, false);
		layer.addEventListener('touchcancel', this.onTouchCancel, false);

		// Hack is required for browsers that don't support Event#stopImmediatePropagation (e.g. Android 2)
		// which is how FastClick normally stops click events bubbling to callbacks registered on the FastClick
		// layer when they are cancelled.
		if (!Event.prototype.stopImmediatePropagation) {
			layer.removeEventListener = function(type, callback, capture) {
				var rmv = Node.prototype.removeEventListener;
				if (type === 'click') {
					rmv.call(layer, type, callback.hijacked || callback, capture);
				} else {
					rmv.call(layer, type, callback, capture);
				}
			};

			layer.addEventListener = function(type, callback, capture) {
				var adv = Node.prototype.addEventListener;
				if (type === 'click') {
					adv.call(layer, type, callback.hijacked || (callback.hijacked = function(event) {
						if (!event.propagationStopped) {
							callback(event);
						}
					}), capture);
				} else {
					adv.call(layer, type, callback, capture);
				}
			};
		}

		// If a handler is already declared in the element's onclick attribute, it will be fired before
		// FastClick's onClick handler. Fix this by pulling out the user-defined handler function and
		// adding it as listener.
		if (typeof layer.onclick === 'function') {

			// Android browser on at least 3.2 requires a new reference to the function in layer.onclick
			// - the old one won't work if passed to addEventListener directly.
			oldOnClick = layer.onclick;
			layer.addEventListener('click', function(event) {
				oldOnClick(event);
			}, false);
			layer.onclick = null;
		}
	}

	/**
	* Windows Phone 8.1 fakes user agent string to look like Android and iPhone.
	*
	* @type boolean
	*/
	var deviceIsWindowsPhone = navigator.userAgent.indexOf("Windows Phone") >= 0;

	/**
	 * Android requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsAndroid = navigator.userAgent.indexOf('Android') > 0 && !deviceIsWindowsPhone;


	/**
	 * iOS requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsIOS = /iP(ad|hone|od)/.test(navigator.userAgent) && !deviceIsWindowsPhone;


	/**
	 * iOS 4 requires an exception for select elements.
	 *
	 * @type boolean
	 */
	var deviceIsIOS4 = deviceIsIOS && (/OS 4_\d(_\d)?/).test(navigator.userAgent);


	/**
	 * iOS 6.0-7.* requires the target element to be manually derived
	 *
	 * @type boolean
	 */
	var deviceIsIOSWithBadTarget = deviceIsIOS && (/OS [6-7]_\d/).test(navigator.userAgent);

	/**
	 * BlackBerry requires exceptions.
	 *
	 * @type boolean
	 */
	var deviceIsBlackBerry10 = navigator.userAgent.indexOf('BB10') > 0;

	/**
	 * Determine whether a given element requires a native click.
	 *
	 * @param {EventTarget|Element} target Target DOM element
	 * @returns {boolean} Returns true if the element needs a native click
	 */
	FastClick.prototype.needsClick = function(target) {
		switch (target.nodeName.toLowerCase()) {

		// Don't send a synthetic click to disabled inputs (issue #62)
		case 'button':
		case 'select':
		case 'textarea':
			if (target.disabled) {
				return true;
			}

			break;
		case 'input':

			// File inputs need real clicks on iOS 6 due to a browser bug (issue #68)
			if ((deviceIsIOS && target.type === 'file') || target.disabled) {
				return true;
			}

			break;
		case 'label':
		case 'iframe': // iOS8 homescreen apps can prevent events bubbling into frames
		case 'video':
			return true;
		}

		return (/\bneedsclick\b/).test(target.className);
	};


	/**
	 * Determine whether a given element requires a call to focus to simulate click into element.
	 *
	 * @param {EventTarget|Element} target Target DOM element
	 * @returns {boolean} Returns true if the element requires a call to focus to simulate native click.
	 */
	FastClick.prototype.needsFocus = function(target) {
		switch (target.nodeName.toLowerCase()) {
		case 'textarea':
			return true;
		case 'select':
			return !deviceIsAndroid;
		case 'input':
			switch (target.type) {
			case 'button':
			case 'checkbox':
			case 'file':
			case 'image':
			case 'radio':
			case 'submit':
				return false;
			}

			// No point in attempting to focus disabled inputs
			return !target.disabled && !target.readOnly;
		default:
			return (/\bneedsfocus\b/).test(target.className);
		}
	};


	/**
	 * Send a click event to the specified element.
	 *
	 * @param {EventTarget|Element} targetElement
	 * @param {Event} event
	 */
	FastClick.prototype.sendClick = function(targetElement, event) {
		var clickEvent, touch;

		// On some Android devices activeElement needs to be blurred otherwise the synthetic click will have no effect (#24)
		if (document.activeElement && document.activeElement !== targetElement) {
			document.activeElement.blur();
		}

		touch = event.changedTouches[0];

		// Synthesise a click event, with an extra attribute so it can be tracked
		clickEvent = document.createEvent('MouseEvents');
		clickEvent.initMouseEvent(this.determineEventType(targetElement), true, true, window, 1, touch.screenX, touch.screenY, touch.clientX, touch.clientY, false, false, false, false, 0, null);
		clickEvent.forwardedTouchEvent = true;
		targetElement.dispatchEvent(clickEvent);
	};

	FastClick.prototype.determineEventType = function(targetElement) {

		//Issue #159: Android Chrome Select Box does not open with a synthetic click event
		if (deviceIsAndroid && targetElement.tagName.toLowerCase() === 'select') {
			return 'mousedown';
		}

		return 'click';
	};


	/**
	 * @param {EventTarget|Element} targetElement
	 */
	FastClick.prototype.focus = function(targetElement) {
		var length;

		// Issue #160: on iOS 7, some input elements (e.g. date datetime month) throw a vague TypeError on setSelectionRange. These elements don't have an integer value for the selectionStart and selectionEnd properties, but unfortunately that can't be used for detection because accessing the properties also throws a TypeError. Just check the type instead. Filed as Apple bug #15122724.
		if (deviceIsIOS && targetElement.setSelectionRange && targetElement.type.indexOf('date') !== 0 && targetElement.type !== 'time' && targetElement.type !== 'month') {
			length = targetElement.value.length;
			targetElement.setSelectionRange(length, length);
		} else {
			targetElement.focus();
		}
	};


	/**
	 * Check whether the given target element is a child of a scrollable layer and if so, set a flag on it.
	 *
	 * @param {EventTarget|Element} targetElement
	 */
	FastClick.prototype.updateScrollParent = function(targetElement) {
		var scrollParent, parentElement;

		scrollParent = targetElement.fastClickScrollParent;

		// Attempt to discover whether the target element is contained within a scrollable layer. Re-check if the
		// target element was moved to another parent.
		if (!scrollParent || !scrollParent.contains(targetElement)) {
			parentElement = targetElement;
			do {
				if (parentElement.scrollHeight > parentElement.offsetHeight) {
					scrollParent = parentElement;
					targetElement.fastClickScrollParent = parentElement;
					break;
				}

				parentElement = parentElement.parentElement;
			} while (parentElement);
		}

		// Always update the scroll top tracker if possible.
		if (scrollParent) {
			scrollParent.fastClickLastScrollTop = scrollParent.scrollTop;
		}
	};


	/**
	 * @param {EventTarget} targetElement
	 * @returns {Element|EventTarget}
	 */
	FastClick.prototype.getTargetElementFromEventTarget = function(eventTarget) {

		// On some older browsers (notably Safari on iOS 4.1 - see issue #56) the event target may be a text node.
		if (eventTarget.nodeType === Node.TEXT_NODE) {
			return eventTarget.parentNode;
		}

		return eventTarget;
	};


	/**
	 * On touch start, record the position and scroll offset.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchStart = function(event) {
		var targetElement, touch, selection;

		// Ignore multiple touches, otherwise pinch-to-zoom is prevented if both fingers are on the FastClick element (issue #111).
		if (event.targetTouches.length > 1) {
			return true;
		}

		targetElement = this.getTargetElementFromEventTarget(event.target);
		touch = event.targetTouches[0];

		if (deviceIsIOS) {

			// Only trusted events will deselect text on iOS (issue #49)
			selection = window.getSelection();
			if (selection.rangeCount && !selection.isCollapsed) {
				return true;
			}

			if (!deviceIsIOS4) {

				// Weird things happen on iOS when an alert or confirm dialog is opened from a click event callback (issue #23):
				// when the user next taps anywhere else on the page, new touchstart and touchend events are dispatched
				// with the same identifier as the touch event that previously triggered the click that triggered the alert.
				// Sadly, there is an issue on iOS 4 that causes some normal touch events to have the same identifier as an
				// immediately preceeding touch event (issue #52), so this fix is unavailable on that platform.
				// Issue 120: touch.identifier is 0 when Chrome dev tools 'Emulate touch events' is set with an iOS device UA string,
				// which causes all touch events to be ignored. As this block only applies to iOS, and iOS identifiers are always long,
				// random integers, it's safe to to continue if the identifier is 0 here.
				if (touch.identifier && touch.identifier === this.lastTouchIdentifier) {
					event.preventDefault();
					return false;
				}

				this.lastTouchIdentifier = touch.identifier;

				// If the target element is a child of a scrollable layer (using -webkit-overflow-scrolling: touch) and:
				// 1) the user does a fling scroll on the scrollable layer
				// 2) the user stops the fling scroll with another tap
				// then the event.target of the last 'touchend' event will be the element that was under the user's finger
				// when the fling scroll was started, causing FastClick to send a click event to that layer - unless a check
				// is made to ensure that a parent layer was not scrolled before sending a synthetic click (issue #42).
				this.updateScrollParent(targetElement);
			}
		}

		this.trackingClick = true;
		this.trackingClickStart = event.timeStamp;
		this.targetElement = targetElement;

		this.touchStartX = touch.pageX;
		this.touchStartY = touch.pageY;

		// Prevent phantom clicks on fast double-tap (issue #36)
		if ((event.timeStamp - this.lastClickTime) < this.tapDelay) {
			event.preventDefault();
		}

		return true;
	};


	/**
	 * Based on a touchmove event object, check whether the touch has moved past a boundary since it started.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.touchHasMoved = function(event) {
		var touch = event.changedTouches[0], boundary = this.touchBoundary;

		if (Math.abs(touch.pageX - this.touchStartX) > boundary || Math.abs(touch.pageY - this.touchStartY) > boundary) {
			return true;
		}

		return false;
	};


	/**
	 * Update the last position.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchMove = function(event) {
		if (!this.trackingClick) {
			return true;
		}

		// If the touch has moved, cancel the click tracking
		if (this.targetElement !== this.getTargetElementFromEventTarget(event.target) || this.touchHasMoved(event)) {
			this.trackingClick = false;
			this.targetElement = null;
		}

		return true;
	};


	/**
	 * Attempt to find the labelled control for the given label element.
	 *
	 * @param {EventTarget|HTMLLabelElement} labelElement
	 * @returns {Element|null}
	 */
	FastClick.prototype.findControl = function(labelElement) {

		// Fast path for newer browsers supporting the HTML5 control attribute
		if (labelElement.control !== undefined) {
			return labelElement.control;
		}

		// All browsers under test that support touch events also support the HTML5 htmlFor attribute
		if (labelElement.htmlFor) {
			return document.getElementById(labelElement.htmlFor);
		}

		// If no for attribute exists, attempt to retrieve the first labellable descendant element
		// the list of which is defined here: http://www.w3.org/TR/html5/forms.html#category-label
		return labelElement.querySelector('button, input:not([type=hidden]), keygen, meter, output, progress, select, textarea');
	};


	/**
	 * On touch end, determine whether to send a click event at once.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onTouchEnd = function(event) {
		var forElement, trackingClickStart, targetTagName, scrollParent, touch, targetElement = this.targetElement;

		if (!this.trackingClick) {
			return true;
		}

		// Prevent phantom clicks on fast double-tap (issue #36)
		if ((event.timeStamp - this.lastClickTime) < this.tapDelay) {
			this.cancelNextClick = true;
			return true;
		}

		if ((event.timeStamp - this.trackingClickStart) > this.tapTimeout) {
			return true;
		}

		// Reset to prevent wrong click cancel on input (issue #156).
		this.cancelNextClick = false;

		this.lastClickTime = event.timeStamp;

		trackingClickStart = this.trackingClickStart;
		this.trackingClick = false;
		this.trackingClickStart = 0;

		// On some iOS devices, the targetElement supplied with the event is invalid if the layer
		// is performing a transition or scroll, and has to be re-detected manually. Note that
		// for this to function correctly, it must be called *after* the event target is checked!
		// See issue #57; also filed as rdar://13048589 .
		if (deviceIsIOSWithBadTarget) {
			touch = event.changedTouches[0];

			// In certain cases arguments of elementFromPoint can be negative, so prevent setting targetElement to null
			targetElement = document.elementFromPoint(touch.pageX - window.pageXOffset, touch.pageY - window.pageYOffset) || targetElement;
			targetElement.fastClickScrollParent = this.targetElement.fastClickScrollParent;
		}

		targetTagName = targetElement.tagName.toLowerCase();
		if (targetTagName === 'label') {
			forElement = this.findControl(targetElement);
			if (forElement) {
				this.focus(targetElement);
				if (deviceIsAndroid) {
					return false;
				}

				targetElement = forElement;
			}
		} else if (this.needsFocus(targetElement)) {

			// Case 1: If the touch started a while ago (best guess is 100ms based on tests for issue #36) then focus will be triggered anyway. Return early and unset the target element reference so that the subsequent click will be allowed through.
			// Case 2: Without this exception for input elements tapped when the document is contained in an iframe, then any inputted text won't be visible even though the value attribute is updated as the user types (issue #37).
			if ((event.timeStamp - trackingClickStart) > 100 || (deviceIsIOS && window.top !== window && targetTagName === 'input')) {
				this.targetElement = null;
				return false;
			}

			this.focus(targetElement);
			this.sendClick(targetElement, event);

			// Select elements need the event to go through on iOS 4, otherwise the selector menu won't open.
			// Also this breaks opening selects when VoiceOver is active on iOS6, iOS7 (and possibly others)
			if (!deviceIsIOS || targetTagName !== 'select') {
				this.targetElement = null;
				event.preventDefault();
			}

			return false;
		}

		if (deviceIsIOS && !deviceIsIOS4) {

			// Don't send a synthetic click event if the target element is contained within a parent layer that was scrolled
			// and this tap is being used to stop the scrolling (usually initiated by a fling - issue #42).
			scrollParent = targetElement.fastClickScrollParent;
			if (scrollParent && scrollParent.fastClickLastScrollTop !== scrollParent.scrollTop) {
				return true;
			}
		}

		// Prevent the actual click from going though - unless the target node is marked as requiring
		// real clicks or if it is in the whitelist in which case only non-programmatic clicks are permitted.
		if (!this.needsClick(targetElement)) {
			event.preventDefault();
			this.sendClick(targetElement, event);
		}

		return false;
	};


	/**
	 * On touch cancel, stop tracking the click.
	 *
	 * @returns {void}
	 */
	FastClick.prototype.onTouchCancel = function() {
		this.trackingClick = false;
		this.targetElement = null;
	};


	/**
	 * Determine mouse events which should be permitted.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onMouse = function(event) {

		// If a target element was never set (because a touch event was never fired) allow the event
		if (!this.targetElement) {
			return true;
		}

		if (event.forwardedTouchEvent) {
			return true;
		}

		// Programmatically generated events targeting a specific element should be permitted
		if (!event.cancelable) {
			return true;
		}

		// Derive and check the target element to see whether the mouse event needs to be permitted;
		// unless explicitly enabled, prevent non-touch click events from triggering actions,
		// to prevent ghost/doubleclicks.
		if (!this.needsClick(this.targetElement) || this.cancelNextClick) {

			// Prevent any user-added listeners declared on FastClick element from being fired.
			if (event.stopImmediatePropagation) {
				event.stopImmediatePropagation();
			} else {

				// Part of the hack for browsers that don't support Event#stopImmediatePropagation (e.g. Android 2)
				event.propagationStopped = true;
			}

			// Cancel the event
			event.stopPropagation();
			event.preventDefault();

			return false;
		}

		// If the mouse event is permitted, return true for the action to go through.
		return true;
	};


	/**
	 * On actual clicks, determine whether this is a touch-generated click, a click action occurring
	 * naturally after a delay after a touch (which needs to be cancelled to avoid duplication), or
	 * an actual click which should be permitted.
	 *
	 * @param {Event} event
	 * @returns {boolean}
	 */
	FastClick.prototype.onClick = function(event) {
		var permitted;

		// It's possible for another FastClick-like library delivered with third-party code to fire a click event before FastClick does (issue #44). In that case, set the click-tracking flag back to false and return early. This will cause onTouchEnd to return early.
		if (this.trackingClick) {
			this.targetElement = null;
			this.trackingClick = false;
			return true;
		}

		// Very odd behaviour on iOS (issue #18): if a submit element is present inside a form and the user hits enter in the iOS simulator or clicks the Go button on the pop-up OS keyboard the a kind of 'fake' click event will be triggered with the submit-type input element as the target.
		if (event.target.type === 'submit' && event.detail === 0) {
			return true;
		}

		permitted = this.onMouse(event);

		// Only unset targetElement if the click is not permitted. This will ensure that the check for !targetElement in onMouse fails and the browser's click doesn't go through.
		if (!permitted) {
			this.targetElement = null;
		}

		// If clicks are permitted, return true for the action to go through.
		return permitted;
	};


	/**
	 * Remove all FastClick's event listeners.
	 *
	 * @returns {void}
	 */
	FastClick.prototype.destroy = function() {
		var layer = this.layer;

		if (deviceIsAndroid) {
			layer.removeEventListener('mouseover', this.onMouse, true);
			layer.removeEventListener('mousedown', this.onMouse, true);
			layer.removeEventListener('mouseup', this.onMouse, true);
		}

		layer.removeEventListener('click', this.onClick, true);
		layer.removeEventListener('touchstart', this.onTouchStart, false);
		layer.removeEventListener('touchmove', this.onTouchMove, false);
		layer.removeEventListener('touchend', this.onTouchEnd, false);
		layer.removeEventListener('touchcancel', this.onTouchCancel, false);
	};


	/**
	 * Check whether FastClick is needed.
	 *
	 * @param {Element} layer The layer to listen on
	 */
	FastClick.notNeeded = function(layer) {
		var metaViewport;
		var chromeVersion;
		var blackberryVersion;
		var firefoxVersion;

		// Devices that don't support touch don't need FastClick
		if (typeof window.ontouchstart === 'undefined') {
			return true;
		}

		// Chrome version - zero for other browsers
		chromeVersion = +(/Chrome\/([0-9]+)/.exec(navigator.userAgent) || [,0])[1];

		if (chromeVersion) {

			if (deviceIsAndroid) {
				metaViewport = document.querySelector('meta[name=viewport]');

				if (metaViewport) {
					// Chrome on Android with user-scalable="no" doesn't need FastClick (issue #89)
					if (metaViewport.content.indexOf('user-scalable=no') !== -1) {
						return true;
					}
					// Chrome 32 and above with width=device-width or less don't need FastClick
					if (chromeVersion > 31 && document.documentElement.scrollWidth <= window.outerWidth) {
						return true;
					}
				}

			// Chrome desktop doesn't need FastClick (issue #15)
			} else {
				return true;
			}
		}

		if (deviceIsBlackBerry10) {
			blackberryVersion = navigator.userAgent.match(/Version\/([0-9]*)\.([0-9]*)/);

			// BlackBerry 10.3+ does not require Fastclick library.
			// https://github.com/ftlabs/fastclick/issues/251
			if (blackberryVersion[1] >= 10 && blackberryVersion[2] >= 3) {
				metaViewport = document.querySelector('meta[name=viewport]');

				if (metaViewport) {
					// user-scalable=no eliminates click delay.
					if (metaViewport.content.indexOf('user-scalable=no') !== -1) {
						return true;
					}
					// width=device-width (or less than device-width) eliminates click delay.
					if (document.documentElement.scrollWidth <= window.outerWidth) {
						return true;
					}
				}
			}
		}

		// IE10 with -ms-touch-action: none or manipulation, which disables double-tap-to-zoom (issue #97)
		if (layer.style.msTouchAction === 'none' || layer.style.touchAction === 'manipulation') {
			return true;
		}

		// Firefox version - zero for other browsers
		firefoxVersion = +(/Firefox\/([0-9]+)/.exec(navigator.userAgent) || [,0])[1];

		if (firefoxVersion >= 27) {
			// Firefox 27+ does not have tap delay if the content is not zoomable - https://bugzilla.mozilla.org/show_bug.cgi?id=922896

			metaViewport = document.querySelector('meta[name=viewport]');
			if (metaViewport && (metaViewport.content.indexOf('user-scalable=no') !== -1 || document.documentElement.scrollWidth <= window.outerWidth)) {
				return true;
			}
		}

		// IE11: prefixed -ms-touch-action is no longer supported and it's recomended to use non-prefixed version
		// http://msdn.microsoft.com/en-us/library/windows/apps/Hh767313.aspx
		if (layer.style.touchAction === 'none' || layer.style.touchAction === 'manipulation') {
			return true;
		}

		return false;
	};


	/**
	 * Factory method for creating a FastClick object
	 *
	 * @param {Element} layer The layer to listen on
	 * @param {Object} [options={}] The options to override the defaults
	 */
	FastClick.attach = function(layer, options) {
		return new FastClick(layer, options);
	};


	if (typeof define === 'function' && typeof define.amd === 'object' && define.amd) {

		// AMD. Register as an anonymous module.
		define(function() {
			return FastClick;
		});
	} else if (typeof module !== 'undefined' && module.exports) {
		module.exports = FastClick.attach;
		module.exports.FastClick = FastClick;
	} else {
		window.FastClick = FastClick;
	}
}());

/**
 * Simple localStorage with Cookie Fallback
 * v.1.0.0
 *
 * USAGE:
 * ----------------------------------------
 * Set New / Modify:
 *   store('my_key', 'some_value');
 *
 * Retrieve:
 *   store('my_key');
 *
 * Delete / Remove:
 *   store('my_key', null);
 */
 
var store = function store(key, value) {
 
    var lsSupport = false;
    
    // Check for native support
    if (window['localStorage']) {
        lsSupport = true;
    }
    
    // If value is detected, set new or modify store
    if (typeof value !== "undefined" && value !== null) {
        // Convert object values to JSON
        if ( typeof value === 'object' ) {
            value = JSON.stringify(value);
        }
        // Set the store
        if (lsSupport) { // Native support
            window['localStorage'].setItem(key, value);
        } else { // Use Cookie
            createCookie(key, value, 30);
        }
    }
    
    // No value supplied, return value
    if (typeof value === "undefined") {
        // Get value
        if (lsSupport) { // Native support
            data = window['localStorage'].getItem(key);
        } else { // Use cookie 
            data = readCookie(key);
        }
        
        // Try to parse JSON...
        try {
           data = JSON.parse(data);
        }
        catch(e) {
           data = data;
        }
        
        return data;
        
    }
    
    // Null specified, remove store
    if (value === null) {
        if (lsSupport) { // Native support
            window['localStorage'].removeItem(key);
        } else { // Use cookie
            createCookie(key, '', -1);
        }
    }
    
    /**
     * Creates new cookie or removes cookie with negative expiration
     * @param  key       The key or identifier for the store
     * @param  value     Contents of the store
     * @param  exp       Expiration - creation defaults to 30 days
     */
    
    function createCookie(key, value, exp) {
        var date = new Date();
        date.setTime(date.getTime() + (exp * 24 * 60 * 60 * 1000));
        var expires = "; expires=" + date.toGMTString();
        document.cookie = key + "=" + value + expires + "; path=/";
    }
    
    /**
     * Returns contents of cookie
     * @param  key       The key or identifier for the store
     */
    
    function readCookie(key) {
        var nameEQ = key + "=";
        var ca = document.cookie.split(';');
        for (var i = 0, max = ca.length; i < max; i++) {
            var c = ca[i];
            while (c.charAt(0) === ' ') c = c.substring(1, c.length);
            if (c.indexOf(nameEQ) === 0) return c.substring(nameEQ.length, c.length);
        }
        return null;
    }
    
};
/*! highlight.js v9.12.0 | BSD3 License | git.io/hljslicense */
!function(e){var t="object"==typeof window&&window||"object"==typeof self&&self;"undefined"!=typeof exports?e(exports):t&&(t.hljs=e({}),"function"==typeof define&&define.amd&&define([],function(){return t.hljs}))}(function(e){function t(e){return e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;")}function r(e){return e.nodeName.toLowerCase()}function a(e,t){var r=e&&e.exec(t);return r&&0===r.index}function n(e){return E.test(e)}function i(e){var t,r,a,i,s=e.className+" ";if(s+=e.parentNode?e.parentNode.className:"",r=M.exec(s))return w(r[1])?r[1]:"no-highlight";for(s=s.split(/\s+/),t=0,a=s.length;a>t;t++)if(i=s[t],n(i)||w(i))return i}function s(e){var t,r={},a=Array.prototype.slice.call(arguments,1);for(t in e)r[t]=e[t];return a.forEach(function(e){for(t in e)r[t]=e[t]}),r}function c(e){var t=[];return function a(e,n){for(var i=e.firstChild;i;i=i.nextSibling)3===i.nodeType?n+=i.nodeValue.length:1===i.nodeType&&(t.push({event:"start",offset:n,node:i}),n=a(i,n),r(i).match(/br|hr|img|input/)||t.push({event:"stop",offset:n,node:i}));return n}(e,0),t}function o(e,a,n){function i(){return e.length&&a.length?e[0].offset!==a[0].offset?e[0].offset<a[0].offset?e:a:"start"===a[0].event?e:a:e.length?e:a}function s(e){function a(e){return" "+e.nodeName+'="'+t(e.value).replace('"',"&quot;")+'"'}u+="<"+r(e)+N.map.call(e.attributes,a).join("")+">"}function c(e){u+="</"+r(e)+">"}function o(e){("start"===e.event?s:c)(e.node)}for(var l=0,u="",d=[];e.length||a.length;){var b=i();if(u+=t(n.substring(l,b[0].offset)),l=b[0].offset,b===e){d.reverse().forEach(c);do o(b.splice(0,1)[0]),b=i();while(b===e&&b.length&&b[0].offset===l);d.reverse().forEach(s)}else"start"===b[0].event?d.push(b[0].node):d.pop(),o(b.splice(0,1)[0])}return u+t(n.substr(l))}function l(e){return e.v&&!e.cached_variants&&(e.cached_variants=e.v.map(function(t){return s(e,{v:null},t)})),e.cached_variants||e.eW&&[s(e)]||[e]}function u(e){function t(e){return e&&e.source||e}function r(r,a){return new RegExp(t(r),"m"+(e.cI?"i":"")+(a?"g":""))}function a(n,i){if(!n.compiled){if(n.compiled=!0,n.k=n.k||n.bK,n.k){var s={},c=function(t,r){e.cI&&(r=r.toLowerCase()),r.split(" ").forEach(function(e){var r=e.split("|");s[r[0]]=[t,r[1]?Number(r[1]):1]})};"string"==typeof n.k?c("keyword",n.k):k(n.k).forEach(function(e){c(e,n.k[e])}),n.k=s}n.lR=r(n.l||/\w+/,!0),i&&(n.bK&&(n.b="\\b("+n.bK.split(" ").join("|")+")\\b"),n.b||(n.b=/\B|\b/),n.bR=r(n.b),n.e||n.eW||(n.e=/\B|\b/),n.e&&(n.eR=r(n.e)),n.tE=t(n.e)||"",n.eW&&i.tE&&(n.tE+=(n.e?"|":"")+i.tE)),n.i&&(n.iR=r(n.i)),null==n.r&&(n.r=1),n.c||(n.c=[]),n.c=Array.prototype.concat.apply([],n.c.map(function(e){return l("self"===e?n:e)})),n.c.forEach(function(e){a(e,n)}),n.starts&&a(n.starts,i);var o=n.c.map(function(e){return e.bK?"\\.?("+e.b+")\\.?":e.b}).concat([n.tE,n.i]).map(t).filter(Boolean);n.t=o.length?r(o.join("|"),!0):{exec:function(){return null}}}}a(e)}function d(e,r,n,i){function s(e,t){var r,n;for(r=0,n=t.c.length;n>r;r++)if(a(t.c[r].bR,e))return t.c[r]}function c(e,t){if(a(e.eR,t)){for(;e.endsParent&&e.parent;)e=e.parent;return e}return e.eW?c(e.parent,t):void 0}function o(e,t){return!n&&a(t.iR,e)}function l(e,t){var r=v.cI?t[0].toLowerCase():t[0];return e.k.hasOwnProperty(r)&&e.k[r]}function p(e,t,r,a){var n=a?"":L.classPrefix,i='<span class="'+n,s=r?"":R;return i+=e+'">',i+t+s}function m(){var e,r,a,n;if(!N.k)return t(E);for(n="",r=0,N.lR.lastIndex=0,a=N.lR.exec(E);a;)n+=t(E.substring(r,a.index)),e=l(N,a),e?(M+=e[1],n+=p(e[0],t(a[0]))):n+=t(a[0]),r=N.lR.lastIndex,a=N.lR.exec(E);return n+t(E.substr(r))}function f(){var e="string"==typeof N.sL;if(e&&!x[N.sL])return t(E);var r=e?d(N.sL,E,!0,k[N.sL]):b(E,N.sL.length?N.sL:void 0);return N.r>0&&(M+=r.r),e&&(k[N.sL]=r.top),p(r.language,r.value,!1,!0)}function g(){C+=null!=N.sL?f():m(),E=""}function _(e){C+=e.cN?p(e.cN,"",!0):"",N=Object.create(e,{parent:{value:N}})}function h(e,t){if(E+=e,null==t)return g(),0;var r=s(t,N);if(r)return r.skip?E+=t:(r.eB&&(E+=t),g(),r.rB||r.eB||(E=t)),_(r,t),r.rB?0:t.length;var a=c(N,t);if(a){var n=N;n.skip?E+=t:(n.rE||n.eE||(E+=t),g(),n.eE&&(E=t));do N.cN&&(C+=R),N.skip||(M+=N.r),N=N.parent;while(N!==a.parent);return a.starts&&_(a.starts,""),n.rE?0:t.length}if(o(t,N))throw new Error('Illegal lexeme "'+t+'" for mode "'+(N.cN||"<unnamed>")+'"');return E+=t,t.length||1}var v=w(e);if(!v)throw new Error('Unknown language: "'+e+'"');u(v);var y,N=i||v,k={},C="";for(y=N;y!==v;y=y.parent)y.cN&&(C=p(y.cN,"",!0)+C);var E="",M=0;try{for(var B,S,$=0;;){if(N.t.lastIndex=$,B=N.t.exec(r),!B)break;S=h(r.substring($,B.index),B[0]),$=B.index+S}for(h(r.substr($)),y=N;y.parent;y=y.parent)y.cN&&(C+=R);return{r:M,value:C,language:e,top:N}}catch(A){if(A.message&&-1!==A.message.indexOf("Illegal"))return{r:0,value:t(r)};throw A}}function b(e,r){r=r||L.languages||k(x);var a={r:0,value:t(e)},n=a;return r.filter(w).forEach(function(t){var r=d(t,e,!1);r.language=t,r.r>n.r&&(n=r),r.r>a.r&&(n=a,a=r)}),n.language&&(a.second_best=n),a}function p(e){return L.tabReplace||L.useBR?e.replace(B,function(e,t){return L.useBR&&"\n"===e?"<br>":L.tabReplace?t.replace(/\t/g,L.tabReplace):""}):e}function m(e,t,r){var a=t?C[t]:r,n=[e.trim()];return e.match(/\bhljs\b/)||n.push("hljs"),-1===e.indexOf(a)&&n.push(a),n.join(" ").trim()}function f(e){var t,r,a,s,l,u=i(e);n(u)||(L.useBR?(t=document.createElementNS("http://www.w3.org/1999/xhtml","div"),t.innerHTML=e.innerHTML.replace(/\n/g,"").replace(/<br[ \/]*>/g,"\n")):t=e,l=t.textContent,a=u?d(u,l,!0):b(l),r=c(t),r.length&&(s=document.createElementNS("http://www.w3.org/1999/xhtml","div"),s.innerHTML=a.value,a.value=o(r,c(s),l)),a.value=p(a.value),e.innerHTML=a.value,e.className=m(e.className,u,a.language),e.result={language:a.language,re:a.r},a.second_best&&(e.second_best={language:a.second_best.language,re:a.second_best.r}))}function g(e){L=s(L,e)}function _(){if(!_.called){_.called=!0;var e=document.querySelectorAll("pre code");N.forEach.call(e,f)}}function h(){addEventListener("DOMContentLoaded",_,!1),addEventListener("load",_,!1)}function v(t,r){var a=x[t]=r(e);a.aliases&&a.aliases.forEach(function(e){C[e]=t})}function y(){return k(x)}function w(e){return e=(e||"").toLowerCase(),x[e]||x[C[e]]}var N=[],k=Object.keys,x={},C={},E=/^(no-?highlight|plain|text)$/i,M=/\blang(?:uage)?-([\w-]+)\b/i,B=/((^(<[^>]+>|\t|)+|(?:\n)))/gm,R="</span>",L={classPrefix:"hljs-",tabReplace:null,useBR:!1,languages:void 0};return e.highlight=d,e.highlightAuto=b,e.fixMarkup=p,e.highlightBlock=f,e.configure=g,e.initHighlighting=_,e.initHighlightingOnLoad=h,e.registerLanguage=v,e.listLanguages=y,e.getLanguage=w,e.inherit=s,e.IR="[a-zA-Z]\\w*",e.UIR="[a-zA-Z_]\\w*",e.NR="\\b\\d+(\\.\\d+)?",e.CNR="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",e.BNR="\\b(0b[01]+)",e.RSR="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",e.BE={b:"\\\\[\\s\\S]",r:0},e.ASM={cN:"string",b:"'",e:"'",i:"\\n",c:[e.BE]},e.QSM={cN:"string",b:'"',e:'"',i:"\\n",c:[e.BE]},e.PWM={b:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},e.C=function(t,r,a){var n=e.inherit({cN:"comment",b:t,e:r,c:[]},a||{});return n.c.push(e.PWM),n.c.push({cN:"doctag",b:"(?:TODO|FIXME|NOTE|BUG|XXX):",r:0}),n},e.CLCM=e.C("//","$"),e.CBCM=e.C("/\\*","\\*/"),e.HCM=e.C("#","$"),e.NM={cN:"number",b:e.NR,r:0},e.CNM={cN:"number",b:e.CNR,r:0},e.BNM={cN:"number",b:e.BNR,r:0},e.CSSNM={cN:"number",b:e.NR+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",r:0},e.RM={cN:"regexp",b:/\//,e:/\/[gimuy]*/,i:/\n/,c:[e.BE,{b:/\[/,e:/\]/,r:0,c:[e.BE]}]},e.TM={cN:"title",b:e.IR,r:0},e.UTM={cN:"title",b:e.UIR,r:0},e.METHOD_GUARD={b:"\\.\\s*"+e.UIR,r:0},e.registerLanguage("apache",function(e){var t={cN:"number",b:"[\\$%]\\d+"};return{aliases:["apacheconf"],cI:!0,c:[e.HCM,{cN:"section",b:"</?",e:">"},{cN:"attribute",b:/\w+/,r:0,k:{nomarkup:"order deny allow setenv rewriterule rewriteengine rewritecond documentroot sethandler errordocument loadmodule options header listen serverroot servername"},starts:{e:/$/,r:0,k:{literal:"on off all"},c:[{cN:"meta",b:"\\s\\[",e:"\\]$"},{cN:"variable",b:"[\\$%]\\{",e:"\\}",c:["self",t]},t,e.QSM]}}],i:/\S/}}),e.registerLanguage("bash",function(e){var t={cN:"variable",v:[{b:/\$[\w\d#@][\w\d_]*/},{b:/\$\{(.*?)}/}]},r={cN:"string",b:/"/,e:/"/,c:[e.BE,t,{cN:"variable",b:/\$\(/,e:/\)/,c:[e.BE]}]},a={cN:"string",b:/'/,e:/'/};return{aliases:["sh","zsh"],l:/\b-?[a-z\._]+\b/,k:{keyword:"if then else elif fi for while in do done case esac function",literal:"true false",built_in:"break cd continue eval exec exit export getopts hash pwd readonly return shift test times trap umask unset alias bind builtin caller command declare echo enable help let local logout mapfile printf read readarray source type typeset ulimit unalias set shopt autoload bg bindkey bye cap chdir clone comparguments compcall compctl compdescribe compfiles compgroups compquote comptags comptry compvalues dirs disable disown echotc echoti emulate fc fg float functions getcap getln history integer jobs kill limit log noglob popd print pushd pushln rehash sched setcap setopt stat suspend ttyctl unfunction unhash unlimit unsetopt vared wait whence where which zcompile zformat zftp zle zmodload zparseopts zprof zpty zregexparse zsocket zstyle ztcp",_:"-ne -eq -lt -gt -f -d -e -s -l -a"},c:[{cN:"meta",b:/^#![^\n]+sh\s*$/,r:10},{cN:"function",b:/\w[\w\d_]*\s*\(\s*\)\s*\{/,rB:!0,c:[e.inherit(e.TM,{b:/\w[\w\d_]*/})],r:0},e.HCM,r,a,t]}}),e.registerLanguage("coffeescript",function(e){var t={keyword:"in if for while finally new do return else break catch instanceof throw try this switch continue typeof delete debugger super yield import export from as default await then unless until loop of by when and or is isnt not",literal:"true false null undefined yes no on off",built_in:"npm require console print module global window document"},r="[A-Za-z$_][0-9A-Za-z$_]*",a={cN:"subst",b:/#\{/,e:/}/,k:t},n=[e.BNM,e.inherit(e.CNM,{starts:{e:"(\\s*/)?",r:0}}),{cN:"string",v:[{b:/'''/,e:/'''/,c:[e.BE]},{b:/'/,e:/'/,c:[e.BE]},{b:/"""/,e:/"""/,c:[e.BE,a]},{b:/"/,e:/"/,c:[e.BE,a]}]},{cN:"regexp",v:[{b:"///",e:"///",c:[a,e.HCM]},{b:"//[gim]*",r:0},{b:/\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/}]},{b:"@"+r},{sL:"javascript",eB:!0,eE:!0,v:[{b:"```",e:"```"},{b:"`",e:"`"}]}];a.c=n;var i=e.inherit(e.TM,{b:r}),s="(\\(.*\\))?\\s*\\B[-=]>",c={cN:"params",b:"\\([^\\(]",rB:!0,c:[{b:/\(/,e:/\)/,k:t,c:["self"].concat(n)}]};return{aliases:["coffee","cson","iced"],k:t,i:/\/\*/,c:n.concat([e.C("###","###"),e.HCM,{cN:"function",b:"^\\s*"+r+"\\s*=\\s*"+s,e:"[-=]>",rB:!0,c:[i,c]},{b:/[:\(,=]\s*/,r:0,c:[{cN:"function",b:s,e:"[-=]>",rB:!0,c:[c]}]},{cN:"class",bK:"class",e:"$",i:/[:="\[\]]/,c:[{bK:"extends",eW:!0,i:/[:="\[\]]/,c:[i]},i]},{b:r+":",e:":",rB:!0,rE:!0,r:0}])}}),e.registerLanguage("cpp",function(e){var t={cN:"keyword",b:"\\b[a-z\\d_]*_t\\b"},r={cN:"string",v:[{b:'(u8?|U)?L?"',e:'"',i:"\\n",c:[e.BE]},{b:'(u8?|U)?R"',e:'"',c:[e.BE]},{b:"'\\\\?.",e:"'",i:"."}]},a={cN:"number",v:[{b:"\\b(0b[01']+)"},{b:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{b:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],r:0},n={cN:"meta",b:/#\s*[a-z]+\b/,e:/$/,k:{"meta-keyword":"if else elif endif define undef warning error line pragma ifdef ifndef include"},c:[{b:/\\\n/,r:0},e.inherit(r,{cN:"meta-string"}),{cN:"meta-string",b:/<[^\n>]*>/,e:/$/,i:"\\n"},e.CLCM,e.CBCM]},i=e.IR+"\\s*\\(",s={keyword:"int float while private char catch import module export virtual operator sizeof dynamic_cast|10 typedef const_cast|10 const for static_cast|10 union namespace unsigned long volatile static protected bool template mutable if public friend do goto auto void enum else break extern using asm case typeid short reinterpret_cast|10 default double register explicit signed typename try this switch continue inline delete alignof constexpr decltype noexcept static_assert thread_local restrict _Bool complex _Complex _Imaginary atomic_bool atomic_char atomic_schar atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong atomic_ullong new throw return and or not",built_in:"std string cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap array shared_ptr abort abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr",literal:"true false nullptr NULL"},c=[t,e.CLCM,e.CBCM,a,r];return{aliases:["c","cc","h","c++","h++","hpp"],k:s,i:"</",c:c.concat([n,{b:"\\b(deque|list|queue|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<",e:">",k:s,c:["self",t]},{b:e.IR+"::",k:s},{v:[{b:/=/,e:/;/},{b:/\(/,e:/\)/},{bK:"new throw return else",e:/;/}],k:s,c:c.concat([{b:/\(/,e:/\)/,k:s,c:c.concat(["self"]),r:0}]),r:0},{cN:"function",b:"("+e.IR+"[\\*&\\s]+)+"+i,rB:!0,e:/[{;=]/,eE:!0,k:s,i:/[^\w\s\*&]/,c:[{b:i,rB:!0,c:[e.TM],r:0},{cN:"params",b:/\(/,e:/\)/,k:s,r:0,c:[e.CLCM,e.CBCM,r,a,t]},e.CLCM,e.CBCM,n]},{cN:"class",bK:"class struct",e:/[{;:]/,c:[{b:/</,e:/>/,c:["self"]},e.TM]}]),exports:{preprocessor:n,strings:r,k:s}}}),e.registerLanguage("cs",function(e){var t={keyword:"abstract as base bool break byte case catch char checked const continue decimal default delegate do double enum event explicit extern finally fixed float for foreach goto if implicit in int interface internal is lock long nameof object operator out override params private protected public readonly ref sbyte sealed short sizeof stackalloc static string struct switch this try typeof uint ulong unchecked unsafe ushort using virtual void volatile while add alias ascending async await by descending dynamic equals from get global group into join let on orderby partial remove select set value var where yield",literal:"null false true"},r={cN:"string",b:'@"',e:'"',c:[{b:'""'}]},a=e.inherit(r,{i:/\n/}),n={cN:"subst",b:"{",e:"}",k:t},i=e.inherit(n,{i:/\n/}),s={cN:"string",b:/\$"/,e:'"',i:/\n/,c:[{b:"{{"},{b:"}}"},e.BE,i]},c={cN:"string",b:/\$@"/,e:'"',c:[{b:"{{"},{b:"}}"},{b:'""'},n]},o=e.inherit(c,{i:/\n/,c:[{b:"{{"},{b:"}}"},{b:'""'},i]});n.c=[c,s,r,e.ASM,e.QSM,e.CNM,e.CBCM],i.c=[o,s,a,e.ASM,e.QSM,e.CNM,e.inherit(e.CBCM,{i:/\n/})];var l={v:[c,s,r,e.ASM,e.QSM]},u=e.IR+"(<"+e.IR+"(\\s*,\\s*"+e.IR+")*>)?(\\[\\])?";return{aliases:["csharp"],k:t,i:/::/,c:[e.C("///","$",{rB:!0,c:[{cN:"doctag",v:[{b:"///",r:0},{b:"<!--|-->"},{b:"</?",e:">"}]}]}),e.CLCM,e.CBCM,{cN:"meta",b:"#",e:"$",k:{"meta-keyword":"if else elif endif define undef warning error line region endregion pragma checksum"}},l,e.CNM,{bK:"class interface",e:/[{;=]/,i:/[^\s:]/,c:[e.TM,e.CLCM,e.CBCM]},{bK:"namespace",e:/[{;=]/,i:/[^\s:]/,c:[e.inherit(e.TM,{b:"[a-zA-Z](\\.?\\w)*"}),e.CLCM,e.CBCM]},{cN:"meta",b:"^\\s*\\[",eB:!0,e:"\\]",eE:!0,c:[{cN:"meta-string",b:/"/,e:/"/}]},{bK:"new return throw await else",r:0},{cN:"function",b:"("+u+"\\s+)+"+e.IR+"\\s*\\(",rB:!0,e:/[{;=]/,eE:!0,k:t,c:[{b:e.IR+"\\s*\\(",rB:!0,c:[e.TM],r:0},{cN:"params",b:/\(/,e:/\)/,eB:!0,eE:!0,k:t,r:0,c:[l,e.CNM,e.CBCM]},e.CLCM,e.CBCM]}]}}),e.registerLanguage("css",function(e){var t="[a-zA-Z-][a-zA-Z0-9_-]*",r={b:/[A-Z\_\.\-]+\s*:/,rB:!0,e:";",eW:!0,c:[{cN:"attribute",b:/\S/,e:":",eE:!0,starts:{eW:!0,eE:!0,c:[{b:/[\w-]+\(/,rB:!0,c:[{cN:"built_in",b:/[\w-]+/},{b:/\(/,e:/\)/,c:[e.ASM,e.QSM]}]},e.CSSNM,e.QSM,e.ASM,e.CBCM,{cN:"number",b:"#[0-9A-Fa-f]+"},{cN:"meta",b:"!important"}]}}]};return{cI:!0,i:/[=\/|'\$]/,c:[e.CBCM,{cN:"selector-id",b:/#[A-Za-z0-9_-]+/},{cN:"selector-class",b:/\.[A-Za-z0-9_-]+/},{cN:"selector-attr",b:/\[/,e:/\]/,i:"$"},{cN:"selector-pseudo",b:/:(:)?[a-zA-Z0-9\_\-\+\(\)"'.]+/},{b:"@(font-face|page)",l:"[a-z-]+",k:"font-face page"},{b:"@",e:"[{;]",i:/:/,c:[{cN:"keyword",b:/\w+/},{b:/\s/,eW:!0,eE:!0,r:0,c:[e.ASM,e.QSM,e.CSSNM]}]},{cN:"selector-tag",b:t,r:0},{b:"{",e:"}",i:/\S/,c:[e.CBCM,r]}]}}),e.registerLanguage("diff",function(e){return{aliases:["patch"],c:[{cN:"meta",r:10,v:[{b:/^@@ +\-\d+,\d+ +\+\d+,\d+ +@@$/},{b:/^\*\*\* +\d+,\d+ +\*\*\*\*$/},{b:/^\-\-\- +\d+,\d+ +\-\-\-\-$/}]},{cN:"comment",v:[{b:/Index: /,e:/$/},{b:/={3,}/,e:/$/},{b:/^\-{3}/,e:/$/},{b:/^\*{3} /,e:/$/},{b:/^\+{3}/,e:/$/},{b:/\*{5}/,e:/\*{5}$/}]},{cN:"addition",b:"^\\+",e:"$"},{cN:"deletion",b:"^\\-",e:"$"},{cN:"addition",b:"^\\!",e:"$"}]}}),e.registerLanguage("http",function(e){var t="HTTP/[0-9\\.]+";return{aliases:["https"],i:"\\S",c:[{b:"^"+t,e:"$",c:[{cN:"number",b:"\\b\\d{3}\\b"}]},{b:"^[A-Z]+ (.*?) "+t+"$",rB:!0,e:"$",c:[{cN:"string",b:" ",e:" ",eB:!0,eE:!0},{b:t},{cN:"keyword",b:"[A-Z]+"}]},{cN:"attribute",b:"^\\w",e:": ",eE:!0,i:"\\n|\\s|=",starts:{e:"$",r:0}},{b:"\\n\\n",starts:{sL:[],eW:!0}}]}}),e.registerLanguage("ini",function(e){var t={cN:"string",c:[e.BE],v:[{b:"'''",e:"'''",r:10},{b:'"""',e:'"""',r:10},{b:'"',e:'"'},{b:"'",e:"'"}]};return{aliases:["toml"],cI:!0,i:/\S/,c:[e.C(";","$"),e.HCM,{cN:"section",b:/^\s*\[+/,e:/\]+/},{b:/^[a-z0-9\[\]_-]+\s*=\s*/,e:"$",rB:!0,c:[{cN:"attr",b:/[a-z0-9\[\]_-]+/},{b:/=/,eW:!0,r:0,c:[{cN:"literal",b:/\bon|off|true|false|yes|no\b/},{cN:"variable",v:[{b:/\$[\w\d"][\w\d_]*/},{b:/\$\{(.*?)}/}]},t,{cN:"number",b:/([\+\-]+)?[\d]+_[\d_]+/},e.NM]}]}]}}),e.registerLanguage("java",function(e){var t="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",r=t+"(<"+t+"(\\s*,\\s*"+t+")*>)?",a="false synchronized int abstract float private char boolean static null if const for true while long strictfp finally protected import native final void enum else break transient catch instanceof byte super volatile case assert short package default double public try this switch continue throws protected public private module requires exports do",n="\\b(0[bB]([01]+[01_]+[01]+|[01]+)|0[xX]([a-fA-F0-9]+[a-fA-F0-9_]+[a-fA-F0-9]+|[a-fA-F0-9]+)|(([\\d]+[\\d_]+[\\d]+|[\\d]+)(\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))?|\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))([eE][-+]?\\d+)?)[lLfF]?",i={cN:"number",b:n,r:0};return{aliases:["jsp"],k:a,i:/<\/|#/,c:[e.C("/\\*\\*","\\*/",{r:0,c:[{b:/\w+@/,r:0},{cN:"doctag",b:"@[A-Za-z]+"}]}),e.CLCM,e.CBCM,e.ASM,e.QSM,{cN:"class",bK:"class interface",e:/[{;=]/,eE:!0,k:"class interface",i:/[:"\[\]]/,c:[{bK:"extends implements"},e.UTM]},{bK:"new throw return else",r:0},{cN:"function",b:"("+r+"\\s+)+"+e.UIR+"\\s*\\(",rB:!0,e:/[{;=]/,eE:!0,k:a,c:[{b:e.UIR+"\\s*\\(",rB:!0,r:0,c:[e.UTM]},{cN:"params",b:/\(/,e:/\)/,k:a,r:0,c:[e.ASM,e.QSM,e.CNM,e.CBCM]},e.CLCM,e.CBCM]},i,{cN:"meta",b:"@[A-Za-z]+"}]}}),e.registerLanguage("javascript",function(e){var t="[A-Za-z$_][0-9A-Za-z$_]*",r={keyword:"in of if for while finally var new function do return void else break catch instanceof with throw case default try this switch continue typeof delete let yield const export super debugger as async await static import from as",literal:"true false null undefined NaN Infinity",built_in:"eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent encodeURI encodeURIComponent escape unescape Object Function Boolean Error EvalError InternalError RangeError ReferenceError StopIteration SyntaxError TypeError URIError Number Math Date String RegExp Array Float32Array Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require module console window document Symbol Set Map WeakSet WeakMap Proxy Reflect Promise"},a={cN:"number",v:[{b:"\\b(0[bB][01]+)"},{b:"\\b(0[oO][0-7]+)"},{b:e.CNR}],r:0},n={cN:"subst",b:"\\$\\{",e:"\\}",k:r,c:[]},i={cN:"string",b:"`",e:"`",c:[e.BE,n]};n.c=[e.ASM,e.QSM,i,a,e.RM];var s=n.c.concat([e.CBCM,e.CLCM]);return{aliases:["js","jsx"],k:r,c:[{cN:"meta",r:10,b:/^\s*['"]use (strict|asm)['"]/},{cN:"meta",b:/^#!/,e:/$/},e.ASM,e.QSM,i,e.CLCM,e.CBCM,a,{b:/[{,]\s*/,r:0,c:[{b:t+"\\s*:",rB:!0,r:0,c:[{cN:"attr",b:t,r:0}]}]},{b:"("+e.RSR+"|\\b(case|return|throw)\\b)\\s*",k:"return throw case",c:[e.CLCM,e.CBCM,e.RM,{cN:"function",b:"(\\(.*?\\)|"+t+")\\s*=>",rB:!0,e:"\\s*=>",c:[{cN:"params",v:[{b:t},{b:/\(\s*\)/},{b:/\(/,e:/\)/,eB:!0,eE:!0,k:r,c:s}]}]},{b:/</,e:/(\/\w+|\w+\/)>/,sL:"xml",c:[{b:/<\w+\s*\/>/,skip:!0},{b:/<\w+/,e:/(\/\w+|\w+\/)>/,skip:!0,c:[{b:/<\w+\s*\/>/,skip:!0},"self"]}]}],r:0},{cN:"function",bK:"function",e:/\{/,eE:!0,c:[e.inherit(e.TM,{b:t}),{cN:"params",b:/\(/,e:/\)/,eB:!0,eE:!0,c:s}],i:/\[|%/},{b:/\$[(.]/},e.METHOD_GUARD,{cN:"class",bK:"class",e:/[{;=]/,eE:!0,i:/[:"\[\]]/,c:[{bK:"extends"},e.UTM]},{bK:"constructor",e:/\{/,eE:!0}],i:/#(?!!)/}}),e.registerLanguage("json",function(e){var t={literal:"true false null"},r=[e.QSM,e.CNM],a={e:",",eW:!0,eE:!0,c:r,k:t},n={b:"{",e:"}",c:[{cN:"attr",b:/"/,e:/"/,c:[e.BE],i:"\\n"},e.inherit(a,{b:/:/})],i:"\\S"},i={b:"\\[",e:"\\]",c:[e.inherit(a)],i:"\\S"};return r.splice(r.length,0,n,i),{c:r,k:t,i:"\\S"}}),e.registerLanguage("makefile",function(e){var t={cN:"variable",v:[{b:"\\$\\("+e.UIR+"\\)",c:[e.BE]},{b:/\$[@%<?\^\+\*]/}]},r={cN:"string",b:/"/,e:/"/,c:[e.BE,t]},a={cN:"variable",b:/\$\([\w-]+\s/,e:/\)/,k:{built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"},c:[t]},n={b:"^"+e.UIR+"\\s*[:+?]?=",i:"\\n",rB:!0,c:[{b:"^"+e.UIR,e:"[:+?]?=",eE:!0}]},i={cN:"meta",b:/^\.PHONY:/,e:/$/,k:{"meta-keyword":".PHONY"},l:/[\.\w]+/},s={cN:"section",b:/^[^\s]+:/,e:/$/,c:[t]};return{aliases:["mk","mak"],k:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath",l:/[\w-]+/,c:[e.HCM,t,r,a,n,i,s]}}),e.registerLanguage("xml",function(e){var t="[A-Za-z0-9\\._:-]+",r={eW:!0,i:/</,r:0,c:[{cN:"attr",b:t,r:0},{b:/=\s*/,r:0,c:[{cN:"string",endsParent:!0,v:[{b:/"/,e:/"/},{b:/'/,e:/'/},{b:/[^\s"'=<>`]+/}]}]}]};return{aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist"],cI:!0,c:[{cN:"meta",b:"<!DOCTYPE",e:">",r:10,c:[{b:"\\[",e:"\\]"}]},e.C("<!--","-->",{r:10}),{b:"<\\!\\[CDATA\\[",e:"\\]\\]>",r:10},{b:/<\?(php)?/,e:/\?>/,sL:"php",c:[{b:"/\\*",e:"\\*/",skip:!0}]},{cN:"tag",b:"<style(?=\\s|>|$)",e:">",k:{name:"style"},c:[r],starts:{e:"</style>",rE:!0,sL:["css","xml"]}},{cN:"tag",b:"<script(?=\\s|>|$)",e:">",k:{name:"script"},c:[r],starts:{e:"</script>",rE:!0,sL:["actionscript","javascript","handlebars","xml"]}},{cN:"meta",v:[{b:/<\?xml/,e:/\?>/,r:10},{b:/<\?\w+/,e:/\?>/}]},{cN:"tag",b:"</?",e:"/?>",c:[{cN:"name",b:/[^\/><\s]+/,r:0},r]}]}}),e.registerLanguage("markdown",function(e){return{aliases:["md","mkdown","mkd"],c:[{cN:"section",v:[{b:"^#{1,6}",e:"$"},{b:"^.+?\\n[=-]{2,}$"}]},{b:"<",e:">",sL:"xml",r:0},{cN:"bullet",b:"^([*+-]|(\\d+\\.))\\s+"},{cN:"strong",b:"[*_]{2}.+?[*_]{2}"},{cN:"emphasis",v:[{b:"\\*.+?\\*"},{b:"_.+?_",r:0}]},{cN:"quote",b:"^>\\s+",e:"$"},{cN:"code",v:[{b:"^```w*s*$",e:"^```s*$"},{b:"`.+?`"},{b:"^( {4}|	)",e:"$",r:0}]},{b:"^[-\\*]{3,}",e:"$"},{b:"\\[.+?\\][\\(\\[].*?[\\)\\]]",rB:!0,c:[{cN:"string",b:"\\[",e:"\\]",eB:!0,rE:!0,r:0},{cN:"link",b:"\\]\\(",e:"\\)",eB:!0,eE:!0},{cN:"symbol",b:"\\]\\[",e:"\\]",eB:!0,eE:!0}],r:10},{b:/^\[[^\n]+\]:/,rB:!0,c:[{cN:"symbol",b:/\[/,e:/\]/,eB:!0,eE:!0},{cN:"link",b:/:\s*/,e:/$/,eB:!0}]}]}}),e.registerLanguage("nginx",function(e){var t={cN:"variable",v:[{b:/\$\d+/},{b:/\$\{/,e:/}/},{b:"[\\$\\@]"+e.UIR}]},r={eW:!0,l:"[a-z/_]+",k:{literal:"on off yes no true false none blocked debug info notice warn error crit select break last permanent redirect kqueue rtsig epoll poll /dev/poll"},r:0,i:"=>",c:[e.HCM,{cN:"string",c:[e.BE,t],v:[{b:/"/,e:/"/},{b:/'/,e:/'/}]},{b:"([a-z]+):/",e:"\\s",eW:!0,eE:!0,c:[t]},{cN:"regexp",c:[e.BE,t],v:[{b:"\\s\\^",e:"\\s|{|;",rE:!0},{b:"~\\*?\\s+",e:"\\s|{|;",rE:!0},{b:"\\*(\\.[a-z\\-]+)+"},{b:"([a-z\\-]+\\.)+\\*"}]},{cN:"number",b:"\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b"},{cN:"number",b:"\\b\\d+[kKmMgGdshdwy]*\\b",r:0},t]};return{aliases:["nginxconf"],c:[e.HCM,{b:e.UIR+"\\s+{",rB:!0,e:"{",c:[{cN:"section",b:e.UIR}],r:0},{b:e.UIR+"\\s",e:";|{",rB:!0,c:[{cN:"attribute",b:e.UIR,starts:r}],r:0}],i:"[^\\s\\}]"}}),e.registerLanguage("objectivec",function(e){var t={cN:"built_in",b:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"},r={keyword:"int float while char export sizeof typedef const struct for union unsigned long volatile static bool mutable if do return goto void enum else break extern asm case short default double register explicit signed typename this switch continue wchar_t inline readonly assign readwrite self @synchronized id typeof nonatomic super unichar IBOutlet IBAction strong weak copy in out inout bycopy byref oneway __strong __weak __block __autoreleasing @private @protected @public @try @property @end @throw @catch @finally @autoreleasepool @synthesize @dynamic @selector @optional @required @encode @package @import @defs @compatibility_alias __bridge __bridge_transfer __bridge_retained __bridge_retain __covariant __contravariant __kindof _Nonnull _Nullable _Null_unspecified __FUNCTION__ __PRETTY_FUNCTION__ __attribute__ getter setter retain unsafe_unretained nonnull nullable null_unspecified null_resettable class instancetype NS_DESIGNATED_INITIALIZER NS_UNAVAILABLE NS_REQUIRES_SUPER NS_RETURNS_INNER_POINTER NS_INLINE NS_AVAILABLE NS_DEPRECATED NS_ENUM NS_OPTIONS NS_SWIFT_UNAVAILABLE NS_ASSUME_NONNULL_BEGIN NS_ASSUME_NONNULL_END NS_REFINED_FOR_SWIFT NS_SWIFT_NAME NS_SWIFT_NOTHROW NS_DURING NS_HANDLER NS_ENDHANDLER NS_VALUERETURN NS_VOIDRETURN",literal:"false true FALSE TRUE nil YES NO NULL",built_in:"BOOL dispatch_once_t dispatch_queue_t dispatch_sync dispatch_async dispatch_once"},a=/[a-zA-Z@][a-zA-Z0-9_]*/,n="@interface @class @protocol @implementation";return{aliases:["mm","objc","obj-c"],k:r,l:a,i:"</",c:[t,e.CLCM,e.CBCM,e.CNM,e.QSM,{cN:"string",v:[{b:'@"',e:'"',i:"\\n",c:[e.BE]},{b:"'",e:"[^\\\\]'",i:"[^\\\\][^']"}]},{cN:"meta",b:"#",e:"$",c:[{cN:"meta-string",v:[{b:'"',e:'"'},{b:"<",e:">"}]}]},{cN:"class",b:"("+n.split(" ").join("|")+")\\b",e:"({|$)",eE:!0,k:n,l:a,c:[e.UTM]},{b:"\\."+e.UIR,r:0}]}}),e.registerLanguage("perl",function(e){var t="getpwent getservent quotemeta msgrcv scalar kill dbmclose undef lc ma syswrite tr send umask sysopen shmwrite vec qx utime local oct semctl localtime readpipe do return format read sprintf dbmopen pop getpgrp not getpwnam rewinddir qqfileno qw endprotoent wait sethostent bless s|0 opendir continue each sleep endgrent shutdown dump chomp connect getsockname die socketpair close flock exists index shmgetsub for endpwent redo lstat msgctl setpgrp abs exit select print ref gethostbyaddr unshift fcntl syscall goto getnetbyaddr join gmtime symlink semget splice x|0 getpeername recv log setsockopt cos last reverse gethostbyname getgrnam study formline endhostent times chop length gethostent getnetent pack getprotoent getservbyname rand mkdir pos chmod y|0 substr endnetent printf next open msgsnd readdir use unlink getsockopt getpriority rindex wantarray hex system getservbyport endservent int chr untie rmdir prototype tell listen fork shmread ucfirst setprotoent else sysseek link getgrgid shmctl waitpid unpack getnetbyname reset chdir grep split require caller lcfirst until warn while values shift telldir getpwuid my getprotobynumber delete and sort uc defined srand accept package seekdir getprotobyname semop our rename seek if q|0 chroot sysread setpwent no crypt getc chown sqrt write setnetent setpriority foreach tie sin msgget map stat getlogin unless elsif truncate exec keys glob tied closedirioctl socket readlink eval xor readline binmode setservent eof ord bind alarm pipe atan2 getgrent exp time push setgrent gt lt or ne m|0 break given say state when",r={cN:"subst",b:"[$@]\\{",e:"\\}",k:t},a={b:"->{",e:"}"},n={v:[{b:/\$\d/},{b:/[\$%@](\^\w\b|#\w+(::\w+)*|{\w+}|\w+(::\w*)*)/},{b:/[\$%@][^\s\w{]/,r:0}]},i=[e.BE,r,n],s=[n,e.HCM,e.C("^\\=\\w","\\=cut",{eW:!0}),a,{cN:"string",c:i,v:[{b:"q[qwxr]?\\s*\\(",e:"\\)",r:5},{b:"q[qwxr]?\\s*\\[",e:"\\]",r:5},{b:"q[qwxr]?\\s*\\{",e:"\\}",r:5},{b:"q[qwxr]?\\s*\\|",e:"\\|",r:5},{b:"q[qwxr]?\\s*\\<",e:"\\>",r:5},{b:"qw\\s+q",e:"q",r:5},{b:"'",e:"'",c:[e.BE]},{b:'"',e:'"'},{b:"`",e:"`",c:[e.BE]},{b:"{\\w+}",c:[],r:0},{b:"-?\\w+\\s*\\=\\>",c:[],r:0}]},{cN:"number",b:"(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",r:0},{b:"(\\/\\/|"+e.RSR+"|\\b(split|return|print|reverse|grep)\\b)\\s*",k:"split return print reverse grep",r:0,c:[e.HCM,{cN:"regexp",b:"(s|tr|y)/(\\\\.|[^/])*/(\\\\.|[^/])*/[a-z]*",r:10},{cN:"regexp",b:"(m|qr)?/",e:"/[a-z]*",c:[e.BE],r:0}]},{cN:"function",bK:"sub",e:"(\\s*\\(.*?\\))?[;{]",eE:!0,r:5,c:[e.TM]},{b:"-\\w\\b",r:0},{b:"^__DATA__$",e:"^__END__$",sL:"mojolicious",c:[{b:"^@@.*",e:"$",cN:"comment"}]}];return r.c=s,a.c=s,{aliases:["pl","pm"],l:/[\w\.]+/,k:t,c:s}}),e.registerLanguage("php",function(e){var t={b:"\\$+[a-zA-Z_-ÿ][a-zA-Z0-9_-ÿ]*"},r={cN:"meta",b:/<\?(php)?|\?>/},a={cN:"string",c:[e.BE,r],v:[{b:'b"',e:'"'},{b:"b'",e:"'"},e.inherit(e.ASM,{i:null}),e.inherit(e.QSM,{i:null})]},n={v:[e.BNM,e.CNM]};return{aliases:["php3","php4","php5","php6"],cI:!0,k:"and include_once list abstract global private echo interface as static endswitch array null if endwhile or const for endforeach self var while isset public protected exit foreach throw elseif include __FILE__ empty require_once do xor return parent clone use __CLASS__ __LINE__ else break print eval new catch __METHOD__ case exception default die require __FUNCTION__ enddeclare final try switch continue endfor endif declare unset true false trait goto instanceof insteadof __DIR__ __NAMESPACE__ yield finally",c:[e.HCM,e.C("//","$",{c:[r]}),e.C("/\\*","\\*/",{c:[{cN:"doctag",b:"@[A-Za-z]+"}]}),e.C("__halt_compiler.+?;",!1,{eW:!0,k:"__halt_compiler",l:e.UIR}),{cN:"string",b:/<<<['"]?\w+['"]?$/,e:/^\w+;?$/,c:[e.BE,{cN:"subst",v:[{b:/\$\w+/},{b:/\{\$/,e:/\}/}]}]},r,{cN:"keyword",b:/\$this\b/},t,{b:/(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/},{cN:"function",bK:"function",e:/[;{]/,eE:!0,i:"\\$|\\[|%",c:[e.UTM,{cN:"params",b:"\\(",e:"\\)",c:["self",t,e.CBCM,a,n]}]},{cN:"class",bK:"class interface",e:"{",eE:!0,i:/[:\(\$"]/,c:[{bK:"extends implements"},e.UTM]},{bK:"namespace",e:";",i:/[\.']/,c:[e.UTM]},{bK:"use",e:";",c:[e.UTM]},{b:"=>"},a,n]}}),e.registerLanguage("python",function(e){var t={keyword:"and elif is global as in if from raise for except finally print import pass return exec else break not with class assert yield try while continue del or def lambda async await nonlocal|10 None True False",built_in:"Ellipsis NotImplemented"},r={cN:"meta",b:/^(>>>|\.\.\.) /},a={cN:"subst",b:/\{/,e:/\}/,k:t,i:/#/},n={cN:"string",c:[e.BE],v:[{b:/(u|b)?r?'''/,e:/'''/,c:[r],r:10},{b:/(u|b)?r?"""/,e:/"""/,c:[r],r:10},{b:/(fr|rf|f)'''/,e:/'''/,c:[r,a]},{b:/(fr|rf|f)"""/,e:/"""/,c:[r,a]},{b:/(u|r|ur)'/,e:/'/,r:10},{b:/(u|r|ur)"/,e:/"/,r:10},{b:/(b|br)'/,e:/'/},{b:/(b|br)"/,e:/"/},{b:/(fr|rf|f)'/,e:/'/,c:[a]},{b:/(fr|rf|f)"/,e:/"/,c:[a]},e.ASM,e.QSM]},i={cN:"number",r:0,v:[{b:e.BNR+"[lLjJ]?"},{b:"\\b(0o[0-7]+)[lLjJ]?"},{b:e.CNR+"[lLjJ]?"}]},s={cN:"params",b:/\(/,e:/\)/,c:["self",r,i,n]};return a.c=[n,i,r],{aliases:["py","gyp"],k:t,i:/(<\/|->|\?)|=>/,c:[r,i,n,e.HCM,{v:[{cN:"function",bK:"def"},{cN:"class",bK:"class"}],e:/:/,i:/[${=;\n,]/,c:[e.UTM,s,{b:/->/,eW:!0,k:"None"}]},{cN:"meta",b:/^[\t ]*@/,e:/$/},{b:/\b(print|exec)\(/}]}}),e.registerLanguage("ruby",function(e){
var t="[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?",r={keyword:"and then defined module in return redo if BEGIN retry end for self when next until do begin unless END rescue else break undef not super class case require yield alias while ensure elsif or include attr_reader attr_writer attr_accessor",literal:"true false nil"},a={cN:"doctag",b:"@[A-Za-z]+"},n={b:"#<",e:">"},i=[e.C("#","$",{c:[a]}),e.C("^\\=begin","^\\=end",{c:[a],r:10}),e.C("^__END__","\\n$")],s={cN:"subst",b:"#\\{",e:"}",k:r},c={cN:"string",c:[e.BE,s],v:[{b:/'/,e:/'/},{b:/"/,e:/"/},{b:/`/,e:/`/},{b:"%[qQwWx]?\\(",e:"\\)"},{b:"%[qQwWx]?\\[",e:"\\]"},{b:"%[qQwWx]?{",e:"}"},{b:"%[qQwWx]?<",e:">"},{b:"%[qQwWx]?/",e:"/"},{b:"%[qQwWx]?%",e:"%"},{b:"%[qQwWx]?-",e:"-"},{b:"%[qQwWx]?\\|",e:"\\|"},{b:/\B\?(\\\d{1,3}|\\x[A-Fa-f0-9]{1,2}|\\u[A-Fa-f0-9]{4}|\\?\S)\b/},{b:/<<(-?)\w+$/,e:/^\s*\w+$/}]},o={cN:"params",b:"\\(",e:"\\)",endsParent:!0,k:r},l=[c,n,{cN:"class",bK:"class module",e:"$|;",i:/=/,c:[e.inherit(e.TM,{b:"[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?"}),{b:"<\\s*",c:[{b:"("+e.IR+"::)?"+e.IR}]}].concat(i)},{cN:"function",bK:"def",e:"$|;",c:[e.inherit(e.TM,{b:t}),o].concat(i)},{b:e.IR+"::"},{cN:"symbol",b:e.UIR+"(\\!|\\?)?:",r:0},{cN:"symbol",b:":(?!\\s)",c:[c,{b:t}],r:0},{cN:"number",b:"(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",r:0},{b:"(\\$\\W)|((\\$|\\@\\@?)(\\w+))"},{cN:"params",b:/\|/,e:/\|/,k:r},{b:"("+e.RSR+"|unless)\\s*",k:"unless",c:[n,{cN:"regexp",c:[e.BE,s],i:/\n/,v:[{b:"/",e:"/[a-z]*"},{b:"%r{",e:"}[a-z]*"},{b:"%r\\(",e:"\\)[a-z]*"},{b:"%r!",e:"![a-z]*"},{b:"%r\\[",e:"\\][a-z]*"}]}].concat(i),r:0}].concat(i);s.c=l,o.c=l;var u="[>?]>",d="[\\w#]+\\(\\w+\\):\\d+:\\d+>",b="(\\w+-)?\\d+\\.\\d+\\.\\d(p\\d+)?[^>]+>",p=[{b:/^\s*=>/,starts:{e:"$",c:l}},{cN:"meta",b:"^("+u+"|"+d+"|"+b+")",starts:{e:"$",c:l}}];return{aliases:["rb","gemspec","podspec","thor","irb"],k:r,i:/\/\*/,c:i.concat(p).concat(l)}}),e.registerLanguage("shell",function(e){return{aliases:["console"],c:[{cN:"meta",b:"^\\s{0,3}[\\w\\d\\[\\]()@-]*[>%$#]",starts:{e:"$",sL:"bash"}}]}}),e.registerLanguage("sql",function(e){var t=e.C("--","$");return{cI:!0,i:/[<>{}*#]/,c:[{bK:"begin end start commit rollback savepoint lock alter create drop rename call delete do handler insert load replace select truncate update set show pragma grant merge describe use explain help declare prepare execute deallocate release unlock purge reset change stop analyze cache flush optimize repair kill install uninstall checksum restore check backup revoke comment",e:/;/,eW:!0,l:/[\w\.]+/,k:{keyword:"abort abs absolute acc acce accep accept access accessed accessible account acos action activate add addtime admin administer advanced advise aes_decrypt aes_encrypt after agent aggregate ali alia alias allocate allow alter always analyze ancillary and any anydata anydataset anyschema anytype apply archive archived archivelog are as asc ascii asin assembly assertion associate asynchronous at atan atn2 attr attri attrib attribu attribut attribute attributes audit authenticated authentication authid authors auto autoallocate autodblink autoextend automatic availability avg backup badfile basicfile before begin beginning benchmark between bfile bfile_base big bigfile bin binary_double binary_float binlog bit_and bit_count bit_length bit_or bit_xor bitmap blob_base block blocksize body both bound buffer_cache buffer_pool build bulk by byte byteordermark bytes cache caching call calling cancel capacity cascade cascaded case cast catalog category ceil ceiling chain change changed char_base char_length character_length characters characterset charindex charset charsetform charsetid check checksum checksum_agg child choose chr chunk class cleanup clear client clob clob_base clone close cluster_id cluster_probability cluster_set clustering coalesce coercibility col collate collation collect colu colum column column_value columns columns_updated comment commit compact compatibility compiled complete composite_limit compound compress compute concat concat_ws concurrent confirm conn connec connect connect_by_iscycle connect_by_isleaf connect_by_root connect_time connection consider consistent constant constraint constraints constructor container content contents context contributors controlfile conv convert convert_tz corr corr_k corr_s corresponding corruption cos cost count count_big counted covar_pop covar_samp cpu_per_call cpu_per_session crc32 create creation critical cross cube cume_dist curdate current current_date current_time current_timestamp current_user cursor curtime customdatum cycle data database databases datafile datafiles datalength date_add date_cache date_format date_sub dateadd datediff datefromparts datename datepart datetime2fromparts day day_to_second dayname dayofmonth dayofweek dayofyear days db_role_change dbtimezone ddl deallocate declare decode decompose decrement decrypt deduplicate def defa defau defaul default defaults deferred defi defin define degrees delayed delegate delete delete_all delimited demand dense_rank depth dequeue des_decrypt des_encrypt des_key_file desc descr descri describ describe descriptor deterministic diagnostics difference dimension direct_load directory disable disable_all disallow disassociate discardfile disconnect diskgroup distinct distinctrow distribute distributed div do document domain dotnet double downgrade drop dumpfile duplicate duration each edition editionable editions element ellipsis else elsif elt empty enable enable_all enclosed encode encoding encrypt end end-exec endian enforced engine engines enqueue enterprise entityescaping eomonth error errors escaped evalname evaluate event eventdata events except exception exceptions exchange exclude excluding execu execut execute exempt exists exit exp expire explain export export_set extended extent external external_1 external_2 externally extract failed failed_login_attempts failover failure far fast feature_set feature_value fetch field fields file file_name_convert filesystem_like_logging final finish first first_value fixed flash_cache flashback floor flush following follows for forall force form forma format found found_rows freelist freelists freepools fresh from from_base64 from_days ftp full function general generated get get_format get_lock getdate getutcdate global global_name globally go goto grant grants greatest group group_concat group_id grouping grouping_id groups gtid_subtract guarantee guard handler hash hashkeys having hea head headi headin heading heap help hex hierarchy high high_priority hosts hour http id ident_current ident_incr ident_seed identified identity idle_time if ifnull ignore iif ilike ilm immediate import in include including increment index indexes indexing indextype indicator indices inet6_aton inet6_ntoa inet_aton inet_ntoa infile initial initialized initially initrans inmemory inner innodb input insert install instance instantiable instr interface interleaved intersect into invalidate invisible is is_free_lock is_ipv4 is_ipv4_compat is_not is_not_null is_used_lock isdate isnull isolation iterate java join json json_exists keep keep_duplicates key keys kill language large last last_day last_insert_id last_value lax lcase lead leading least leaves left len lenght length less level levels library like like2 like4 likec limit lines link list listagg little ln load load_file lob lobs local localtime localtimestamp locate locator lock locked log log10 log2 logfile logfiles logging logical logical_reads_per_call logoff logon logs long loop low low_priority lower lpad lrtrim ltrim main make_set makedate maketime managed management manual map mapping mask master master_pos_wait match matched materialized max maxextents maximize maxinstances maxlen maxlogfiles maxloghistory maxlogmembers maxsize maxtrans md5 measures median medium member memcompress memory merge microsecond mid migration min minextents minimum mining minus minute minvalue missing mod mode model modification modify module monitoring month months mount move movement multiset mutex name name_const names nan national native natural nav nchar nclob nested never new newline next nextval no no_write_to_binlog noarchivelog noaudit nobadfile nocheck nocompress nocopy nocycle nodelay nodiscardfile noentityescaping noguarantee nokeep nologfile nomapping nomaxvalue nominimize nominvalue nomonitoring none noneditionable nonschema noorder nopr nopro noprom nopromp noprompt norely noresetlogs noreverse normal norowdependencies noschemacheck noswitch not nothing notice notrim novalidate now nowait nth_value nullif nulls num numb numbe nvarchar nvarchar2 object ocicoll ocidate ocidatetime ociduration ociinterval ociloblocator ocinumber ociref ocirefcursor ocirowid ocistring ocitype oct octet_length of off offline offset oid oidindex old on online only opaque open operations operator optimal optimize option optionally or oracle oracle_date oradata ord ordaudio orddicom orddoc order ordimage ordinality ordvideo organization orlany orlvary out outer outfile outline output over overflow overriding package pad parallel parallel_enable parameters parent parse partial partition partitions pascal passing password password_grace_time password_lock_time password_reuse_max password_reuse_time password_verify_function patch path patindex pctincrease pctthreshold pctused pctversion percent percent_rank percentile_cont percentile_disc performance period period_add period_diff permanent physical pi pipe pipelined pivot pluggable plugin policy position post_transaction pow power pragma prebuilt precedes preceding precision prediction prediction_cost prediction_details prediction_probability prediction_set prepare present preserve prior priority private private_sga privileges procedural procedure procedure_analyze processlist profiles project prompt protection public publishingservername purge quarter query quick quiesce quota quotename radians raise rand range rank raw read reads readsize rebuild record records recover recovery recursive recycle redo reduced ref reference referenced references referencing refresh regexp_like register regr_avgx regr_avgy regr_count regr_intercept regr_r2 regr_slope regr_sxx regr_sxy reject rekey relational relative relaylog release release_lock relies_on relocate rely rem remainder rename repair repeat replace replicate replication required reset resetlogs resize resource respect restore restricted result result_cache resumable resume retention return returning returns reuse reverse revoke right rlike role roles rollback rolling rollup round row row_count rowdependencies rowid rownum rows rtrim rules safe salt sample save savepoint sb1 sb2 sb4 scan schema schemacheck scn scope scroll sdo_georaster sdo_topo_geometry search sec_to_time second section securefile security seed segment select self sequence sequential serializable server servererror session session_user sessions_per_user set sets settings sha sha1 sha2 share shared shared_pool short show shrink shutdown si_averagecolor si_colorhistogram si_featurelist si_positionalcolor si_stillimage si_texture siblings sid sign sin size size_t sizes skip slave sleep smalldatetimefromparts smallfile snapshot some soname sort soundex source space sparse spfile split sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows sql_small_result sql_variant_property sqlcode sqldata sqlerror sqlname sqlstate sqrt square standalone standby start starting startup statement static statistics stats_binomial_test stats_crosstab stats_ks_test stats_mode stats_mw_test stats_one_way_anova stats_t_test_ stats_t_test_indep stats_t_test_one stats_t_test_paired stats_wsr_test status std stddev stddev_pop stddev_samp stdev stop storage store stored str str_to_date straight_join strcmp strict string struct stuff style subdate subpartition subpartitions substitutable substr substring subtime subtring_index subtype success sum suspend switch switchoffset switchover sync synchronous synonym sys sys_xmlagg sysasm sysaux sysdate sysdatetimeoffset sysdba sysoper system system_user sysutcdatetime table tables tablespace tan tdo template temporary terminated tertiary_weights test than then thread through tier ties time time_format time_zone timediff timefromparts timeout timestamp timestampadd timestampdiff timezone_abbr timezone_minute timezone_region to to_base64 to_date to_days to_seconds todatetimeoffset trace tracking transaction transactional translate translation treat trigger trigger_nestlevel triggers trim truncate try_cast try_convert try_parse type ub1 ub2 ub4 ucase unarchived unbounded uncompress under undo unhex unicode uniform uninstall union unique unix_timestamp unknown unlimited unlock unpivot unrecoverable unsafe unsigned until untrusted unusable unused update updated upgrade upped upper upsert url urowid usable usage use use_stored_outlines user user_data user_resources users using utc_date utc_timestamp uuid uuid_short validate validate_password_strength validation valist value values var var_samp varcharc vari varia variab variabl variable variables variance varp varraw varrawc varray verify version versions view virtual visible void wait wallet warning warnings week weekday weekofyear wellformed when whene whenev wheneve whenever where while whitespace with within without work wrapped xdb xml xmlagg xmlattributes xmlcast xmlcolattval xmlelement xmlexists xmlforest xmlindex xmlnamespaces xmlpi xmlquery xmlroot xmlschema xmlserialize xmltable xmltype xor year year_to_month years yearweek",literal:"true false null",built_in:"array bigint binary bit blob boolean char character date dec decimal float int int8 integer interval number numeric real record serial serial8 smallint text varchar varying void"},c:[{cN:"string",b:"'",e:"'",c:[e.BE,{b:"''"}]},{cN:"string",b:'"',e:'"',c:[e.BE,{b:'""'}]},{cN:"string",b:"`",e:"`",c:[e.BE]},e.CNM,e.CBCM,t]},e.CBCM,t]}}),e});
/*!
 * Fuse.js v3.1.0 - Lightweight fuzzy-search (http://fusejs.io)
 *
 * Copyright (c) 2012-2017 Kirollos Risk (http://kiro.me)
 * All Rights Reserved. Apache Software License 2.0
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 */
(function webpackUniversalModuleDefinition(root, factory) {
    if(typeof exports === 'object' && typeof module === 'object')
        module.exports = factory();
    else if(typeof define === 'function' && define.amd)
        define("Fuse", [], factory);
    else if(typeof exports === 'object')
        exports["Fuse"] = factory();
    else
        root["Fuse"] = factory();
})(this, function() {
    return /******/ (function(modules) { // webpackBootstrap
        /******/ 	// The module cache
        /******/ 	var installedModules = {};
        /******/
        /******/ 	// The require function
        /******/ 	function __webpack_require__(moduleId) {
            /******/
            /******/ 		// Check if module is in cache
            /******/ 		if(installedModules[moduleId]) {
                /******/ 			return installedModules[moduleId].exports;
                /******/ 		}
            /******/ 		// Create a new module (and put it into the cache)
            /******/ 		var module = installedModules[moduleId] = {
                /******/ 			i: moduleId,
                /******/ 			l: false,
                /******/ 			exports: {}
                /******/ 		};
            /******/
            /******/ 		// Execute the module function
            /******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
            /******/
            /******/ 		// Flag the module as loaded
            /******/ 		module.l = true;
            /******/
            /******/ 		// Return the exports of the module
            /******/ 		return module.exports;
            /******/ 	}
        /******/
        /******/
        /******/ 	// expose the modules object (__webpack_modules__)
        /******/ 	__webpack_require__.m = modules;
        /******/
        /******/ 	// expose the module cache
        /******/ 	__webpack_require__.c = installedModules;
        /******/
        /******/ 	// identity function for calling harmony imports with the correct context
        /******/ 	__webpack_require__.i = function(value) { return value; };
        /******/
        /******/ 	// define getter function for harmony exports
        /******/ 	__webpack_require__.d = function(exports, name, getter) {
            /******/ 		if(!__webpack_require__.o(exports, name)) {
                /******/ 			Object.defineProperty(exports, name, {
                    /******/ 				configurable: false,
                    /******/ 				enumerable: true,
                    /******/ 				get: getter
                    /******/ 			});
                /******/ 		}
            /******/ 	};
        /******/
        /******/ 	// getDefaultExport function for compatibility with non-harmony modules
        /******/ 	__webpack_require__.n = function(module) {
            /******/ 		var getter = module && module.__esModule ?
                /******/ 			function getDefault() { return module['default']; } :
                /******/ 			function getModuleExports() { return module; };
            /******/ 		__webpack_require__.d(getter, 'a', getter);
            /******/ 		return getter;
            /******/ 	};
        /******/
        /******/ 	// Object.prototype.hasOwnProperty.call
        /******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
        /******/
        /******/ 	// __webpack_public_path__
        /******/ 	__webpack_require__.p = "";
        /******/
        /******/ 	// Load entry module and return exports
        /******/ 	return __webpack_require__(__webpack_require__.s = 8);
        /******/ })
    /************************************************************************/
    /******/ ([
        /* 0 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (obj) {
                return Object.prototype.toString.call(obj) === '[object Array]';
            };

            /***/ }),
        /* 1 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

            function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

            var bitapRegexSearch = __webpack_require__(5);
            var bitapSearch = __webpack_require__(7);
            var patternAlphabet = __webpack_require__(4);

            var Bitap = function () {
                function Bitap(pattern, _ref) {
                    var _ref$location = _ref.location,
                        location = _ref$location === undefined ? 0 : _ref$location,
                        _ref$distance = _ref.distance,
                        distance = _ref$distance === undefined ? 100 : _ref$distance,
                        _ref$threshold = _ref.threshold,
                        threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                        _ref$maxPatternLength = _ref.maxPatternLength,
                        maxPatternLength = _ref$maxPatternLength === undefined ? 32 : _ref$maxPatternLength,
                        _ref$isCaseSensitive = _ref.isCaseSensitive,
                        isCaseSensitive = _ref$isCaseSensitive === undefined ? false : _ref$isCaseSensitive,
                        _ref$tokenSeparator = _ref.tokenSeparator,
                        tokenSeparator = _ref$tokenSeparator === undefined ? / +/g : _ref$tokenSeparator,
                        _ref$findAllMatches = _ref.findAllMatches,
                        findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                        _ref$minMatchCharLeng = _ref.minMatchCharLength,
                        minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng;

                    _classCallCheck(this, Bitap);

                    this.options = {
                        location: location,
                        distance: distance,
                        threshold: threshold,
                        maxPatternLength: maxPatternLength,
                        isCaseSensitive: isCaseSensitive,
                        tokenSeparator: tokenSeparator,
                        findAllMatches: findAllMatches,
                        minMatchCharLength: minMatchCharLength
                    };

                    this.pattern = this.options.isCaseSensitive ? pattern : pattern.toLowerCase();

                    if (this.pattern.length <= maxPatternLength) {
                        this.patternAlphabet = patternAlphabet(this.pattern);
                    }
                }

                _createClass(Bitap, [{
                    key: 'search',
                    value: function search(text) {
                        if (!this.options.isCaseSensitive) {
                            text = text.toLowerCase();
                        }

                        // Exact match
                        if (this.pattern === text) {
                            return {
                                isMatch: true,
                                score: 0,
                                matchedIndices: [[0, text.length - 1]]
                            };
                        }

                        // When pattern length is greater than the machine word length, just do a a regex comparison
                        var _options = this.options,
                            maxPatternLength = _options.maxPatternLength,
                            tokenSeparator = _options.tokenSeparator;

                        if (this.pattern.length > maxPatternLength) {
                            return bitapRegexSearch(text, this.pattern, tokenSeparator);
                        }

                        // Otherwise, use Bitap algorithm
                        var _options2 = this.options,
                            location = _options2.location,
                            distance = _options2.distance,
                            threshold = _options2.threshold,
                            findAllMatches = _options2.findAllMatches,
                            minMatchCharLength = _options2.minMatchCharLength;

                        return bitapSearch(text, this.pattern, this.patternAlphabet, {
                            location: location,
                            distance: distance,
                            threshold: threshold,
                            findAllMatches: findAllMatches,
                            minMatchCharLength: minMatchCharLength
                        });
                    }
                }]);

                return Bitap;
            }();

// let x = new Bitap("od mn war", {})
// let result = x.search("Old Man's War")
// console.log(result)

            module.exports = Bitap;

            /***/ }),
        /* 2 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var isArray = __webpack_require__(0);

            var deepValue = function deepValue(obj, path, list) {
                if (!path) {
                    // If there's no path left, we've gotten to the object we care about.
                    list.push(obj);
                } else {
                    var dotIndex = path.indexOf('.');
                    var firstSegment = path;
                    var remaining = null;

                    if (dotIndex !== -1) {
                        firstSegment = path.slice(0, dotIndex);
                        remaining = path.slice(dotIndex + 1);
                    }

                    var value = obj[firstSegment];

                    if (value !== null && value !== undefined) {
                        if (!remaining && (typeof value === 'string' || typeof value === 'number')) {
                            list.push(value.toString());
                        } else if (isArray(value)) {
                            // Search each item in the array.
                            for (var i = 0, len = value.length; i < len; i += 1) {
                                deepValue(value[i], remaining, list);
                            }
                        } else if (remaining) {
                            // An object. Recurse further.
                            deepValue(value, remaining, list);
                        }
                    }
                }

                return list;
            };

            module.exports = function (obj, path) {
                return deepValue(obj, path, []);
            };

            /***/ }),
        /* 3 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function () {
                var matchmask = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
                var minMatchCharLength = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;

                var matchedIndices = [];
                var start = -1;
                var end = -1;
                var i = 0;

                for (var len = matchmask.length; i < len; i += 1) {
                    var match = matchmask[i];
                    if (match && start === -1) {
                        start = i;
                    } else if (!match && start !== -1) {
                        end = i - 1;
                        if (end - start + 1 >= minMatchCharLength) {
                            matchedIndices.push([start, end]);
                        }
                        start = -1;
                    }
                }

                // (i-1 - start) + 1 => i - start
                if (matchmask[i - 1] && i - start >= minMatchCharLength) {
                    matchedIndices.push([start, i - 1]);
                }

                return matchedIndices;
            };

            /***/ }),
        /* 4 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (pattern) {
                var mask = {};
                var len = pattern.length;

                for (var i = 0; i < len; i += 1) {
                    mask[pattern.charAt(i)] = 0;
                }

                for (var _i = 0; _i < len; _i += 1) {
                    mask[pattern.charAt(_i)] |= 1 << len - _i - 1;
                }

                return mask;
            };

            /***/ }),
        /* 5 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var SPECIAL_CHARS_REGEX = /[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g;

            module.exports = function (text, pattern) {
                var tokenSeparator = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : / +/g;

                var regex = new RegExp(pattern.replace(SPECIAL_CHARS_REGEX, '\\$&').replace(tokenSeparator, '|'));
                var matches = text.match(regex);
                var isMatch = !!matches;
                var matchedIndices = [];

                if (isMatch) {
                    for (var i = 0, matchesLen = matches.length; i < matchesLen; i += 1) {
                        var match = matches[i];
                        matchedIndices.push([text.indexOf(match), match.length - 1]);
                    }
                }

                return {
                    // TODO: revisit this score
                    score: isMatch ? 0.5 : 1,
                    isMatch: isMatch,
                    matchedIndices: matchedIndices
                };
            };

            /***/ }),
        /* 6 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            module.exports = function (pattern, _ref) {
                var _ref$errors = _ref.errors,
                    errors = _ref$errors === undefined ? 0 : _ref$errors,
                    _ref$currentLocation = _ref.currentLocation,
                    currentLocation = _ref$currentLocation === undefined ? 0 : _ref$currentLocation,
                    _ref$expectedLocation = _ref.expectedLocation,
                    expectedLocation = _ref$expectedLocation === undefined ? 0 : _ref$expectedLocation,
                    _ref$distance = _ref.distance,
                    distance = _ref$distance === undefined ? 100 : _ref$distance;

                var accuracy = errors / pattern.length;
                var proximity = Math.abs(expectedLocation - currentLocation);

                if (!distance) {
                    // Dodge divide by zero error.
                    return proximity ? 1.0 : accuracy;
                }

                return accuracy + proximity / distance;
            };

            /***/ }),
        /* 7 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var bitapScore = __webpack_require__(6);
            var matchedIndices = __webpack_require__(3);

            module.exports = function (text, pattern, patternAlphabet, _ref) {
                var _ref$location = _ref.location,
                    location = _ref$location === undefined ? 0 : _ref$location,
                    _ref$distance = _ref.distance,
                    distance = _ref$distance === undefined ? 100 : _ref$distance,
                    _ref$threshold = _ref.threshold,
                    threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                    _ref$findAllMatches = _ref.findAllMatches,
                    findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                    _ref$minMatchCharLeng = _ref.minMatchCharLength,
                    minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng;

                var expectedLocation = location;
                // Set starting location at beginning text and initialize the alphabet.
                var textLen = text.length;
                // Highest score beyond which we give up.
                var currentThreshold = threshold;
                // Is there a nearby exact match? (speedup)
                var bestLocation = text.indexOf(pattern, expectedLocation);

                var patternLen = pattern.length;

                // a mask of the matches
                var matchMask = [];
                for (var i = 0; i < textLen; i += 1) {
                    matchMask[i] = 0;
                }

                if (bestLocation !== -1) {
                    var score = bitapScore(pattern, {
                        errors: 0,
                        currentLocation: bestLocation,
                        expectedLocation: expectedLocation,
                        distance: distance
                    });
                    currentThreshold = Math.min(score, currentThreshold);

                    // What about in the other direction? (speed up)
                    bestLocation = text.lastIndexOf(pattern, expectedLocation + patternLen);

                    if (bestLocation !== -1) {
                        var _score = bitapScore(pattern, {
                            errors: 0,
                            currentLocation: bestLocation,
                            expectedLocation: expectedLocation,
                            distance: distance
                        });
                        currentThreshold = Math.min(_score, currentThreshold);
                    }
                }

                // Reset the best location
                bestLocation = -1;

                var lastBitArr = [];
                var finalScore = 1;
                var binMax = patternLen + textLen;

                var mask = 1 << patternLen - 1;

                for (var _i = 0; _i < patternLen; _i += 1) {
                    // Scan for the best match; each iteration allows for one more error.
                    // Run a binary search to determine how far from the match location we can stray
                    // at this error level.
                    var binMin = 0;
                    var binMid = binMax;

                    while (binMin < binMid) {
                        var _score3 = bitapScore(pattern, {
                            errors: _i,
                            currentLocation: expectedLocation + binMid,
                            expectedLocation: expectedLocation,
                            distance: distance
                        });

                        if (_score3 <= currentThreshold) {
                            binMin = binMid;
                        } else {
                            binMax = binMid;
                        }

                        binMid = Math.floor((binMax - binMin) / 2 + binMin);
                    }

                    // Use the result from this iteration as the maximum for the next.
                    binMax = binMid;

                    var start = Math.max(1, expectedLocation - binMid + 1);
                    var finish = findAllMatches ? textLen : Math.min(expectedLocation + binMid, textLen) + patternLen;

                    // Initialize the bit array
                    var bitArr = Array(finish + 2);

                    bitArr[finish + 1] = (1 << _i) - 1;

                    for (var j = finish; j >= start; j -= 1) {
                        var currentLocation = j - 1;
                        var charMatch = patternAlphabet[text.charAt(currentLocation)];

                        if (charMatch) {
                            matchMask[currentLocation] = 1;
                        }

                        // First pass: exact match
                        bitArr[j] = (bitArr[j + 1] << 1 | 1) & charMatch;

                        // Subsequent passes: fuzzy match
                        if (_i !== 0) {
                            bitArr[j] |= (lastBitArr[j + 1] | lastBitArr[j]) << 1 | 1 | lastBitArr[j + 1];
                        }

                        if (bitArr[j] & mask) {
                            finalScore = bitapScore(pattern, {
                                errors: _i,
                                currentLocation: currentLocation,
                                expectedLocation: expectedLocation,
                                distance: distance
                            });

                            // This match will almost certainly be better than any existing match.
                            // But check anyway.
                            if (finalScore <= currentThreshold) {
                                // Indeed it is
                                currentThreshold = finalScore;
                                bestLocation = currentLocation;

                                // Already passed `loc`, downhill from here on in.
                                if (bestLocation <= expectedLocation) {
                                    break;
                                }

                                // When passing `bestLocation`, don't exceed our current distance from `expectedLocation`.
                                start = Math.max(1, 2 * expectedLocation - bestLocation);
                            }
                        }
                    }

                    // No hope for a (better) match at greater error levels.
                    var _score2 = bitapScore(pattern, {
                        errors: _i + 1,
                        currentLocation: expectedLocation,
                        expectedLocation: expectedLocation,
                        distance: distance
                    });

                    if (_score2 > currentThreshold) {
                        break;
                    }

                    lastBitArr = bitArr;
                }

                // Count exact matches (those with a score of 0) to be "almost" exact
                return {
                    isMatch: bestLocation >= 0,
                    score: finalScore === 0 ? 0.001 : finalScore,
                    matchedIndices: matchedIndices(matchMask, minMatchCharLength)
                };
            };

            /***/ }),
        /* 8 */
        /***/ (function(module, exports, __webpack_require__) {

            "use strict";


            var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

            function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

            var Bitap = __webpack_require__(1);
            var deepValue = __webpack_require__(2);
            var isArray = __webpack_require__(0);

            var Fuse = function () {
                function Fuse(list, _ref) {
                    var _ref$location = _ref.location,
                        location = _ref$location === undefined ? 0 : _ref$location,
                        _ref$distance = _ref.distance,
                        distance = _ref$distance === undefined ? 100 : _ref$distance,
                        _ref$threshold = _ref.threshold,
                        threshold = _ref$threshold === undefined ? 0.6 : _ref$threshold,
                        _ref$maxPatternLength = _ref.maxPatternLength,
                        maxPatternLength = _ref$maxPatternLength === undefined ? 32 : _ref$maxPatternLength,
                        _ref$caseSensitive = _ref.caseSensitive,
                        caseSensitive = _ref$caseSensitive === undefined ? false : _ref$caseSensitive,
                        _ref$tokenSeparator = _ref.tokenSeparator,
                        tokenSeparator = _ref$tokenSeparator === undefined ? / +/g : _ref$tokenSeparator,
                        _ref$findAllMatches = _ref.findAllMatches,
                        findAllMatches = _ref$findAllMatches === undefined ? false : _ref$findAllMatches,
                        _ref$minMatchCharLeng = _ref.minMatchCharLength,
                        minMatchCharLength = _ref$minMatchCharLeng === undefined ? 1 : _ref$minMatchCharLeng,
                        _ref$id = _ref.id,
                        id = _ref$id === undefined ? null : _ref$id,
                        _ref$keys = _ref.keys,
                        keys = _ref$keys === undefined ? [] : _ref$keys,
                        _ref$shouldSort = _ref.shouldSort,
                        shouldSort = _ref$shouldSort === undefined ? true : _ref$shouldSort,
                        _ref$getFn = _ref.getFn,
                        getFn = _ref$getFn === undefined ? deepValue : _ref$getFn,
                        _ref$sortFn = _ref.sortFn,
                        sortFn = _ref$sortFn === undefined ? function (a, b) {
                            return a.score - b.score;
                        } : _ref$sortFn,
                        _ref$tokenize = _ref.tokenize,
                        tokenize = _ref$tokenize === undefined ? false : _ref$tokenize,
                        _ref$matchAllTokens = _ref.matchAllTokens,
                        matchAllTokens = _ref$matchAllTokens === undefined ? false : _ref$matchAllTokens,
                        _ref$includeMatches = _ref.includeMatches,
                        includeMatches = _ref$includeMatches === undefined ? false : _ref$includeMatches,
                        _ref$includeScore = _ref.includeScore,
                        includeScore = _ref$includeScore === undefined ? false : _ref$includeScore,
                        _ref$verbose = _ref.verbose,
                        verbose = _ref$verbose === undefined ? false : _ref$verbose;

                    _classCallCheck(this, Fuse);

                    this.options = {
                        location: location,
                        distance: distance,
                        threshold: threshold,
                        maxPatternLength: maxPatternLength,
                        isCaseSensitive: caseSensitive,
                        tokenSeparator: tokenSeparator,
                        findAllMatches: findAllMatches,
                        minMatchCharLength: minMatchCharLength,
                        id: id,
                        keys: keys,
                        includeMatches: includeMatches,
                        includeScore: includeScore,
                        shouldSort: shouldSort,
                        getFn: getFn,
                        sortFn: sortFn,
                        verbose: verbose,
                        tokenize: tokenize,
                        matchAllTokens: matchAllTokens
                    };

                    this.setCollection(list);
                }

                _createClass(Fuse, [{
                    key: 'setCollection',
                    value: function setCollection(list) {
                        this.list = list;
                        return list;
                    }
                }, {
                    key: 'search',
                    value: function search(pattern) {
                        this._log('---------\nSearch pattern: "' + pattern + '"');

                        var _prepareSearchers2 = this._prepareSearchers(pattern),
                            tokenSearchers = _prepareSearchers2.tokenSearchers,
                            fullSearcher = _prepareSearchers2.fullSearcher;

                        var _search2 = this._search(tokenSearchers, fullSearcher),
                            weights = _search2.weights,
                            results = _search2.results;

                        this._computeScore(weights, results);

                        if (this.options.shouldSort) {
                            this._sort(results);
                        }

                        return this._format(results);
                    }
                }, {
                    key: '_prepareSearchers',
                    value: function _prepareSearchers() {
                        var pattern = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

                        var tokenSearchers = [];

                        if (this.options.tokenize) {
                            // Tokenize on the separator
                            var tokens = pattern.split(this.options.tokenSeparator);
                            for (var i = 0, len = tokens.length; i < len; i += 1) {
                                tokenSearchers.push(new Bitap(tokens[i], this.options));
                            }
                        }

                        var fullSearcher = new Bitap(pattern, this.options);

                        return { tokenSearchers: tokenSearchers, fullSearcher: fullSearcher };
                    }
                }, {
                    key: '_search',
                    value: function _search() {
                        var tokenSearchers = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
                        var fullSearcher = arguments[1];

                        var list = this.list;
                        var resultMap = {};
                        var results = [];

                        // Check the first item in the list, if it's a string, then we assume
                        // that every item in the list is also a string, and thus it's a flattened array.
                        if (typeof list[0] === 'string') {
                            // Iterate over every item
                            for (var i = 0, len = list.length; i < len; i += 1) {
                                this._analyze({
                                    key: '',
                                    value: list[i],
                                    record: i,
                                    index: i
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }

                            return { weights: null, results: results };
                        }

                        // Otherwise, the first item is an Object (hopefully), and thus the searching
                        // is done on the values of the keys of each item.
                        var weights = {};
                        for (var _i = 0, _len = list.length; _i < _len; _i += 1) {
                            var item = list[_i];
                            // Iterate over every key
                            for (var j = 0, keysLen = this.options.keys.length; j < keysLen; j += 1) {
                                var key = this.options.keys[j];
                                if (typeof key !== 'string') {
                                    weights[key.name] = {
                                        weight: 1 - key.weight || 1
                                    };
                                    if (key.weight <= 0 || key.weight > 1) {
                                        throw new Error('Key weight has to be > 0 and <= 1');
                                    }
                                    key = key.name;
                                } else {
                                    weights[key] = {
                                        weight: 1
                                    };
                                }

                                this._analyze({
                                    key: key,
                                    value: this.options.getFn(item, key),
                                    record: item,
                                    index: _i
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }
                        }

                        return { weights: weights, results: results };
                    }
                }, {
                    key: '_analyze',
                    value: function _analyze(_ref2, _ref3) {
                        var key = _ref2.key,
                            _ref2$arrayIndex = _ref2.arrayIndex,
                            arrayIndex = _ref2$arrayIndex === undefined ? -1 : _ref2$arrayIndex,
                            value = _ref2.value,
                            record = _ref2.record,
                            index = _ref2.index;
                        var _ref3$tokenSearchers = _ref3.tokenSearchers,
                            tokenSearchers = _ref3$tokenSearchers === undefined ? [] : _ref3$tokenSearchers,
                            _ref3$fullSearcher = _ref3.fullSearcher,
                            fullSearcher = _ref3$fullSearcher === undefined ? [] : _ref3$fullSearcher,
                            _ref3$resultMap = _ref3.resultMap,
                            resultMap = _ref3$resultMap === undefined ? {} : _ref3$resultMap,
                            _ref3$results = _ref3.results,
                            results = _ref3$results === undefined ? [] : _ref3$results;

                        // Check if the texvaluet can be searched
                        if (value === undefined || value === null) {
                            return;
                        }

                        var exists = false;
                        var averageScore = -1;
                        var numTextMatches = 0;

                        if (typeof value === 'string') {
                            this._log('\nKey: ' + (key === '' ? '-' : key));

                            var mainSearchResult = fullSearcher.search(value);
                            this._log('Full text: "' + value + '", score: ' + mainSearchResult.score);

                            if (this.options.tokenize) {
                                var words = value.split(this.options.tokenSeparator);
                                var scores = [];

                                for (var i = 0; i < tokenSearchers.length; i += 1) {
                                    var tokenSearcher = tokenSearchers[i];

                                    this._log('\nPattern: "' + tokenSearcher.pattern + '"');

                                    // let tokenScores = []
                                    var hasMatchInText = false;

                                    for (var j = 0; j < words.length; j += 1) {
                                        var word = words[j];
                                        var tokenSearchResult = tokenSearcher.search(word);
                                        var obj = {};
                                        if (tokenSearchResult.isMatch) {
                                            obj[word] = tokenSearchResult.score;
                                            exists = true;
                                            hasMatchInText = true;
                                            scores.push(tokenSearchResult.score);
                                        } else {
                                            obj[word] = 1;
                                            if (!this.options.matchAllTokens) {
                                                scores.push(1);
                                            }
                                        }
                                        this._log('Token: "' + word + '", score: ' + obj[word]);
                                        // tokenScores.push(obj)
                                    }

                                    if (hasMatchInText) {
                                        numTextMatches += 1;
                                    }
                                }

                                averageScore = scores[0];
                                var scoresLen = scores.length;
                                for (var _i2 = 1; _i2 < scoresLen; _i2 += 1) {
                                    averageScore += scores[_i2];
                                }
                                averageScore = averageScore / scoresLen;

                                this._log('Token score average:', averageScore);
                            }

                            var finalScore = mainSearchResult.score;
                            if (averageScore > -1) {
                                finalScore = (finalScore + averageScore) / 2;
                            }

                            this._log('Score average:', finalScore);

                            var checkTextMatches = this.options.tokenize && this.options.matchAllTokens ? numTextMatches >= tokenSearchers.length : true;

                            this._log('\nCheck Matches: ' + checkTextMatches);

                            // If a match is found, add the item to <rawResults>, including its score
                            if ((exists || mainSearchResult.isMatch) && checkTextMatches) {
                                // Check if the item already exists in our results
                                var existingResult = resultMap[index];
                                if (existingResult) {
                                    // Use the lowest score
                                    // existingResult.score, bitapResult.score
                                    existingResult.output.push({
                                        key: key,
                                        arrayIndex: arrayIndex,
                                        value: value,
                                        score: finalScore,
                                        matchedIndices: mainSearchResult.matchedIndices
                                    });
                                } else {
                                    // Add it to the raw result list
                                    resultMap[index] = {
                                        item: record,
                                        output: [{
                                            key: key,
                                            arrayIndex: arrayIndex,
                                            value: value,
                                            score: finalScore,
                                            matchedIndices: mainSearchResult.matchedIndices
                                        }]
                                    };

                                    results.push(resultMap[index]);
                                }
                            }
                        } else if (isArray(value)) {
                            for (var _i3 = 0, len = value.length; _i3 < len; _i3 += 1) {
                                this._analyze({
                                    key: key,
                                    arrayIndex: _i3,
                                    value: value[_i3],
                                    record: record,
                                    index: index
                                }, {
                                    resultMap: resultMap,
                                    results: results,
                                    tokenSearchers: tokenSearchers,
                                    fullSearcher: fullSearcher
                                });
                            }
                        }
                    }
                }, {
                    key: '_computeScore',
                    value: function _computeScore(weights, results) {
                        this._log('\n\nComputing score:\n');

                        for (var i = 0, len = results.length; i < len; i += 1) {
                            var output = results[i].output;
                            var scoreLen = output.length;

                            var totalScore = 0;
                            var bestScore = 1;

                            for (var j = 0; j < scoreLen; j += 1) {
                                var score = output[j].score;
                                var weight = weights ? weights[output[j].key].weight : 1;
                                var nScore = score * weight;

                                if (weight !== 1) {
                                    bestScore = Math.min(bestScore, nScore);
                                } else {
                                    output[j].nScore = nScore;
                                    totalScore += nScore;
                                }
                            }

                            results[i].score = bestScore === 1 ? totalScore / scoreLen : bestScore;

                            this._log(results[i]);
                        }
                    }
                }, {
                    key: '_sort',
                    value: function _sort(results) {
                        this._log('\n\nSorting....');
                        results.sort(this.options.sortFn);
                    }
                }, {
                    key: '_format',
                    value: function _format(results) {
                        var finalOutput = [];

                        this._log('\n\nOutput:\n\n', JSON.stringify(results));

                        var transformers = [];

                        if (this.options.includeMatches) {
                            transformers.push(function (result, data) {
                                var output = result.output;
                                data.matches = [];

                                for (var i = 0, len = output.length; i < len; i += 1) {
                                    var item = output[i];

                                    if (item.matchedIndices.length === 0) {
                                        continue;
                                    }

                                    var obj = {
                                        indices: item.matchedIndices,
                                        value: item.value
                                    };
                                    if (item.key) {
                                        obj.key = item.key;
                                    }
                                    if (item.hasOwnProperty('arrayIndex') && item.arrayIndex > -1) {
                                        obj.arrayIndex = item.arrayIndex;
                                    }
                                    data.matches.push(obj);
                                }
                            });
                        }

                        if (this.options.includeScore) {
                            transformers.push(function (result, data) {
                                data.score = result.score;
                            });
                        }

                        for (var i = 0, len = results.length; i < len; i += 1) {
                            var result = results[i];

                            if (this.options.id) {
                                result.item = this.options.getFn(result.item, this.options.id)[0];
                            }

                            if (!transformers.length) {
                                finalOutput.push(result.item);
                                continue;
                            }

                            var data = {
                                item: result.item
                            };

                            for (var j = 0, _len2 = transformers.length; j < _len2; j += 1) {
                                transformers[j](result, data);
                            }

                            finalOutput.push(data);
                        }

                        return finalOutput;
                    }
                }, {
                    key: '_log',
                    value: function _log() {
                        if (this.options.verbose) {
                            var _console;

                            (_console = console).log.apply(_console, arguments);
                        }
                    }
                }]);

                return Fuse;
            }();

            module.exports = Fuse;

            /***/ })
        /******/ ]);
});
//# sourceMappingURL=fuse.js.map
var AllInOneMenuTemplate = '<%var chunks = ["<div class=\'cont all-in-one-toc\'><h1 class=\'heading1\'>" + localization.TableOfContents + "</h1>"],    markup;function htmlTreeBuilder(items) {    if (items.length) {        chunks.push("<ul class=\'contents contents_all-in-one\'>");    }    items.forEach(function (item) {        if (!item.hidden) {            chunks.push("<li class=\'contents__item\'>");            chunks.push("<a href=\'");            chunks.push(item.url.match(/([\\w_]+\\.htm[l]?)/i)[1]);            chunks.push("\'>");            chunks.push(item.text);            chunks.push("</a>");            if (item.children) {                htmlTreeBuilder(item.children);            }            chunks.push("</li>");        }    });    if (items.length) {        chunks.push("</ul>");    }}htmlTreeBuilder(menu);chunks.push("</div>");markup = chunks.join("");%><%= markup %>';
var AsideTemplate = '<div class="aside ">    <div class="aside__inner">        <div class="aside__search search hidden-xs hidden-sm">            <div class="search__wrapper">                <input  class="search__field js_search_text" id="serch-text"                        placeholder="<%= localization.SearchLabel %>" type="text" />                <button class="search__btn js_search" id="search-button"></button>                <button class="search__clear is-hidden js_search_clear"></button>            </div>        </div>        <div class="selector-mobile js_selector_mobile_versions"></div>        <div class="selector-mobile js_selector_mobile_langs"></div>        <div class="aside__menu js_tabs_viewport">            <div class="js-menu-content">                <div class="js_menu"></div>            </div><!--            <div id="tab-names" class="b-tab__content js-tab-content">                <div class="b-index js_index_literals"></div>            </div>-->            <div class="js-search-content js_not_default">                <div class="search-results js_search_result_wrapper"></div>            </div>        </div>    </div></div>';
var BottomLinksTemplate = '<div class="bottom-links">    <!--<div class="feedback">        <div class="feedback__heading">Feedback</div>        <div class="feedback__text">            Was this article helpful?        </div>        <div>            <button class="button" type="button">Yes</button>            <button class="button" type="button">No</button>        </div>    </div>-->    <% if ((localization.ArticleIdText && localization.ArticleIdText.trim() && serviceInfo.id) ||            (localization.LastReviewText && localization.LastReviewText.trim() && serviceInfo.reviewDate)) { %>        <div class="bottom-links__service-info">            <% if (serviceInfo.id) { %>                <%= localization.ArticleIdText %> <%= serviceInfo.id %>,            <% } %>            <% if (serviceInfo.reviewDate) { %>                <%= localization.LastReviewText %> <%= serviceInfo.reviewDate %>            <% } %>        </div>    <% } %>    <div class="bottom-links__link">        <%= homeBtnHtml %>    </div></div>';
var ContainerTemplate = '<div class="main js_container">    <header class="js_header_placeholder"></header>    <div class="content js_main">        <div class="container">            <div class="row">                <div class="col-md-4 col-xs-20 menu-box js_aside_placeholder"></div>                <div class="col-md-1 hidden-xs hidden-sm js_prev_btn_placeholder"></div>                <div class="col-md-14 col-xs-20 js_content"></div>                <div class="col-md-1 hidden-xs hidden-sm js_next_btn_placeholder"></div>                <div class="col-md-16 col-xs-20 align-flex-end">                    <footer class="js_footer_placeholder"></footer>                </div>            </div>        </div>    </div>    <aside class="mobile-search-results is-hidden g-scrollable js_scrollable js_mobile_search_result js_mobile_aside"></aside></div><!--<div class="b-modal js_overlay">    <div class="b-modal__window js_modal">        <header class="b-modal__header js_modal_header"></header>        <div class="b-modal__content js_modal_content"></div>        <button href="#" class="b-modal__close-button js_modal_close"></button>    </div></div>--><div class="tooltip js_tooltip" data-id="">    <div class="tooltip__content js_tooltip_content"></div></div>';
var CustomStylesTemplate = '<style>    html {        color: <%= customization.ContentColorMain %>;    }    a {        color: <%= customization.LinkColor %>    }    a:hover {        color: <%= customization.LinkColorHover %>    }    a:visited {        color: <%= customization.LinkColorVisited %>    }    .page-title {        color: <%= customization.TitleColor %>;    }    /*.tablename,    .picturename,    .examplebodytext,    .examplebodytextblue2015,    .bottom-links__service-info,    .search-results__total,    .footer {        color: <%= customization.ContentColorSecondary %>;    }*/    .attentionbody,    .attentionbodytextindent,    .attentioncontinue1,    .attentioncontinue2,    .attentioncontinue3 {        color: <%= customization.AttentionBlockColor %>;    }    .warningbody,    .warningbodytextindent,    .warningcontinue1,    .warningcontinue2,    .warningcontinue3 {        color: <%= customization.WarningBlockColor %>;        border-color: <%= customization.WarningBlockBorder %>;        background: <%= customization.WarningBlockBackground %>;    }    .example-wrapper {        background: <%= customization.ExampleBlockBackground %> !important;    }    .exampleheading,    .examplebodytext,    .exampleheadingblue2015,    .examplebodytextblue2015 {        color: <%= customization.ExampleBlockColor %>;    }    mark {        background: <%= customization.SearchHighlightBackground %>;        color: <%= customization.SearchHighlightColor %>;    }</style>';
var FooterTemplate = '<div class="footer footer_inner">    <!--<div class="container">-->        <div class="row">            <div class="col-xs-20">                <div class="footer__divider"></div>            </div>            <div class="col-md-10 col-xs-20">                <div class="footer__text">                    <%= localization.FooterCopyrightText %>                </div>            </div>            <div class="col-md-10 col-xs-20">                <div class="footer__links">                    <% var hasOldFormatLinks = false %>                    <% if ( localization.FooterPrivacyPolicyLink && localization.FooterPrivacyPolicyLink.trim() &&                            localization.FooterPrivacyPolicyText && localization.FooterPrivacyPolicyText.trim() &&                            (!customization.FooterPrivacyPolicyLink || !customization.FooterPrivacyPolicyLink.hidden)) { %>                        <% hasOldFormatLinks = true %>                        <span class="footer__links-item">                            <% if (customization.FooterPrivacyPolicyLink && customization.FooterPrivacyPolicyLink.disabled) { %>                                <span class="footer__link">                                    <%= localization.FooterPrivacyPolicyText %>                                </span>                            <% } else { %>                                <a class="footer__link" target="blank" href="<%= localization.FooterPrivacyPolicyLink %>">                                    <%= localization.FooterPrivacyPolicyText %>                                </a>                            <% } %>                        </span>                    <% } %>                    <% if ( localization.FooterLegalLink && localization.FooterLegalLink.trim() &&                            localization.FooterLegalText && localization.FooterLegalText.trim() &&                            (!customization.FooterLegalLink || !customization.FooterLegalLink.hidden)) { %>                        <% hasOldFormatLinks = true %>                        <span class="footer__links-item">                            <% if (customization.FooterLegalLink && customization.FooterLegalLink.disabled) { %>                                <span class="footer__link">                                    <%= localization.FooterLegalText %>                                </span>                            <% } else { %>                                <a class="footer__link" target="blank" href="<%= localization.FooterLegalLink %>">                                    <%= localization.FooterLegalText %>                                </a>                            <% } %>                        </span>                    <% } %>                    <% if ( localization.FooterLinks && !hasOldFormatLinks ) { %>                        <% for (var i = 0, link; i < localization.FooterLinks.length; i++ ) { %>                            <% link = localization.FooterLinks[i] %>                            <span class="footer__links-item">                                <a class="footer__link" target="blank" href="<%= link.url %>">                                    <%= link.label %>                                </a>                            </span>                        <% } %>                    <% } %>                </div>            </div>        </div>    <!--</div>--></div>';
var HeaderTemplate = '<div class="header header_inner-help">    <div class="container">        <div class="row">            <div class="col-md-10 col-xs-20">                <button class="header__mobile-menu-btn js_burger" type="button"></button>                <div class="header__title hidden-xs hidden-sm">                    <% if ((!customization.HeaderLogoLink || !customization.HeaderLogoLink.hidden) && localization.HeaderTitle) { %>                        <% if ((customization.HeaderLogoLink && customization.HeaderLogoLink.disabled) || isOffline) { %>                            <span class="header__title-link">                        <% } else { %>                            <a href="<%= localization.HeaderLogoLink %>" class="header__title-link">                        <% } %>                            <% var index = localization.HeaderTitle.indexOf(" ") %>                            <%= localization.HeaderTitle.slice(0, index) %>                            <div class="header__title-big header__title-big_inner-help">                                <%= localization.HeaderTitle.slice(index, localization.HeaderTitle.length) %>                            </div>                        <%= (customization.HeaderLogoLink && customization.HeaderLogoLink.disabled) ? "</span>" : "</a>" %>                    <% } %>                </div>                <div class="header__title header__title_product"><%= titlePreffix %> <%= title %></div>                <div class="header__search">                    <button class="header__search-btn js_mobile_search_button" type="button"></button>                    <input type="search" class="header__search-input is-hidden js_mobile_search_input"                           placeholder="<%= localization.SearchPlaceholder %>" />                    <button class="header__clear-btn is-hidden js_mobile_search_clear" type="button"></button>                </div>            </div>            <div class="col-md-10 hidden-xs hidden-sm">                <div class="header__logo">                    <% if (!customization.FooterLogoLink || !customization.FooterLogoLink.hidden) { %>                        <% if (customization.FooterLogoLink && customization.FooterLogoLink.disabled) { %>                            <span class="logo"></span>                        <% } else { %>                            <a href="<%= localization.FooterLogoLink %>" class="logo"                               title="<%= localization.FooterLogoTitle %>"></a>                        <% } %>                    <% } %>                </div>            </div>        </div>    </div></div><div class="top-bar hidden-xs hidden-sm">    <div class="container">        <div class="row">            <div class="col-md-5">                <div class="top-bar__product-box">                    <div class="top-bar__product js_product_logo"></div>                    <h1 class="top-bar__title js_title">                        <% if (titlePreffix && titlePreffix.trim() ) { %>                            <span class="top-bar__title-small"><%= titlePreffix %></span>                        <% } %>                        <%= title %>                    </h1>                </div>            </div>            <div class="col-md-15">                <div class="top-bar__links-box">                    <div class="top-bar__links">                        <% if ( localization.PrintButtonText && localization.PrintButtonText.trim() ) { %>                            <% if (isAllInOne) { %>                                <a class="top-bar__link top-bar__link_print" href="javascript:print();">                                    <span class="top-bar__icon top-bar__icon_print"></span><%= localization.PrintButtonText %>                                </a>                            <% } else { %>                                <div class="dropdown js_dropdown">                                    <a class="top-bar__link top-bar__link_print js_dropdown_btn" href="#">                                        <span class="top-bar__icon top-bar__icon_print"></span><%= localization.PrintButtonText %>                                        <span class="top-bar__triangle"></span>                                    </a>                                    <ul class="dropdown__list js_dropdown_list">                                        <li class="dropdown__item">                                            <a class="dropdown__link" href="javascript:print();">                                                <%= localization.PrintPageText %>                                            </a>                                        </li>                                        <li class="dropdown__item">                                            <a class="dropdown__link js_print_section" href="">                                                <%= localization.PrintSectionText %>                                            </a>                                        </li>                                        <li class="dropdown__item">                                            <a class="dropdown__link js_print_all" href="all-in-one.htm" target="_blank">                                                <%= localization.PrintAllText %>                                            </a>                                        </li>                                    </ul>                                </div>                            <% } %>                        <% } %>                        <% if ( localization.SupportButtonText && localization.SupportButtonText.trim() &&                                localization.SupportButtonLink && localization.SupportButtonLink.trim() &&                                (!customization.SupportButtonLink || !customization.SupportButtonLink.hidden)) { %>                            <% if (customization.SupportButtonLink && customization.SupportButtonLink.disabled) { %>                                <span class="top-bar__link top-bar__link_support">                                    <span class="top-bar__icon top-bar__icon_support"></span><%= localization.SupportButtonText %>                                </span>                            <% } else { %>                                <a class="top-bar__link top-bar__link_support" href="<%= localization.SupportButtonLink %>" target="blank">                                    <span class="top-bar__icon top-bar__icon_support"></span><%= localization.SupportButtonText %>                                </a>                            <% } %>                        <% } %>                        <% if ( localization.SendLinkButtonText && localization.SendLinkButtonText.trim() &&                                (!customization.SendLinkButton || !customization.SendLinkButton.hidden)) { %>                            <% if (customization.SendLinkButton && customization.SendLinkButton.disabled) { %>                                <span class="top-bar__link top-bar__link_feedback">                                    <span class="top-bar__icon top-bar__icon_feedback"></span><%= localization.SendLinkButtonText %>                                </span>                            <% } else { %>                                <a class="top-bar__link top-bar__link_feedback js_feedback_link" href="">                                    <span class="top-bar__icon top-bar__icon_feedback"></span><%= localization.SendLinkButtonText %>                                </a>                            <% } %>                        <% } %>                    </div>                    <div class="top-bar__langs">                        <span class="top-bar__versions js_header_versions_list"></span>                        <span class="js_header_lang_list"></span>                    </div>                </div>            </div>        </div>    </div></div>';
var IndexLiteralsTemplate = '<ul class="b-index__list"><%    var result,        html = [];    for (var i= 0, item; i < index.length; i++ ) {        item = index[i];        if ( item.nested) {            html.push( "<li class=\'b-index__item js_menu_item b-index__item--nested\'>" );        } else {            html.push( "<li class=\'b-index__item js_menu_item\'>" );        }        if ( item["class"] === "indexlink" ) {            html.push( "<a class=\'b-index__link js_menu_link\' href=\'");            html.push( item.href );            html.push( "\'>" );            html.push( item.text );            html.push( "</a>" )        } else if ( item["class"] === "indexheading" ) {            html.push( "<span class=\'b-index__header\'>" );            html.push( item.text );            html.push( "</span>" )        } else {            html.push( "<span class=\'b-index__subheader\'>" );            html.push( item.text );            html.push( "</span>" )        }        html.push( "</li>" );    }    result = html.join("");%><%= result %></ul>';
var LangListTemplate = '<div class="dropdown dropdown_right js_dropdown">    <a class="dropdown__btn js_dropdown_btn">        <%= currentLang.name %>        <span class="dropdown__arrow"></span>    </a>    <ul class="dropdown__list js_dropdown_list">        <% _.each( langs, function( lang ) {%>            <% var dir = lang.dirname || lang.id %>            <% if (lang.id !== currentLang.id ) { %>                <li class="dropdown__item">                    <% if ( isMac ) { %>                        <a class="dropdown__link js_lang_item" data-lang-id="<%= dir %>" href="../../<%= dir %>/pgs">                            <%= lang.name %>                        </a>                    <% } else { %>                        <a class="dropdown__link js_lang_item" data-lang-id="<%= dir %>" href="../<%= dir %>">                            <%= lang.name %>                        </a>                    <% } %>                </li>            <% } %>        <% }) %>    </ul></div>';
var MenuTemplate = '<%var chunks = [],    isMac = isMacProject,    markup;function htmlTreeBuilder( items, opened ) {    if (items.length) {        chunks.push( "<ul class=\'contents js_contents_level\'" );        chunks.push( !opened ? " style=\'display:none\' ": "" );        chunks.push( ">" );    }    for (var i = 0, item; i < items.length; i++) {        item = items[i];        if ( !item.hidden ) {            if ( item.isActive ) {                chunks.push( "<li class=\'contents__item js_menu_item is-active\'>" );            } else {                chunks.push( "<li class=\'contents__item js_menu_item\'>" );            }            if ( item.children ) {                chunks.push( "<button class=\'contents__toggle js_contents_toggle" );                chunks.push( item.childIsActive || item.isActive ? " is-toggled" : "" );                chunks.push( "\' href=\'#\'></button>" );            }            chunks.push( "<a class=\'contents__item-link js_menu_link\' href=\'" );            chunks.push( (isMac ? "index.htm#" : "") + item.url );            chunks.push( "\'>" );            chunks.push( item.text );            chunks.push( "</a>" );            if ( item.children ) {                /*chunks.push( "<a class=\'contents__item-link-direct js_menu_link_direct\' href=\'" );                chunks.push( item.url );                chunks.push( "\'>" );                chunks.push( "</a>" );*/            }            if ( item.children ) {                htmlTreeBuilder( item.children, item.childIsActive || item.isActive );            }        }    }    if (items.length) {        chunks.push( "</ul>" );    }}htmlTreeBuilder( menu, true );markup = chunks.join("");%><%= markup %>';
var MobileSearchResultsTemplate = '<%if (!isInit){%>    <div class="mobile-search-results__total">        <% if ( resultsCount > 0) { %>            <%= localization.FoundTextBegin %> <%= resultsCount %> <%= localization.FoundTextEnd %>        <% } else { %>            <%= localization.NothingFoundText %>        <%}%>    </div>    <div class="mobile-search-results__content">        <%if ( found ){%>            <ul class="mobile-search-results__list">                <%_.each(results, function( page ){%>                    <li class="mobile-search-result">                        <% var link = isMacProject ? "index.htm#" + page.link : page.link %>                        <a class="mobile-search-result__title" href="<%= link %>"><%= page.title %></a>                        <%_.each( page.texts, function( text ){%>                            <p class="mobile-search-result__content"><%= text %></p>                        <%})%>                    </li>                <%})%>            </ul>        <%}%>    </div><%}%>';
var NextLinkTemplate = '<div class="nav-btn">    <% if (nextPage && nextPage.url) { %>        <% var link = isMacProject ? "index.htm#" + nextPage.url : nextPage.url %>        <a class="nav-btn__link-next js_next_link"           href="<%= link %>"           title="<%= nextPage.text %>"></a>    <% } else { %>        <span class="nav-btn__link-next-inactive"></span>    <% } %></div>';
var PageTitleTemplate = '<div class="page-title">    <div class="page-title__text">        <%= titleHtml %>    </div></div>';
var PrevLinkTemplate = '<div class="nav-btn">    <% if (prevPage && prevPage.url) { %>        <% var link = isMacProject ? "index.htm#" + prevPage.url : prevPage.url %>        <a class="nav-btn__link-prev js_prev_link"           href="<%= link %>"           title="<%= prevPage.text %>"></a>    <% } else { %>        <span class="nav-btn__link-prev-inactive"></span>    <% } %></div>';
var SearchResultsTemplate = '<%if (!isInit){%>    <div class="search-results__header">        <div class="search-results__total">            <%= localization.FoundTextBegin %> <%= resultsCount %> <%= localization.FoundTextEnd %>        </div>    </div>    <%if ( found ){%>        <div class="search-results__content">            <ul class="search-results__list">                <%_.each(results, function( page ){%>                    <li class="search-result">                        <% var link = isMacProject ? "index.htm#" + page.link : page.link %>                        <a class="search-result__title" href="<%= link %>"><%= page.title %></a>                        <%_.each( page.texts, function( text ){%>                            <p class="search-result__content"><%= text %></p>                        <%})%>                    </li>                <%})%>            </ul>        </div>    <%}%><%}%>';
var VersionsTemplate = '<div class="dropdown dropdown_right js_dropdown">    <a class="dropdown__btn js_dropdown_btn">        <%= currentVersion.label %>        <span class="dropdown__arrow"></span>    </a>    <ul class="dropdown__list js_dropdown_list">        <% _.each(versions, function(version)  {%>            <% if (version.url !== currentVersion.url) { %>                <li class="dropdown__item">                    <a class="dropdown__link js_version_item"                       data-version-url="<%= version.url %>" href="../../<%= version.url %>">                        <%= version.label %>                    </a>                </li>            <% } %>        <% }) %>    </ul></div>';
var LangsLocalization = {"en-US":"English","id-ID":"Bahasa Indonesia","cs-CZ":"Čeština &#x202A;(Česká republika)","da-DK":"Dansk &#x202A;(Danmark)","de-DE":"Deutsch","et-EE":"Eesti","es-ES":"Español &#x202A;(España, alfabetización internacional)","es-MX":"Español &#x202A;(México)","fr-FR":"Français","it-IT":"Italiano","lv-LV":"Latviešu","lt-LT":"Lietuvių","hu-HU":"Magyar &#x202A;(Magyarország)","nl-NL":"Nederlands &#x202A;(Nederland)","nb-NO":"Norsk, bokmål &#x202A;(Norge)","pl-PL":"Polski &#x202A;(Polska)","pt-BR":"Português &#x202A;(Brasil)","pt-PT":"Português &#x202A;(Portugal)","ro-RO":"Română &#x202A;(România)","sr-Latn":"Srpski","fi-FI":"Suomi &#x202A;(Suomi)","sv-SE":"Svenska &#x202A;(Sverige)","vi-VN":"Tiếng Việt &#x202A;(Việt Nam)","tr-TR":"Türkçe &#x202A;(Türkiye)","el-GR":"Ελληνικά &#x202A;(Ελλάδα)","bg-BG":"Български","kk-KZ":"Қазақ","ru-RU":"Русский","sr-Cyrl":"Српски","uk-UA":"Українська","ar-AE":"العربية (الإمارات العربية المتحدة&#x202B;)","fa-IR":"فارسى (ایران&#x202B;)","hi-IN":"हिंदी &#x202A;(भारत)","th-TH":"ไทย &#x202A;(ไทย)","ko-KR":"한국어 &#x202A;(대한민국)","ja-JP":"日本語&#x202A;(日本)","zh-Hans":"简体中文","zh-Hant":"繁體中文"};
var Page=new Array("著作権"," "," "," "," ","Kaspersky Lab の製品をお使いの皆さまへ ","このたびは Kaspersky Lab をセキュリティソフトウェアプロバイダとしてお選びいただき、ありがとうございます。このガイドが当社製品をご利用いただく際の一助となることを願っております。","ご注意：この文書は AO Kaspersky Lab （以降、「Kaspersky Lab」）の財産です。この文書に対するすべての権利は、ロシア連邦の著作権法および国際条約によって留保されています。この文書またはその一部を不正に複製および配布すると、適用法により民法上、行政上、または刑法上の責任を負うこととなります。 ","文書（このガイド以外の文書も含む）の複製または配布は、いかなる形であれ（翻訳されたものも含む）、Kaspersky Lab の書面による同意がないかぎり認められておりません。","このガイドおよびガイドに含まれる画像は、非商用（個人使用）の目的で提供されています。","Kaspersky Lab は、このガイドを事前の通知なしに改訂する権利を有するものとします。","このガイドに利用されている資料のうち、他社が権利を有するものの内容、品質、妥当性、正確性について、また、このガイドの使用に関連する潜在的な損害、および実際に発生した損害について、Kaspersky Lab は一切の責任を負いません。","ガイド改訂日：2018 年 3 月 1 日","© 2018 AO Kaspersky Lab.無断複写・転載を禁じます。","https://www.kaspersky.co.jphttps://support.kaspersky.co.jp"," &#x8457;&#x4F5C;&#x6A29; ","55937.htm");
Page[1]=new Array("このガイドについて","Kaspersky Endpoint Security 10 Service Pack 1 for Linux（以降、「Kaspersky Endpoint Security」）のユーザーガイドは、Kaspersky Endpoint Security をインストールして管理する技術者や、Kaspersky Endpoint Security を使用する組織にテクニカルサポートを提供する技術者を対象としています。","このガイドの情報を利用して、以下のことができます：","Kaspersky Endpoint Security のインストールを準備し、インストールしてアクティベートする。Kaspersky Endpoint Security を設定して使用する。また、このガイドでは、製品の情報源や、テクニカルサポートを受ける方法についても確認できます。","このセクションの内容本ガイドの内容文書規約"," &#x3053;&#x306E;&#x30AC;&#x30A4;&#x30C9;&#x306B;&#x3064;&#x3044;&#x3066; ","161208.htm");
Page[2]=new Array("本ガイドの内容","このガイドは、次のセクションで構成されます：","製品の情報源","このセクションには、製品の情報源が記載されています。","Kaspersky Endpoint Security","このセクションでは、本製品の機能にやコンポーネントの概要について説明します。配信キットの内容、本製品の登録ユーザーが利用できるサービスについても確認できます。","本製品のインストール","このセクションでは、ご使用のコンピューターへの Kaspersky Endpoint Security のインストールと、初期設定について説明します。","アプリケーションの削除","このセクションでは、コンピューターからの製品の削除について説明します。","本製品のライセンス管理","このセクションでは、本製品のライセンス管理について説明します。","本製品の起動および停止","このセクションでは、コマンドラインからの製品の起動、再起動、終了について説明します。","Kaspersky Endpoint Security の全般設定","このセクションでは、製品の全般設定について説明します。","コマンドラインを使用した Kaspersky Endpoint Security のタスクの管理","このセクションでは、Kaspersky Endpoint Security のタスクの種別に関する情報、およびコマンドラインを使用してこれらのタスクを管理する方法について説明します。","リアルタイム保護タスク（File_Monitoring ID:1）","このセクションでは、リアルタイム保護タスクに関する情報、およびこのタスクの設定の手順について説明します。","オンデマンドスキャンタスク（Scan_My_Computer ID:2）","このセクションでは、オンデマンドスキャンタスクに関する情報、およびこのタスクの設定の手順について説明します。","オブジェクトスキャンタスク（Scan_File ID:3）","このセクションでは、オブジェクトスキャンタスクに関する情報、およびこのタスクの設定の手順について説明します。","ブートセクタースキャンタスク（Boot_Scan ID:4）","このセクションでは、ブートセクタースキャンタスクに関する情報、およびこのタスクの設定の手順について説明します。","プロセスメモリスキャンタスク（Memory_Scan ID_5）","このセクションでは、プロセスメモリスキャンタスクに関する情報、およびこのタスクの設定の手順について説明します。","アップデートタスク（Update ID:6）","このセクションでは、定義データベースと製品モジュールのアップデート（以降、まとめて「アップデート」）に関する情報、およびアップデートの設定方法の手順について説明します。","アップデートのロールバックタスク（Rollback ID:7）","このセクションでは、アップデートのロールバックタスクに関する情報、およびこのタスクを管理する方法について説明します。","アップデートの再変換タスク（Retranslate ID:8）","このセクションでは、定義データベースとアップデートの再変換に関する情報、およびこのタスクの設定の手順について説明します。","ライセンスタスク（License ID:9）","このセクションでは、ライセンスタスクに関する情報、およびこのタスクを管理する方法について説明します。","保管領域の管理タスク（Backup ID:10）","このセクションでは、保管領域の設定の手順、および保管領域にあるオブジェクトで実行できる処理について説明します。","ファイル変更監視タスク（Integrity_Monitoring ID:11）","このセクションでは、ファイル変更監視タスクに関する情報、およびこのタスクを管理する方法について説明します。","ファイアウォール管理タスク（Firewall ID:12）","このセクションでは、ファイアウォール管理タスクに関する情報、およびこのタスクを管理する方法について説明します。","アンチ暗号化タスク（AntiCryptor ID:13）","このセクションでは、アンチクリプタータスクに関する情報、およびこのタスクを管理する方法について説明します。","Kaspersky Security Network への参加","このセクションでは、Kaspersky Security Network への参加に関する情報、および Kaspersky Security Network の利用を有効または無効にする方法の手順について説明します。","Kaspersky Endpoint Security のグラフィカルユーザーインターフェイスの使用","このセクションでは、本製品のグラフィカルユーザーインターフェイスに関する情報、および有効化または無効化する方法について説明します。","テクニカルサポートへの問い合わせ","このセクションでは、テクニカルサポートの利用方法や使用される用語について説明します。","付録","このセクションでは、設定ファイルの既定設定、およびコマンドラインのリターンコードに関する情報について説明します。また、Kaspersky Anti-Virus for Linux Mail Server を設定する方法についても説明します。","AO Kaspersky Lab","このセクションでは、Kaspersky Lab について説明します。","サードパーティ製のコードに関する情報","このセクションでは、サードパーティ製コードに関する情報について説明します。","商標に関する通知","このセクションでは、本ガイドで言及する商標について説明します。","用語解説","このセクションでは、本ガイドで使用する用語のリスト、およびそれぞれの定義について説明します。","キーワード","このセクションでは、必要な情報をすばやく見つけることができます。"," &#x672C;&#x30AC;&#x30A4;&#x30C9;&#x306E;&#x5185;&#x5BB9; ","161209.htm");
Page[3]=new Array("文書規約","このガイドでは次の規約を使用します（次の表を参照）。","文書規約"," ","サンプルテキスト","文書規約の説明","...に注意してください","警告は赤色で強調表示されて枠で囲まれます。警告は望ましくない結果を生じる可能性がある処理に関する情報を示します。","...を使用してください","注記は枠で囲まれます。注記は追加情報および参照情報を提供します。"," "," ","例：","…"," ","例は、「例」という見出しの下にある青色の背景の箇所に表記します。","アップデートとは…","［定義データベースが未アップデート］イベントが発生します。","次の要素はテキスト内で太字表記されます：","新しい用語本製品のステータス名とイベント名。","ENTER キーを押します。","ALT+F4 キーを押します。","キーボードのキー名は太字で、すべて大文字になっています。","+（プラス）記号で連結されたキー名は複数のキーの組み合わせを意味します。これらのキーは同時に押す必要があります。","［有効にする］をクリックします。","入力フィールド、メニュー項目、ボタンなどのアプリケーションインターフェイスの要素名は太字で表記されます。 ","タスクスケジュールを設定するには：","手順は太字表記され、矢印のマークで示されます。","コマンドラインに「help」と入力してください。","次のメッセージが表示されます：","日付は、dd:mm:yy 形式で指定します。","次の種類のテキストの内容は特殊フォントで表記されます：","コマンドラインのテキスト本製品が画面上に表示するメッセージのテキストキーボードを使用して入力するデータ","<ユーザー名>","変数は山括弧で囲まれています。変数の代わりに、対応する値を挿入します。山括弧は含みません。"," &#x6587;&#x66F8;&#x898F;&#x7D04; ","68566.htm");
Page[4]=new Array("製品の情報源","カスペルスキーの Web サイトの「Kaspersky Endpoint Security」ページ","カスペルスキーの Web サイトの「Kaspersky Endpoint Security」ページでは、本製品に関する全般情報と機能および特徴に関する情報を確認できます。","ナレッジベースの「Kaspersky Endpoint Security」ページ","ナレッジベースは、テクニカルサポートサイトにあるセクションの 1 つです。","ナレッジベースの「Kaspersky Endpoint Security」ページには、本製品の購入、インストール、および利用方法に関する有益な情報、推奨事項、およびよくある質問への回答を含む記事が掲載されています。","ナレッジベースの記事は、Kaspersky Endpoint Security のみでなく、他のカスペルスキー製品の問題解決にも利用できます。ナレッジベースの記事には、テクニカルサポートのニュースが含まれることもあります。","Web フォーラムの利用","特に緊急の対応が必要ではない場合は、Kaspersky Lab の Web フォーラムをご利用ください。ここでは、Kaspersky Lab のエキスパートやカスペルスキー製品のユーザーが、さまざまなトピックで意見交換しています。","フォーラムでは、これまでに公開されたトピックの閲覧、コメントの書き込み、新しいトピックの作成が可能です。","Web サイトへアクセスするにはインターネット接続が必要です。","問題の解決策が見つからない場合は、テクニカルサポートにお問い合わせください。","このセクションの内容自分で調べる場合の情報入手先Web フォーラムの利用"," &#x88FD;&#x54C1;&#x306E;&#x60C5;&#x5831;&#x6E90; ","80831.htm");
Page[5]=new Array("自分で調べる場合の情報入手先","次の情報源を使用して Kaspersky Endpoint Security に関する情報を検索できます：","カスペルスキーの Web サイトの「Kaspersky Endpoint Security」ページテクニカルサポートサイト（ナレッジベース）の「Kaspersky Endpoint Security」ページ本製品に含まれるヘルプ","問題に対する解決策をご自身で見つけられない場合は、カスペルスキーのテクニカルサポートへお問い合わせください。","Web サイトへアクセスするにはインターネット接続が必要です。","カスペルスキーの Web サイトの「Kaspersky Endpoint Security」ページ","「Kaspersky Endpoint Security」ページでは、本製品に関する全般情報と機能および特徴に関する情報を確認できます。","「The Kaspersky Endpoint Security」ページには、オンラインショップへのリンクがあります。オンラインショップで本製品のライセンスを購入または更新できます。","ナレッジベースの「Kaspersky Endpoint Security」ページ","ナレッジベースは、テクニカルサポートサイトにあるセクションの 1 つです。","ナレッジベースの「Kaspersky Endpoint Security」ページには、本製品の購入、インストール、および利用方法に関する有益な情報、推奨事項、およびよくある質問への回答を含む記事が掲載されています。","ナレッジベースの記事は、Kaspersky Endpoint Security のみでなく、他のカスペルスキー製品の問題解決にも利用できます。また、ナレッジベースにはテクニカルサポートからのニュースが含まれている場合があります。","本製品に含まれるヘルプ","本製品にはフルヘルプとコンテキストヘルプが含まれます。","フルヘルプでは、Kaspersky Endpoint Security の設定方法と使用方法について説明しています。","コンテキストヘルプには、Kaspersky Endpoint Security のウィンドウに関する情報、Kaspersky Endpoint Security の設定に関する説明、およびそれらの設定が使用されているタスクの記述のへのリンクが含まれます。","ヘルプは配信キットに含まれているか、カスペルスキーの Web サイトにあります。オンラインヘルプが利用可能な場合、オンラインヘルプへアクセスするとブラウザーのウィンドウが開きます。オンラインヘルプの閲覧にはインターネット接続が必要です。","ガイド","ユーザーガイドでは、本製品のインストール方法、アクティベーション方法、設定方法、および使用方法を確認できます。また、本製品のインターフェイスと最も典型的なユーザータスクの実行方法についても、ガイドに記載しています。"," &#x81EA;&#x5206;&#x3067;&#x8ABF;&#x3079;&#x308B;&#x5834;&#x5408;&#x306E;&#x60C5;&#x5831;&#x5165;&#x624B;&#x5148; ","166041.htm");
Page[6]=new Array("Web フォーラムの利用","特に緊急の対応が必要ではない場合は、Kaspersky Lab の Web フォーラムをご利用ください。ここでは、Kaspersky Lab のエキスパートやカスペルスキー製品のユーザーが、さまざまなトピックで意見交換しています。","フォーラムでは、これまでに公開されたトピックの閲覧、コメントの書き込み、新しいトピックの作成が可能です。"," Web &#x30D5;&#x30A9;&#x30FC;&#x30E9;&#x30E0;&#x306E;&#x5229;&#x7528; ","35700.htm");
Page[7]=new Array("Kaspersky Endpoint Security 10 Service Pack 1 for Linux","このセクションでは、Kaspersky Endpoint Security の機能、コンポーネント、および配信キットについて説明します。さらに、Kaspersky Endpoint Security のシステム要件についても説明します。","このセクションの内容Kaspersky Endpoint Security について主な変更点製品の購入システム要件"," Kaspersky Endpoint Security 10 Service Pack 1 for Linux ","161213.htm");
Page[8]=new Array("Kaspersky Endpoint Security について","Kaspersky Endpoint Security は、Linux® オペレーティングシステムが動作するコンピューターをマルウェアから保護します。脅威は、ネットワークのデータ転送チャネルやリムーバブルディスクからシステムに侵入する可能性があります。","本製品でできること：","コンピューターのローカルドライブにあるファイルシステムオブジェクトと、SMB および NFS プロトコルを使用してアクセスされるマウントされたリソースと共有リソースのスキャン。リアルタイム保護タスクを使用したリアルタイムでのファイルシステムオブジェクトのスキャン、およびオンデマンドスキャンタスクを使用したオンデマンドでのファイルシステムオブジェクトのスキャン。ブートセクターのスキャン。プロセスメモリのスキャン。感染したオブジェクトの検知。オブジェクトに既知のウイルスのコードが含まれていることが検知された場合、Kaspersky Endpoint Security はオブジェクトが感染しているものとみなします。ファイル内で検知された脅威の無害化。脅威を無害化するために実行する処理を自動的に選択します。駆除または削除の前にファイルのバックアップコピーを保存して、バックアップコピーからファイルを復元します。タスクの管理と設定。リアルタイム保護タスク、オンデマンドスキャンタスク、ブートセクタースキャンタスク、プロセスメモリスキャンタスク、アップデートタスク、アップデートのロールバックタスク、アップデートの再変換タスクを管理します。ライセンスの追加と、アクティベーションコードを使用した製品のアクティベーション。Kaspersky Endpoint Security の操作中に発生したイベントに関する管理者への通知。Kaspersky Lab のアップデートサーバー、管理サーバー、またはユーザーが指定したアップデート元からの、スケジュールまたはオンデマンドによる定義データベースのアップデート。定義データベースを使用した、感染したファイルの検知と駆除。スキャンプロセス中に各ファイルの脅威を分析します。ファイルのコードが特定の脅威に類似しているコードと一致するか照合します。指定されたファイルの変更監視と変更の通知。ファイル変更監視は常時監視モードおよびオンデマンドスキャンモードで実行できます。オペレーティングシステムのファイアウォールを管理し、必要に応じて、変更されたファイアウォールルールのセットを復元します。SMB / NFS プロトコルによるネットワークアクセスを使ったリモートによる悪意のある暗号化から、ローカルディレクトリにあるファイルを保護します。root 権限のないユーザーがグラフィカルユーザーインターフェイスを使用して基本的な製品機能を管理できます。アップデートパッケージを使用して製品をアップデートします。Kaspersky Endpoint Security を管理するには、次の方法を使用します：アプリケーションコントロールコマンドを使ってコマンドラインを使用する。グラフィカルユーザーインターフェイスを使用する。Kaspersky Security Center を使用する。"," Kaspersky Endpoint Security &#x306B;&#x3064;&#x3044;&#x3066; ","161214.htm");
Page[9]=new Array("主な変更点","Kaspersky Endpoint Security 10 Service Pack 1 for Linux には、次のような新機能と改良点があります：","ファイル整合性監視指定されたファイルの変更監視と変更の通知。ファイル変更監視はリアルタイム監視モードおよびオンデマンドスキャンモードで実行できます。","ファイアウォールの管理オペレーティングシステムのファイアウォールを管理し、必要に応じて、変更されたファイアウォールルールのセットを復元できます。","アンチ暗号化SMB / NFS プロトコルによるネットワークアクセスを使ったリモートによる悪意のある暗号化から、ローカルディレクトリにあるファイルを保護します。","グラフィカルユーザーインターフェイスroot 権限のないユーザーがグラフィカルユーザーインターフェイス（GUI）を使用して基本的な製品機能を管理できるようにします。","ソフトウェアアップデート：アップデートパッケージを使用して本製品をアップデートできます。","kesl-control はシステムディレクトリの /usr/bin に位置します。"," &#x4E3B;&#x306A;&#x5909;&#x66F4;&#x70B9; ","162018.htm");
Page[10]=new Array("製品の購入","配信キットには、次のファイルを含む Kaspersky Endpoint Security のインストールパッケージが含まれています：","kesl-10.1.0-<ビルド番号>.i386.rpm、kesl_10.1.0-<ビルド番号>_i386.debKaspersky Endpoint Security のメインファイルが含まれています。パッケージは、パッケージマネージャーの種別に基づき 32 ビットオペレーティングシステムにインストールできます。","kesl-10.1.0-<ビルド番号>.x86_64.rpm、kesl_10.1.0-<ビルド番号>_amd64.debKaspersky Endpoint Security のメインファイルが含まれています。パッケージは、パッケージマネージャーの種別に基づき 64 ビットオペレーティングシステムにインストールできます。","kesl.zipKaspersky Security Center を使用して Kaspersky Endpoint Security をリモートでインストールするための手順で使用されるファイルが含まれています。","klnagent-<ビルド番号>.i386.rpm、klnagent_<ビルド番号>_i386.deb、klnagent64-<ビルド番号>.x86_64.rpm、klnagent64_<ビルド番号>_amd64.debネットワークエージェント（Kaspersky Endpoint Security を Kaspersky Security Center に接続するユーティリティ）が含まれています。","klnagent-rpm.tar.gz、klnagent-deb.tar.gzKaspersky Security Center を使用した管理コンソールのリモートインストール手順に使用される、ファイル klnagent.kpd および akinstall.sh が含まれています。","ksn_license.<言語 ID> ファイル：Kaspersky Security Network への参加条件を表示するために使用できます。license.<言語 ID> ファイル：使用許諾契約書を表示するために使用できます。使用許諾契約書には、製品の使用条件が指定されています。"," &#x88FD;&#x54C1;&#x306E;&#x8CFC;&#x5165; ","161216.htm");
Page[11]=new Array("システム要件","Kaspersky Endpoint Security が適切に動作するには、次の要件を満たす必要があります：","一般的な最小要件：","プロセッサ：Core™ 2 Duo 1.86 GHz 以上メモリ：1 GB（32 ビットオペレーティングシステムの場合）メモリ：2 GB（64 ビットオペレーティングシステムの場合）スワップパーティション：1 GB 以上ハードディスク：1 GB 以上の空き容量ソフトウェア要件：","サポートされる 32 ビットオペレーティングシステム：Red Hat® Enterprise Linux® 6.9CentOS-6.9Ubuntu Server 14.04.5 LTSUbuntu Server 16.04.5 LTSUbuntu Server 17.10.1 LTSDebian GNU/Linux 7、全エディション（グラフィカルユーザーインターフェイスはサポートされていません）Debian GNU/Linux 8.10Debian GNU/Linux 9.3サポートされる 64 ビットオペレーティングシステム：Red Hat Enterprise Linux 6.9Red Hat Enterprise Linux 7.4CentOS-6.9CentOS-7.4Ubuntu Server 14.04.5 LTSUbuntu Server 16.04.5 LTSUbuntu Server 17.10.1 LTSDebian GNU/Linux 7、全エディション（グラフィカルユーザーインターフェイスはサポートされていません）Debian GNU/Linux 8.10Debian GNU/Linux 9.3openSUSE 42.3SUSE Linux Enterprise Server 12.3Novell OES2015、全エディション（グラフィカルユーザーインターフェイスはサポートされていません）Oracle Linux 7.4Perl - バージョン 5.10 以上Which ユーティリティ製品をコンパイルするためにインストールされるパッケージ（gcc、binutils、glibc、glibc-devel、make、ld）オペレーティングシステムのカーネルのソースコード - fanotify テクノロジーをサポートしないオペレーティングシステム上での Kaspersky Endpoint Security のモジュールのコンパイル用。Kaspersky Endpoint Security 10 for Linux は、Kaspersky Security Center 10 SP1 および Kaspersky Security Center 10 SP2 と互換性があります。Kaspersky Endpoint Security 管理用プラグインが適切に機能するには、Microsoft® Visual C++ 2015 Redistributable Update 3 RC がインストールされている必要があります。ネットワークエージェントをインストールする前に、次のモジュールがインストールされている必要があります：64 ビット版の Debian と Ubuntu には、libc6-i386 モジュールがインストールされている必要があります。Red Hat Enterprise Linux 7 以降、CentOS 6 以降、Oracle Linux 7 以降、Novel には、glibc.i686 モジュールがインストールされている必要があります。openSUSE 42.2、CentOS 6 以降、Novel には、glibc-32bit モジュールがインストールされている必要があります。"," &#x30B7;&#x30B9;&#x30C6;&#x30E0;&#x8981;&#x4EF6; ","161217.htm");
Page[12]=new Array("本製品のインストール","このセクションでは、Kaspersky Endpoint Security とネットワークエージェントのインストーラーパッケージ（以降、「パッケージ」）のインストール方法の手順について説明します。","このセクションの内容Kaspersky Endpoint Security のインストールについてKaspersky Endpoint Security パッケージのインストールKaspersky Endpoint Security の初期設定Kaspersky Endpoint Security の自動初期設定Kaspersky Security Center による Kaspersky Endpoint Security のインストールネットワークエージェントのインストール古い製品バージョンのアップグレードSELinux システムの権限の設定AppArmor システムの権限の設定"," &#x672C;&#x88FD;&#x54C1;&#x306E;&#x30A4;&#x30F3;&#x30B9;&#x30C8;&#x30FC;&#x30EB; ","161219.htm");
Page[13]=new Array("Kaspersky Endpoint Security のインストールについて","Kaspersky Endpoint Security は、DEB および RPM 形式のパッケージで配信されます。","Kaspersky Endpoint Security を使用するには、以下のことを実行する必要があります：","Kaspersky Endpoint Security パッケージをインストールします。設定のアップデートスクリプトを実行します。Kaspersky Security Center を使用して Kaspersky Endpoint Security を管理する場合は、ネットワークエージェントのパッケージと Kaspersky Endpoint Security 管理用プラグインをインストールします。インストール中、またはアップデートのダウンロードおよび適用中に、アプリケーションファイルやディレクトリにアクセスするには、root 権限が必要です。"," Kaspersky Endpoint Security &#x306E;&#x30A4;&#x30F3;&#x30B9;&#x30C8;&#x30FC;&#x30EB;&#x306B;&#x3064;&#x3044;&#x3066; ","161220.htm");
Page[14]=new Array("Kaspersky Endpoint Security パッケージのインストール","Kaspersky Endpoint Security は、DEB および RPM 形式のパッケージで配信されます。","Kaspersky Endpoint Security を RPM パッケージから 32 ビットオペレーティングシステムにインストールするには、次のコマンドを実行します：","# rpm -i kesl-10.1.0-<ビルド番号>.i386.rpm","Kaspersky Endpoint Security を RPM パッケージから 64 ビットオペレーティングシステムにインストールするには、次のコマンドを実行します：","# rpm -i kesl-10.1.0-<ビルド番号>.x86_64.rpm","Kaspersky Endpoint Security を DEB パッケージから 32 ビットオペレーティングシステムにインストールするには、次のコマンドを実行します：","# dpkg -i kesl-10.1.0-<ビルド番号>_i386.deb","Kaspersky Endpoint Security を DEB パッケージから 64 ビットオペレーティングシステムにインストールするには、次のコマンドを実行します：","# dpkg -i kesl_10.1.0-<ビルド番号>_amd64.deb"," Kaspersky Endpoint Security &#x30D1;&#x30C3;&#x30B1;&#x30FC;&#x30B8;&#x306E;&#x30A4;&#x30F3;&#x30B9;&#x30C8;&#x30FC;&#x30EB; ","161221.htm");
Page[15]=new Array("Kaspersky Endpoint Security の初期設定","Kaspersky Endpoint Security をインストールしたあと、Kaspersky Endpoint Security のインストール後の設定を行うためのスクリプトを実行してください。Kaspersky Endpoint Security のインストール後の設定スクリプトは、Kaspersky Endpoint Security のパッケージに含まれています。","Kaspersky Endpoint Security の初期設定の手順を完了していない場合、コンピューターのアンチウイルスによる保護は動作しません。","Kaspersky Endpoint Security のインストール後の設定スクリプトを開始するには、次のコマンドを実行します：","# /opt/kaspersky/kesl/bin/kesl-setup.pl","インストール後の設定スクリプトは、Kaspersky Endpoint Security のパラメータ値を順番に入力するよう求めます。","Kaspersky Endpoint Security パッケージのインストールが完了したあと、インストール後の設定スクリプトを root 権限で実行する必要があります。","Kaspersky Endpoint Security 10 for Linux を Kaspersky Endpoint Security 10 Service Pack 1 for Linux にアップグレードできます。 ","Kaspersky Anti-Virus 8.0 for Linux File Server を Kaspersky Endpoint Security 10 Service Pack 1 for Linux にアップグレードすることはできません。Kaspersky Endpoint Security 10 Service Pack 1 for Linux をインストールする前に、以前のバージョンの製品をアンインストールする必要があります。"," Kaspersky Endpoint Security &#x306E;&#x521D;&#x671F;&#x8A2D;&#x5B9A; ","161222.htm");
Page[16]=new Array("ステップ 1：ロケールの選択","このステップでは、Kaspersky Endpoint Security の操作中に使用されるロケールを割り当てる必要があります。","RFC 3066 で定義される形式でロケールを割り当てることができます。","ロケール値の全リストを受信するには、次のコマンドを実行します：","# locale -a","既定では、root に対して設定されているロケールを使用するよう推奨されます。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 1&#xFF1A;&#x30ED;&#x30B1;&#x30FC;&#x30EB;&#x306E;&#x9078;&#x629E; ","161223.htm");
Page[17]=new Array("ステップ 2：使用許諾契約書への同意","このステップでは、使用許諾契約書の条件に同意するかしないかを指定する必要があります。","less ユーティリティを使用して、テキストを表示できます。テキスト内を移動するには、矢印キーを使用するか、B キー（1 つ前の画面に戻る）および F キー（次の画面に進む）を使用します。ヘルプを取得するには、H キーを使用します。確認を終了する場合は、Q キーを使用します。","表示モードを終了したら、次の値のいずれかを入力します：","yes（または y）：使用許諾契約書の条件に同意する場合。no（または n）：使用許諾契約書の条件に同意しない場合。使用許諾契約書の条件に同意しないと、Kaspersky Endpoint Security の設定プロセスが終了します。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 2&#xFF1A;&#x4F7F;&#x7528;&#x8A31;&#x8AFE;&#x5951;&#x7D04;&#x66F8;&#x3078;&#x306E;&#x540C;&#x610F; ","161224.htm");
Page[18]=new Array("ステップ 3：プライバシーポリシーに同意する","このステップでは、プライバシーポリシーの条件に同意するかしないかを指定する必要があります。","less ユーティリティを使用して、テキストを表示できます。テキスト内を移動するには、矢印キーを使用するか、B キー（1 つ前の画面に戻る）および F キー（次の画面に進む）を使用します。ヘルプを取得するには、H キーを使用します。確認を終了する場合は、Q キーを使用します。","表示モードを終了したら、次の値のいずれかを入力します：","yes（または y）：プライバシーポリシーに同意する場合。no（または n）：プライバシーポリシーに同意しない場合。プライバシーポリシーに同意しないと、Kaspersky Endpoint Security の設定プロセスが終了します。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 3&#xFF1A;&#x30D7;&#x30E9;&#x30A4;&#x30D0;&#x30B7;&#x30FC;&#x30DD;&#x30EA;&#x30B7;&#x30FC;&#x306B;&#x540C;&#x610F;&#x3059;&#x308B; ","166206.htm");
Page[19]=new Array("ステップ 4：Kaspersky Security Network への参加","このステップでは、Kaspersky Security Network 声明の条件に同意するかしないかを指定する必要があります。Kaspersky Security Network 声明が記載されているファイルは、ディレクトリ /opt/kaspersky/kesl/doc/ksn_license.<言語 ID> にあります。","次のいずれかの値を入力します：","yes（または y）：Kaspersky Security Network 声明の条件に同意する場合。Kaspersky Security Network の拡張モードが有効になります。 no（または n）：Kaspersky Security Network 声明の条件に同意しない場合。Kaspersky Security Network への参加に同意しなくても、Kaspersky Endpoint Security のインストールプロセスは中断されません。Kaspersky Security Network のモードは、いつでも有効化、無効化、または変更することができます。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 4&#xFF1A;Kaspersky Security Network &#x3078;&#x306E;&#x53C2;&#x52A0; ","161225.htm");
Page[20]=new Array("ステップ 5：ファイル操作のインターセプターの種別を判断する","このステップでは、使用されるオペレーティングシステムのファイル操作のインターセプターの種別が判断されます。fanotify テクノロジーをサポートしないオペレーティングシステムの場合、カーネルモジュールのコンパイルが開始されます。カーネルモジュールは、リアルタイム保護タスクの操作に必要です。","カーネルモジュールをコンパイルするには、System.map-<カーネルのバージョン> ファイルが /boot/ ディレクトリに存在していなければなりません。","スクリプトが既定のディレクトリにオペレーティングシステムのモジュールのカーネルソースコードを検出した場合、このディレクトリへのパスが使用されます。それ以外の場合は、モジュールのカーネルソースコードへのパスを指定する必要があります。","モジュールのカーネルのコンパイルプロセス中に必要なパッケージが検出されない場合、Kaspersky Endpoint Security はダウンロードを試行します。パッケージをダウンロードできない場合、エラーメッセージが表示されます。","Kaspersky Endpoint Security の初期設定が完了したあとで、カーネルモジュールをコンパイルできます。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 5&#xFF1A;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x64CD;&#x4F5C;&#x306E;&#x30A4;&#x30F3;&#x30BF;&#x30FC;&#x30BB;&#x30D7;&#x30BF;&#x30FC;&#x306E;&#x7A2E;&#x5225;&#x3092;&#x5224;&#x65AD;&#x3059;&#x308B; ","161226.htm");
Page[21]=new Array("ステップ 6：定義データベースのダウンロード","このステップでは、Kaspersky Endpoint Security の定義データベースをコンピューターにダウンロードできます。定義データベースには、脅威シグネチャの説明と脅威の対処方法が格納されています。Kaspersky Endpoint Security は、脅威を検索して無害化するときにこれらのレコードを使用します。Kaspersky Lab のウイルスアナリストは、新しい脅威に関する新しいレコードを定期的に追加します。","定義データベースをコンピューターにダウンロードするには、「yes」を入力する必要があります。","定義データベースをすぐにダウンロードしない場合は、「no」を入力します。","既定の応答は「yes」です。","コンピューターのアンチウイルスによる保護は、定義データベースをダウンロードしたあとでのみ提供されます。","アップデートタスクは初期設定スクリプトを使用しなくても開始できます。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 6&#xFF1A;&#x5B9A;&#x7FA9;&#x30C7;&#x30FC;&#x30BF;&#x30D9;&#x30FC;&#x30B9;&#x306E;&#x30C0;&#x30A6;&#x30F3;&#x30ED;&#x30FC;&#x30C9; ","161228.htm");
Page[22]=new Array("ステップ 7：プロキシサーバーの設定","このステップでは、プロキシサーバーを使用してインターネットにアクセスしている場合にプロキシサーバー設定を指定する必要があります。アップデートサーバーから Kaspersky Endpoint Security の定義データベースをダウンロードするには、インターネット接続が必要です。","プロキシサーバーを設定するには、次の処理のいずれかを実行します：","インターネットへの接続にプロキシサーバーを使用する場合、次の形式いずれかを使用して、プロキシサーバーのアドレスを指定します：proxy_server_IP:port_number - プロキシサーバーへの接続に認証が不要な場合user_name:password@proxy_server_IP_address:port_number - プロキシサーバーへの接続に認証が必要な場合インターネットへの接続にプロキシサーバーを使用しない場合は、「no」と入力します。","既定では、「no」が指定されます。","プロキシサーバー設定の指定は、初期設定スクリプトを使用せずに行うことができます。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 7&#xFF1A;&#x30D7;&#x30ED;&#x30AD;&#x30B7;&#x30B5;&#x30FC;&#x30D0;&#x30FC;&#x306E;&#x8A2D;&#x5B9A; ","161227.htm");
Page[23]=new Array("ステップ 8：定義データベースの自動アップデートの有効化","このステップでは、定義データベースの自動アップデートを有効にすることができます。","定義データベースの自動アップデートを有効にするには、「yes」を入力します。既定では、Kaspersky Endpoint Security は 60 分ごとに使用可能な定義データベースのアップデートを確認します。アップデートが使用可能な場合、Kaspersky Endpoint Security は更新された定義データベースをダウンロードします。","定義データベースを自動的にダウンロードしない場合は、「no」を入力します。","アップデートタスクのスケジュールを管理することにより、初期設定スクリプトを使用しなくても定義データベースの自動アップデートを有効にすることができます。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 8&#xFF1A;&#x5B9A;&#x7FA9;&#x30C7;&#x30FC;&#x30BF;&#x30D9;&#x30FC;&#x30B9;&#x306E;&#x81EA;&#x52D5;&#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x306E;&#x6709;&#x52B9;&#x5316; ","161229.htm");
Page[24]=new Array("ステップ 9：アプリケーションのアクティベーション","このステップでは、アクティベーションコードまたはライセンス情報ファイルを使用してアプリケーションのアクティベーションを行う必要があります。","アクティベーションコードを使用してアプリケーションのアクティベーションを行うには、アクティベーションコードを入力する必要があります。","ライセンス情報ファイルを使用してアプリケーションのアクティベーションを行うには、ライセンス情報ファイルの絶対パスを指定する必要があります。","アクティベーションコードまたはライセンス情報ファイルが指定されていない場合、試用版ライセンスを使用して 1 か月間アクティベートされます。","ライセンス情報ファイルのインストールは、初期設定スクリプトを使用しなくても行えます。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 9&#xFF1A;&#x30A2;&#x30D7;&#x30EA;&#x30B1;&#x30FC;&#x30B7;&#x30E7;&#x30F3;&#x306E;&#x30A2;&#x30AF;&#x30C6;&#x30A3;&#x30D9;&#x30FC;&#x30B7;&#x30E7;&#x30F3; ","161230.htm");
Page[25]=new Array("ステップ 10：グラフィカルユーザーインターフェイスの設定","このステップでは、グラフィカルユーザーインターフェイス（GUI）の使用を有効にできます。","次のいずれかの値を入力します：","yes（または y）：グラフィカルユーザーインターフェイスの使用を有効にする場合。Kaspersky Endpoint Security はすべての必要なライブラリをチェックし、必要に応じて、不足しているライブラリのインストールを試みます。no（または n）：グラフィカルユーザーインターフェイスの使用を有効にしない場合。グラフィカルユーザーインターフェイスの使用はいつでも有効または無効にできます。"," &#x30B9;&#x30C6;&#x30C3;&#x30D7; 10&#xFF1A;&#x30B0;&#x30E9;&#x30D5;&#x30A3;&#x30AB;&#x30EB;&#x30E6;&#x30FC;&#x30B6;&#x30FC;&#x30A4;&#x30F3;&#x30BF;&#x30FC;&#x30D5;&#x30A7;&#x30A4;&#x30B9;&#x306E;&#x8A2D;&#x5B9A; ","161231.htm");
Page[26]=new Array("Kaspersky Endpoint Security の自動初期設定","Kaspersky Endpoint Security の自動初期設定を実行できます。設定の値は、初期設定ファイルに指定された通りに設定されます。","Kaspersky Endpoint Security の自動初期設定を開始するには、次のコマンドを実行します：","kesl-setup.pl --autoinstall=<初期設定ファイルの絶対パス>"," Kaspersky Endpoint Security &#x306E;&#x81EA;&#x52D5;&#x521D;&#x671F;&#x8A2D;&#x5B9A; ","161232.htm");
Page[27]=new Array("Kaspersky Endpoint Security の初期設定ファイルの設定","Kaspersky Endpoint Security の初期設定ファイルには、以下の表に示す設定が含まれます。","Kaspersky Endpoint Security の初期設定ファイルの設定","設定","説明","使用できる値","EULA_AGREED","必須の設定","使用許諾契約書の条件の同意","yes - 製品のインストール手順を続行するには、使用許諾契約書の条件に同意する必要があります。","no - 使用許諾契約に同意しない。製品のインストールが中断されます。","PRIVACY_POLICY_AGREED","必須の設定","プライバシーポリシーの同意","yes - 製品のインストール手順を続行するには、プライバシーポリシーに同意する必要があります。","no - プライバシーポリシーに同意しません。製品のインストールが中断されます。","USE_KSN","Kaspersky Security Network 声明の同意","yes - Kaspersky Security Network 声明に同意する","no - Kaspersky Security Network 声明に同意しない","SERVICE_LOCALE","オプション設定","Kaspersky Endpoint Security の操作中に使用されるロケール","RFC 3066 で指定されている形式のロケール。","SERVICE_LOCALE 設定が指定されていない場合、既定ではシステムのロケールが設定されます。","INSTALL_LICENSE","アクティベーションコードまたはライセンス情報ファイル","—","UPDATER_SOURCE","アップデート元","SCServer - Kaspersky Security Center 管理サーバーをアップデート元として使用するKLServers - Kaspersky Lab のサーバーをアップデート元として使用するアップデート元のアドレス","PROXY_SERVER","インターネットへの接続に使用するプロキシサーバーのアドレス","プロキシサーバーのアドレスno - プロキシサーバーを使用しない","UPDATE_EXECUTE","設定中に定義データベースアップデートタスクを開始する","yes - アップデートタスクを開始するno - アップデートタスクを開始しない","KERNEL_SRCS_INSTALL","カーネルモジュールのコンパイルの自動開始","yes - カーネルモジュールをコンパイルするno - カーネルモジュールをコンパイルしない","USE_GUI","グラフィカルユーザーインターフェイスの使用の有効化","yes - グラフィカルユーザーインターフェイスの使用の有効化no - グラフィカルユーザーインターフェイスの使用を無効にする","IMPORT_SETTINGS","設定ファイルの製品設定を使用する ","yes - 設定ファイルの製品設定を使用するno - 設定ファイルの製品設定を使用しない","Kaspersky Endpoint Security の初期設定ファイルの設定を変更する場合は、parameter_name=parameter_value 形式の設定値を入力します（パラメータ名とその値の間のスペースは処理されません）。"," Kaspersky Endpoint Security &#x306E;&#x521D;&#x671F;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x306E;&#x8A2D;&#x5B9A; ","161233.htm");
Page[28]=new Array("Kaspersky Security Center による Kaspersky Endpoint Security のインストール","Kaspersky Security Center を使用して Kaspersky Endpoint Security をコンピューターにインストールできます。","この種別の製品のインストールの詳細については、『Kaspersky Security Center ガイド』を参照してください。"," Kaspersky Security Center &#x306B;&#x3088;&#x308B; Kaspersky Endpoint Security &#x306E;&#x30A4;&#x30F3;&#x30B9;&#x30C8;&#x30FC;&#x30EB; ","161234.htm");
Page[29]=new Array("ネットワークエージェントのインストール","Kaspersky Security Center を使用して Kaspersky Endpoint Security を管理する場合は、ネットワークエージェントをインストールする必要があります。","ネットワークエージェントのインストールプロセスは、root 権限で開始する必要があります。","ネットワークエージェントを RPM パッケージから 32 ビットオペレーティングシステムにインストールする場合は、次のコマンドを実行します：","# rpm -i klnagent-<ビルド番号>.i386.rpm","ネットワークエージェントを RPM パッケージから 64 ビットオペレーティングシステムにインストールする場合は、次のコマンドを実行します：","# rpm -i klnagent64-<ビルド番号>.x86_64.rpm","ネットワークエージェントを DEB パッケージから 32 ビットオペレーティングシステムにインストールする場合は、次のコマンドを実行します：","# dpkg -i klnagent_<ビルド番号>_i386.deb","ネットワークエージェントを DEB パッケージから 64 ビットオペレーティングシステムにインストールする場合は、次のコマンドを実行します：","# dpkg -i klnagent64_<ビルド番号>_amd64.deb","パッケージをインストールしたあとで、Kaspersky Endpoint Security のインストール後の設定スクリプトを開始するには、次のコマンドを実行します：","32 ビットオペレーティングシステムの場合：/opt/kaspersky/klnagent/lib/bin/setup/postinstall.pl","64 ビットオペレーティングシステムの場合：/opt/kaspersky/klnagent64/lib/bin/setup/postinstall.pl"," &#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30A8;&#x30FC;&#x30B8;&#x30A7;&#x30F3;&#x30C8;&#x306E;&#x30A4;&#x30F3;&#x30B9;&#x30C8;&#x30FC;&#x30EB; ","161235.htm");
Page[30]=new Array("ネットワークエージェントの初期設定","Kaspersky Security Center を使用して Kaspersky Endpoint Security を管理する場合は、ネットワークエージェントの設定を行う必要があります。","ネットワークエージェントの設定を行うには：","次のコマンドを実行します：32 ビットオペレーティングシステムの場合：# /opt/kaspersky/klnagent/lib/bin/setup/postinstall.pl","64 ビットオペレーティングシステムの場合：# /opt/kaspersky/klnagent64/lib/bin/setup/postinstall.pl","管理サーバーの DNS 名または IP アドレスを指定します。管理サーバーのポート番号を指定します。ポート 14000 が既定で使用されます。","SSL 接続を使用するには、管理サーバーの SSL ポート番号を指定します。ポート 13000 が既定で使用されます。","次のいずれかの操作を実行します：SSL 接続を使用する場合は、「yes」を入力します。SSL 接続を使用しない場合は、「no」を入力します。既定では、SSL 接続は有効になっています。","必要に応じて、接続ゲートウェイモードを指定します：0 - 接続ゲートウェイを使用しない。1 - このネットワークエージェントを接続ゲートウェイとして使用する。2 - 接続ゲートウェイから管理サーバーに接続する。ネットワークエージェントの設定に関する詳細情報は、『Kaspersky Security Center ガイド』を参照してください。"," &#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30A8;&#x30FC;&#x30B8;&#x30A7;&#x30F3;&#x30C8;&#x306E;&#x521D;&#x671F;&#x8A2D;&#x5B9A; ","161236.htm");
Page[31]=new Array("古い製品バージョンのアップグレード","Kaspersky Endpoint Security 10 for Linux を Kaspersky Endpoint Security 10 Service Pack 1 for Linux にアップグレードできます。 ","古いバージョンの製品をアップグレードするには、次の方法で行います：","コマンドラインを使用してローカルでアップグレードするKaspersky Security Center ソフトウェアスイートを使用してリモートでアップグレードする（『Kaspersky Security Center ガイド』を参照）本製品の以前のバージョンを Kaspersky Endpoint Security 10 Service Pack 1 for Linux にアップグレードする際、本製品の以前のバージョンを削除する必要はありません。以前のバージョンの製品をアップグレードする前に、すべてのアクティブなアプリケーションを終了してください。"," &#x53E4;&#x3044;&#x88FD;&#x54C1;&#x30D0;&#x30FC;&#x30B8;&#x30E7;&#x30F3;&#x306E;&#x30A2;&#x30C3;&#x30D7;&#x30B0;&#x30EC;&#x30FC;&#x30C9; ","161237.htm");
Page[32]=new Array("コマンドラインを使用して製品をアップグレードする","次の操作を実行して、Kaspersky Endpoint Security 10 for Linux を Kaspersky Endpoint Security 10 Service Pack 1 for Linux にローカルでアップグレードできます。","アップグレード手順の完了後、オペレーティングシステムまたは製品の再起動が必要になる場合があります。","本製品をアップグレードするには：","Kaspersky Endpoint Security 10 Service Pack 1 for Linux の必要なパッケージのインストールを実行します。Kaspersky Endpoint Security 10 for Linux が停止され、本製品の設定とイベントログがエクスポートされます。","インストール後の設定スクリプトを実行します。インストール後の設定スクリプトは、Kaspersky Endpoint Security のパラメータ値を順番に入力するよう求めます。","使用許諾契約書（EULA）とプライバシーポリシーに必ず同意していただく必要があります。","本製品の設定とイベントログが、アップグレードされた本製品へ移されます。新しい設定項目には既定値が設定されます。本製品の設定が移されると、本製品は停止します。","必要に応じて、オペレーティングシステムまたは本製品を再起動します。本製品のアップグレード手順の実行中にエラーが発生した場合、本製品の以前のバージョンは自動的には復元されません。エラーメッセージが表示されます。","製品の設定の移行が失敗した場合、失敗した理由に関わらず、本製品は既定値に設定されます。"," &#x30B3;&#x30DE;&#x30F3;&#x30C9;&#x30E9;&#x30A4;&#x30F3;&#x3092;&#x4F7F;&#x7528;&#x3057;&#x3066;&#x88FD;&#x54C1;&#x3092;&#x30A2;&#x30C3;&#x30D7;&#x30B0;&#x30EC;&#x30FC;&#x30C9;&#x3059;&#x308B; ","165607.htm");
Page[33]=new Array("Kaspersky Security Center を使用して製品をアップグレードする","Kaspersky Security Center を使用して Kaspersky Endpoint Security 10 for Linux to Kaspersky Endpoint Security 10 Service Pack 1 for Linux を遠隔からアップグレードできます。そのためには、次の手順を実行します。","Kaspersky Security Center のポリシーで管理されている製品をアップグレードするには：","ネットワークエージェントをアップグレードします。ネットワークエージェントがアップグレードされていない場合、本製品を Kaspersky Security Center で管理することはできません。","ネットワークエージェントのアップグレード中、本製品は正常に機能します。","Kaspersky Endpoint Security 10 Service Pack 1 for Linux を遠隔からインストールします。この種別の製品のインストールの詳細については、『Kaspersky Security Center ガイド』を参照してください。"," Kaspersky Security Center &#x3092;&#x4F7F;&#x7528;&#x3057;&#x3066;&#x88FD;&#x54C1;&#x3092;&#x30A2;&#x30C3;&#x30D7;&#x30B0;&#x30EC;&#x30FC;&#x30C9;&#x3059;&#x308B; ","165608.htm");
Page[34]=new Array("SELinux システムの権限の設定","Kaspersky Endpoint Security の操作に必要なルールを使用して SELinux モジュールを作成するには：","SELinux を Permissive モードに切り替えます：SELinux がアクティベートされた場合は、次のコマンドを実行します：# setenforce Permissive","SELinux が無効になっている場合は、設定ファイル /etc/selinux/config でパラメータ値 SELINUX=permissive を指定し、オペレーティングシステムを再起動します。次のタスクを実行します：リアルタイム保護タスク：kesl-control --start-t 1","プロセスメモリスキャンタスク：kesl-control --start-t 4 -W","ブートセクタースキャンタスク：kesl-control --start-t 5 -W","ブロック化レコードに基づいて、ルールモジュールを作成します：grep kesl /var/log/audit/audit.log | audit2allow -M kesl","作成されたリストには Kaspersky Endpoint Security に関するルールのみが含まれていることを確認します。","新しいルールモジュールを読み込みます：# semodule -i kesl.pp","SELinux を Enforcing モードに切り替えます：# setenforce Enforcing","Kaspersky Endpoint Security に関する新しい監査メッセージが表示された場合は、ルールモジュールファイルをアップデートする必要があります。","詳細については、関連するオペレーティングシステムのガイドを参照してください。"," SELinux &#x30B7;&#x30B9;&#x30C6;&#x30E0;&#x306E;&#x6A29;&#x9650;&#x306E;&#x8A2D;&#x5B9A; ","161238.htm");
Page[35]=new Array("AppArmor システムの権限の設定","Kaspersky Endpoint Security を実行するのに必要な AppArmor プロファイルをアップデートするには：","次のいずれかの方法を使用して、AppArmor モジュールが読み込まれていることを確認します：systemctl status apparmor/etc/init.d/apparmor statusKaspersky Endpoint Security プロファイルを作成します：最初のコンソールで、次のコマンドを実行します：cd /etc/apparmor.d","aa-genprof /opt/kaspersky/kesl/libexec/kesl","2 番目のコンソールで、次のタスクを実行します：リアルタイム保護タスク：kesl-control --start-t 1","プロセスメモリスキャンタスク：kesl-control --start-t 4 -W","ブートセクタースキャンタスク：kesl-control --start-t 5 -W","アップデートタスク：kesl-control --start-t 6 -W","最初のコンソールで、S を押します。イベントのスキャンが完了した後で、F を押します。作成された Kaspersky Endpoint Security プロファイルをメッセージディスプレイモードに切り替えます：aa-complain opt.kaspersky.kesl.libexec.kesl","製品を数日間実行したあとで、次のコマンドを実行してプロファイルをアップデートします：aa-logprof","この期間中に Kaspersky Endpoint Security が使用したすべてのファイルに対して Allow 権限または Glob 権限を指定します。","Kaspersky Endpoint Security プロファイルをブロック化モードに切り替えます：aa-enforce opt.kaspersky.kesl.libexec.kesl","Kaspersky Endpoint Security に関する新しい監査メッセージが表示された場合は、ルールモジュールファイルをアップデートする必要があります。","詳細については、関連するオペレーティングシステムのガイドを参照してください。"," AppArmor &#x30B7;&#x30B9;&#x30C6;&#x30E0;&#x306E;&#x6A29;&#x9650;&#x306E;&#x8A2D;&#x5B9A; ","161239.htm");
Page[36]=new Array("製品の削除","このセクションでは、ローカルで、または Kaspersky Security Center を使用して Kaspersky Endpoint Security を削除する方法について説明します。","このセクションの内容Kaspersky Endpoint Security のローカルでの削除Kaspersky Security Center による Kaspersky Endpoint Security の削除"," &#x88FD;&#x54C1;&#x306E;&#x524A;&#x9664; ","161240.htm");
Page[37]=new Array("Kaspersky Endpoint Security のローカルでの削除","製品が削除されている間、Kaspersky Endpoint Security のすべてのタスクが停止します。","RPM パッケージからインストールされた Kaspersky Endpoint Security をアンインストールするには、次のコマンドを実行します：","# rpm -e kesl","DEB パッケージからインストールされた Kaspersky Endpoint Security をアンインストールするには、次のコマンドを実行します：","# dpkg -r kesl","RPM パッケージからインストールされたネットワークエージェントを削除するには、次のコマンドを実行します：","# rpm -e klnagent","DEB パッケージからインストールされたネットワークエージェントを削除するには、次のコマンドを実行します：","# dpkg -r klnagent","削除手順を自動的に実行します。完了すると、削除の結果が記されたメッセージが表示されます。","Kaspersky Endpoint Security の削除後、製品の再インストール時に使用できるライセンスデータベースが残ります。"," Kaspersky Endpoint Security &#x306E;&#x30ED;&#x30FC;&#x30AB;&#x30EB;&#x3067;&#x306E;&#x524A;&#x9664; ","161241.htm");
Page[38]=new Array("Kaspersky Security Center による Kaspersky Endpoint Security の削除","Kaspersky Security Center を使用して Kaspersky Endpoint Security を削除できます。それには、Kaspersky Endpoint Security の削除タスクを作成して開始する必要があります。","Kaspersky Endpoint Security の削除タスクの作成と開始に関する詳細情報は、『Kaspersky Security Center ガイド』を参照してください。"," Kaspersky Security Center &#x306B;&#x3088;&#x308B; Kaspersky Endpoint Security &#x306E;&#x524A;&#x9664; ","161242.htm");
Page[39]=new Array("本製品のライセンス管理","このセクションでは、本製品のライセンス管理について説明します。","このセクションの内容使用許諾契約書についてライセンスについてライセンス証明書についてアクティベーションコードについてライセンスについてライセンス情報ファイルについて定額制サービスについてデータ提供について"," &#x672C;&#x88FD;&#x54C1;&#x306E;&#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x7BA1;&#x7406; ","161243.htm");
Page[40]=new Array("使用許諾契約書について","使用許諾契約書は、ユーザーと AO Kaspersky Lab との間で締結される契約で、製品を使用できる条件を明記しています。","使用許諾契約書の条件をよく読んでから、製品の使用を開始してください。","使用許諾契約書の条項は次の方法で表示できます：","Kaspersky Endpoint Security のインストール中。license.<言語 ID> ファイルの確認。このファイルには本製品の配信キットが含まれています。製品のインストール時に使用許諾契約書の同意を確認することにより、使用許諾契約書の条項を受諾したこととみなされます。使用許諾契約書の条項に同意しない場合は、製品のインストールを終了するか、製品の使用を中止する必要があります。"," &#x4F7F;&#x7528;&#x8A31;&#x8AFE;&#x5951;&#x7D04;&#x66F8;&#x306B;&#x3064;&#x3044;&#x3066; ","161244.htm");
Page[41]=new Array("ライセンスについて","「ライセンス」は、製品の期間限定の使用権であり、使用許諾契約書に基づいて付与されます。","有効なライセンスにより、次のサービスの使用が許可されます：","使用許諾契約書の条項に従った本製品の使用テクニカルサポートの取得サービスの範囲と製品の使用可能期間は、アクティベーションに使用したライセンス種別によって異なります。","ライセンス種別には、以下があります：","試用版 - 製品を試してみるための無償ライセンス。通常、試用版ライセンスには短い有効期間が設定されています。試用版の有効期間が終了したら、すべての Kaspersky Endpoint Security の機能が無効になります。製品を引き続き使用するには、製品版ライセンスを購入する必要があります。","試用版ライセンスで製品をアクティベートできるのは 1 度だけです。","Commercial - 製品の購入で提供される有償ライセンス。製品版ライセンスの期限が切れても製品は動作を続けますが、使える機能は制限されます（たとえば、Kaspersky Endpoint Security の定義データベースのアップデートは使用できません）。Kaspersky Endpoint Security を機能が制限されていない状態で使用し続けるには、製品版ライセンスを更新する必要があります。","有効期限が切れる前にライセンスを更新し、すべてのセキュリティ脅威から最大限に保護された環境を維持できるようにしてください。"," &#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x306B;&#x3064;&#x3044;&#x3066; ","161245.htm");
Page[42]=new Array("ライセンス証明書について","ライセンス証明書 - ライセンス情報ファイルまたはアクティベーションコードを使用して提供される文書。","ライセンス証明書には次のライセンス情報が含まれます：","注文番号ライセンス所有者の詳細ライセンスを使用してアクティベーションを実行可能な製品の情報ライセンスユニット（ライセンスによって製品の使用が許可されるデバイス）の数の制限ライセンスの開始日ライセンスの有効期限またはライセンスの有効期間ライセンス種別"," &#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x8A3C;&#x660E;&#x66F8;&#x306B;&#x3064;&#x3044;&#x3066; ","161246.htm");
Page[43]=new Array("アクティベーションコードについて","アクティベーションコード - 20 桁の英数字の一意の並び。Kaspersky Endpoint Security のアクティベーションを実行するキーを追加するには、アクティベーションコードを入力する必要があります。Kaspersky Security の購入時または試用版の Kaspersky Endpoint Security の注文時に登録したメールアドレスで、アクティベーションコードを受け取ります。","アクティベーションコードを使用して製品のアクティベーションを実行するには、カスペルスキーのアクティベーションサーバーへの接続時にインターネット接続が確立されている必要があります。","本製品のアクティベーション完了後にアクティベーションコードを紛失した場合は、アクティベーションコードを復元できます。カスペルスキーカンパニーアカウントを登録する際に、アクティベーションコードが必要になる場合があります。アクティベーションコードを復元するには、カスペルスキーのテクニカルサポートにお問い合わせください。"," &#x30A2;&#x30AF;&#x30C6;&#x30A3;&#x30D9;&#x30FC;&#x30B7;&#x30E7;&#x30F3;&#x30B3;&#x30FC;&#x30C9;&#x306B;&#x3064;&#x3044;&#x3066; ","161247.htm");
Page[44]=new Array("ライセンスについて","ライセンス - 使用許諾契約書の条件に応じて製品をアクティベートしてから使用できるようになるビットの並び。ライセンスは Kaspersky Lab が生成します。","製品にライセンスを追加するには、ライセンス情報ファイルを適用するか、アクティベーションコードを入力します。本製品にライセンスを追加すると、そのライセンスは一意の英数字の並びとして製品インターフェイスに表示されます。","Kaspersky Lab は、使用許諾契約書に違反したライセンスをブラックリストに掲載します。ライセンスがブラックリストに掲載されている場合、本製品の使用を続けるには、別のライセンスを追加する必要があります。","ライセンスには、現在のライセンスと予備のライセンスの 2 種類があります。","現在のライセンス - 製品で現在使用されるライセンス。現在のライセンスとして追加できるのは、試用版または製品版のライセンスです。本製品で使用できる現在のライセンスは、1 つのみです。","予備のライセンス - 製品を使用する権利を証明するもので、現在使用されていないライセンス。現在のライセンスの有効期限が切れると、予備のライセンスが自動的に現在のライセンスとなります。予備のライセンスは、現在のライセンスが使用可能な場合のみ追加できます。","試用版ライセンスは現在のライセンスとしてのみ追加できます。試用版ライセンスを予備のライセンスとして追加することはできません。"," &#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x306B;&#x3064;&#x3044;&#x3066; ","161248.htm");
Page[45]=new Array("ライセンス情報ファイルについて","ライセンス情報ファイルは、カスペルスキーから受信する、拡張子 .key を持つファイルです。ライセンス情報ファイルを追加することで本製品のアクティベーションが実行されるよう設計されています。","Kaspersky Endpoint Security の購入時または試用版の Kaspersky Security の注文時に登録したメールアドレスで、ライセンス情報ファイルを受け取ります。","ライセンス情報ファイルを使って本製品のアクティベーションを実行するために、Kaspersky のアクティベーションサーバーを接続する必要はありません。","誤ってライセンス情報ファイルを削除した場合は、復元することができます。カスペルスキーカンパニーアカウントで登録する際に、ライセンス情報ファイルが必要になる場合があります。","ライセンス情報ファイルを復元するには、次を実行します：","テクニカルサポート（http://support.kaspersky.co.jp/）に連絡してください。使用可能なアクティベーションコードを使って、ライセンス情報ファイルを Kaspersky Lab の Web サイト（）から受信します。"," &#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x60C5;&#x5831;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x306B;&#x3064;&#x3044;&#x3066; ","161249.htm");
Page[46]=new Array("定額制サービスについて","Kaspersky Endpoint Security の定額制サービスは、特定のパラメータ（定額制サービスの有効期限が切れる日、保護されるデバイスの数）を使用した製品の購入注文です。Kaspersky Endpoint Security の定額制サービスをサービスプロバイダー（ISP など）から注文できます。定額制サービスは手動または自動で更新でき、定額制サービスをキャンセルすることもできます。サービスプロバイダーの Web サイトで定額制サービスを管理できます。","定額制サービスは、制限すること（1 年など）も、無制限にすること（有効期限なし）もできます。制限された定額制サービスの有効期限が切れたあとに Kaspersky Endpoint Security が引き続き機能するには、定額制サービスを更新する必要があります。無制限の定額制サービスは、プロバイダーのサービスが予定どおりに前払いされたときに、自動的に更新されます。","制限された定額制サービスの場合、有効期限が切れると、定額制サービスを更新する猶予期間が提供され、その期間は製品が機能を保持します。サービスプロバイダーにより猶予期間が付与されるかどうかが決定され、付与する場合は猶予期間の長さを決定されます。","定額制サービスで Kaspersky Endpoint Security を使用するには、サービスプロバイダーから取得したアクティベーションコードを適用する必要があります。アクティベーションコードが適用されると、現在のライセンスがインストールされます。現在のライセンスは、定額制サービスで製品を使用するためのライセンスを定義します。予備のライセンスは、アクティベーションコードを使用した場合にのみインストールでき、ライセンス情報ファイルを使用して、または定額制サービスでインストールすることはできません。","定額制サービスによって使用できる製品の機能は、以下の種別の製品版ライセンスの機能に対応します：Standard、Kaspersky Business Space Security、Kaspersky Enterprise Space Security。これらの種別のライセンスは、ファイルサーバー、ワークステーション、およびモバイル端末の保護のために設計され、ワークステーションとモバイル端末の制御コンポーネントの使用をサポートします。","使用可能な定額制サービスの管理オプションは、サービスプロバイダーごとに異なる場合があります。サービスプロバイダーは、定額制サービスの更新のために製品の機能を保持する猶予期間を提供しない場合があります。","定額制サービスで購入されたアクティベーションコードは、Kaspersky Endpoint Security の以前のバージョンのアクティベートに使用できない場合があります。"," &#x5B9A;&#x984D;&#x5236;&#x30B5;&#x30FC;&#x30D3;&#x30B9;&#x306B;&#x3064;&#x3044;&#x3066; ","161250.htm");
Page[47]=new Array("データ提供について","使用許諾契約書に同意すると、製品の使用に関する情報を自動的に送信することに同意したことになります。送信される情報には、インストールされる製品の種別、バージョン、ローカライゼーション、製品のインストーラの一意の ID、インストールの種別、現在のライセンスと予備のライセンスのデータ（ライセンスの種別、有効期間、製品のアクティベーションの日付とライセンスの有効期限が切れる日付、ライセンスの数、ライセンスの現在の状態、アクティベーションサーバーとの通信プロトコルのバージョンを含む）などがあります。","Kaspersky Security Network 声明の条件に同意することで、次の情報が自動的に送信されることにも承諾します：","同意または拒否した Kaspersky Security Network 声明の ID とバージョン。Kaspersky Security Network 声明の同意または拒否に関する情報。Kaspersky Security Network 声明を同意または拒否した日時。統計情報のオプションが選択されていない Kaspersky Security Network に関する情報。統計情報のオプションが選択されている Kaspersky Security Network に関する情報。コンピューターとユーザーの一意の ID、製品の完全バージョン、製品の種別。配信に関する統計情報とライセンス保持者の製品の使用に関する情報を受信するために、アクティベーションコードを使用して製品をアクティベートした場合、使用する製品のバージョン（インストールされた製品のアップデート、製品のインストール ID、ライセンスの情報を含む）、オペレーティングシステムのバージョン、および情報の提供時にアクティブな製品コンポーネントの ID を自動的に提供することに同意したことになります。","Kaspersky Lab は、法律と該当する Kaspersky Lab のルールに従って、受信した情報を保護します。","Kaspersky Lab は、受信した情報を匿名化された形式で、全般的な統計情報の目的でのみ使用します。収集した統計情報は受信した元の情報から自動的に生成され、個人情報やその他の機密情報は含まれません。受信した元情報は、新しい情報が集まった時点で破棄されます（年に 1 回）。収集した統計情報は無期限に保存されます。","使用許諾契約書と KSN 声明に同意した場合、本製品がどのように情報を収集、処理、保存、および破棄するかは、使用許諾契約書とカスペルスキーの Web サイトで確認してください。license.<言語 ID> ファイルと ksn_license.<言語 ID> ファイルには使用許諾契約書と Kaspersky Security Network 声明が記載されており、製品の配信パッケージに組み込まれています。"," &#x30C7;&#x30FC;&#x30BF;&#x63D0;&#x4F9B;&#x306B;&#x3064;&#x3044;&#x3066; ","161251.htm");
Page[48]=new Array("本製品の起動および停止","既定では、Kaspersky Endpoint Security は、オペレーティングシステムの起動時に（各オペレーティングシステムの既定の実行レベルで）自動的に起動します。Kaspersky Endpoint Security はすべてのサービスタスクを開始し、さらにスケジュール設定で PS が設定されているカスタムタスクも開始します。","Kaspersky Endpoint Security を停止すると、実行中のすべてのタスクが中断されます。Kaspersky Endpoint Security を再起動したあと、中断されたカスタムタスクは自動的に再開されません。スケジュール設定で PS が設定されているカスタムタスクのみが再起動されます。","Kaspersky Endpoint Security を開始するには、次のコマンドを実行します：","/etc/init.d/kesl-supervisor start","Kaspersky Endpoint Security を停止するには、次のコマンドを実行します：","/etc/init.d/kesl-supervisor stop","Kaspersky Endpoint Security を再起動するには、次のコマンドを実行します：","/etc/init.d/kesl-supervisor restart","Kaspersky Endpoint Security のステータスを表示するには、次のコマンドを実行します：","/etc/init.d/kesl-supervisor status","systemd システムの Kaspersky Endpoint Security を開始するには、次のコマンドを実行します：","systemctl start kesl-supervisor","systemd システムの Kaspersky Endpoint Security を停止するには、次のコマンドを実行します：","systemctl stop kesl-supervisor","systemd システムの Kaspersky Endpoint Security を再起動するには、次のコマンドを実行します：","systemctl restart kesl-supervisor","systemd システムの Kaspersky Endpoint Security のステータスを表示するには、次のコマンドを実行します：","systemctl status kesl-supervisor","製品状態の監視","製品状態はウォッチドッグサービスで監視されます。ウォッチドッグサービスは、製品の起動時に自動的に開始します。","製品がクラッシュした場合、ダンプファイルが生成され、製品は自動的に再起動されます。ダンプファイルを除く /var/opt/kaspersky/kesl ディレクトリがバックアップされます。"," &#x672C;&#x88FD;&#x54C1;&#x306E;&#x8D77;&#x52D5;&#x304A;&#x3088;&#x3073;&#x505C;&#x6B62; ","161252.htm");
Page[49]=new Array("Kaspersky Endpoint Security の全般設定","このセクションでは、Kaspersky Endpoint Security の全般設定について説明します。","Kaspersky Endpoint Security の全般設定を変更したあとは、製品を再起動してください。","設定ファイルの全般設定では、次の値を指定します：","SambaConfigPath","Samba 設定ファイルを格納するディレクトリ。Samba 設定ファイルは、AllShared または Shared:SMB の値が Path オプションに対して適用される際に必要です。","既定では、コンピューター上の SAMBA 設定ファイルの標準ディレクトリが指定されます。","既定値：/etc/samba/smb.conf","NfsExportPath","NFS 設定ファイルを格納するディレクトリ。NFS 設定ファイルは、AllShared または Shared:NFS の値が Path オプションに対して適用される際に必要です。","既定では、コンピューター上の NFS 設定ファイルの標準ディレクトリが指定されています。","既定値：/etc/exports","TraceFolder","Kaspersky Endpoint Security によりトレースログファイルが格納されるディレクトリ。","別のディレクトリを指定する場合は、Kaspersky Endpoint Security を動作しているアカウントが、このディレクトリに対して読み取り / 書き込み権限を持っていることを確認します。","既定値：/var/log/kaspersky/kesl","TraceLevel","トレースログの詳細レベル。","使用できる値：","Detailed - 最も詳細なトレースログ。","NotDetailed - トレースログにはエラー通知が含まれます。","None - トレースログを作成しません。","既定値：None","BlockFilesGreaterMaxFileNamePath","絶対パスの長さがバイト単位で指定されたパラメータの定義値を超えているファイルへのアクセスをブロックします。","スキャン対象のファイルの絶対パスがこの設定の値を超えると、オンデマンドスキャンタスクのスキャン中にそのファイルはスキップされます。","使用できる値：4096 - 33554432。","既定値：16384","DetectOtherObjects","ハッカーがコンピューターやユーザーデータに損害を与えるために使用される可能性がある合法のソフトウェアの検知を有効または無効にします。","使用できる値：","Yes - コンピューターやユーザーデータに損害を与えるためにハッカーが使用する可能性のある合法のソフトウェアの検知を有効にします。","No - コンピューターやユーザーデータに損害を与えるためにハッカーが使用する可能性のある合法のソフトウェアの検知を無効にします。","既定値：No","UseKSN","Kaspersky Security Network への参加を有効または無効にします。","使用できる値：","No - Kaspersky Security Network への参加を無効にします。","Basic - Kaspersky Security Network（統計情報の送信なし）への参加を有効にします。","Extended - Kaspersky Security Network（統計情報の送信あり）への参加を有効にします。","既定値：No","UseProxy","Kaspersky Security Network、製品のアクティベーション、およびアップデートの実行時におけるプロキシの使用を有効または無効にします。","使用できる値：","Yes - プロキシの使用を有効にします。","No - プロキシの使用を無効にします。","既定値：No","ProxyServer","プロキシサーバー設定の形式、[user[:password]@]host[:port]。","MaxEventsNumber","Kaspersky Endpoint Security によって保存されるイベントの最大数。指定されたイベントの数を超えると、Kaspersky Endpoint Security は最も古いイベントを削除します。","既定値：500000","LimitNumberOfScanFileTasks","権限のないユーザーがコンピューターで同時に開始できる Scan_File タスクの最大数。このパラメータは、root 権限を持つユーザーが開始できるタスクの数を制限しません。値 0 が定義された場合、権限のないユーザーは Scan_File タスクを開始できません。","使用できる値：0 - 4294967295。","既定値：0","本製品のインストール中に USE_GUI の設定を yes に指定したの場合、LimitNumberOfScanFileTasks の既定値は 5 です。","UseSysLog","イベントに関する情報を syslog へ記録することを有効または無効にします。場合によっては、製品がイベントの生成および保存ができないことがあります。情報は syslog に保存されます。","Yes - イベントに関する情報を syslog へ記録することを有効にします。","No - イベントに関する情報を syslog へ記録することを無効にします。","既定値：No","UIReportsForRootOnly","グラフィカルユーザーインターフェイスからレポートの表示を有効にするかどうかを選択します。","Yes - root ユーザーのみ GUI でレポートの表示を許可します。","No - root 権限のないユーザーに GUI でレポートの表示を許可します。また、root 権限のないユーザーは最大 5 個のオブジェクトスキャンタスクを作成、開始できます。","既定値：No","EventsStoragePath","Kaspersky Endpoint Security がイベントに関する情報を保存するデータベースファイル。","既定値：/var/opt/kaspersky/kesl/events.db","このセクションの内容Kaspersky Endpoint Security の設定とタスクを管理するためのコマンドKaspersky Endpoint Security のコマンドヘルプの表示イベントの表示の有効化製品に関する情報の表示Kaspersky Endpoint Security のコマンド製品設定のエクスポートとインポート"," Kaspersky Endpoint Security &#x306E;&#x5168;&#x822C;&#x8A2D;&#x5B9A; ","161254.htm");
Page[50]=new Array("Kaspersky Endpoint Security の設定とタスクを管理するためのコマンド","このセクションでは、Kaspersky Endpoint Security の設定とタスクの管理に使用されるコマンドについて説明します。"," Kaspersky Endpoint Security &#x306E;&#x8A2D;&#x5B9A;&#x3068;&#x30BF;&#x30B9;&#x30AF;&#x3092;&#x7BA1;&#x7406;&#x3059;&#x308B;&#x305F;&#x3081;&#x306E;&#x30B3;&#x30DE;&#x30F3;&#x30C9; ","161255.htm");
Page[51]=new Array("Kaspersky Endpoint Security の全般設定の取得","コマンド --get-app-settings は、Kaspersky Endpoint Security の全般設定を表示します。また、このコマンドを使用して、コマンドキーを使用して割り当てられた Kaspersky Endpoint Security の全般設定を取得することもできます。","このコマンドを使用して、コンピューターにインストールされている Kaspersky Endpoint Security の全般設定を編集できます：","オプション --get-app-settings を使用して、Kaspersky Endpoint Security の全般設定を設定ファイルに保存します。作成された設定ファイルを開き、必要な設定を編集して、変更内容を保存します。オプション --set-app-settings を使用して、設定ファイルから Kaspersky Endpoint Security に設定をインポートします。Kaspersky Endpoint Security を停止して再起動すると、設定の新しい値が適用されます。作成された設定ファイルを使用して、別のコンピューターにインストールされている Kaspersky Endpoint Security に設定をインポートできます。","コマンド構文","kesl-control [-T] --get-app-settings [--file <設定ファイルの名前>]","kesl-control [-T] --get-app-settings","引数、キー","--file <設定ファイルの名前>","Kaspersky Endpoint Security の設定を保存する設定ファイルの名前。パスを指定しないでファイルの名前を指定した場合、そのファイルは現在のディレクトリに作成されます。指定された名前のファイルが指定されたパスにすでに存在する場合は、上書きされます。指定されたディレクトリがディスクに見つからない場合、設定ファイルは作成されません。","例：","Kaspersky Endpoint Security の全般設定を kesl_config.ini という名前のファイルにエクスポートします。作成されたファイルを現在のディレクトリに保存します：","kesl-control --get-app-settings --file kesl_config.ini"," Kaspersky Endpoint Security &#x306E;&#x5168;&#x822C;&#x8A2D;&#x5B9A;&#x306E;&#x53D6;&#x5F97; ","161256.htm");
Page[52]=new Array("Kaspersky Endpoint Security の全般設定の編集","コマンド --set-app-settings は、コマンドキーを使用して Kaspersky Endpoint Security の全般設定を設定するか、指定された設定ファイルから Kaspersky Endpoint Security の全般設定をインポートします。","このコマンドを使用して、Kaspersky Endpoint Security の全般設定を編集できます：","オプション --get-app-settings を使用して、Kaspersky Endpoint Security の全般設定を設定ファイルに保存します。作成された設定ファイルを開き、必要な設定を編集して、変更内容を保存します。オプション --set-app-settings を使用して、設定ファイルから Kaspersky Endpoint Security に設定をインポートします。オプション --stop-app および --start-app を使用するか、オプション --restart-app を使用して Kaspersky Endpoint Security を停止して再起動すると、設定の新しい値が適用されます。コマンド構文","kesl-control [-T] --set-app-settings --file <設定ファイルの名前>","kesl-control [-T] --set-app-settings <パラメータ名>=<パラメータ名> <パラメータ名>=<パラメータ名>","引数、キー","--file <設定ファイルの名前>","設定が Kaspersky Endpoint Security にインポートされる設定ファイルの名前。ファイルへの絶対パスを含みます。","例：","全般設定を /home/test/kav_config.ini という名前の設定ファイルから Kaspersky Endpoint Security にインポートします：","kesl-control --set-app-settings --file /home/test/kav_config.ini","トレースログに記録する情報の詳細度を低く設定します：","kesl-control --set-app-settings TraceLevel=NotDetailed"," Kaspersky Endpoint Security &#x306E;&#x5168;&#x822C;&#x8A2D;&#x5B9A;&#x306E;&#x7DE8;&#x96C6; ","161257.htm");
Page[53]=new Array("Kaspersky Endpoint Security のコマンドヘルプの表示","キー --help <Kaspersky Endpoint Security コマンドのセット> を持つ kesl-control コマンドは、Kaspersky Endpoint Security コマンドのヘルプを表示します。","コマンド構文","kesl-control --help [<Kaspersky Endpoint Security のコマンドのセット>]","<Kaspersky Endpoint Security のコマンドのセット>","使用できる値：","[-T] - Kaspersky Endpoint Security のタスクと全般設定を管理するコマンド。","[-L] - ライセンス管理コマンド。","[-B] - 保管領域の管理コマンド。","[-E] - Kaspersky Endpoint Security のイベントを管理するコマンド。","[-F] - ファイアウォールタスクを管理するコマンド。","[-H] - アンチクリプタータスクを管理するコマンド。","[-S] - 統計コマンド。","-W - イベントの監視。"," Kaspersky Endpoint Security &#x306E;&#x30B3;&#x30DE;&#x30F3;&#x30C9;&#x30D8;&#x30EB;&#x30D7;&#x306E;&#x8868;&#x793A; ","161258.htm");
Page[54]=new Array("イベントの表示の有効化","コマンド -W は、Kaspersky Endpoint Security イベントの表示を有効にします。このコマンドを単独で使用して Kaspersky Endpoint Security のすべてのイベントを表示するか、または --start-task コマンドとともに使用して実行中のタスクに関連するイベントのみを表示できます。--query を -W フラグとともに使用して、特定のイベントのみを表示できます。","このコマンドにより、イベント名、およびイベントに関する追加情報が表示されます。","コマンド構文","kesl-control -W","例：","Kaspersky Endpoint Security イベントの表示を有効にします：","kesl-control -W"," &#x30A4;&#x30D9;&#x30F3;&#x30C8;&#x306E;&#x8868;&#x793A;&#x306E;&#x6709;&#x52B9;&#x5316; ","161259.htm");
Page[55]=new Array("製品に関する情報の表示","コマンド --app-info は、Kaspersky Endpoint Security に関する情報を表示します。","コマンド構文","kesl-control [-S] --app-info","コマンド実行の結果","名前","製品名。","Version","現在の製品バージョン。","ライセンスステータス","ライセンスのステータス。","定額制サービスのステータス","定額制サービスのステータス。このフィールドは、定額制で製品を使用している場合に表示されます。","License expiration date","ライセンスの有効期限が切れる日","保管領域の状態","保管領域の状態。時間またはサイズ制限に関する情報を表示します。","保管領域の使用量","保管領域のサイズ。","Scan_My_Computer タスクの前回の実行日時","スキャンタスクが前回実行された時間。","定義データベースの前回の公開日時","最新の定義データベースが公開された日時。","定義データベースを読み込みました","定義データベースがダウンロードされたかどうかを表示。","定義データベースのレコード","定義データベースのレコード件数。","KSN の状態","Kaspersky Security Network への参加状態。","ファイル監視","ファイル監視コンポーネントの状態。","変更監視","ファイル変更監視コンポーネントの状態。","ファイアウォール","ファイアウォールマネージャーコンポーネントの状態。","アンチ暗号化","アンチクリプターコンポーネントの状態。","ソフトウェアアップデートの状態","ソフトウェアアップデートが可能かを表示します。"," &#x88FD;&#x54C1;&#x306B;&#x95A2;&#x3059;&#x308B;&#x60C5;&#x5831;&#x306E;&#x8868;&#x793A; ","161260.htm");
Page[56]=new Array("Kaspersky Endpoint Security のコマンド","Kaspersky Endpoint Security の設定の値を変更できます。","Kaspersky Endpoint Security のコマンドのルールは次のとおりです：","大文字と小文字を区別します。空白文字でキーを区切ります。コマンドまたはキーの完全な名前を使用するときは、等号（=）文字のあとに値を入力します。","例：","コマンドラインから、アップデートタスク（ID=6）のカスタムのアップデート元の URL のパラメータ値を指定します：","kesl-control --set-settings 6","SourceType=Custom CustomSources.item_0000.URL=http://site.domain/path CustomSources.item_0000.Enabled=Yes","Kaspersky Endpoint Security のコマンドヘルプの表示","--help","Kaspersky Endpoint Security のコマンドのヘルプを表示します。","Kaspersky Endpoint Security のイベントの表示","-W","Kaspersky Endpoint Security のイベントの表示を有効にします。","Kaspersky Endpoint Security の設定とタスクを管理するためのコマンド","-T","Kaspersky Endpoint Security の設定の管理またはタスクの管理（オプション）に使用されるコマンドのグループに、そのコマンドが属することを示す接頭辞。","[-S] --app-info","Kaspersky Endpoint Security に関する全般設定を表示します。","[-Т] --get-app-settings --file <ファイル名とディレクトリ>","Kaspersky Endpoint Security の全般設定を返します。","[-T] --set-app-settings --file <ファイル名とディレクトリ>","Kaspersky Endpoint Security の全般設定を設定します。","[-T] --get-task-list","既存の Kaspersky Endpoint Security タスクのリストを返します。","[-T] --get-task-state <タスク ID>|<タスク名>","指定されたタスクのステータスを表示します。","[-T] --create-task <タスク名> --type <タスクの種別> --file <ファイル名とディレクトリ>","指定した種別のタスクを作成します。指定した設定ファイルからタスクに設定を読み込みます。","[-T] --delete-task <タスク ID>|<タスク名>","タスクを削除します。","[-T] --start-task <タスク ID>|<タスク名> [-W] [--progress] [--file <ファイル名とディレクトリ>]","タスクを開始します。","[-T] --stop-task <タスク ID>|<タスク名>","タスクを停止します。","[-T] --suspend-task <タスク ID>|<タスク名>","タスクを一時停止します。","[-T] --resume-task <タスク ID>|<タスク名>","タスクを再開します。","[-T] --get-settings <タスク ID>|<タスク名> --file <ファイル名とディレクトリ>","タスクの設定を返します。","[-T] --set-settings <タスク ID>|<タスク名> [<パラメータ>] [--file <ファイル名とディレクトリ>] [--add-path <パス>] [--del-path <パス>] [--add-exclusion <実行>] [--del-exclusion <実行>]","タスクの設定を指定します。","[-T] --scan-file <パス> [--action <処理>]","一時的な Scan_File タスクを作成して開始します。","[-T] --import-settings <--file file>","製品設定を設定ファイルにインポートします。","[-T] --update-application","製品をアップデートします。","[-S] --omsinfo --file <パス>","Microsoft Operations Management Suite と統合するためのファイルを JSON 形式で作成します。","ライセンス管理コマンド","-L","ライセンスの管理に使用されるコマンドのグループに、そのコマンドが属することを示す接頭辞。","[-L] --install-active-key <アクティベーションコード>|<ライセンス情報ファイル>","現在のライセンスを追加します。","[-L] --install-additional-key <アクティベーションコード>|<ライセンス情報ファイル>","予備のライセンスを追加します。","[-L] --revoke-active-key","現在のライセンスを削除します。","[-L] --revoke-additional-key","予備のライセンスを削除します。","[-L] --query","ライセンスに関する情報を表示します。","ファイアウォールマネージャータスクのコマンド","[-F] --add-rule [--name <文字列>] [--action <処理>] [--protocol <プロトコル>] [--direction <ディレクトリ>] [--remote <リモート>] [--local <ローカル>] [--at <インデックス>]","新しいルールを追加します。","[-F] --del-rule [--name <string>] [--index <index>]","ルールを削除します。","[-F] --move-rule [--name <string>] [--index <index>] [--at <index>]","ルールの優先度を変更します。","[-F] --add-zone --zone <ゾーン> [--address <アドレス>]","ゾーンに IP アドレスを追加します。","[-F] --del-zone [--zone <ゾーン>] [--address <アドレス>] [--index <インデックス>]","ゾーンから IP アドレスを削除します。","-F --query","情報を表示します。","アンチクリプタータスクのコマンド","[-H] --get-blocked-hosts","ブロックされるホストの一覧を表示します。","[-H] --allow-hosts","信頼しないホストをブロックしません。","保管領域を管理するためのコマンド","-B","保管領域の管理に使用されるコマンドのグループに、そのコマンドが属することを示す接頭辞。","[-B] --mass-remove --query","保管領域を完全に、または選択してクリアします。","[-B] --query --limit --offset","保管領域内のオブジェクトに関する情報を表示します：","--limit","情報が表示されるオブジェクトの最大数。","--offset","サンプルの開始からオフセットするためのレコードの数。","[-B] --restore <オブジェクト ID> --file <ファイル名とディレクトリ>","保管領域からオブジェクトを復元します。","イベントログを管理するために使用されるコマンド","-E","イベントログの管理に使用されるコマンドのグループに、そのコマンドが属することを示す接頭辞。","[-E] --query --limit --offset --file <ファイル名とディレクトリ> --db <db ファイル>","情報が表示されるイベントの最大数。","--query","イベントログまたは指定されたログローテーションファイルからフィルタリングされるイベントに関する情報を返します。","--offset","サンプルの開始からオフセットするためのレコードの数。","--db","データベースファイルの名前。","タスクスケジュールの管理コマンド","[-T] --set-schedule <タスク ID>|<タスク名> --file <ファイル名とディレクトリ>","タスクスケジュール設定を行うか、または設定ファイルからタスクスケジュール設定をタスクに読み込みます。","[-T] --get-schedule <タスク ID>|<タスク名> --file <ファイル名とディレクトリ>","タスクスケジュールの設定を返します。","RuleType=Once|Monthly|Weekly|Daily|Hourly|Minutely|Manual|PS|BR","タスクの開始スケジュール。","PS - Kaspersky Endpoint Security の起動後にタスクを開始します。","BR - 定義データベースがアップデートされたあとでタスクを開始します。","StartTime=[年/月/日] [hh]:[mm]:[ss]; [<日>|<曜日>]; [<期間>]","タスクの開始時刻。","RandomInterval=<分>","いくつかのタスクが同時に実行されている場合のタスクの実行頻度を設定します（分単位）。","ExecuteTimeLimit=<分>","タスクの実行時間を制限します（分単位）。","RunMissedStartRules","Kaspersky Endpoint Security の起動後にスキップしたタスクの開始を有効または無効にします。"," Kaspersky Endpoint Security &#x306E;&#x30B3;&#x30DE;&#x30F3;&#x30C9; ","161262.htm");
Page[57]=new Array("製品設定のエクスポートとインポート","Kaspersky Endpoint Security では、トラブルシューティング、設定の確認、および他のコンピューターの製品をより簡単に設定するために、製品のすべての設定をエクスポートとインポートできます。","設定をエクスポートする時、製品およびタスクのすべての設定が設定ファイルに保存されます。この設定ファイルは本製品を設定するために設定をインポートする場合に使用されます。","設定をインポートまたはエクスポートする時、Kaspersky Endpoint Security が起動されている必要があります。設定のインポート後には本製品を再起動する必要があります。 ","Kaspersky Security Center を通して本製品が管理されている場合、設定のインポートは使用できません。 ","製品の以前のバージョンから設定をインポートまたはエクスポートする場合、新しい設定項目には既定値が設定されます。新しい製品バージョンと以前の製品バージョンの設定ファイルが一致する場合、リターンコードは 1 です。","以前のバージョンに設定をインポートすることはできません。","製品の設定をインポートする時、UseKSN の設定は No となります。Kaspersky Security Network への参加を開始または再開するには、UseKSN=Basic または UseKSN=Extended を指定します。","製品の設定のインポート後に内部タスク ID を変更できます。管理にはタスク名を使用してください。","製品の設定を設定ファイルにエクスポートするには、次のコマンドを実行します：","kesl-control --export-settings [--設定ファイルのファイルフルパス] ","設定ファイルの設定を使用して本製品を設定するには（設定のインポート）、次のコマンドを実行します：","kesl-control --import-settings --設定ファイルのファイルフルパス"," &#x88FD;&#x54C1;&#x8A2D;&#x5B9A;&#x306E;&#x30A8;&#x30AF;&#x30B9;&#x30DD;&#x30FC;&#x30C8;&#x3068;&#x30A4;&#x30F3;&#x30DD;&#x30FC;&#x30C8; ","162401.htm");
Page[58]=new Array("コマンドラインを使用した Kaspersky Endpoint Security のタスクの管理","このセクションでは、Kaspersky Endpoint Security のタスクの種別に関する情報、およびこれらのタスクの管理方法の手順について説明します。","このセクションの内容Kaspersky Endpoint Security のタスクについてKaspersky Endpoint Security タスクのリストの表示タスクの作成設定ファイルを使用したタスク設定の編集コマンドラインを使用したタスク設定の編集タスクの開始と停止コマンドラインからのスキャン範囲の管理コマンドラインからの除外範囲の管理タスク状態の表示タスクの一時停止と再開タスクスケジュールの設定タスクのスケジュール設定の取得タスクのスケジュール設定の編集タスクの削除"," &#x30B3;&#x30DE;&#x30F3;&#x30C9;&#x30E9;&#x30A4;&#x30F3;&#x3092;&#x4F7F;&#x7528;&#x3057;&#x305F; Kaspersky Endpoint Security &#x306E;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x7BA1;&#x7406; ","161263.htm");
Page[59]=new Array("Kaspersky Endpoint Security のタスクについて","Kaspersky Endpoint Security の操作は、コンピューター上のローカルでタスクを使用して（コマンドラインまたは設定ファイルを使用して）管理することも、Kaspersky Security Center を使用して一元的に管理することもできます。","Kaspersky Endpoint Security で動作する、2 つの種別のタスクがあります：","事前に定義されたタスク - 製品のインストール中に作成されるタスク。事前に定義されたタスクは作成または削除することはできませんが、これらのタスクの設定を変更することができます。カスタムタスク - 独自に作成または削除できるタスク。次のタスクを管理できます：","File_Monitoring - リアルタイム保護タスク（ID=1、種別 - OAS）。Scan_My_Computer - オンデマンドスキャンタスク（ID=2、種別 - ODS）。Scan_File - オブジェクトスキャンタスク（ID=3、種別 - ODS）既定では、このタスクの設定は Scan_My_Computer タスクの設定に一致します。Boot_Scan - ブートセクタースキャンタスク（ID=4、種別 - BootScan）。Memory_Scan - メモリスキャンタスク（ID=5、種別 - MemoryScan）。Update - アップデートタスク（ID=6、種別 - Update）。Rollback - アップデートのロールバックタスク（ID=7、種別 - Rollback）。このタスクには設定がありません。このタスクは開始、停止のみ可能です。Retranslate - アップデートのコピータスク（ID=8、種別 - Retranslate）。License - ライセンスサーバー導入タスク（ID=9、種別 - License）。Backup - 保管領域の管理タスク（ID=10、種別 - Backup）。Integrity_Monitoring - ファイル変更監視タスク（ID=11、種別 - OAFIM）。Firewall - システムのファイアウォールの管理タスク（ID=12、種別 - Firewall）。Anti-Cryptor - アンチクリプタータスク（ID=13、種別 - AntiCryptor）。ID - Kaspersky Endpoint Security が作成時にタスクに割り当てる数値。","タスクに対して次の処理を実行できます：","タスクの開始と停止。タスクの作成と削除（カスタムタスクのみ）。タスクの設定の編集。"," Kaspersky Endpoint Security &#x306E;&#x30BF;&#x30B9;&#x30AF;&#x306B;&#x3064;&#x3044;&#x3066; ","161264.htm");
Page[60]=new Array("Kaspersky Endpoint Security タスクのリストの表示","Kaspersky Endpoint Security のタスクのリストを表示するには、次のコマンドを実行します：","kesl-control [-T] --get-task-list","Kaspersky Endpoint Security のタスクのリストが表示されます。","タスクごとに次の情報が表示されます：","名前：タスクの名前。ID：タスク ID。種別：タスクの種別。状態：現在のタスクの状態。編集したタスク設定の表示をユーザーが禁止されている場合、Scan_File、Backup、License、File_Monitoring、Integrity_Monitor、Anti_Cryptor のタスクに関する情報が表示されます。その他のタスクの情報は使用できません。","お持ちのライセンスがアンチクリプターおよびファイル変更監視に対応していない場合、これらのタスクに関する情報は表示されません。","詳細については、「Kaspersky Endpoint Security のタスクについて」を参照してください。"," Kaspersky Endpoint Security &#x30BF;&#x30B9;&#x30AF;&#x306E;&#x30EA;&#x30B9;&#x30C8;&#x306E;&#x8868;&#x793A; ","161267.htm");
Page[61]=new Array("タスクの作成","既定の設定または設定タスクで指定された設定でタスクを作成できます。","OAS、Firewall、OAFIM、License、Backup、AntiCryptor 種別のタスクは作成できません。","既定の設定でタスクを作成するには、次のコマンドを実行します：","kesl-control [-T] --create-task <タスク名> --type <タスクの種別>","説明：","<タスク名> - 新しいタスクに指定する名前<タスクの種別> - 事前に定義されたタスクの種別指定された種別のタスクは既定の設定で作成されます。","設定ファイルで指定された設定でタスクを作成するには、次のコマンドを実行します：","kesl-control [-T] --create-task <タスク名> --type <タスクの種別> --file <設定ファイルへの絶対パス>","説明：","<タスク名> - 新しいタスクに指定する名前<タスクの種別> - 事前に定義されたタスクの種別<設定ファイルへの絶対パス> - 設定ファイルへの絶対パス指定された種別のタスクは設定ファイルで指定された設定で作成されます。"," &#x30BF;&#x30B9;&#x30AF;&#x306E;&#x4F5C;&#x6210; ","161268.htm");
Page[62]=new Array("設定ファイルを使用したタスク設定の編集","設定ファイルを変更してタスク設定を編集するには：","タスク設定を設定ファイルに保存します：kesl-control --get-settings <タスク名>|<タスク ID> --file <ファイルのフルパス>","作成した設定ファイルを編集のために開きます。設定ファイル内の必要な設定を編集します。変更内容を設定ファイルに保存します。設定ファイルの設定をタスクに読み込めます。kesl-control --set-settings <タスク名>|<タスク ID> --file <ファイルのフルパス>","この結果、タスクは更新した設定で実行されます。"," &#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x3092;&#x4F7F;&#x7528;&#x3057;&#x305F;&#x30BF;&#x30B9;&#x30AF;&#x8A2D;&#x5B9A;&#x306E;&#x7DE8;&#x96C6; ","162022.htm");
Page[63]=new Array("コマンドラインを使用したタスク設定の編集","コマンドラインを使用してタスク設定を編集するには、","必要な設定の値を指定します：kesl-control --set-settings <タスク名またはタスク ID> setting=value [setting=value]","Kaspersky Endpoint Security は指定された設定を変更します。","タスク設定ファイル内で、設定値が間違いなく変更されているようにします：kesl-control --get-settings <tタスク名またはタスク ID>","すべての設定を指定せずに新しいスキャン範囲または除外範囲を追加する場合、既定設定値の範囲が設定ファイルに追加されます。","例：","新しいスキャン範囲を指定するには、次のコマンドを実行します：","--set-settings 100 ScanScope.item_0001.UseScanArea=Yes ScanScope.item_0001.Path=/home","ID=100 を含むタスクの設定ファイルに、スキャン範囲に関する新しいセクションが追加されます：","[ScanScope.item_0001]","AreaDesc=","UseScanArea=Yes","Path=/home","AreaMask.item_0000=*"," &#x30B3;&#x30DE;&#x30F3;&#x30C9;&#x30E9;&#x30A4;&#x30F3;&#x3092;&#x4F7F;&#x7528;&#x3057;&#x305F;&#x30BF;&#x30B9;&#x30AF;&#x8A2D;&#x5B9A;&#x306E;&#x7DE8;&#x96C6; ","162393.htm");
Page[64]=new Array("タスクの開始と停止","バックアップタスクおよびライセンスタスクは開始または停止できません。","タスクを開始するには、次のコマンドを実行します：","kesl-control --start-task <タスク ID>|<タスク名>","タスクを停止するには、次のコマンドを実行します：","kesl-control --stop-task <タスク ID>|<タスク名>"," &#x30BF;&#x30B9;&#x30AF;&#x306E;&#x958B;&#x59CB;&#x3068;&#x505C;&#x6B62; ","161269.htm");
Page[65]=new Array("コマンドラインからのスキャン範囲の管理","コマンドラインから、OAS、ODS、OAFIM、ODFIM およびアンチクリプターのタスク用の特定の Path を含むスキャン範囲を追加または削除できます。","新しいスキャン範囲を追加するには、次のコマンドを実行します：","kesl-control --set-settings <タスク ID またはタスク名> --add-path <パス>","新しい [ScanScope.item_#] セクションがタスク設定ファイルに追加されます。Kaspersky Endpoint Security は、Path パラメータで指定されているディレクトリに位置するオブジェクトをスキャンします。 ","指定された Path の [ScanScope.item_#] セクションがすでに存在している場合、重複するセクションは設定ファイルに追加されません。UseScanArea 設定が No に設定されていた場合、このコマンドの実行すると値は Yes となり、このディレクトリに位置するオブジェクトがスキャンされます。","タスク範囲を削除するには、次のコマンドを実行します：","kesl-control --set-settings <タスク ID またはタスク名> --del-path <パス>","指定したパスを含む [ScanScope.item_#] セクションがタスク設定ファイルから削除されます。Kaspersky Endpoint Security は、Path パラメータで指定されているディレクトリに位置するオブジェクトをスキャンしません。 "," &#x30B3;&#x30DE;&#x30F3;&#x30C9;&#x30E9;&#x30A4;&#x30F3;&#x304B;&#x3089;&#x306E;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x7BC4;&#x56F2;&#x306E;&#x7BA1;&#x7406; ","162407.htm");
Page[66]=new Array("コマンドラインからの除外範囲の管理","OAS、ODS、OAFIM、ODFIM、およびアンチクリプターのタスクに指定した Path を含む除外範囲を、コマンドラインから追加または削除できます。","新しい除外範囲を追加するには、次のコマンドを実行します：","kesl-control --set-settings <タスク ID またはタスク名> --add-exclusion <パス>","新しい [ExcludedFromScanScope.item_#] セクションがタスク設定ファイルに追加されます。Kaspersky Endpoint Security は Path パラメータで指定されたディレクトリに位置するオブジェクトを除外します。 ","指定した Path の [ExcludedFromScanScope.item_#] セクションがすでに存在している場合、設定ファイルに重複するセクションは追加されません。UseScanArea 設定が No に設定されていた場合、このコマンドを実行すると値は Yes になり、このディレクトリに位置するオブジェクトがスキャンから除外されます。","除外範囲を削除するには、次のコマンドを実行します：","kesl-control --set-settings <タスク ID またはタスク名> --del-exclusion <パス>","指定したパスを含む [ExcludedFromScanScope.item_#] セクションがタスク設定ファイルから削除されます。Kaspersky Endpoint Security は Path パラメータで指定されたディレクトリに位置するオブジェクトを除外しません。 "," &#x30B3;&#x30DE;&#x30F3;&#x30C9;&#x30E9;&#x30A4;&#x30F3;&#x304B;&#x3089;&#x306E;&#x9664;&#x5916;&#x7BC4;&#x56F2;&#x306E;&#x7BA1;&#x7406; ","162408.htm");
Page[67]=new Array("タスク状態の表示","タスク状態を表示できます。","タスク状態を表示するには、次のコマンドを実行します：","kesl-control --get-task-state <タスク ID>|<タスク名>","説明：","<タスク ID> - Kaspersky Endpoint Security が作成時にタスクに割り当てるタスク ID。<タスク名> - 新しいタスクに指定する名前。Kaspersky Endpoint Security タスクは、次のいずれかの状態になります：","Started - タスクを実行中です。Starting - タスクを起動中です。Stopped - タスクを停止しました。Stopping - タスクを停止しています。Suspended - タスクを一時停止しました。Suspending - タスクを一時停止しています。Resumed - タスクを再開しました。Resuming - タスクを再開中です。"," &#x30BF;&#x30B9;&#x30AF;&#x72B6;&#x614B;&#x306E;&#x8868;&#x793A; ","161277.htm");
Page[68]=new Array("タスクの一時停止と再開","次の種別のタスクを一時停止および再開できます：ODS、BootScan、MemoryScan、Rollback、Retranslate、Update。","タスクを一時停止するには、次のコマンドを実行します：","kesl-control --suspend-task <タスク ID>|<タスク名>","コマンドが実行されると、タスクが一時停止されます。","タスクを再開するには、次のコマンドを実行します：","kesl-control --resume-task <タスク ID>|<タスク名>","コマンドが実行されると、タスクが再開されます。"," &#x30BF;&#x30B9;&#x30AF;&#x306E;&#x4E00;&#x6642;&#x505C;&#x6B62;&#x3068;&#x518D;&#x958B; ","161271.htm");
Page[69]=new Array("タスクスケジュールの設定","タスクスケジュールを設定するには：","タスクのスケジュール設定を設定ファイルに保存するには、次のコマンドを実行します：kesl-control --get-schedule <タスク ID>|<タスク名>","設定ファイルを編集のために開きます。スケジュール設定を指定します。変更内容を設定ファイルに保存します。スケジュール設定をタスクにインポートするには、次のコマンドを実行します：kesl-control --set-schedule <タスク ID>|<タスク名> --file <ファイルの絶対パス>"," &#x30BF;&#x30B9;&#x30AF;&#x30B9;&#x30B1;&#x30B8;&#x30E5;&#x30FC;&#x30EB;&#x306E;&#x8A2D;&#x5B9A; ","161272.htm");
Page[70]=new Array("タスクのスケジュール設定の取得","コマンド --get-schedule は、タスクのスケジュール設定を返します。また、このコマンドを使用して、コマンドキーを使用して割り当てられたタスクのスケジュール設定を取得することもできます。","このコマンドを使用して、タスクのスケジュールを編集できます：","コマンド --get-schedule を使用して、スケジュールの設定を設定ファイルに保存します。作成された設定ファイルを開き、必要な設定を編集して、変更内容を保存します。コマンド --set-schedule を使用して、設定ファイルから Kaspersky Endpoint Security に設定をインポートします。Kaspersky Endpoint Security は、スケジュール設定の新しい値を即時適用します。コマンド構文","kesl-control [-T] --get-schedule <タスク ID>|<タスク名> [--file <設定ファイルの名前>]","kesl-control [-T] --get-schedule <タスク ID>|<タスク名> <パラメータ名>","引数、キー","<タスク ID>","Kaspersky Endpoint Security のタスクの ID 番号。","<タスクの名前>","タスクの名前。","--file <設定ファイルの名前>","スケジュールの設定を保存する設定ファイルの名前。パスを指定しないでファイルの名前を指定した場合、そのファイルは現在のディレクトリに作成されます。指定された名前のファイルが指定されたパスにすでに存在する場合は、上書きされます。指定されたディレクトリがディスクに見つからない場合、設定ファイルは作成されません。","例：","Kaspersky Endpoint Security の設定を update_schedule.ini という名前のファイルに保存します。作成されたファイルを現在のディレクトリに保存します：","kesl-control --get-schedule 6 --file update_schedule.ini","アップデートタスクのスケジュールを返します：","kesl-control --get-schedule 6"," &#x30BF;&#x30B9;&#x30AF;&#x306E;&#x30B9;&#x30B1;&#x30B8;&#x30E5;&#x30FC;&#x30EB;&#x8A2D;&#x5B9A;&#x306E;&#x53D6;&#x5F97; ","161274.htm");
Page[71]=new Array("タスクのスケジュール設定の編集","コマンド --set-schedule は、コマンドキーを使用してタスクのスケジュール設定を設定するか、指定された設定ファイルからタスクのスケジュール設定をインポートします。","このコマンドを使用して、Kaspersky Endpoint Security の設定を編集できます：","コマンド --get-schedule を実行して、スケジュールの設定を設定ファイルに保存します。作成された設定ファイルを開き、必要な設定を編集して、変更内容を保存します。コマンド -T --set-schedule を実行して、設定ファイルから Kaspersky Endpoint Security に設定をインポートします。Kaspersky Endpoint Security は、スケジュール設定の新しい値を即時適用します。コマンド構文","kesl-control --set-schedule <タスク ID>|<タスク名> --file <設定ファイルの名前>","kesl-control --set-schedule <タスク ID>|<タスク名> <パラメータ名>=<パラメータ値> <パラメータ名>=<パラメータ値>","引数、キー","<タスク ID>","Kaspersky Endpoint Security のタスクの ID 番号。","<タスクの名前>","タスクの名前。","--file <設定ファイルの名前>","スケジュール設定がタスクにインポートされる設定ファイルの名前。ファイルへの絶対パスを含みます。","例：","/home/test/on_demand_schedule.ini という名前の設定ファイルのスケジュール設定を ID=2 のタスクに読み込みます：","kesl-control --set-schedule 2 --file /home/test/on_demand_schedule.ini"," &#x30BF;&#x30B9;&#x30AF;&#x306E;&#x30B9;&#x30B1;&#x30B8;&#x30E5;&#x30FC;&#x30EB;&#x8A2D;&#x5B9A;&#x306E;&#x7DE8;&#x96C6; ","161275.htm");
Page[72]=new Array("タスクの削除","作成したタスクを削除できます（カスタムタスク）。","タスクを削除するには、次のコマンドを実行します：","kesl-control --delete-task <タスク ID>|<タスク名>"," &#x30BF;&#x30B9;&#x30AF;&#x306E;&#x524A;&#x9664; ","161270.htm");
Page[73]=new Array("リアルタイム保護タスク（File_Monitoring ID:1）","このセクションでは、リアルタイム保護タスクに関する情報について説明します。","このセクションの内容リアルタイム保護について感染したファイルについてシンボリックリンクとハードリンクのスキャンに関する特別な考慮事項リアルタイム保護タスクの設定グローバル除外範囲の指定"," &#x30EA;&#x30A2;&#x30EB;&#x30BF;&#x30A4;&#x30E0;&#x4FDD;&#x8B77;&#x30BF;&#x30B9;&#x30AF;&#xFF08;File_Monitoring ID:1&#xFF09; ","161279.htm");
Page[74]=new Array("リアルタイム保護について","リアルタイム保護は、コンピューターのファイルシステムの感染を防止します。リアルタイム保護タスクは、Kaspersky Endpoint Security がコンピューターにインストールされるときに、既定の設定で作成されます。既定では、Kaspersky Endpoint Security が開始したときにリアルタイム保護は自動的に開始されます。タスクはコンピューターのメモリに常駐し、開いたファイル、保存されたファイル、アクティブなファイルをすべてスキャンします。タスクを停止および開始できます。","カスタムのリアルタイム保護タスクは作成できません。事前に定義されたリアルタイム保護タスクの設定を変更できます。","リアルタイム保護の設定は、リアルタイム保護タスクによって使用される設定ファイルに含まれています。 "," &#x30EA;&#x30A2;&#x30EB;&#x30BF;&#x30A4;&#x30E0;&#x4FDD;&#x8B77;&#x306B;&#x3064;&#x3044;&#x3066; ","161280.htm");
Page[75]=new Array("感染したファイルについて","Kaspersky Endpoint Security は、ファイルのスキャン時に定義データベースを使用します。これらのデータベースには、悪意のあるコードの断片、およびそのような脅威を含むオブジェクトを駆除するためのアルゴリズムに関するファイルが含まれます。定義データベースは、スキャンされるファイルの既知の脅威の検知を有効にします。","ファイルに既知の脅威のコードに完全に一致するコードが含まれる場合、Kaspersky Endpoint Security は感染のステータスをファイルに割り当てます。"," &#x611F;&#x67D3;&#x3057;&#x305F;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x306B;&#x3064;&#x3044;&#x3066; ","161281.htm");
Page[76]=new Array("シンボリックリンクとハードリンクのスキャンに関する特別な考慮事項","Kaspersky Endpoint Security では、ファイルへのシンボリックリンクとハードリンクをスキャンできます。","シンボリックリンクのスキャン","Kaspersky Endpoint Security は、シンボリックリンクによって参照されるファイルがリアルタイム保護タスクの保護範囲内にある場合、またはオンデマンドスキャンタスクのスキャン範囲内にある場合にのみ、シンボリックリンクをスキャンします。","シンボリックリンクによって参照されるファイルが保護範囲またはタスクのスキャン範囲内にない場合、このファイルはスキャンされません。ただし、ファイルに悪意のあるコードが含まれている場合、コンピューターのセキュリティは危険な状態になります。","ハードリンクのスキャン","Kaspersky Endpoint Security が複数のハードリンクを持つファイルを処理する場合、オブジェクトに対して実行する割り当てられた処理に基づいて処理を選択します：","［推奨される処理を実行］が選択されている場合、オブジェクトで検知された脅威の危険性に関するデータ、およびその脅威を駆除できる可能性に関するデータに基づいて、Kaspersky Endpoint Security により自動的に処理が選択され、オブジェクトに対して実行されます。［削除］処理が選択されている場合、処理中のハードリンクを削除します。  このファイルに対するその他のハードリンクは処理されません。［駆除］処理が選択されている場合、ソースファイルを駆除します。駆除できない場合は、ハードリンクを削除し、その削除されたハードリンクの名前でソースファイルのコピーを作成します。保管領域からハードリンクを持つファイルを復元する場合、保管領域に移動されたハードリンクの名前でソースファイルのコピーを作成します。ソースファイルへのその他のハードリンクへの接続は復元されません。"," &#x30B7;&#x30F3;&#x30DC;&#x30EA;&#x30C3;&#x30AF;&#x30EA;&#x30F3;&#x30AF;&#x3068;&#x30CF;&#x30FC;&#x30C9;&#x30EA;&#x30F3;&#x30AF;&#x306E;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x306B;&#x95A2;&#x3059;&#x308B;&#x7279;&#x5225;&#x306A;&#x8003;&#x616E;&#x4E8B;&#x9805; ","161283.htm");
Page[77]=new Array("リアルタイム保護タスクの設定","このセクションでは、リアルタイム保護タスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","ScanArchived","アーカイブ（自己解凍型アーカイブを含む）のスキャンを有効または無効にします。Kaspersky Endpoint Security では、アーカイブ内の脅威は検知されますが、駆除はされせん。以下のアーカイブの種別が対応しています：.zip、.7z*、.7-z、.rar、.iso、.cab、.jar、.bz、.bz2、.tbz、.tbz2、.gz、.tgz、.arj。","使用できる値：","Yes - アーカイブをスキャンします。","No - アーカイブをスキャンしません。","既定値：No","ScanSfxArchived","自己解凍型アーカイブのみ（実行可能な解凍モジュールを含むアーカイブ）のスキャンを有効または無効にします。","使用できる値：","Yes - 自己解凍型アーカイブをスキャンします。","No - 自己解凍型アーカイブをスキャンしません。","既定値：No","ScanMailBases","Microsoft Outlook®、Outlook Express、およびその他のメールクライアントのメールデータベースのスキャンを有効または無効にします。","使用できる値：","Yes - メールデータベースのファイルをスキャンします。","No - メールデータベースのファイルをスキャンしません。","既定値：No","ScanPlainMail","プレーンテキストのメールメッセージのスキャンを有効または無効にします。","使用できる値：","Yes - プレーンテキストのメールメッセージをスキャンします。","No - プレーンテキストのメールメッセージをスキャンしません。","既定値：No","SizeLimit","スキャン対象のオブジェクトの最大サイズを指定します（メガバイト単位）。指定された値よりもスキャン対象オブジェクトが大きい場合、オブジェクトはスキップされます。","この設定は UseSizeLimit 設定とともに使用されます。","使用できる値：","0 ～ 999,999","0 - すべてのサイズのオブジェクトがスキャンされます。","既定値：0","TimeLimit","オブジェクトスキャンの最長時間を指定します（秒単位）。このパラメータで指定された秒数よりも時間がかかる場合は、オブジェクトのスキャンが停止されます。","この設定は UseTimeLimit 設定とともに使用されます。","使用できる値：","0 ～ 9999","0 - オブジェクトのスキャン時間は無制限です。","既定値：60","FirstAction","感染したオブジェクトに対して Kaspersky Endpoint Security によって実行される最初の処理の選択。","リアルタイム保護タスクでは、オブジェクトに対してユーザーによって指定された処理を実行する前に、アプリケーションによって試行されるオブジェクトへのアクセスがブロックされます。","使用できる値：","Cure（駆除） - Kaspersky Endpoint Security は、保管領域にオブジェクトのコピーを保存することで、オブジェクトの駆除を試行します。駆除できない場合（オブジェクトの種別またはオブジェクト内の脅威の種別が駆除できない場合など）、オブジェクトは変更されないままです。最初の処理が［Cure］に設定された場合は、［SecondAction］の設定を使用して次の処理を指定してください。","Remove - まず感染したオブジェクトのバックアップコピーを作成し、そのオブジェクトを削除します。","Recommended（推奨される処理を実行） - オブジェクトで検知された脅威に関する情報に基づいてオブジェクトの処理を時自動的に選択して実行します。たとえば、トロイの木馬の場合は、Kaspersky Endpoint Security により即座に削除されます。トロイの木馬は他のファイルに寄生することはなく、駆除の必要がないためです。","Block - 感染したオブジェクトへのアクセスをブロックします。感染したオブジェクトに関する情報がログに記録されます。","既定値：推奨","SecondAction","感染したオブジェクトに対して Kaspersky Endpoint Security によって実行される次の処理の選択。Kaspersky Endpoint Security は、最初の処理に失敗した場合に、次の処理を実行します。","SecondAction の設定の値は、FirstAction の設定の値と同じです。","Block または Remove が最初の処理として選択された場合、次の処理を指定する必要はありません。他の場合には、2 つの処理を指定してください。次の処理を指定しない場合、Block が次の処理として適用されます。","既定値：Block","UseExcludeMasks","ExcludeMasks 設定を使用して指定されたオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeMasks 設定で指定されたオブジェクトを除外します。","No - ExcludeMasks 設定で指定されたオブジェクトを除外しません。","既定値：No","ExcludeMasks","名前またはマスクにより、オブジェクトをスキャンから除外します。この設定を使用すると、指定されたスキャン範囲から名前によって個別のファイルを除外したり、コマンドシェル形式でマスクを使用して複数のファイルを除外したりできます。","既定値は定義されていません。","例：","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","ExcludeThreats 設定を使用して指定された脅威を持つオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外します。","No - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外しません。","既定値：No","ExcludeThreats","オブジェクト内で検知された脅威の名前によってスキャンからオブジェクトを除外します。この設定の値を指定する前に、UseExcludeThreats 設定が有効になっていることを確認します。","スキャンから単一オブジェクトを除外するには、このオブジェクト内で検知された脅威の完全な名前（このオブジェクトが感染していると判断した文字列）を指定します。","たとえば、ネットワークに関する情報を収集するユーティリティを使用している場合があります。これをブロックしないようにするには、スキャンから除外される脅威のリストに、Kaspersky Endpoint Security に含まれる脅威の完全な名前を追加します。","オブジェクト内で検知された脅威の完全な名前は、Kaspersky Endpoint Security ログで確認できます。また、脅威の完全な名前は、ウイルス百科事典の Web サイト（）でも確認できます。脅威の名前を見つけるには、［検索］に製品の名前を入力します。","設定値では大文字と小文字が区別されます。","既定値は定義されていません。","例：","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Kaspersky Endpoint Security が感染していないとみなしたスキャン済みオブジェクトに関する情報のログへの記録を有効または無効にします。","この設定は、たとえば特定のオブジェクトが Kaspersky Endpoint Security によってスキャン済みであることを確認するために有効にできます。","使用できる値：","Yes - 感染していないオブジェクトに関する情報をログに記録します。","No - 感染していないオブジェクトに関する情報をログに記録しません。","既定値：No","ReportPackedObjects","複合オブジェクトの一部を構成するスキャン済みオブジェクトに関する情報のログへの記録を有効または無効にします。","この設定は、たとえば、アーカイブ内のオブジェクトが Kaspersky Endpoint Security によってスキャン済みであることを確認するために有効にできます。","使用できる値：","Yes - アーカイブ内のオブジェクトのスキャンに関する情報をログに記録します。","No - アーカイブ内のスキャン済みオブジェクトに関する情報をログに記録しません。","既定値：No","ReportUnprocessedObjects","スキャンされていないオブジェクトに関する情報のログへの記録を有効または無効にします。","使用できる値：","Yes - スキャンされていないオブジェクトに関する情報をログに記録します。","No - スキャンされていないオブジェクトに関する情報をログに記録しません。","既定値：No","UseAnalyzer","ヒューリスティック分析を有効または無効にします。","ヒューリスティック分析により、新しい脅威がウイルスアナリストに知られるようになる前に検知することができます。 ","使用できる値：","Yes - ヒューリスティック分析を有効にします。","No - ヒューリスティック分析を無効にします。","既定値：Yes","HeuristicLevel","ヒューリスティック分析レベル。","ヒューリスティック分析のレベルを指定できます。ヒューリスティック分析レベルは、脅威の検索範囲とオペレーティングシステムのリソースに対する負荷およびスキャンの所要時間のバランスを設定します。ヒューリスティック分析レベルが高いほど、スキャンに必要なリソースと時間が増加します。","使用できる値：","Light - 最小限の徹底的なスキャンを行い、システムへの負荷は最小です。","Medium - 中間のヒューリスティック分析レベルで、オペレーティングシステムへの負荷ともバランスが取れています。","Deep - 最も徹底的なスキャンを行い、システムへの負荷が最大となります。","Recommended - 推奨される値です。","既定値：推奨","UseIChecker","iChecker 技術の使用を有効または無効にします。","使用できる値：","Yes - iChecker 技術の使用を有効にします。","No - iChecker 技術の使用を無効にします。","既定値：Yes","ScanByAccessType","この設定を使用して、リアルタイム保護モードを指定できます。ScanByAccessType の設定は、リアルタイム保護タスクにのみ適用されます。","使用できる値：","SmartCheck - ファイルが開かれたときにファイルをスキャンし、ファイルが変更されている場合は閉じるときにもう一度スキャンします。ある処理によってオブジェクトが操作の過程で複数回アクセスされ、変更された場合は、処理によってオブジェクトが最後に閉じられたときにのみもう一度スキャンが実行されます。","OpenAndModify - ファイルが開かれたときにファイルをスキャンし、ファイルが変更されている場合は閉じるときにもう一度スキャンします。","Open - 読み取り、実行、または修正のためにファイルが開かれたときにファイルがスキャンされます。","既定値：SmartCheck","[ScanScope.item_#] セクションには、次の設定が含まれています：","AreaDesc","スキャン範囲に関する追加情報を含むスキャン範囲の説明。この設定を使用して指定される文字列の最大長は 4096 文字です。","既定値：すべてのオブジェクト","例：","AreaDesc=\"Scan mail databases\"","UseScanArea","この設定では、指定された範囲のスキャンを有効または無効にします。タスクを実行するには、スキャンする領域を少なくとも 1 つ含める必要があります。","使用できる値：","Yes - 指定された範囲をスキャンします。","No - 指定された範囲をスキャンしません。","既定値：Yes","AreaMask","この設定を使用して、スキャン範囲を制限できます。","スキャン範囲で、コマンドシェルマスクを使用して指定したファイルのみスキャンされます。","この設定が指定されていない場合、スキャン範囲のすべてのオブジェクトがスキャンされます。この設定には複数の値を指定できます。","既定値：*（すべてのオブジェクトをスキャン）","例：","AreaMask=re:.*\\.doc","Path","この設定を使用して、スキャンするオブジェクトへのパスを指定できます。","Path 設定の値には、<ファイルシステムの種別>:<アクセスプロトコル> の 2 つの要素が含まれます。また、ローカルファイルシステムのディレクトリへのパスを含めることもできます。","使用できる値：","<ローカルディレクトリのパス> - 指定されたディレクトリのオブジェクトをスキャンします。","Shared:NFS - NFS プロトコルによってアクセスできるコンピューターのファイルシステムリソースをスキャンします。","Shared:SMB - SMB プロトコルによってアクセスできるコンピューターのファイルシステムリソースをスキャンします。","AllRemoteMounted - SMB プロトコルと NFS プロトコルを使用してコンピューターにマウントされるすべてのリモートディレクトリをスキャンします。","AllShared - SMB プロトコルと NFS プロトコルによって共有されるコンピューターのすべてのファイルシステムリソースをスキャンします。","[ExcludedFromScanScope.item_#] セクションには、次の設定が含まれています：","AreaDesc","スキャンを除外する範囲の説明。除外する範囲に関する追加情報が含まれます。","既定値は定義されていません。","例：","AreaDesc=\"Exclude separate SAMBA\"","UseScanArea","この設定では、指定された範囲のスキャンを有効または無効にします。","使用できる値：","Yes - 指定された範囲を除外します。","No - 指定された範囲を除外しません。","既定値：Yes","Path","この設定を使用して、スキャンから除外するオブジェクトへのパスを指定できます。","Path 設定の値には、<ファイルシステムの種別>:<アクセスプロトコル> の 2 つの要素が含まれます。また、ローカルファイルシステムのディレクトリへのパスを含めることもできます。","使用できる値：","<ローカルディレクトリのパス> - 指定されたディレクトリのオブジェクトをスキャンから除外します。","Shared:NFS - NFS プロトコルによってアクセスできるコンピューターのファイルシステムリソースを除外します。","Shared:SMB - Samba プロトコルによってアクセスできるコンピューターのファイルシステムリソースを除外します。","AllRemoteMounted - SMB プロトコルと NFS プロトコルを使用してコンピューターにマウントされるすべてのリモートディレクトリを除外します。","AllShared - SMB プロトコルと NFS プロトコルによって共有されるコンピューターのすべてのファイルシステムリソースを除外します。"," &#x30EA;&#x30A2;&#x30EB;&#x30BF;&#x30A4;&#x30E0;&#x4FDD;&#x8B77;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161284.htm");
Page[78]=new Array("グローバル除外範囲の指定","リアルタイム保護タスクには、グローバル除外範囲を指定できます。グローバル除外範囲内のファイルはリアルタイム保護の範囲から除外されます。","グローバル除外範囲を作成するには、","次のコマンドを使用してリアルタイム保護タスクの設定をファイルに保存します：kesl-control --get-settings <タスク名またはタスク ID> --file <設定ファイルのフルパス>","作成したファイルに [ExcludedFromScanScope.item_#] セクションを追加します：[ExcludedFromScanScope.item_#] の各セクションには、次の設定が含まれています：AreaMask - 保護範囲から除外されるファイルのファイル名マスクを指定します。AreaDesc - 除外範囲の一意の名前を指定します。Path - 保護範囲から除外されるファイルへのパスを指定します。 次のコマンドを使用して設定ファイルからリアルタイム保護タスクに設定を読み込みます：kesl-control --set-settings <タスク名またはタスク ID> --file <設定ファイルのフルパス>"," &#x30B0;&#x30ED;&#x30FC;&#x30D0;&#x30EB;&#x9664;&#x5916;&#x7BC4;&#x56F2;&#x306E;&#x6307;&#x5B9A; ","162099.htm");
Page[79]=new Array("オンデマンドスキャンタスク（Scan_My_Computer ID:2）","このセクションでは、オンデマンドスキャンタスクに関する情報について説明します。","このセクションの内容オンデマンドスキャンについてオンデマンドスキャンタスクの設定"," &#x30AA;&#x30F3;&#x30C7;&#x30DE;&#x30F3;&#x30C9;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Scan_My_Computer ID:2&#xFF09; ","161286.htm");
Page[80]=new Array("オンデマンドスキャンについて","オンデマンドスキャンは、Kaspersky Endpoint Security によって実行される、コンピューター上のファイルに対して 1 回のみの完全スキャンまたはオブジェクトスキャンです。Kaspersky Endpoint Security では、複数のオンデマンドスキャンタスクを同時に実行できます。","既定では、1 つの事前に定義されたオンデマンドスキャンタスク（完全スキャン）が作成されます。コンピューターのローカルドライブ上にあるすべてのオブジェクト、さらには推奨されるセキュリティ設定を使用して Samba プロトコルおよび NFS プロトコルでアクセスされるすべてのマウントおよび共有されるオブジェクトがスキャンされます。","ユーザーは、カスタムオンデマンドスキャンタスクを作成できます。","既定では、事前に定義されたオブジェクトスキャンタスクも作成されます。","オンデマンドスキャンタスクの実行中に製品がウォッチドッグにより再起動された場合、またはユーザーが手動で再起動した場合、タスクが中断されます。OnDemandTaskInterrupted イベントがログに記録されます。"," &#x30AA;&#x30F3;&#x30C7;&#x30DE;&#x30F3;&#x30C9;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x306B;&#x3064;&#x3044;&#x3066; ","161287.htm");
Page[81]=new Array("オンデマンドスキャンタスクの設定","このセクションでは、オンデマンドスキャンタスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","ScanArchived ","アーカイブ（自己解凍型アーカイブを含む）のスキャンを有効または無効にします。Kaspersky Endpoint Security では、アーカイブ内の脅威は検知されますが、駆除はされせん。以下のアーカイブの種別が対応しています：.zip、.7z*、.7-z、.rar、.iso、.cab、.jar、.bz、.bz2、.tbz、.tbz2、.gz、.tgz、.arj。","使用できる値：","Yes - アーカイブをスキャンします。","No - アーカイブをスキャンしません。","既定値：Yes","ScanSfxArchived","自己解凍型アーカイブのみ（実行可能な解凍モジュールを含むアーカイブ）のスキャンを有効または無効にします。","使用できる値：","Yes - 自己解凍型アーカイブをスキャンします。","No - 自己解凍型アーカイブをスキャンしません。","既定値：Yes","ScanMailBases","Microsoft Outlook®、Outlook Express、およびその他のメールクライアントのメールデータベースのスキャンを有効または無効にします。","使用できる値：","Yes - メールデータベースのファイルをスキャンします。","No - メールデータベースのファイルをスキャンしません。","既定値：No","ScanPlainMail","プレーンテキストのメールメッセージのスキャンを有効または無効にします。","使用できる値：","Yes - プレーンテキストのメールメッセージをスキャンします。","No - プレーンテキストのメールメッセージをスキャンしません。","既定値：No","UseSizeLimit","SizeLimit 設定（スキャンされるオブジェクトの最大サイズ）の使用を有効または無効にします。","使用できる値：","Yes - SizeLimit パラメータを適用します。","No - SizeLimit パラメータを適用しません。","既定値：No","SizeLimit","スキャン対象のオブジェクトの最大サイズを指定します（メガバイト単位）。指定された値よりもスキャン対象オブジェクトが大きい場合、オブジェクトはスキップされます。","この設定は UseSizeLimit 設定とともに使用されます。","使用できる値：","0 ～ 999,999","0 - すべてのサイズのオブジェクトがスキャンされます。","既定値：0","UseTimeLimit","TimeLimit 設定（オブジェクトスキャンの最長時間）の使用を有効または無効にします。","使用できる値：","Yes - TimeLimit パラメータを適用します。","No - TimeLimit パラメータを適用しません。","既定値：No","TimeLimit","オブジェクトスキャンの最長時間を指定します（秒単位）。このパラメータで指定された秒数よりも時間がかかる場合は、オブジェクトのスキャンが停止されます。","この設定は UseTimeLimit 設定とともに使用されます。","使用できる値：","0 ～ 9999","0 - オブジェクトのスキャン時間は無制限です。","既定値：0","FirstAction","感染したオブジェクトに対して Kaspersky Endpoint Security によって実行される最初の処理の選択。","使用できる値：","Cure（駆除） - Kaspersky Endpoint Security は、保管領域にオブジェクトのコピーを保存することで、オブジェクトの駆除を試行します。駆除できない場合（オブジェクトの種別またはオブジェクト内の脅威の種別が駆除できない場合など）、オブジェクトは変更されないままです。最初の処理が［Cure］に設定された場合は、［SecondAction］の設定を使用して次の処理を指定してください。","Remove - まず感染したオブジェクトのバックアップコピーを作成し、そのオブジェクトを削除します。","Recommended（推奨される処理を実行） - オブジェクトで検知された脅威に関する情報に基づいてオブジェクトの処理を時自動的に選択して実行します。たとえば、トロイの木馬の場合は、Kaspersky Endpoint Security により即座に削除されます。トロイの木馬は他のファイルに寄生することはなく、駆除の必要がないためです。","Skip - 感染したオブジェクトの駆除または削除を行いません。感染したオブジェクトに関する情報がログに記録されます。","既定値：推奨","SecondAction","感染したオブジェクトに対して Kaspersky Endpoint Security によって実行される次の処理の選択。Kaspersky Endpoint Security は、最初の処理に失敗した場合に、次の処理を実行します。","SecondAction の設定の値は、FirstAction の設定の値と同じです。","Skip または Remove が最初の処理として選択された場合、次の処理を指定する必要はありません。他の場合には、2 つの処理を指定してください。次の処理を指定しない場合、Skip が次の処理として適用されます。","既定値：Skip","UseExcludeMasks","ExcludeMasks 設定を使用して指定されたオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeMasks 設定で指定されたオブジェクトを除外します。","No - ExcludeMasks 設定で指定されたオブジェクトを除外しません。","既定値：No","ExcludeMasks","名前またはマスクにより、オブジェクトをスキャンから除外します。この設定を使用すると、指定されたスキャン範囲から名前によって個別のファイルを除外したり、コマンドシェル形式でマスクを使用して複数のファイルを除外したりできます。","既定値は定義されていません。","例：","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","ExcludeThreats 設定を使用して指定された脅威を持つオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外します。","No - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外しません。","既定値：No","ExcludeThreats","オブジェクト内で検知された脅威の名前によってスキャンからオブジェクトを除外します。この設定の値を指定する前に、UseExcludeThreats 設定が有効になっていることを確認します。","スキャンから単一オブジェクトを除外するには、このオブジェクト内で検知された脅威の完全な名前（このオブジェクトが感染していると判断した文字列）を指定します。","たとえば、ネットワークに関する情報を収集するユーティリティを使用している場合があります。これをブロックしないようにするには、スキャンから除外される脅威のリストに、Kaspersky Endpoint Security に含まれる脅威の完全な名前を追加します。","オブジェクト内で検知された脅威の完全な名前は、Kaspersky Endpoint Security ログで確認できます。また、脅威の完全な名前は、ウイルス百科事典の Web サイト（）でも確認できます。脅威の名前を見つけるには、［検索］に製品の名前を入力します。","設定値では大文字と小文字が区別されます。","既定値は定義されていません。","例：","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Kaspersky Endpoint Security が感染していないとみなしたスキャン済みオブジェクトに関する情報のログへの記録を有効または無効にします。","この設定は、たとえば特定のオブジェクトが Kaspersky Endpoint Security によってスキャン済みであることを確認するために有効にできます。","使用できる値：","Yes - 感染していないオブジェクトに関する情報をログに記録します。","No - 感染していないオブジェクトに関する情報をログに記録しません。","既定値：No","ReportPackedObjects","複合オブジェクトの一部を構成するスキャン済みオブジェクトに関する情報のログへの記録を有効または無効にします。","この設定は、たとえば、アーカイブ内のオブジェクトが Kaspersky Endpoint Security によってスキャン済みであることを確認するために有効にできます。","使用できる値：","Yes - アーカイブ内のオブジェクトのスキャンに関する情報をログに記録します。","No - アーカイブ内のスキャン済みオブジェクトに関する情報をログに記録しません。","既定値：No","ReportUnprocessedObjects","スキャンされていないオブジェクトに関する情報のログへの記録を有効または無効にします。","使用できる値：","Yes - スキャンされていないオブジェクトに関する情報をログに記録します。","No - スキャンされていないオブジェクトに関する情報をログに記録しません。","既定値：No","UseAnalyzer","ヒューリスティック分析を有効または無効にします。","ヒューリスティック分析により、新しい脅威がウイルスアナリストに知られるようになる前に検知することができます。","使用できる値：","Yes - ヒューリスティック分析を有効にします。","No - ヒューリスティック分析を無効にします。","既定値：Yes","HeuristicLevel","ヒューリスティック分析レベル。","ヒューリスティック分析のレベルを指定できます。ヒューリスティック分析レベルは、脅威の検索範囲とオペレーティングシステムのリソースに対する負荷およびスキャンの所要時間のバランスを設定します。ヒューリスティック分析レベルが高いほど、スキャンに必要なリソースと時間が増加します。","使用できる値：","Light - 最小限の徹底的なスキャンを行い、システムへの負荷は最小です。","Medium - 中間のヒューリスティック分析レベルで、オペレーティングシステムへの負荷ともバランスが取れています。","Deep - 最も徹底的なスキャンを行い、システムへの負荷が最大となります。","Recommended - 推奨される値です。","既定値：推奨","UseIChecker","iChecker 技術の使用を有効または無効にします。","使用できる値：","Yes - iChecker 技術の使用を有効にします。","No - iChecker 技術の使用を無効にします。","既定値：Yes","ScanByAccessType","この設定を使用して、リアルタイム保護モードを指定できます。ScanByAccessType の設定は、リアルタイム保護タスクにのみ適用されます。","使用できる値：","SmartCheck - ファイルが開かれたときにファイルをスキャンし、ファイルが変更されている場合は閉じるときにもう一度スキャンします。ある処理によってオブジェクトが操作の過程で複数回アクセスされ、変更された場合は、処理によってオブジェクトが最後に閉じられたときにのみもう一度スキャンが実行されます。","OpenAndModify - ファイルが開かれたときにファイルをスキャンし、ファイルが変更されている場合は閉じるときにもう一度スキャンします。","Open - 読み取り、実行、または修正のためにファイルが開かれたときにファイルがスキャンされます。","既定値：SmartCheck","[ScanScope.item_#] セクションには、次の設定が含まれています：","AreaDesc","スキャン範囲に関する追加情報を含むスキャン範囲の説明。この設定を使用して指定される文字列の最大長は 4096 文字です。","既定値：All objects","例：","AreaDesc=\"Scan mail databases\"","UseScanArea","この設定では、指定された範囲のスキャンを有効または無効にします。タスクを実行するには、スキャンする領域を少なくとも 1 つ含める必要があります。","使用できる値：","Yes - 指定された範囲をスキャンします。","No - 指定された範囲をスキャンしません。","既定値：Yes。","AreaMask","この設定を使用して、スキャン範囲を制限できます。","スキャン範囲で、コマンドシェルマスクを使用して指定したファイルのみスキャンされます。","この設定が指定されていない場合、スキャン範囲のすべてのオブジェクトがスキャンされます。この設定には複数の値を指定できます。","既定値：*（すべてのオブジェクトをスキャン）","例：","AreaMask=re:.*\\.doc","Path","この設定を使用して、スキャンするオブジェクトへのパスを指定できます。","Path 設定の値には、<ファイルシステムの種別>:<アクセスプロトコル> の 2 つの要素が含まれます。また、ローカルファイルシステムのディレクトリへのパスを含めることもできます。","使用できる値：","<ローカルディレクトリのパス> - 指定されたディレクトリのオブジェクトをスキャンします。","Shared:NFS - NFS プロトコルによってアクセスできるコンピューターのファイルシステムリソースをスキャンします。","Shared:SMB - SMB プロトコルによってアクセスできるコンピューターのファイルシステムリソースをスキャンします。","AllRemoteMounted - SMB プロトコルと NFS プロトコルを使用してコンピューターにマウントされるすべてのリモートディレクトリをスキャンします。","AllShared - SMB プロトコルと NFS プロトコルによって共有されるコンピューターのすべてのファイルシステムリソースをスキャンします。","[ExcludedFromScanScope.item_#] セクションには、次の設定が含まれています：","AreaDesc","スキャンを除外する範囲の説明。除外する範囲に関する追加情報が含まれます。","既定値は定義されていません。","例：","AreaDesc=\"Exclude separate SAMBA\"","UseScanArea","この設定では、指定された範囲のスキャンを有効または無効にします。","使用できる値：","Yes - 指定された範囲を除外します。","No - 指定された範囲を除外しません。","既定値：Yes","Path","この設定を使用して、スキャンから除外するオブジェクトへのパスを指定できます。","Path 設定の値には、<ファイルシステムの種別>:<アクセスプロトコル> の 2 つの要素が含まれます。また、ローカルファイルシステムのディレクトリへのパスを含めることもできます。","使用できる値：","<ローカルディレクトリのパス> - 指定されたディレクトリのオブジェクトをスキャンから除外します。","Shared:NFS - NFS プロトコルによってアクセスできるコンピューターのファイルシステムリソースを除外します。","Shared:SMB - Samba プロトコルによってアクセスできるコンピューターのファイルシステムリソースを除外します。","AllRemoteMounted - SMB プロトコルと NFS プロトコルを使用してコンピューターにマウントされるすべてのリモートディレクトリを除外します。","AllShared - SMB プロトコルと NFS プロトコルによって共有されるコンピューターのすべてのファイルシステムリソースを除外します。"," &#x30AA;&#x30F3;&#x30C7;&#x30DE;&#x30F3;&#x30C9;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161288.htm");
Page[82]=new Array("オブジェクトスキャンタスク（Scan_File ID:3）","このセクションでは、オブジェクトスキャンタスクに関する情報について説明します。","このセクションの内容オブジェクトスキャンタスクについてオブジェクトスキャンタスクの設定"," &#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Scan_File ID:3&#xFF09; ","161290.htm");
Page[83]=new Array("オブジェクトスキャンタスクについて","オブジェクトスキャンタスクは、--scan-file コマンドで適用された設定を使用します。","次のコマンドを使用して、ファイルまたはディレクトリをスキャンできます：","--scan-file <ファイルパス>","Scan_File タスクの設定を使用して、一時的なオンデマンドスキャン（ODS）のタスクを作成します。スキャンの完了後、一時的なタスクは自動的に削除されます。","一時的な Scan_File タスクのスキャンパラメータをコマンドラインから変更できます。"," &#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306B;&#x3064;&#x3044;&#x3066; ","161291.htm");
Page[84]=new Array("オブジェクトスキャンタスクの設定","このセクションでは、オブジェクトスキャンタスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","ScanArchived","アーカイブ（自己解凍型アーカイブを含む）のスキャンを有効または無効にします。Kaspersky Endpoint Security では、アーカイブ内の脅威は検知されますが、駆除はされせん。以下のアーカイブの種別が対応しています：.zip、.7z*、.7-z、.rar、.iso、.cab、.jar、.bz、.bz2、.tbz、.tbz2、.gz、.tgz、.arj。","使用できる値：","Yes - アーカイブをスキャンします。","No - アーカイブをスキャンしません。","既定値：Yes","ScanSfxArchived","自己解凍型アーカイブのみ（実行可能な解凍モジュールを含むアーカイブ）のスキャンを有効または無効にします。","使用できる値：","Yes - 自己解凍型アーカイブをスキャンします。","No - 自己解凍型アーカイブをスキャンしません。","既定値：Yes","ScanMailBases","Microsoft Outlook®、Outlook Express、およびその他のメールクライアントのメールデータベースのスキャンを有効または無効にします。","使用できる値：","Yes - メールデータベースのファイルをスキャンします。","No - メールデータベースのファイルをスキャンしません。","既定値：No","ScanPlainMail","プレーンテキストのメールメッセージのスキャンを有効または無効にします。","使用できる値：","Yes - プレーンテキストのメールメッセージをスキャンします。","No - プレーンテキストのメールメッセージをスキャンしません。","既定値：No","UseSizeLimit","SizeLimit 設定（スキャンされるオブジェクトの最大サイズ）の使用を有効または無効にします。","使用できる値：","Yes - SizeLimit パラメータを適用します。","No - SizeLimit パラメータを適用しません。","既定値：No","SizeLimit","スキャン対象のオブジェクトの最大サイズを指定します（メガバイト単位）。指定された値よりもスキャン対象オブジェクトが大きい場合、オブジェクトはスキップされます。","この設定は UseSizeLimit 設定とともに使用されます。","使用できる値：","0 ～ 999,999","0 - すべてのサイズのオブジェクトがスキャンされます。","既定値：0","UseTimeLimit","TimeLimit 設定（オブジェクトスキャンの最長時間）の使用を有効または無効にします。","使用できる値：","Yes - TimeLimit パラメータを適用します。","No - TimeLimit パラメータを適用しません。","既定値：No","TimeLimit","オブジェクトスキャンの最長時間を指定します（秒単位）。このパラメータで指定された秒数よりも時間がかかる場合は、オブジェクトのスキャンが停止されます。","この設定は UseTimeLimit 設定とともに使用されます。","使用できる値：","0～9999。","0 - オブジェクトのスキャン時間は無制限です。","既定値：0","FirstAction","感染したオブジェクトに対して Kaspersky Endpoint Security によって実行される最初の処理の選択。","使用できる値：","Cure（駆除） - Kaspersky Endpoint Security は、保管領域にオブジェクトのコピーを保存することで、オブジェクトの駆除を試行します。駆除できない場合（オブジェクトの種別またはオブジェクト内の脅威の種別が駆除できない場合など）、オブジェクトは変更されないままです。最初の処理が［Cure］に設定された場合は、［SecondAction］の設定を使用して次の処理を指定してください。","Remove - まず感染したオブジェクトのバックアップコピーを作成し、そのオブジェクトを削除します。","Recommended（推奨される処理を実行） - オブジェクトで検知された脅威に関する情報に基づいてオブジェクトの処理を時自動的に選択して実行します。たとえば、トロイの木馬の場合は、Kaspersky Endpoint Security により即座に削除されます。トロイの木馬は他のファイルに寄生することはなく、駆除の必要がないためです。","Skip - 感染したオブジェクトの駆除または削除を行いません。感染したオブジェクトに関する情報がログに記録されます。","既定値：推奨","SecondAction","感染したオブジェクトに対して Kaspersky Endpoint Security によって実行される次の処理の選択。Kaspersky Endpoint Security は、最初の処理に失敗した場合に、次の処理を実行します。","SecondAction の設定の値は、FirstAction の設定の値と同じです。","Skip または Remove が最初の処理として選択された場合、次の処理を指定する必要はありません。他の場合には、2 つの処理を指定してください。次の処理を指定しない場合、Skip が次の処理として適用されます。","既定値：Skip","UseExcludeMasks","ExcludeMasks 設定を使用して指定されたオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeMasks 設定で指定されたオブジェクトを除外します。","No - ExcludeMasks 設定で指定されたオブジェクトを除外しません。","既定値：No","ExcludeMasks","名前またはマスクにより、オブジェクトをスキャンから除外します。この設定を使用すると、指定されたスキャン範囲から名前によって個別のファイルを除外したり、コマンドシェル形式でマスクを使用して複数のファイルを除外したりできます。","既定値は定義されていません。","例：","UseExcludeMasks=Yes","ExcludeMasks.item_0000=eicar1.*","ExcludeMasks.item_0001=eicar2.*","UseExcludeThreats","ExcludeThreats 設定を使用して指定された脅威を持つオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外します。","No - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外しません。","既定値：No","ExcludeThreats","オブジェクト内で検知された脅威の名前によってスキャンからオブジェクトを除外します。この設定の値を指定する前に、UseExcludeThreats 設定が有効になっていることを確認します。","スキャンから単一オブジェクトを除外するには、このオブジェクト内で検知された脅威の完全な名前（このオブジェクトが感染していると判断した文字列）を指定します。","たとえば、ネットワークに関する情報を収集するユーティリティを使用している場合があります。これをブロックしないようにするには、スキャンから除外される脅威のリストに、Kaspersky Endpoint Security に含まれる脅威の完全な名前を追加します。","オブジェクト内で検知された脅威の完全な名前は、Kaspersky Endpoint Security ログで確認できます。また、脅威の完全な名前は、ウイルス百科事典の Web サイト（）でも確認できます。脅威の名前を見つけるには、［検索］に製品の名前を入力します。","設定値では大文字と小文字が区別されます。","既定値は定義されていません。","例：","UseExcludeThreats=Yes","ExcludeThreats.item_0000=EICAR-Test-*","ExcludeThreats.item_0001=?rojan.Linux","ReportCleanObjects","Kaspersky Endpoint Security が感染していないとみなしたスキャン済みオブジェクトに関する情報のログへの記録を有効または無効にします。","この設定は、たとえば特定のオブジェクトが Kaspersky Endpoint Security によってスキャン済みであることを確認するために有効にできます。","使用できる値：","Yes - 感染していないオブジェクトに関する情報をログに記録します。","No - 感染していないオブジェクトに関する情報をログに記録しません。","既定値：No","ReportPackedObjects","複合オブジェクトの一部を構成するスキャン済みオブジェクトに関する情報のログへの記録を有効または無効にします。","この設定は、たとえば、アーカイブ内のオブジェクトが Kaspersky Endpoint Security によってスキャン済みであることを確認するために有効にできます。","使用できる値：","Yes - アーカイブ内のオブジェクトのスキャンに関する情報をログに記録します。","No - アーカイブ内のスキャン済みオブジェクトに関する情報をログに記録しません。","既定値：No","ReportUnprocessedObjects","スキャンされていないオブジェクトに関する情報のログへの記録を有効または無効にします。","使用できる値：","Yes - スキャンされていないオブジェクトに関する情報をログに記録します。","No - スキャンされていないオブジェクトに関する情報をログに記録しません。","既定値：No","UseAnalyzer","ヒューリスティック分析を有効または無効にします。ヒューリスティック分析により、新しい脅威がウイルスアナリストに知られるようになる前に検知することができます。 ","使用できる値：","Yes - ヒューリスティック分析を有効にします。","No - ヒューリスティック分析を無効にします。","既定値：Yes","HeuristicLevel","ヒューリスティック分析レベル。","ヒューリスティック分析のレベルを指定できます。ヒューリスティック分析レベルは、脅威の検索範囲とオペレーティングシステムのリソースに対する負荷およびスキャンの所要時間のバランスを設定します。ヒューリスティック分析レベルが高いほど、スキャンに必要なリソースと時間が増加します。","使用できる値：","Light - 最小限の徹底的なスキャンを行い、システムへの負荷は最小です。","Medium - 中間のヒューリスティック分析レベルで、オペレーティングシステムへの負荷ともバランスが取れています。","Deep - 最も徹底的なスキャンを行い、システムへの負荷が最大となります。","Recommended - 推奨される値です。","既定値：推奨","UseIChecker","iChecker 技術の使用を有効または無効にします。","使用できる値：","Yes - iChecker 技術の使用を有効にします。","No - iChecker 技術の使用を無効にします。","既定値：Yes","ScanByAccessType","この設定を使用して、リアルタイム保護モードを指定できます。ScanByAccessType の設定は、リアルタイム保護タスクにのみ適用されます。","使用できる値：","SmartCheck - ファイルが開かれたときにファイルをスキャンし、ファイルが変更されている場合は閉じるときにもう一度スキャンします。ある処理によってオブジェクトが操作の過程で複数回アクセスされ、変更された場合は、処理によってオブジェクトが最後に閉じられたときにのみもう一度スキャンが実行されます。","OpenAndModify - ファイルが開かれたときにファイルをスキャンし、ファイルが変更されている場合は閉じるときにもう一度スキャンします。","Open - 読み取り、実行、または修正のためにファイルが開かれたときにファイルがスキャンされます。","既定値：SmartCheck","[ScanScope.item_#] セクションには、次の設定が含まれています：","AreaDesc","スキャン範囲に関する追加情報を含むスキャン範囲の説明。この設定を使用して指定される文字列の最大長は 4096 文字です。","既定値：すべてのオブジェクト","例：","AreaDesc=\"Scan mail databases\"","UseScanArea","この設定では、指定された範囲のスキャンを有効または無効にします。タスクを実行するには、スキャンする領域を少なくとも 1 つ含める必要があります。","使用できる値：","Yes - 指定された範囲をスキャンします。","No - 指定された範囲をスキャンしません。","既定値：Yes","AreaMask","この設定を使用して、スキャン範囲を制限できます。","スキャン範囲で、コマンドシェルマスクを使用して指定したファイルのみスキャンされます。","この設定が指定されていない場合、スキャン範囲のすべてのオブジェクトがスキャンされます。この設定には複数の値を指定できます。","既定値：*（すべてのオブジェクトをスキャン）","例：","AreaMask=re:.*\\.doc","Path","この設定を使用して、スキャンするオブジェクトへのパスを指定できます。","Path 設定の値には、<ファイルシステムの種別>:<アクセスプロトコル> の 2 つの要素が含まれます。また、ローカルファイルシステムのディレクトリへのパスを含めることもできます。","使用できる値：","<ローカルディレクトリのパス> - 指定されたディレクトリのオブジェクトをスキャンします。","Shared:NFS - NFS プロトコルによってアクセスできるコンピューターのファイルシステムリソースをスキャンします。","Shared:SMB - SMB プロトコルによってアクセスできるコンピューターのファイルシステムリソースをスキャンします。","AllRemoteMounted - SMB プロトコルと NFS プロトコルを使用してコンピューターにマウントされるすべてのリモートディレクトリをスキャンします。","AllShared - SMB プロトコルと NFS プロトコルによって共有されるコンピューターのすべてのファイルシステムリソースをスキャンします。","[ExcludedFromScanScope.item_#] セクションには、次の設定が含まれています：","AreaDesc","スキャンを除外する範囲の説明。除外する範囲に関する追加情報が含まれます。","既定値は定義されていません。","例：","AreaDesc=\"Exclude separate SAMBA\"","UseScanArea","この設定では、指定された範囲のスキャンを有効または無効にします。","使用できる値：","Yes - 指定された範囲を除外します。","No - 指定された範囲を除外しません。","既定値：Yes","Path","この設定を使用して、スキャンから除外するオブジェクトへのパスを指定できます。","Path 設定の値には、<ファイルシステムの種別>:<アクセスプロトコル> の 2 つの要素が含まれます。また、ローカルファイルシステムのディレクトリへのパスを含めることもできます。","使用できる値：","<ローカルディレクトリのパス> - 指定されたディレクトリのオブジェクトをスキャンから除外します。","Shared:NFS - NFS プロトコルによってアクセスできるコンピューターのファイルシステムリソースを除外します。","Shared:SMB - Samba プロトコルによってアクセスできるコンピューターのファイルシステムリソースを除外します。","AllRemoteMounted - SMB プロトコルと NFS プロトコルを使用してコンピューターにマウントされるすべてのリモートディレクトリを除外します。","AllShared - SMB プロトコルと NFS プロトコルによって共有されるコンピューターのすべてのファイルシステムリソースを除外します。"," &#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161292.htm");
Page[85]=new Array("ブートセクタースキャンタスク（Boot_Scan ID:4）","このセクションでは、ブートセクタースキャンタスクに関する情報について説明します。","このセクションの内容ブートセクタースキャンタスクについてブートセクタースキャンタスクの設定"," &#x30D6;&#x30FC;&#x30C8;&#x30BB;&#x30AF;&#x30BF;&#x30FC;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Boot_Scan ID:4&#xFF09; ","161294.htm");
Page[86]=new Array("ブートセクタースキャンタスクについて","ブートセクタースキャンタスクでは、スキャン範囲を指定しないブートセクターをスキャンできます。"," &#x30D6;&#x30FC;&#x30C8;&#x30BB;&#x30AF;&#x30BF;&#x30FC;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306B;&#x3064;&#x3044;&#x3066; ","161295.htm");
Page[87]=new Array("ブートセクタースキャンタスクの設定","このセクションでは、ブートセクタースキャンタスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","UseExcludeMasks ","ExcludeMasks 設定を使用して指定されたオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeMasks 設定で指定されたオブジェクトを除外します。","No - ExcludeMasks 設定で指定されたオブジェクトを除外しません。","既定値：No","ExcludeMasks","名前またはマスクにより、オブジェクトをスキャンから除外します。この設定を使用すると、指定されたスキャン範囲から名前によって個別のファイルを除外したり、コマンドシェル形式でマスクを使用して複数のファイルを除外したりできます。","既定値は定義されていません。","UseExcludeThreats","ExcludeThreats 設定を使用して指定された脅威を持つオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外します。","No - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外しません。","既定値：No","ExcludeThreats","オブジェクト内で検知された脅威の名前によってスキャンからオブジェクトを除外します。この設定の値を指定する前に、UseExcludeThreats 設定が有効になっていることを確認します。","スキャンから単一オブジェクトを除外するには、このオブジェクト内で検知された脅威の完全な名前（このオブジェクトが感染していると判断した文字列）を指定します。","たとえば、ネットワークに関する情報を収集するユーティリティを使用している場合があります。これをブロックしないようにするには、スキャンから除外される脅威のリストに、Kaspersky Endpoint Security に含まれる脅威の完全な名前を追加します。","オブジェクト内で検知された脅威の完全な名前は、Kaspersky Endpoint Security ログで確認できます。また、脅威の完全な名前は、ウイルス百科事典の Web サイト（）でも確認できます。脅威の名前を見つけるには、［検索］に製品の名前を入力します。","設定値では大文字と小文字が区別されます。","既定値は定義されていません。","ReportCleanObjects","Kaspersky Endpoint Security が感染していないとみなしたスキャン済みオブジェクトに関する情報のログへの記録を有効または無効にします。","この設定は、たとえば特定のオブジェクトが Kaspersky Endpoint Security によってスキャン済みであることを確認するために有効にできます。","使用できる値：","Yes - 感染していないオブジェクトに関する情報をログに記録します。","No - 感染していないオブジェクトに関する情報をログに記録しません。","既定値：No","ReportUnprocessedObjects","何らかの理由により処理されていないファイルに関する情報のログへの記録を有効または無効にします。","使用できる値：","Yes - 処理されていないオブジェクトに関する情報をログに記録します。大量の情報をログに記録すると製品のパフォーマンスが低下することがあるため、このパラメータ値を長期間［Yes］に設定しないでください。","No - 処理されていないオブジェクトに関する情報をログに記録しません。","既定値：No","UseAnalyzer","ヒューリスティック分析を有効または無効にします。ヒューリスティック分析により、新しい脅威がウイルスアナリストに知られるようになる前に検知することができます。","使用できる値：","Yes - ヒューリスティック分析を有効にします。","No - ヒューリスティック分析を無効にします。","既定値：Yes","HeuristicLevel","ヒューリスティック分析レベル。","ヒューリスティック分析のレベルを指定できます。ヒューリスティック分析レベルは、脅威の検索範囲とオペレーティングシステムのリソースに対する負荷およびスキャンの所要時間のバランスを設定します。ヒューリスティック分析レベルが高いほど、スキャンに必要なリソースと時間が増加します。","使用できる値：","Light - 最小限の徹底的なスキャンを行い、システムへの負荷は最小です。","Medium - 中間のヒューリスティック分析レベルで、システムへの負荷ともバランスが取れています。","Deep - 最も徹底的なスキャンを行い、システムへの負荷が最大となります。","Recommended - 推奨される値です。","既定値：推奨","処理","感染したオブジェクトに対して Kaspersky Endpoint Security によって実行される処理の選択。","使用できる値：","Cure（駆除） - Kaspersky Endpoint Security は、保管領域にオブジェクトのコピーを保存することで、オブジェクトの駆除を試行します。駆除できない場合（オブジェクトの種別またはオブジェクト内の脅威の種別が駆除できない場合など）、オブジェクトは変更されないままです。","Skip - 感染したオブジェクトの駆除または削除を行いません。感染したオブジェクトに関する情報がログに記録されます。","既定値：Cure"," &#x30D6;&#x30FC;&#x30C8;&#x30BB;&#x30AF;&#x30BF;&#x30FC;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161296.htm");
Page[88]=new Array("プロセスメモリスキャンタスク（Memory_Scan ID:5）","このセクションでは、プロセスメモリスキャンタスクに関する情報について説明します。","このセクションの内容プロセスメモリスキャンタスクについてプロセスメモリスキャンタスクの設定"," &#x30D7;&#x30ED;&#x30BB;&#x30B9;&#x30E1;&#x30E2;&#x30EA;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Memory_Scan ID:5&#xFF09; ","161297.htm");
Page[89]=new Array("プロセスメモリスキャンタスクについて","プロセスメモリスキャンタスクでは、スキャン範囲を指定しないプロセスメモリをスキャンできます。"," &#x30D7;&#x30ED;&#x30BB;&#x30B9;&#x30E1;&#x30E2;&#x30EA;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306B;&#x3064;&#x3044;&#x3066; ","161298.htm");
Page[90]=new Array("プロセスメモリスキャンタスクの設定","このセクションでは、プロセスメモリスキャンタスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","UseExcludeThreats","ExcludeThreats 設定を使用して指定された脅威を持つオブジェクトのスキャンの除外を有効または無効にします。","使用できる値：","Yes - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外します。","No - ExcludeThreats 設定を使用して指定された脅威を含むオブジェクトのスキャンを除外しません。","既定値：No","ExcludeThreats","オブジェクト内で検知された脅威の名前によってスキャンからオブジェクトを除外します。この設定の値を指定する前に、UseExcludeThreats 設定が有効になっていることを確認します。","スキャンから単一オブジェクトを除外するには、このオブジェクト内で検知された脅威の完全な名前（このオブジェクトが感染していると判断した文字列）を指定します。","たとえば、ネットワークに関する情報を収集するユーティリティを使用している場合があります。これをブロックしないようにするには、スキャンから除外される脅威のリストに、Kaspersky Endpoint Security に含まれる脅威の完全な名前を追加します。","オブジェクト内で検知された脅威の完全な名前は、Kaspersky Endpoint Security ログで確認できます。また、脅威の完全な名前は、ウイルス百科事典の Web サイト（）でも確認できます。脅威の名前を見つけるには、［検索］に製品の名前を入力します。","設定値では大文字と小文字が区別されます。","既定値は定義されていません。","ReportCleanObjects","Kaspersky Endpoint Security が感染していないとみなしたスキャン済みオブジェクトに関する情報のログへの記録を有効または無効にします。","この設定は、たとえば特定のオブジェクトが Kaspersky Endpoint Security によってスキャン済みであることを確認するために有効にできます。","使用できる値：","Yes - 感染していないオブジェクトに関する情報をログに記録します。","No - 感染していないオブジェクトに関する情報をログに記録しません。","既定値：No","ReportUnprocessedObjects","何らかの理由により処理されていないファイルに関する情報のログへの記録を有効または無効にします。","使用できる値：","Yes - 処理されていないオブジェクトに関する情報をログに記録します。大量の情報をログに記録すると製品のパフォーマンスが低下することがあるため、このパラメータ値を長期間［Yes］に設定しないでください。","No - 処理されていないオブジェクトに関する情報をログに記録しません。","既定値：No","処理","感染したオブジェクトに対して Kaspersky Endpoint Security によって実行される処理の選択。","使用できる値：","Cure（駆除） - Kaspersky Endpoint Security は、保管領域にオブジェクトのコピーを保存することで、オブジェクトの駆除を試行します。駆除できない場合（オブジェクトの種別またはオブジェクト内の脅威の種別が駆除できない場合など）、オブジェクトは変更されないままです。","Skip - 感染したオブジェクトの駆除または削除を行いません。感染したオブジェクトに関する情報がログに記録されます。","既定値：Cure"," &#x30D7;&#x30ED;&#x30BB;&#x30B9;&#x30E1;&#x30E2;&#x30EA;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161299.htm");
Page[91]=new Array("アップデートタスク（Update ID:6）","このセクションでは、アップデートタスクに関する情報について説明します。","このセクションの内容定期データベースとソフトウェアモジュールのアップデートについてアップデート元についてアップデートタスクの設定ソフトウェアアップデートの手動インストール"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Update ID:6&#xFF09; ","161300.htm");
Page[92]=new Array("定期データベースとソフトウェアモジュールのアップデートについて","Kaspersky Endpoint Security の定義データベースとソフトウェアモジュールをアップデートすることで、コンピューターの最新の保護状態が保たれます。世界中で日々新たなウイルスやマルウェアが出現しています。Kaspersky Endpoint Security の定義データベースには、脅威に関する情報とその脅威を無害化する方法が記録されています。迅速に脅威を検知するには、定期的に定義データベースとソフトウェアモジュールをアップデートしてください。","定期的にアップデートするには有効なライセンスが必要です。有効なライセンスがない場合は、一回のみアップデートを実行できます。","Kaspersky Endpoint Security の主なアップデート元は、Kaspersky Lab のアップデートサーバーです。","Kaspersky Lab のアップデートサーバーからアップデートパッケージを正常にダウンロードするには、コンピューターのインターネット接続が必要です。既定では、インターネット接続設定が自動的に決定されます。プロキシサーバーを使用する場合、接続設定の調整が必要です。","アップデート中に、以下のオブジェクトがダウンロードされ、コンピューターにインストールされます：","Kaspersky Endpoint Security の定義データベース：Kaspersky Endpoint Security はインストール中に、Kaspersky Lab の HTTP アップデートサーバーの 1 つから最新の定義データベースをダウンロードします。既定の設定を使用して事前に定義されたタスク（ID=6）がアップデートに使用されます。Kaspersky Endpoint Security は 60 分に 1 度、定義データベースをアップデートします。定義データベースとソフトウェアモジュールのアップデートのために事前に定義されたタスクの設定を編集して、カスタムのアップデートタスクを作成することができます。Kaspersky Endpoint Security は、定義データベースのアップデートのダウンロードが中断された場合やエラーで終了した場合、以前インストールされたバージョンの定義データベースを引き続き使用します。","既定では、前回インストールされた定義データベースのアップデートが、Kaspersky Lab のサーバーで公開されてから 1 日～ 6 日経過している場合、［定義データベースが未アップデート］イベント（AVBasesAreOutOfDate）がログに記録されます。また、定義データベースをアップデートせずに 7 日間が過ぎると、［定義データベースが長期間アップデートされていません］というイベント（AVBasesAreTotallyOutOfDate）がログに記録されます。定義データベースが 24 時間以内にダウンロードされたものであれば現実的です。","ソフトウェアアップデート：Kaspersky Endpoint Security の定義データベースに加え、製品をアップデートすることもできます。ソフトウェアアップデートでは、Kaspersky Endpoint Security の脆弱性の修正や既存の機能の向上を行います。ソフトウェアアップデートは製品の状態（起動、停止、Kaspersky Security Center のポリシーによる管理）やアップデートのスケジュールに関係なくインストールできます。","ソフトウェアアップデートの処理中でも、Kaspersky Endpoint Security によりコンピューターの保護が継続されます。","自動的に製品の設定が移行され、ログに記録されます。以前のバージョンの製品の設定は、アップデートバージョンの起動時に出力されます。","ソフトウェアアップデートのインストール後に Kaspersky Endpoint Security が正しく機能しない場合、製品は自動的に以前のバージョンにロールバックされます。ソフトウェアアップデートのロールバックに関するメッセージが表示されます。カスペルスキーのテクニカルサポートに問い合わせてください。","アップデート中に、コンピューターの製品と定義データベースがアップデート元の最新バージョンと比較されます。現在の定義データベースやソフトウェアモジュールが最新バージョンと異なる場合は、アップデートの不足している部分がコンピューターにインストールされます。","定義データベースが長期間アップデートされていない場合、アップデートパッケージのサイズが大きくなり、インターネットのトラフィック量が増えることがあります（最大数十 MB）。"," &#x5B9A;&#x671F;&#x30C7;&#x30FC;&#x30BF;&#x30D9;&#x30FC;&#x30B9;&#x3068;&#x30BD;&#x30D5;&#x30C8;&#x30A6;&#x30A7;&#x30A2;&#x30E2;&#x30B8;&#x30E5;&#x30FC;&#x30EB;&#x306E;&#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x306B;&#x3064;&#x3044;&#x3066; ","161301.htm");
Page[93]=new Array("アップデート元について","アップデート元は、Kaspersky Endpoint Security の定義データベースとソフトウェアモジュールのアップデートを含むリソースです。アップデート元には、FTP サーバーまたは HTTP サーバー（Kaspersky Security Center、Kaspersky Lab アップデートサーバーなど）、およびユーザーによってマウントされるローカルディレクトリやネットワークディレクトリが含まれます。","事前に定義されたアップデートタスクでは、既定のアップデート元は Kaspersky Lab のアップデートサーバーです。アップデートサーバーには、カスペルスキーの多数の製品のための定義データベースとソフトウェアモジュールのアップデートが含まれています。アップデートは HTTP プロトコルを使用してダウンロードされます。","何らかの理由で Kaspersky Lab のアップデートサーバーをアップデート元として使用できない場合、カスタムのアップデート元からアップデートを取得できます。カスタムのアップデート元とは、ユーザーによってマウントされるローカルディレクトリまたはネットワークディレクトリ（SMB / NFS）、またはユーザーによって指定される FTP サーバーや HTTP サーバーなどです。カスタムのアップデート元は、アップデートタスクの設定ファイルで指定できます。"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x5143;&#x306B;&#x3064;&#x3044;&#x3066; ","161302.htm");
Page[94]=new Array("アップデートタスクの設定","このセクションでは、アップデートタスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","SourceType","この設定では、Kaspersky Endpoint Security がアップデートを取得するアップデート元を選択できます。","使用できる値：","KLServers - Kaspersky Lab のアップデートサーバーのいずれかからアップデートを受信します。アップデートは HTTP プロトコルを使用してダウンロードされます。","SCServer - ローカルネットワーク上にインストールされている Kaspersky Security Center 管理サーバーからアップデートを保護対象のコンピューターにダウンロードします。組織のコンピューターのアンチウイルスによる保護の集中管理に Kaspersky Security Center アプリケーションを使用する場合は、このアップデート元を選択できます。","Custom - [CommonSettings:CustomSources] セクションで指定されたカスタムのアップデート元からアップデートをダウンロードします。HTTP サーバーのディレクトリ、または保護されたコンピューターにマウントされた任意のデバイスのディレクトリ（Samba プロトコルまたは NFS プロトコルでマウントされたリモートコンピューターのディレクトリを含む）を指定できます。","既定値：KLServers","UseKLServersWhenUnavailable","この設定を使用して、すべてのカスタムのアップデート元が利用できない場合に Kaspersky Lab のアップデートサーバーにアクセスするように Kaspersky Endpoint Security を設定できます。","使用できる値：","Yes - すべてのカスタムのアップデート元が利用できない場合に、Kaspersky Lab のアップデートサーバーに接続します。","No - すべてのカスタムのアップデート元が利用できない場合に、Kaspersky Lab のアップデートサーバーに接続しません。","既定値：Yes","IgnoreProxySettingsForKLServers","この設定では、Kaspersky Lab のアップデートサーバーへの接続にプロキシサーバーを使用するよう設定できます。","使用できる値：","Yes - Kaspersky Lab のアップデートサーバーへの接続にプロキシサーバーを使用しません。","No - Kaspersky Lab のアップデートサーバーへの接続にプロキシサーバーを使用します。","既定値：No","IgnoreProxySettingsForCustomSources","この設定では、カスタムのアップデート元への接続にプロキシサーバーを使用するよう設定できます。カスタムの HTTP アップデートサーバーに接続するためにプロキシサーバーへのアクセスが必要な場合は、この設定を有効にする必要があります。","使用できる値：","Yes - カスタムのアップデート元への接続にプロキシサーバーを使用しません。","No - カスタムのアップデート元への接続にプロキシサーバーを使用します。","既定値：No","ApplicationUpdateMode","ソフトウェアアップデートのダウンロードとインストールの設定を指定します。","使用できる値：","Disable - ソフトウェアアップデートのダウンロードもインストールもしない","DownloadOnly - ソフトウェアアップデートのダウンロードするが、インストールはしない","DownloadAndInstall - ソフトウェアアップデートを自動的にダウンロードしてインストールする","既定値：DownloadOnly","ConnectionTimeout","この設定を使用して、接続試行中のアップデート元（HTTP サーバーなど）からの接続タイムアウト時間（秒単位）を指定します。指定した時間内にアップデート元が応答しなかった場合、Kaspersky Endpoint Security はリスト上の次のアップデート元に通信します。","0 ～ 120 の範囲内の整数のみを使用できます。","既定値：10","[CustomSources.item_#] セクションには、次の設定が含まれています：","URL","このセクションでは、ローカルエリアネットワークまたはインターネットにあるカスタムのアップデート元のアドレスを指定できます。","既定値は定義されていません。","例：","URL=http://example.com/bases/ - アップデートが置かれている HTTP サーバーのアドレスとディレクトリ。","URL=/home/bases/ - 定義データベースが置かれている保護されたコンピューターのディレクトリ。","Enabled","この設定では、URL 設定で指定されたアップデート元の使用を有効または無効にできます。タスクを実行するには、アップデート元を少なくとも 1 つ使用する必要があります。","使用できる値：","Yes - アップデート元を使用します。","No - アップデート元を使用しません。","既定値は定義されていません。","例：","Enabled=Yes"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161303.htm");
Page[95]=new Array("ソフトウェアアップデートの手動インストール","コマンドラインから本製品のアップデートを手動でインストールできます。Kaspersky Endpoint Security のアップデートをインストールするには、本製品がお使いのコンピューターにインストールされている必要があります。","RPM パッケージから Kaspersky Endpoint Security のアップデートをインストールするには、次のコマンドを実行します：","# rpm –U <rpm パッケージ名>.rpm","DEB パッケージからKaspersky Endpoint Security のアップデートをインストールするには、次のコマンドを実行します：","# dpkg -i <deb パッケージ名>.deb","本製品のアップデートプロセスが開始されます。","本製品またはオペレーティングシステムの再起動が必要になる場合があります。対応するメッセージが表示されます。本製品またはオペレーティングシステムの再起動後、アップデートされたバージョンの Kaspersky Endpoint Security が開始されます。","本製品のアップデート後、使用許諾契約書および Kaspersky Security Network に関する声明（またはそのいずれか）への同意が必要となります。 ","使用許諾契約書に同意するには、","使用許諾契約書のテキストを読みます。使用許諾契約書に同意する場合、環境変数を指定します：rpm パッケージの場合、# KESL_EULA_AGREED=Yes rpm -U <rpm パッケージ名>.rpmdeb パッケージの場合、# KESL_EULA_AGREED=Yes dpkg -i <deb パッケージ名>.debKaspersky Security Network に関する声明に同意するには、","Kaspersky Security Network に関する声明のテキストを読みます。Kaspersky Security Network に関する声明に同意する場合、環境変数を指定します：rpm パッケージの場合、# KESL_USE_KSN=Yes rpm -U <rpm パッケージ名>.rpmdeb パッケージの場合、# KESL_ USE_KSN=Yes dpkg -i <deb パッケージ名>.deb"," &#x30BD;&#x30D5;&#x30C8;&#x30A6;&#x30A7;&#x30A2;&#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x306E;&#x624B;&#x52D5;&#x30A4;&#x30F3;&#x30B9;&#x30C8;&#x30FC;&#x30EB; ","162013.htm");
Page[96]=new Array("アップデートのロールバックタスク（Rollback ID:7）","このセクションでは、アップデートのロールバックタスクに関する情報について説明します。","アップデートのロールバックタスクは、前回成功した定義データベースのアップデートをロールバックするために実行されます。","このタスクには設定がありません。","アップデートのロールバックタスクの管理の詳細については、「コマンドラインを使用した Kaspersky Endpoint Security のタスクの管理」を参照してください。"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x306E;&#x30ED;&#x30FC;&#x30EB;&#x30D0;&#x30C3;&#x30AF;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Rollback ID:7&#xFF09; ","161304.htm");
Page[97]=new Array("アップデートの再変換タスク（Retranslate ID:8）","このセクションでは、アップデートの再変換タスクに関する情報について説明します。","このセクションの内容アップデートの再変換タスクについてアップデートの再変換タスクの設定"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x306E;&#x518D;&#x5909;&#x63DB;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Retranslate ID:8&#xFF09; ","161306.htm");
Page[98]=new Array("アップデートの再変換タスクについて","アップデートの再変換タスクでは、定義データベースと製品のアップデートを選択したディレクトリにダウンロードできます。アップデートはインストールされません。","再変換されたアップデート定義データベースは、同じビルド番号の製品のみ使用できます。"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x306E;&#x518D;&#x5909;&#x63DB;&#x30BF;&#x30B9;&#x30AF;&#x306B;&#x3064;&#x3044;&#x3066; ","161307.htm");
Page[99]=new Array("アップデートの再変換タスクの設定","このセクションでは、アップデートの再変換タスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","SourceType ","この設定では、Kaspersky Endpoint Security がアップデートを取得するアップデート元を選択できます。","使用できる値：","KLServers - Kaspersky Lab のアップデートサーバーのいずれかからアップデートを受信します。アップデートは HTTP プロトコルを使用してダウンロードされます。","SCServer - ローカルネットワーク上にインストールされている Kaspersky Security Center 管理サーバーからアップデートを保護対象のコンピューターにダウンロードします。組織のコンピューターのアンチウイルスによる保護の集中管理に Kaspersky Security Center アプリケーションを使用する場合は、このアップデート元を選択できます。","Custom - [CommonSettings:CustomSources] セクションで指定されたカスタムのアップデート元からアップデートをダウンロードします。HTTP サーバーのディレクトリ、または保護されたコンピューターにマウントされた任意のデバイスのディレクトリ（Samba プロトコルまたは NFS プロトコルでマウントされたリモートコンピューターのディレクトリを含む）を指定できます。","既定値：KLServers","UseKLServersWhenUnavailable","この設定を使用して、すべてのカスタムのアップデート元が利用できない場合に Kaspersky Lab のアップデートサーバーにアクセスするように Kaspersky Endpoint Security を設定できます。","使用できる値：","Yes - すべてのカスタムのアップデート元が利用できない場合に、Kaspersky Lab のアップデートサーバーに接続します。","No - すべてのカスタムのアップデート元が利用できない場合に、Kaspersky Lab のアップデートサーバーに接続しません。","既定値：Yes","IgnoreProxySettingsForKLServers","この設定では、Kaspersky Lab のアップデートサーバーへの接続にプロキシサーバーを使用するよう設定できます。","使用できる値：","Yes - Kaspersky Lab のアップデートサーバーへの接続にプロキシサーバーを使用しません。","No - Kaspersky Lab のアップデートサーバーへの接続にプロキシサーバーを使用します。","既定値：No","IgnoreProxySettingsForCustomSources","この設定では、カスタムのアップデート元への接続にプロキシサーバーを使用するよう設定できます。カスタムの HTTP アップデートサーバーに接続するためにプロキシサーバーへのアクセスが必要な場合は、この設定を有効にする必要があります。","使用できる値：","Yes - カスタムのアップデート元への接続にプロキシサーバーを使用しません。","No - カスタムのアップデート元への接続にプロキシサーバーを使用します。","既定値：No","ConnectionTimeout","この設定を使用して、接続試行中のアップデート元（HTTP サーバーなど）からの接続タイムアウト時間（秒単位）を指定します。指定した時間内にアップデート元が応答しなかった場合、Kaspersky Endpoint Security はリスト上の次のアップデート元に通信します。","0 ～ 120 の範囲内の整数のみを使用できます。","既定値：10","RetranslationFolder","この設定を使用して、アップデートがコピーされるディレクトリを指定できます。指定されるディレクトリが存在しない場合、アップデートの再変換タスクの実行中に作成されます。","[CustomSources.item_#] セクションには、次の設定が含まれています：","URL","このセクションでは、ローカルエリアネットワークまたはインターネットにあるカスタムのアップデート元のアドレスを指定できます。","既定値は定義されていません。","例：","URL=http://example.com/bases/ - アップデートが置かれている HTTP サーバーのアドレスとディレクトリ。","URL=/home/bases/ - 定義データベースが置かれている保護されたコンピューターのディレクトリ。","Enabled","この設定では、URL 設定で指定されたアップデート元の使用を有効または無効にできます。タスクを実行するには、アップデート元を少なくとも 1 つ使用する必要があります。","使用できる値：","Yes - アップデート元を使用します。","No - アップデート元を使用しません。","既定値は定義されていません。","AutoPatchDownload","ソフトウェアアップデートの自動ダウンロードを有効または無効にします。","使用できる値： ","Yes - ソフトウェアアップデートを自動ダウンロードします","No - ソフトウェアアップデートを自動ダウンロードしません","既定値：Yes"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x306E;&#x518D;&#x5909;&#x63DB;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161308.htm");
Page[100]=new Array("ライセンスタスク（License ID:9）","このセクションでは、ライセンスタスクに関する情報について説明します。","このセクションの内容ライセンスタスクについて現在のライセンスの追加予備のライセンスの追加現在のライセンスの削除予備のライセンスの削除追加のアクティベーションコードの入力"," &#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x30BF;&#x30B9;&#x30AF;&#xFF08;License ID:9&#xFF09; ","161309.htm");
Page[101]=new Array("ライセンスタスクについて","ライセンスタスクを使用して、Kaspersky Endpoint Security のライセンスとアクティベーションコードの管理を行うことができます。"," &#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x30BF;&#x30B9;&#x30AF;&#x306B;&#x3064;&#x3044;&#x3066; ","161310.htm");
Page[102]=new Array("現在のライセンスの追加","コマンド --install-active-key は、現在のライセンスを追加します。ライセンスの詳細については、「ライセンスについて」を参照してください。","コマンド構文","kesl-control [-L] --install-active-key <ライセンス情報ファイルへのパス>|<アクティベーションコード>","引数、キー","<ライセンス情報ファイルへのパス>","ライセンス情報ファイルへのパス。ライセンス情報ファイルが現在のディレクトリにある場合はファイル名だけを指定します。","例：","ファイル /home/test/00000001.key のライセンスを現在のライセンスとして追加します：","kesl-control --install-active-key /home/test/00000001.keу"," &#x73FE;&#x5728;&#x306E;&#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x306E;&#x8FFD;&#x52A0; ","161311.htm");
Page[103]=new Array("予備のライセンスの追加","コマンド --install-additional-key は、予備のライセンスを追加します。ライセンスの詳細については、「ライセンスについて」を参照してください。","現在のライセンスがインストールされていない場合、予備のライセンスが現在のライセンスとしてインストールされます。","コマンド構文","kesl-control [-L] --install-additional-key <ライセンス情報ファイルへのパス>","引数、キー","<ライセンス情報ファイルへのパス>","ライセンス情報ファイルへのパス。ライセンス情報ファイルが現在のディレクトリにある場合はファイル名だけを指定します。","例：","ファイル /home/test/00000002.key の予備のライセンスをインストールします：","kesl-control --install-additional-key /home/test/00000002.key"," &#x4E88;&#x5099;&#x306E;&#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x306E;&#x8FFD;&#x52A0; ","161312.htm");
Page[104]=new Array("現在のライセンスの削除","コマンド --revoke-active-key は、現在のライセンス情報ファイルを削除します。","コマンド構文","kesl-control [-L] --revoke-active-key"," &#x73FE;&#x5728;&#x306E;&#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x306E;&#x524A;&#x9664; ","161313.htm");
Page[105]=new Array("予備のライセンスの削除","コマンド --revoke-additional-key は、予備のライセンス情報ファイルを削除します。","コマンド構文","kesl-control [-L] --revoke-additional-key"," &#x4E88;&#x5099;&#x306E;&#x30E9;&#x30A4;&#x30BB;&#x30F3;&#x30B9;&#x306E;&#x524A;&#x9664; ","161314.htm");
Page[106]=new Array("追加のアクティベーションコードの入力","コマンド --install-additional-key は、追加のアクティベーションコードを入力します。アクティベーションコードの詳細については、「アクティベーションコードについて」を参照してください。","コマンド構文","kesl-control [-L] --install-additional-key <アクティベーションコード>"," &#x8FFD;&#x52A0;&#x306E;&#x30A2;&#x30AF;&#x30C6;&#x30A3;&#x30D9;&#x30FC;&#x30B7;&#x30E7;&#x30F3;&#x30B3;&#x30FC;&#x30C9;&#x306E;&#x5165;&#x529B; ","161315.htm");
Page[107]=new Array("保管領域の管理タスク（Backup ID:10）","このセクションでは、保管領域の管理タスクに関する情報について説明します。","このセクションの内容保管領域について保管領域の管理タスクの設定保管領域にあるオブジェクトの ID の表示保管領域からのオブジェクトの復元について保管領域からのオブジェクトの復元保管領域からのオブジェクトの削除"," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x306E;&#x7BA1;&#x7406;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Backup ID:10&#xFF09; ","161316.htm");
Page[108]=new Array("保管領域について","保管領域は、駆除プロセス中に削除または変更されたファイルのバックアップコピーのリストです。バックアップコピーは、ファイルの駆除または削除を最初に試行したときに作成されたファイルのコピーです。ファイルのバックアップコピーは特別な形式で保存され、脅威はありません。","駆除中に、ファイルの整合性を維持できないことがあります。駆除したあと、駆除されたファイルの重要な情報に部分的または完全にアクセスできなくなった場合は、駆除されたファイルのコピーを元のディレクトリに復元することを試行できます。"," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x306B;&#x3064;&#x3044;&#x3066; ","161317.htm");
Page[109]=new Array("保管領域の管理タスクの設定","このセクションでは、保管領域の管理タスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","DaysToLive","保管領域にオブジェクトを保存する期間（日単位）。","保管領域にオブジェクトを保存する期間の制限をなくすには、値に 0 を指定します。","既定値：90","BackupSizeLimit","保管領域の最大サイズ。","保管領域の最大サイズに到達すると、最も古いオブジェクトが削除されます。","使用できる値：","0 ～ 999,999（メガバイト単位）","保管領域のサイズの制限をなくすには、値に 0 を指定します。","既定値：0","BackupFolder","保管領域のディレクトリへのパス。既定のディレクトリとは異なるカスタムの保管領域のディレクトリを指定できます。","任意のコンピューター端末のディレクトリを保管領域として使用できます。Samba プロトコルや NFS プロトコルでマウントされているような、リモートコンピューターにあるディレクトリは割り当てないでください。","設定をファイルから保管領域タスクにインポートして Kaspersky Endpoint Security を再起動したあと、Kaspersky Endpoint Security はオブジェクトの指定されたディレクトリへの配置を開始します。","指定したディレクトリが存在しない、または使用できない場合、既定の保管領域のディレクトリが使用されます。","既定値：/var/opt/kaspersky/kesl/objects-backup/"," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x306E;&#x7BA1;&#x7406;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161318.htm");
Page[110]=new Array("保管領域にあるオブジェクトの ID の表示","オブジェクトが保管領域に配置される場合、そのオブジェクトには数値の ID が割り当てられます。ID は、オブジェクトを保管領域から復元または削除するなど、オブジェクトに対して処理を実行する場合に使用されます。","保管領域にあるオブジェクトの ID を表示するには、","コマンド kesl-control -B --query を実行します。","オブジェクト ID は ObjectId 文字列に表示されます。"," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x306B;&#x3042;&#x308B;&#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x306E; ID &#x306E;&#x8868;&#x793A; ","161319.htm");
Page[111]=new Array("保管領域からのオブジェクトの復元について","Kaspersky Endpoint Security は、潜在的に有害な影響から保護対象のサーバーを守るため、ファイルを保管領域に暗号化形式で格納します。","オブジェクトは保管領域から復元できます。次の場合に、保管領域からオブジェクトを復元しなければならないことがあります：","感染したファイルの駆除中に、整合性を維持できず、ファイルの情報にアクセスできなくなった場合。オブジェクトをサーバーにとって安全であるとみなして使用する場合、以降のスキャンで検知されないように、オブジェクトをスキャンから除外できます。そのために、リアルタイム保護タスクではオブジェクトの名前または検知された脅威の名前で除外する必要があり、オンデマンドスキャンタスクでもオブジェクトの名前および検知された脅威の名前で除外する必要があります。感染しているオブジェクトを復元すると、コンピューターへの感染を引き起こす可能性があります。","保管領域から復元するときに、新しい名前でオブジェクトを保存できます。"," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x304B;&#x3089;&#x306E;&#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x306E;&#x5FA9;&#x5143;&#x306B;&#x3064;&#x3044;&#x3066; ","161320.htm");
Page[112]=new Array("保管領域からのオブジェクトの復元","オブジェクトを保管領域から復元するには、次のいずれかを実行します：","オブジェクトを元の名前で元の場所に復元するには、次のコマンドを実行します：kesl-control --restore <オブジェクト ID>","ここで オブジェクト ID は保管領域のオブジェクトの ID です。","オブジェクトを新しい名前で指定したディレクトリに復元するには、次のコマンドを実行します：kesl-control --restore <オブジェクト ID> --file <ファイル名とパス>","指定されたディレクトリが存在しない場合は、Kaspersky Endpoint Security によってディレクトリが作成されます。"," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x304B;&#x3089;&#x306E;&#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x306E;&#x5FA9;&#x5143; ","161321.htm");
Page[113]=new Array("保管領域からのオブジェクトの削除","保管領域からオブジェクトを削除するには、次のコマンドを実行します：","kesl-control -B --mass-remove --query \"ObjectId == 'オブジェクト ID>'\"","保管領域から複数のオブジェクトを削除するには、次のコマンドを実行します：","kesl-control -B --mass-remove --query \"<フィールド><比較演算子> '<値>' [and <フィールド> <比較演算子>'<値>' ]* ]","保管領域からすべてのオブジェクトを削除するには、次のコマンドを実行します：","kesl-control -B --mass-remove","or","kesl-control -B --mass-remove --query"," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x304B;&#x3089;&#x306E;&#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x306E;&#x524A;&#x9664; ","161322.htm");
Page[114]=new Array("ファイル変更監視タスク（Integrity_Monitoring ID:11）","このセクションでは、ファイル整合性監視タスクに関する情報について説明します。","このセクションの内容ファイル変更監視についてオンアクセスファイル変更監視（OAFIM）オンデマンドファイル変更監視（ODFIM）オンアクセスファイル変更監視タスクの設定オンデマンドファイル変更監視の設定"," &#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x5909;&#x66F4;&#x76E3;&#x8996;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Integrity_Monitoring ID:11&#xFF09; ","161323.htm");
Page[115]=new Array("ファイル変更監視について","ファイル変更監視タスクは、タスクの設定で指定された監視範囲のファイルとディレクトリに対して実行する処理を追跡するために設計されています。タスクを使用して、保護対象サーバーでセキュリティ違反を示す可能性があるファイルの変更を検知できます。また、監視が中断されている間にファイルの変更を追跡するよう設定することもできます。","ファイル変更監視機能を使用するには、この機能が含まれる拡張ライセンスを購入する必要があります。ファイル変更監視は既定では無効になっています。","ファイル変更監視は、オンアクセスファイル変更監視（OAFIM）タスクを実行してリアルタイムモードで実行できます。また、オンデマンドファイル変更監視（ODFIM）タスクを作成して実行することもできます。","OAFIM タスクと ODFIM タスクはどちらも、オブジェクトのアクセス制御リストの変更に関する通知を送信します。OAFIM タスクでは、実際に変更された内容の詳細は報告されません。ODFIM タスクでは、属性の変更とファイル / ディレクトリの移動に関する情報が報告されます。"," &#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x5909;&#x66F4;&#x76E3;&#x8996;&#x306B;&#x3064;&#x3044;&#x3066; ","161324.htm");
Page[116]=new Array("オンアクセスファイル変更監視（OAFIM）","OAFIM タスクの実行中、 各オブジェクトの変更は、リアルタイムモードでのファイル操作を随時読み取り、決定されます。オブジェクトが変わると、Kaspersky Endpoint Security は Kaspersky Security Center の管理サーバーにイベントを送信します。タスクの実行中、ファイルのチェックサムは計算されません。OAFIM タスクは、監視範囲内にないハードリンクを持つファイルの変更（属性と内容）を監視しません。","Kaspersky Endpoint Security は、特定のファイル、またはタスクのパラメータで指定される範囲内のファイルの操作を監視します。","監視範囲","ファイル変更監視タスクの監視範囲は、常に指定する必要があります。管理者は、リアルタイムモードでスキャン範囲と監視範囲を変更できます。監視範囲が指定されていない場合、設定ファイルにタスク設定を保存することはできません。監視範囲または除外範囲が追加されるとき、本製品は指定されたディレクトリの存在有無を確認しません。","複数の監視範囲を指定できます。","監視除外範囲","監視範囲の除外を作成できます。除外は各個別の範囲に対して指定され、示された監視範囲に対してのみ機能します。複数の除外範囲を指定できます。","除外は監視範囲よりも優先度が高く、指定されたディレクトリまたはファイルが監視範囲にある場合でも、タスクによって監視されません。ルールの 1 つの設定が指定する監視範囲が、除外で指定されたディレクトリよりも下のレベルである場合、タスクが実行されるときにこの監視範囲は考慮されません。","除外を指定するには、監視範囲を指定するために使用するのと同じコマンドラインのシェルマスクを使用できます。","監視対象パラメータ","ファイル変更監視タスクの実行中、次のパラメータの変更が監視されます：","コンテンツ（write (), truncate (), など）メタデータ（所有者権限（chmod / chown））タイムスタンプ（utimensat）拡張属性（setxattr）などLinux オペレーティングシステムの技術的な制限により、どの管理者またはどのプロセスがファイルに変更を加えたのか見つけることはできません。"," &#x30AA;&#x30F3;&#x30A2;&#x30AF;&#x30BB;&#x30B9;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x5909;&#x66F4;&#x76E3;&#x8996;&#xFF08;OAFIM&#xFF09; ","161948.htm");
Page[117]=new Array("オンデマンドファイル変更監視（ODFIM）","ODFIM タスクの実行中、各オブジェクトの変更は、監視対象オブジェクトの現在の状態と、以前ベースラインとして確立された元の状態を比較することで決定されます。","複数の ODFIM タスクを作成できます。","ベースライン","ベースラインはコンピューターで ODFIM タスクを初めて実行する時に確立されます。ODFIM タスクごとに、個別のベースラインが作成されます。タスクはベースラインが監視範囲に対応する場合にのみ実行されます。ベースラインが監視範囲に一致しない場合、Kaspersky Endpoint Security はファイル変更違反に関するイベントを生成します。","対応するパラメータを使用して、タスクのベースラインを再ビルドできます。ベースラインは ODFIM タスクの完了後に再ビルドされます。","また、タスクのパラメータが変更されたとき（新しい監視範囲が追加されたときなど）に、ベースラインは再ビルドされます。ベースラインは次のタスクの実行中に再ビルドされます。","ODFIM タスクは、ファイル変更監視コンポーネントがインストールされたコンピューター上にベースラインの保管領域を作成します。","ベースラインの削除は、対応する ODFIM タスクを削除する場合にのみ行えます。 "," &#x30AA;&#x30F3;&#x30C7;&#x30DE;&#x30F3;&#x30C9;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x5909;&#x66F4;&#x76E3;&#x8996;&#xFF08;ODFIM&#xFF09; ","161949.htm");
Page[118]=new Array("オンアクセスファイル変更監視タスクの設定","このセクションでは、オンアクセスファイル変更監視タスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","UseExcludeMasks","ExcludeMasks 設定で指定されたオブジェクトの監視範囲からの除外を有効または無効にします。","UseExcludeMasks 設定は、ExcludeMasks 設定が指定されている場合にのみ機能します。","使用できる値：","Yes - ExcludeMasks 設定で指定されたオブジェクトを監視範囲から除外します","No - ExcludeMasks 設定で指定されたオブジェクトを監視範囲から除外しない","既定値：No","ExcludeMasks","監視範囲から除外されるオブジェクトを定義するマスクのリストを指定します。","この設定を指定する前に、UseExcludeMasks 設定の値が Yes に設定されていることを確認してください。","マスクはコマンドシェル形式で指定されます。 ","複数のマスクを指定する場合は、新しいインデックスを使用して新しい行に各マスクを指定する必要があります（ExcludeMasks.item_0000、ExcludeMasks.item_0001）。","既定値：定義されていません","セクション [ScanScope.item_#]","[ScanScope.item_#] セクションでは、ファイル変更監視タスクによって監視される範囲を指定します。タスクに対して少なくとも 1 つの監視範囲を指定する必要があります。","設定ファイル内に複数の [ScanScope.item_#] セクションを任意の順序で定義できます。Kaspersky Endpoint Security は範囲を項目のインデックスの昇順で処理します。","[ScanScope.item_#] の各セクションには、次の設定が含まれています：","AreaDesc","監視範囲の名前を指定します。","UseScanArea","指定された範囲の監視を有効または無効にします。","使用できる値：","Yes - 指定された範囲を監視します","No - 指定された範囲を監視しません","既定値：Yes","Path","監視されるオブジェクトまたはディレクトリの絶対パスを指定します。","既定値：/opt/kaspersky/kesl/","AreaMask.item_#","監視されるオブジェクトを定義するコマンドラインのシェルマスクを指定します。","複数の AreaMask.item_# 項目を任意の順序で指定できます。Kaspersky Endpoint Security は項目をインデックスの昇順で処理します。","既定値：*（すべてのオブジェクトが処理されます）","セクション [ExcludedFromScanScope.item_#]","[ExcludedFromScanScope.item_#] セクションでは、すべての [ScanScope.item_#] セクションから除外されるオブジェクトを指定します。","[ExcludedFromScanScope.item_#] セクションのいずれかのルールに一致するすべてのオブジェクトは監視されません。[ExcludedFromScanScope.item_#] セクションの形式は、[ScanScope.item_#] セクションの形式と似ています。","設定ファイル内に複数の [ExcludedFromScanScope.item_#] セクションを任意の順序で定義できます。Kaspersky Endpoint Security は範囲を項目のインデックスの昇順で処理します。","[ScanScope.item_#] の各セクションには、次の設定が含まれています：","AreaDesc","監視から除外される範囲の名前を指定します。","UseScanArea","指定された範囲が監視から除外されるかどうかを指定します。","使用できる値：","Yes - 指定された範囲を監視から除外する","No - 指定された範囲を監視から除外しない","既定値：Yes","Path","監視から除外されるオブジェクトまたはディレクトリへのパスを指定します。","AreaMask.item_#","監視から除外されるオブジェクトを定義するコマンドラインシェルマスクを指定します。","複数の AreaMask.item_# 項目を任意の順序で指定できます。Kaspersky Endpoint Security は項目をインデックスの昇順で処理します。","既定値：*（すべてのオブジェクトが監視されます）"," &#x30AA;&#x30F3;&#x30A2;&#x30AF;&#x30BB;&#x30B9;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x5909;&#x66F4;&#x76E3;&#x8996;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161325.htm");
Page[119]=new Array("オンデマンドファイル変更監視の設定","このセクションでは、オンデマンドファイル変更監視タスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","RebuildBaseline","ODFIM タスクの終了後、基準の再構築を有効化または無効化します。","使用できる値：","Yes - ODFIM タスクの終了後に基準を再構築します","No - ODFIM タスクの終了後に基準を再構築しません","既定値：No","CheckFileHash","ハッシュ（SHA-256）の確認を有効化または無効化します。","使用できる値：","Yes - ハッシュの確認を有効化します","No - ハッシュの確認を無効化します","既定値：No","TrackDirectoryChanges","ディレクトリの監視を有効化または無効化します。","使用できる値：","Yes - ディレクトリを監視します","No - ディレクトリを監視しません","既定値：No","TrackLastAccessTime","最後にファイルへアクセスした時間の確認を有効化または無効化します。（Linux オペレーティングシステムでは、これは noatime パラメータです。）","使用できる値：","Yes - 最後にファイルへアクセスした時間を確認します","No - 最後にファイルへアクセスした時間を確認しません","既定値：No","UseExcludeMasks","ExcludeMasks 設定で指定されたオブジェクトの監視範囲からの除外を有効または無効にします。","この設定は、ExcludeMasks 設定が指定されている場合にのみ機能します。","使用できる値：","Yes - ExcludeMasks 設定で指定されたオブジェクトを監視範囲から除外します","No - ExcludeMasks 設定で指定されたオブジェクトを監視範囲から除外しません","既定値：No","ExcludeMasks","監視範囲から除外されるオブジェクトを定義するマスクのリストを指定します。","この設定を指定する前に、UseExcludeMasks 設定の値が Yes に設定されていることを確認してください。","マスクはコマンドシェル形式で指定されます。 ","複数のマスクを指定する場合は、新しいインデックスを使用して新しい行に各マスクを指定する必要があります（ExcludeMasks.item_0000、ExcludeMasks.item_0001）。","既定値：定義されていません","セクション [ScanScope.item_#]","[ScanScope.item_#] セクションでは、ファイル変更監視タスクによって監視される範囲を指定します。タスクに対して少なくとも 1 つの監視範囲を指定する必要があります。","設定ファイル内に複数の [ScanScope.item_#] セクションを任意の順序で定義できます。Kaspersky Endpoint Security は範囲を項目のインデックスの昇順で処理します。","[ScanScope.item_#] の各セクションには、次の設定が含まれています：","AreaDesc","監視範囲の名前を指定します。","UseScanArea","指定された範囲の監視を有効または無効にします。","使用できる値：","Yes - 指定された範囲を監視します","No - 指定された範囲を監視しません","既定値：Yes","Path","監視されるオブジェクトまたはディレクトリの絶対パスを指定します。","既定値：/opt/kaspersky/kesl/","AreaMask.item_#","監視されるオブジェクトを定義するコマンドラインのシェルマスクを指定します。","複数の AreaMask.item_# 項目を任意の順序で指定できます。Kaspersky Endpoint Security は項目をインデックスの昇順で処理します。","既定値：*（すべてのオブジェクトが処理されます）","セクション [ExcludedFromScanScope.item_#]","[ExcludedFromScanScope.item_#] セクションでは、すべての [ScanScope.item_#] セクションから除外されるオブジェクトを指定します。","[ExcludedFromScanScope.item_#] セクションのいずれかのルールに一致するすべてのオブジェクトは監視されません。[ExcludedFromScanScope.item_#] セクションの形式は、[ScanScope.item_#] セクションの形式と似ています。","設定ファイル内に複数の [ExcludedFromScanScope.item_#] セクションを任意の順序で定義できます。Kaspersky Endpoint Security は範囲を項目のインデックスの昇順で処理します。","[ScanScope.item_#] の各セクションには、次の設定が含まれています：","AreaDesc","監視から除外される範囲の名前を指定します。","UseScanArea","指定された範囲が監視から除外されるかどうかを指定します。","使用できる値：","Yes - 指定された範囲を監視から除外します","No - 指定された範囲を監視から除外しません","既定値：Yes","Path","監視から除外されるオブジェクトまたはディレクトリへのパスを指定します。","AreaMask.item_#","監視から除外されるオブジェクトを定義するコマンドラインシェルマスクを指定します。","複数の AreaMask.item_# 項目を任意の順序で指定できます。Kaspersky Endpoint Security は項目をインデックスの昇順で処理します。","既定値：*（すべてのオブジェクトが監視されます）"," &#x30AA;&#x30F3;&#x30C7;&#x30DE;&#x30F3;&#x30C9;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x5909;&#x66F4;&#x76E3;&#x8996;&#x306E;&#x8A2D;&#x5B9A; ","165474.htm");
Page[120]=new Array("ファイアウォール管理タスク（Firewall ID:12）","このセクションでは、ファイアウォールマネージャータスクに関する情報について説明します。","このセクションの内容ファイアウォールマネージャーについてネットワークパケットルールについて動的ルールについて事前に定義されたネットワークゾーン名についてファイアウォールマネージャータスクの設定ネットワークパケットルールの追加ネットワークパケットルールの削除ネットワークパケットルールの実行の優先順位の変更ネットワークアドレスのゾーンセクションへの追加ゾーンセクションからネットワークアドレスを削除する"," &#x30D5;&#x30A1;&#x30A4;&#x30A2;&#x30A6;&#x30A9;&#x30FC;&#x30EB;&#x7BA1;&#x7406;&#x30BF;&#x30B9;&#x30AF;&#xFF08;Firewall ID:12&#xFF09; ","161326.htm");
Page[121]=new Array("ファイアウォールマネージャーについて","LAN やインターネットの使用中に、コンピューターはウイルスやその他のマルウェア、およびオペレーティングシステムやソフトウェアの脆弱性を悪用するさまざまな攻撃を受けます。","オペレーティングシステムのファイアウォールは、ユーザーのコンピューターに保管されている個人情報を保護します。コンピューターがインターネットや LAN に接続されたときに、ファイアウォールはオペレーティングシステムに対する最も可能性の高い脅威をブロックします。ファイアウォール管理はユーザーのコンピューターのすべてのネットワーク接続を検知し、既定のネットワーク接続の状態を示す IP アドレスのリストを提供します。","ファイアウォール管理コンポーネントは、ネットワークパケットルールに従ってすべてのネットワーク動作をフィルタリングします。ネットワークパケットルールを使用すると、すべてのアプリケーションのインターネットアクセスをブロックする設定から、無制限にアクセスを許可する設定まで、必要なレベルのコンピューター保護を設定できます。","ファイアウォールマネージャータスクの実行中は、オペレーティングシステムのファイアウォールのパラメータとルールを Kaspersky Endpoint Security が管理します。プログラムやツールがルールを追加または削除するとき、本製品はオペレーティングシステムのファイアウォールのパラメータの設定をブロックします。Kaspersky Endpoint Security はオペレーティングシステムのファイアウォールを 60 秒ごとにチェックし、必要に応じてファイアウォールのルールのセットを復元します。チェックの間隔は変更できません。","このオペレーティングシステムのファイアウォールのチェックは、ファイアウォールマネージャータスクが停止されているときも実行されます。これにより、本製品は動的ルールを復元できます。","ファイアウォールマネージャータスクが停止される（コンポーネントが削除される、製品が停止またはアンインストールされる）とき、Kaspersky Endpoint Security はオペレーティングシステムのファイアウォールルールを変更せず、設定の変更を制御しません。","既定では、ファイアウォールマネージャータスクの対応するブロックルールが指定されている場合を除き、すべての送信接続が許可されます（既定の処理設定）。既定の処理は、最も低い優先順位で実行されます。他のネットワークパケットルールが起動されていない場合、またはネットワークパケットルールが指定されていない場合、接続が許可されます。","ファイアウォール管理タスクが有効にされる前に、他の OS のファイアウォール管理ツールを無効にしてください。"," &#x30D5;&#x30A1;&#x30A4;&#x30A2;&#x30A6;&#x30A9;&#x30FC;&#x30EB;&#x30DE;&#x30CD;&#x30FC;&#x30B8;&#x30E3;&#x30FC;&#x306B;&#x3064;&#x3044;&#x3066; ","161327.htm");
Page[122]=new Array("ネットワークパケットルールについて","ネットワークパケットルールは、ネットワーク接続の試行を検知したときにファイアウォール管理によって実行される処理を許可またはブロックします。","ネットワークパケットルールは、プログラムに関係なく、ネットワークパケットを制限します。このようなルールは、選択したデータプロトコルの特定のポートから送受信するネットワークトラフィックを制限します。 ","既定では、ファイアウォールマネージャーは特定のネットワークパケットルールを指定します。独自のネットワークパケットルールを作成して、ネットワークパケットルールごとに実行の優先度を指定できます。"," &#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30D1;&#x30B1;&#x30C3;&#x30C8;&#x30EB;&#x30FC;&#x30EB;&#x306B;&#x3064;&#x3044;&#x3066; ","161953.htm");
Page[123]=new Array("動的ルールについて","Kaspersky Endpoint Security のコンポーネントは、正常な動作のために必要な動的ルールをファイアウォールに追加および削除できます。たとえば、ネットワークエージェントは、製品と Kaspersky Security Center の両方によって開始される Kaspersky Security Center への接続を許可する動的ルールを追加します。","ファイアウォールマネージャータスクは動的ルールを制御せず、製品のコンポーネントに対してネットワークリソースへのアクセスをブロックしません。動的ルールは、ファイアウォールマネージャータスクの状態（開始 / 停止）または設定の変更に依存しません。ネットワークパケットルールよりも、動的ルールの実行が優先されます。たとえば iptables ユーティリティを使用して動的ルールのセットのいずれかが削除されると、Kaspersky Endpoint Security によってそのセットが復元されます。","動的ルールのセットの表示はできますが（kesl-control -F -query コマンドを使用）、動的ルールの設定を変更することはできません。 "," &#x52D5;&#x7684;&#x30EB;&#x30FC;&#x30EB;&#x306B;&#x3064;&#x3044;&#x3066; ","161954.htm");
Page[124]=new Array("事前に定義されたネットワークゾーン名について","ファイアウォールは、ユーザーのコンピューター上のすべてのネットワーク接続を制御します。ネットワークアドレスを事前に定義された次のゾーンの 1 つに追加できます：","パブリックローカル許可"," &#x4E8B;&#x524D;&#x306B;&#x5B9A;&#x7FA9;&#x3055;&#x308C;&#x305F;&#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30BE;&#x30FC;&#x30F3;&#x540D;&#x306B;&#x3064;&#x3044;&#x3066; ","161955.htm");
Page[125]=new Array("ファイアウォールマネージャータスクの設定","このセクションでは、ファイアウォールマネージャータスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","DefaultIncomingAction","この種の接続に適用できるネットワークルールがない場合、受信接続に対して実行する既定の処理。","使用できる値：","Allow - 受信接続を許可する","Block - 受信接続をブロックする","既定値：Allow","DefaultIncomingPacketAction","この種の接続に適用できるネットワークパケットルールがない場合、受信パケットに対して実行する既定の処理。","使用できる値：","Allow - 受信パケットを許可する","Block - 受信パケットをブロックする","既定値：Allow","セクション [PacketRules.item_xxxx]","[PacketRules.item_#] セクションは、ファイアウォールマネージャータスクに対してネットワークパケットルールを指定します。","設定ファイル内に複数の [PacketRules.item_#] セクションを任意の順序で定義できます。Kaspersky Endpoint Security は、項目のインデックスによる範囲を昇順で処理します。","[PacketRules.item_#] の各セクションには、次の設定が含まれています：","名前","ネットワークパケットルールの名前。","既定値：Network rule #<n>（n はインデックス）","FirewallAction","このネットワークパケットルールで指定される接続に対して実行する処理。","使用できる値：","Allow - ネットワーク接続を許可する","Block - ネットワーク接続をブロックする","既定値：Allow","Protocol","監視するネットワーク動作のプロトコルの種別。","使用できる値：","Any - ファイアウォールマネージャーはすべてのネットワーク動作を監視する","TCP","UDP","ICMP","ICMPv6","IGMP","GRE","既定値：Any","RemotePorts","接続を監視するリモートコンピューターのポート番号。","この設定は、Protocol の設定値が TCP または UDP に設定された場合にのみ指定できます。","この設定に対して、整数または範囲を指定できます。","使用できる値：","Any - すべてのリモートポートを監視する","0 ～ 65535","既定値：Any","LocalPorts","接続を監視するローカルコンピューターのポート番号。","この設定は、Protocol の設定値が TCP または UDP に設定された場合にのみ指定できます。","この設定に対して、整数または範囲を指定できます。","使用できる値：","Any - すべてのローカルポートを監視する","0 ～ 65535","既定値：Any","ICMPType","ICMP パケットの種別。","この設定は、Protocol の設定値が ICMP または ICMPv6 に設定された場合にのみ指定できます。","使用できる値：","Any - すべての ICMP パケットの種別を監視する","データ転送プロトコルの仕様に応じた整数","既定値：Any","ICMPCode","ICMP パケットのコード。","この設定は、Protocol の設定値が ICMP または ICMPv6 に設定された場合にのみ指定できます。","使用できる値：","Any - すべての ICMP パケットコードを監視する","データ転送プロトコルの仕様に応じた整数","既定値：Any","Direction","監視するネットワーク動作の通信方向。","使用できる値：","IncomingOutgoing - 受信と送信の両方の接続を監視する","Incoming - 受信接続を監視する","Outgoing - 送信接続を監視する","IncomingPacket - 受信パケットを監視する","OutgoingPacket - 送信パケットを監視する","IncomingOutgoingPacket - 受信と送信の両方の接続を監視する","既定値：IncomingOutgoing","RemoteAddress","ネットワークパケットを送受信できるリモートコンピューターのネットワークアドレス。","使用できる値：","Any - すべての IP アドレスのリモートコンピューターによって送受信されるネットワークパケットを監視する","Trusted - すべての許可するネットワーク","Local - すべてのローカルネットワーク","Public - すべてのパブリックネットワーク","d.d.d.d - IPv4 アドレス、d は 10 進数の 0 ～ 255","d.d.d.d/p - IPv4 のサブネットアドレス、p は数値 0 ～ 32","x:x:x:x:x:x:x:x - IPv6 アドレス、x は 16 進数の 0 ～ ffffff","x:x:x:x::0/p - IPv6 のサブネットアドレス、p は数値 0 ～ 64","既定値：Any","LocalAddress","Kaspersky Endpoint Security がインストールされており、ネットワークパケットを送受信できるコンピューターのネットワークアドレス。","使用できる値：","Any - すべての IP アドレスのリモートコンピューターによって送受信されるネットワークパケットを監視する","d.d.d.d - IPv4 アドレス、d は 10 進数の 0 ～ 255","d.d.d.d/p - IPv4 のサブネットアドレス、p は数値 0 ～ 32","x:x:x:x:x:x:x:x - IPv6 アドレス、x は 16 進数の 0 ～ ffffff","x:x:x:x::0/p - IPv6 のサブネットアドレス、p は数値 0 ～ 64","既定値：Any","LogAttempts","ネットワークルールの処理をレポートに反映するかどうかを指定します。","使用できる値：","Yes - 処理を報告する","No - 処理を報告しない","既定値：No","セクション [NetworkZonesPublic]","セクション [NetworkZonesPublic] は、パブリックネットワークに関連付けられたネットワークアドレスを指定します。","複数の IP アドレスまたは IP アドレスのサブネットを指定できます。","Address.item_xxxx","使用できる値：","d.d.d.d - IPv4 アドレス、d は 10 進数の 0 ～ 255","d.d.d.d/p - IPv4 のサブネットアドレス、p は数値 0 ～ 32","x:x:x:x:x:x:x:x - IPv6 アドレス、x は 16 進数の 0 ～ ffffff","x:x:x:x::0/p - IPv6 のサブネットアドレス、p は数値 0 ～ 64","既定値：“”（このゾーンのネットワークアドレスはありません）","セクション [NetworkZonesLocal]","セクション [NetworkZonesLocal] は、ローカルネットワークに関連付けられたネットワークアドレスを指定します。","複数の IP アドレスまたは IP アドレスのサブネットを指定できます。","Address.item_xxxx","使用できる値：","d.d.d.d - IPv4 アドレス、d は 10 進数の 0 ～ 255","d.d.d.d/p - IPv4 のサブネットアドレス、p は数値 0 ～ 32","x:x:x:x:x:x:x:x - IPv6 アドレス、x は 16 進数の 0 ～ ffffff","x:x:x:x::0/p - IPv6 のサブネットアドレス、p は数値 0 ～ 64","既定値：“”（このゾーンのネットワークアドレスはありません）","セクション [NetworkZonesTrusted]","セクション [NetworkZonesTrusted] は、許可するネットワークに関連付けられたネットワークアドレスを指定します。","複数の IP アドレスまたは IP アドレスのサブネットを指定できます。","Address.item_xxxx","使用できる値：","d.d.d.d - IPv4 アドレス、d は 10 進数の 0 ～ 255","d.d.d.d/p - IPv4 のサブネットアドレス、p は数値 0 ～ 32","x:x:x:x:x:x:x:x - IPv6 アドレス、x は 16 進数の 0 ～ ffffff","x:x:x:x::0/p - IPv6 のサブネットアドレス、p は数値 0 ～ 64","既定値：“”（このゾーンのネットワークアドレスはありません）"," &#x30D5;&#x30A1;&#x30A4;&#x30A2;&#x30A6;&#x30A9;&#x30FC;&#x30EB;&#x30DE;&#x30CD;&#x30FC;&#x30B8;&#x30E3;&#x30FC;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161328.htm");
Page[126]=new Array("ネットワークパケットルールの追加","ネットワークパケットルールを手動で追加できます。","追加できるネットワークパケットルールは 1 回に 1 つのみです。","ネットワークパケットルールを追加するには、次のコマンドを実行します：","kesl-control -F --add-rule --name <ルール名> --action <処理> --protocol <プロトコル> --direction <方向> --remote <リモートアドレス> --local <ローカルアドレス> --at <ネットワークパケットルールのリストのインデックス>","新しいネットワークパケットルールの設定を含むセクションは、ファイアウォールマネージャータスクの設定ファイルに追加されます。コマンドに特定のパラメータを指定しなかった場合、既定値が設定されます。","-at オプションでは、ネットワークパケットルールのリストに、作成されたルールのインデックスを指定できます。-at オプションが指定されていない場合、または値がリストのルールの数より大きい場合、新しいルールがリストの最後に追加されます。"," &#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30D1;&#x30B1;&#x30C3;&#x30C8;&#x30EB;&#x30FC;&#x30EB;&#x306E;&#x8FFD;&#x52A0; ","161956.htm");
Page[127]=new Array("ネットワークパケットルールの削除","ネットワークパケットルールを手動で削除できます。","削除できるネットワークパケットルールは 1 回に 1 つのみです。","ネットワークパケットルールを削除するには、次のコマンドのいずれかを実行します：","kesl-control -F --del-rule --name <名前>削除するネットワークパケットルールは名前で指定します。ネットワークパケットルールのリストに同じ名前のルールが複数含まれている場合、Kaspersky Endpoint Security はいずれも削除しません。","kesl-control -F -del-rule --index <インデックス>削除するネットワークパケットルールはネットワークパケットルールのリストのインデックスで指定します。","ネットワークパケットルールの設定を含むセクションがファイアウォール管理タスクの設定ファイルから削除されます。","ネットワークパケットルールのリストに指定された名前やインデックスを持つルールが含まれていない場合、エラーが発生します。"," &#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30D1;&#x30B1;&#x30C3;&#x30C8;&#x30EB;&#x30FC;&#x30EB;&#x306E;&#x524A;&#x9664; ","161958.htm");
Page[128]=new Array("ネットワークパケットルールの実行の優先順位の変更","ネットワークパケットルールの実行の優先順位を手動で変更できます。","ネットワークパケットルールの実行の優先順位を変更するには、次のコマンドを実行します：","kesl-control -F --move-rule [--name <名前>|--index <インデックス>] --at <インデックス>","ネットワークパケットルールの優先順位が特定のインデックスに対して変更されます。"," &#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30D1;&#x30B1;&#x30C3;&#x30C8;&#x30EB;&#x30FC;&#x30EB;&#x306E;&#x5B9F;&#x884C;&#x306E;&#x512A;&#x5148;&#x9806;&#x4F4D;&#x306E;&#x5909;&#x66F4; ","161960.htm");
Page[129]=new Array("ネットワークアドレスのゾーンセクションへの追加","特定の種別のネットワークと関連するネットワークアドレスをファイアウォール管理タスクの設定ファイルに手動で追加できます。","ネットワークアドレスをゾーンに追加するには、次のコマンドを実行します：","kesl-control -F --add-zone <Public|Local|Trusted> --address <アドレス>","ネットワークアドレスは、タスクの設定ファイルの指定されたゾーンのセクションに追加されます。"," &#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30A2;&#x30C9;&#x30EC;&#x30B9;&#x306E;&#x30BE;&#x30FC;&#x30F3;&#x30BB;&#x30AF;&#x30B7;&#x30E7;&#x30F3;&#x3078;&#x306E;&#x8FFD;&#x52A0; ","161959.htm");
Page[130]=new Array("ゾーンセクションからネットワークアドレスを削除する","特定の種別のネットワークに関連するネットワークアドレスをファイアウォール管理タスクの設定ファイルから手動で削除できます。","設定タスク内でゾーンからネットワークアドレスを削除するには、次のコマンドを実行します：","kesl_control -F --del-zone <ゾーン> [--address <アドレス>| --index <ゾーン内のアドレスインデックス>]","設定ファイル内で指定したゾーンセクションから、指定したネットワークアドレスが削除されます。","同じネットワークアドレスの複数のアイテムが 1 つのゾーンに含まれている場合、コマンド –del-zone が実行されます。","指定したネットワークアドレスまたはインデックスが存在しない場合、エラーが発生します。"," &#x30BE;&#x30FC;&#x30F3;&#x30BB;&#x30AF;&#x30B7;&#x30E7;&#x30F3;&#x304B;&#x3089;&#x30CD;&#x30C3;&#x30C8;&#x30EF;&#x30FC;&#x30AF;&#x30A2;&#x30C9;&#x30EC;&#x30B9;&#x3092;&#x524A;&#x9664;&#x3059;&#x308B; ","161961.htm");
Page[131]=new Array("アンチ暗号化タスク（AntiCryptor ID:13）","このセクションでは、アンチクリプタータスクに関する情報について説明します。","このセクションの内容アンチクリプタータスクについて信頼されないホストのブロックについてアンチクリプタータスクの設定ブロックされるホストのリストの表示ブロックされるホストを許可"," &#x30A2;&#x30F3;&#x30C1;&#x6697;&#x53F7;&#x5316;&#x30BF;&#x30B9;&#x30AF;&#xFF08;AntiCryptor ID:13&#xFF09; ","161329.htm");
Page[132]=new Array("アンチクリプタータスクについて","アンチクリプタータスクは、悪意のあるリモートでの暗号化から SMB / NFS プロトコルでネットワークアクセスされるローカルディレクトリのファイルを保護します。","アンチクリプタータスクの実行中に、Kaspersky Endpoint Security は保護対象のデバイスの共有ネットワークディレクトリにあるファイルへアクセスするためのリモートコンピューターのコールをスキャンします。ネットワークファイルリソースへのリモートコンピューターの処理が、悪意のある暗号化であるとみなされた場合、このコンピューターは信頼されないホストのリストに追加され、共有ネットワークディレクトリにアクセスできなくなります。","Kaspersky Endpoint Security は、アンチクリプタータスクの範囲から除外されたディレクトリで検知された暗号化処理が発生している場合は、処理を悪意のある暗号化であるとみなしません。","既定では、Kaspersky Endpoint Security は信頼されないホストからネットワークファイルリソースへのアクセスを 30 分間ブロックします。","アンチクリプタータスクは、SMB1、SMB2、SMB3、NFS3、TCP / UDP、および IP / IPv6 のプロトコルにおいて適切に動作します。NFS2 プロトコルと NFS4 プロトコルでの動作はサポートされていません。リソースのマウントに NFS2 プロトコルと NFS4 プロトコルを使用できないよう、サーバー設定を構成してください。","アンチ暗号化タスクでは、ホストの動作が悪意があると識別されるまでは、ネットワークファイルリソースへのアクセスをブロックしません。このため、悪意のある処理が検知されるまで、少なくとも 1 つのファイルが暗号化されます。 "," &#x30A2;&#x30F3;&#x30C1;&#x30AF;&#x30EA;&#x30D7;&#x30BF;&#x30FC;&#x30BF;&#x30B9;&#x30AF;&#x306B;&#x3064;&#x3044;&#x3066; ","161330.htm");
Page[133]=new Array("信頼されないホストのブロックについて","悪意のある暗号化処理が検知されると、Kaspersky Endpoint Security は侵入されたホストからのネットワークトラフィックをブロックするオペレーティングシステムのファイアウォールのルールを作成して有効にします。侵入されたホストは、信頼されないホストのリストに追加されます。信頼されないホストのリストにあるすべてのリモートホストに対して、共有ネットワークディレクトリへのアクセスがブロックされます。保護対象のサーバーからのブロックされたホストに関する情報は、Kaspersky Security Center に送信されます。","アンチクリプターによって作成されたファイアウォールのルールは、iptables ユーティリティを使用して削除することはできません。Kaspersky Endpoint Security は 1 分に 1 回ルールのセットを復元します。ホストをブロック解除するには、--allow-hosts オプションを使用します。","既定では、Kaspersky Endpoint Security は、信頼しないコンピューターを、リストに追加されてから 30 分以内にリストから削除します。コンピューターのネットワークファイルリソースへのアクセスは、信頼されないホストのリストから削除されたあとで、自動的に復元されます。ブロックされたホストのリストを変更し、ブロックされたコンピューターが自動的にブロック解除されるまでの時間を指定できます。"," &#x4FE1;&#x983C;&#x3055;&#x308C;&#x306A;&#x3044;&#x30DB;&#x30B9;&#x30C8;&#x306E;&#x30D6;&#x30ED;&#x30C3;&#x30AF;&#x306B;&#x3064;&#x3044;&#x3066; ","161331.htm");
Page[134]=new Array("アンチクリプタータスクの設定","このセクションでは、アンチ暗号化タスクに対して指定できる設定について説明します。","各設定で指定可能なすべての値と既定値について説明します。","UseHostBlocker","信頼されないホストのブロックを有効または無効にします。","信頼されないホストのブロックが無効になっている場合、Kaspersky Endpoint Security はアンチクリプタータスクが実行中の場合に、引き続きネットワークファイルリソースのリモートコンピューターの処理で悪意のある暗号化をスキャンします。悪意のある処理が検知された場合、EncryptionDetected イベントが作成されますが、ホストの攻撃はブロックされません。 ","使用できる値：","Yes - 信頼されないホストのブロックを有効にする","No - 信頼されないホストのブロックを無効にする","既定値：Yes","BlockTime","信頼されないホストをブロックする時間を指定します（分単位）。","侵入されたホストがブロックされてから BlockTime の設定値を変更しても、このホストのブロック時間は変更されません。ブロックの時間は動的な値ではなく、ブロックの瞬間に計算されます。","使用できる値：","1 ～ 4294967295 の整数","既定値：30","UseExcludeMasks","ExcludeMasks 設定で指定されたオブジェクトの保護範囲からの除外を有効または無効にします。","この設定は、ExcludeMasks 設定が指定されている場合にのみ機能します。","使用できる値：","Yes - ExcludeMasks 設定で指定されたオブジェクトを保護範囲から除外する","No - ExcludeMasks 設定で指定されたオブジェクトを保護範囲から除外しない","既定値：No","ExcludeMasks","保護範囲から除外されるオブジェクトを定義するマスクのリストを指定します。","このパラメータを指定する前に、UseExcludeMasks 設定の値が Yes に設定されていることを確認してください。","マスクはコマンドシェル形式で指定されます。 ","複数のマスクを指定する場合は、新しいインデックスを使用して新しい行に各マスクを指定する必要があります（ExcludeMasks.item_0000、ExcludeMasks.item_0001）。","既定値：定義されていません","セクション [ScanScope.item_#]","[ScanScope.item_#] セクションでは、Kaspersky Endpoint Security によって保護される範囲を指定します。アンチクリプタータスクに対して少なくとも 1 つの保護範囲を指定する必要があります。","アンチ暗号化タスクでは、共有ディレクトリのみを指定できます。","設定ファイル内に複数の [ScanScope.item_#] セクションを任意の順序で定義できます。Kaspersky Endpoint Security は、項目のインデックスによる範囲を昇順で処理します。","[ScanScope.item_#] の各セクションには、次の設定が含まれています：","AreaDesc","保護範囲の名前を指定します。","既定値：AllSharedFolders","UseScanArea","指定された範囲の保護を有効または無効にします。","使用できる値：","Yes - 指定された範囲を保護する","No - 指定された範囲を保護しない","既定値：Yes","Path","保護されるオブジェクトのパスを指定します。","使用できる値：","SMB / NFS を使用してアクセス可能な絶対パス（Path=/tmp など）","AllShared - SMB / NFS を使用して共有されるすべてのリソースを保護する","Shared:SMB <パス> - SMB を使用して共有されるリソースを保護する","Shared:NFS <パス> - NFS を使用して共有されるリソースを保護する","既定値：AllShared","AreaMask.item_#","保護されるオブジェクトを定義するコマンドラインのシェルマスクを指定します。","複数の AreaMask.item_# 項目を任意の順序で指定できます。Kaspersky Endpoint Security は、インデックスによる項目を昇順で処理します。","既定値：*（すべてのオブジェクトが処理されます）","セクション [ExcludedFromScanScope.item_#]","[ExcludedFromScanScope.item_#] セクションでは、すべての [ScanScope.item_#] セクションから除外されるオブジェクトを指定します。","[ExcludedFromScanScope.item_#] セクションのルールに一致するすべてのオブジェクトはスキャンされません。[ExcludedFromScanScope.item_#] セクションの形式は、[ScanScope.item_#] セクションの形式と似ています。","設定ファイル内に複数の [ExcludedFromScanScope.item_#] セクションを任意の順序で定義できます。Kaspersky Endpoint Security は、項目のインデックスによる範囲を昇順で処理します。","[ScanScope.item_#] の各セクションには、次の設定が含まれています：","AreaDesc","スキャンから除外される範囲の名前を指定します。","既定値：All objects","UseScanArea","指定された範囲が保護から除外されるかどうかを指定します。","使用できる値：","Yes - 指定された範囲を保護から除外する","No - 指定された範囲を保護から除外しない","既定値：Yes","Path","保護から除外されるオブジェクトへのパスを指定します。","アンチクリプターによって保護されないローカルディレクトリの絶対パス（/root /tmp/123 など）のみを指定できます。","既定値：定義されていません","AreaMask.item_#","保護から除外されるオブジェクトを定義するコマンドラインシェルマスクを指定します。","複数の AreaMask.item_# 項目を任意の順序で指定できます。Kaspersky Endpoint Security は、インデックスによる項目を昇順で処理します。","既定値：*（すべてのオブジェクトが処理されます）"," &#x30A2;&#x30F3;&#x30C1;&#x30AF;&#x30EA;&#x30D7;&#x30BF;&#x30FC;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A; ","161332.htm");
Page[135]=new Array("ブロックされるホストのリストの表示","アンチ暗号化タスクによってブロックされる信頼されないホストのリストを表示できます。","ブロックされるホストのリストを表示するには、次のコマンドを実行します：","kesl-control -H --get-blocked-hosts","アンチ暗号化タスクによってブロックされるホストが表示されます。"," &#x30D6;&#x30ED;&#x30C3;&#x30AF;&#x3055;&#x308C;&#x308B;&#x30DB;&#x30B9;&#x30C8;&#x306E;&#x30EA;&#x30B9;&#x30C8;&#x306E;&#x8868;&#x793A; ","161333.htm");
Page[136]=new Array("ブロックされるホストを許可","アンチ暗号化タスクによってブロックされたホストを手動でブロック解除して、ネットワークアクセスを復元できます。","ホストをブロック解除するには、次のコマンドを実行します：","kesl-control [-H] --allow-hosts <ホスト>","ここでの <ホスト> は、有効な IPv4 / IPv6 のアドレス（短縮形のアドレスを含む）またはサブネットのリストにすることができます。また、ホストをリストとして指定することもできます。","指定されたホストはブロック解除されます。","例：","IPv4 アドレス：","dec - 192.168.0.1","dec - 192.168.0.0/24","IPv6 アドレス：","hex - FEDC:BA98:7654:3210:FEDC:BA98:7654:3210","hex - FEDC:BA98:7654:3210:FEDC:BA98:7654:3210%1","hex - 2001:db8::ae21:ad12","hex - ::ffff:255.255.255.254","hex - ::"," &#x30D6;&#x30ED;&#x30C3;&#x30AF;&#x3055;&#x308C;&#x308B;&#x30DB;&#x30B9;&#x30C8;&#x3092;&#x8A31;&#x53EF; ","161334.htm");
Page[137]=new Array("Kaspersky Security Network への参加","このセクションでは、Kaspersky Security Network への参加に関する情報、および Kaspersky Security Network の利用を有効または無効にする方法の手順について説明します。","このセクションの内容Kaspersky Security Network への参加についてKaspersky Security Network への参加の有効化または無効化Kaspersky Security Network への接続の確認Kaspersky Security Network を使用した保護の拡張"," Kaspersky Security Network &#x3078;&#x306E;&#x53C2;&#x52A0; ","161355.htm");
Page[138]=new Array("Kaspersky Security Network への参加について","コンピューターをより効果的に保護するために、Kaspersky Endpoint Security は世界中のユーザーから収集したデータを使用します。Kaspersky Security Network は、そのようなデータを収集するために設計されています。","Kaspersky Security Network（KSN）は、ファイルのレピュテーション、Web リソース、ソフトウェアに関する情報を含む Kaspersky Lab ナレッジベースへのオンラインアクセスを提供する、クラウドサービスの基盤です。Kaspersky Security Network のデータを利用することで、Kaspersky Endpoint Security が新しい脅威により迅速に対応できるようになり、いくつかの保護コンポーネントのパフォーマンスが改善され、誤検知の可能性が低くなります。","インフラストラクチャの場所に応じて、グローバル KSN サービス（インフラストラクチャが Kaspersky Lab サーバーにホストされている）とプライベート KSN サービス（インフラストラクチャがインターネットサービスプロバイダーのネットワークなど、サードパーティのサーバーにホストされている）があります。","ライセンスを変更したあと、プライベート KSN を使用できるようにするために、新しいライセンスの詳細をサービスプロバイダーに送信します。そうしないと認証エラーが発生し、プライベート KSN とのデータ交換ができなくなります。","KSN に参加するユーザーのおかげで、カスペルスキーは脅威の種別や発生源に関する情報を迅速に収集し、無害化するための解決策を開発して、製品コンポーネントに表示される誤検知の数を最小限に抑えることができます。","KSN への参加には 2 つの方法があります：","［Kaspersky Security Network (統計情報の送信あり)］ - ナレッジベースから情報を受信できます。本製品の実行中に作成された統計は、本製品によって自動的に KSN に送信されます。また、本製品は、侵入者がコンピューターやデータに損害を与えるために使用する可能性がある特定のファイル（またはファイルの一部）を詳細にスキャンするために Kaspersky Lab へ送信することもできます。［Kaspersky Security Network (統計情報の送信なし)］ - ナレッジベースから情報を受信できます。ただし、本製品は匿名の統計や新型の脅威の種別や発生源に関する情報を送信しません。ただし、個人情報の収集、処理、保存は行われません。KSN への参加中に生成される統計情報の送信についてや、その情報の保存と破棄についての詳細な情報は、Kaspersky Security Network 声明とカスペルスキーの Web サイト（http://www.kaspersky.co.jp/privacy）を参照してください。Kaspersky Security Network 声明が記載されているファイルは、製品の配信キットに含まれています。","Kaspersky Security Center 管理サーバーによって管理されるユーザーのコンピューターは、KSN プロキシサービスを使用して KSN とやり取りすることができます。","KSN プロキシサービスは、次の機能を提供します：","ユーザーのコンピューターがインターネットに直接アクセス指定ない場合でも、KSN に照会したり情報を KSN に送信したりできます。KSN プロキシは処理されたデータをキャッシュするため、外部ネットワークへの接続の負荷を軽減し、ユーザーのコンピューターから要求される情報の取得を高速化します。KSN プロキシサービスの詳細については『Kaspersky Security Center ガイド』を参照してください。","KSN プロキシ設定は、Kaspersky Security Center のポリシーのプロパティで設定できます。","Kaspersky Security Network への参加は任意です。製品のインストール中に、KSN への参加をユーザーに促されます。ユーザーは KSN への参加をいつでも開始または終了することができます。"," Kaspersky Security Network &#x3078;&#x306E;&#x53C2;&#x52A0;&#x306B;&#x3064;&#x3044;&#x3066; ","161356.htm");
Page[139]=new Array("Kaspersky Security Network への参加の有効化または無効化","Kaspersky Security Network の利用を有効にするには、次のいずれかのコマンドを実行します：","Kaspersky Security Network (統計情報の送信あり) の使用を有効にするには、kesl-control --set-app-settings UseKSN=Extended","Kaspersky Security Network (統計情報の送信なし) の使用を有効にするには、kesl-control --set-app-settings UseKSN=Basic","Kaspersky Security Network の利用を無効にするには、次のコマンドを実行します：","kesl-control --set-app-settings UseKSN=No","設定ファイルを使用した Kaspersky Security Network の利用を有効または無効にするには、次のコマンドを実行します：","kesl-control --set-app-settings --file <設定ファイルの名前>","コンピューターにインストールされている Kaspersky Endpoint Security が、Kaspersky Security Center に割り当てられたポリシーに従って動作している場合、UseKSN パラメータの値は Kaspersky Security Center を使用する場合のみ変更することができます。","コンピューターにインストールされている Kaspersky Endpoint Security がポリシーの実行を停止すると、UseKSN=No パラメータ値が設定されます。","Kaspersky Security Network 声明が記載されているファイルは、ディレクトリ /opt/kaspersky/kesl/doc/ksn_license.<言語 ID> にあります。"," Kaspersky Security Network &#x3078;&#x306E;&#x53C2;&#x52A0;&#x306E;&#x6709;&#x52B9;&#x5316;&#x307E;&#x305F;&#x306F;&#x7121;&#x52B9;&#x5316; ","161357.htm");
Page[140]=new Array("Kaspersky Security Network への接続の確認","Kaspersky Security Network への接続をチェックするには、次のコマンドを実行します：","kesl-control --app-info","KSN state の文字列は、Kaspersky Security Network への接続のステータスを表示します：","Extended ステータスが表示されていてる場合、Kaspersky Endpoint Security は Kaspersky Security Network に接続しており、ナレッジベースから情報を受信できます。また、新型の脅威の種別や発生源に関する情報を匿名で送信します。Basic ステータスが表示されている場合、Kaspersky Endpoint Security は Kaspersky Security Network に接続しており、ナレッジベースから情報を受信できます。ただし、新型の脅威の種別や発生源に関する情報は送信しません。Off ステータスが表示されている場合、Kaspersky Endpoint Security は Kaspersky Security Network に接続されていません。Kaspersky Security Network への接続は、以下の理由で確立されないことがあります：","コンピューターがインターネットに接続していない。Kaspersky Security Network に参加していない。製品がアクティベートされていない、またはライセンスの有効期間が終了している。ライセンス関連の問題が検出されている。たとえば、ライセンスがブラックリストに記載されている。"," Kaspersky Security Network &#x3078;&#x306E;&#x63A5;&#x7D9A;&#x306E;&#x78BA;&#x8A8D; ","161358.htm");
Page[141]=new Array("Kaspersky Security Network を使用した保護の拡張","カスペルスキーは、Kaspersky Security Network を通じてユーザーに追加の保護を提供します。この保護方法は、APT 攻撃やゼロデイ攻撃を撃退するために設計されています。クラウド技術の統合と、カスペルスキーのウイルスアナリストの専門知識により、Kaspersky Endpoint Security は非常に高度なネットワークの脅威に対する保護として強力な選択肢となります。","Kaspersky Endpoint Security の強化された保護の詳細については、カスペルスキーの Web サイトを参照してください。"," Kaspersky Security Network &#x3092;&#x4F7F;&#x7528;&#x3057;&#x305F;&#x4FDD;&#x8B77;&#x306E;&#x62E1;&#x5F35; ","161359.htm");
Page[142]=new Array("Kaspersky Endpoint Security のグラフィカルユーザーインターフェイスの使用","このセクションでは、グラフィカルユーザーインターフェイス（GUI）使った Kaspersky Endpoint Security の使用について説明します。","このセクションの内容グラフィカルユーザーインターフェイスのローカルでの有効化または無効化製品のインターフェイスタスクとコンポーネントの管理レポート保管領域にあるオブジェクトの表示トレースファイルの作成"," Kaspersky Endpoint Security &#x306E;&#x30B0;&#x30E9;&#x30D5;&#x30A3;&#x30AB;&#x30EB;&#x30E6;&#x30FC;&#x30B6;&#x30FC;&#x30A4;&#x30F3;&#x30BF;&#x30FC;&#x30D5;&#x30A7;&#x30A4;&#x30B9;&#x306E;&#x4F7F;&#x7528; ","161978.htm");
Page[143]=new Array("グラフィカルユーザーインターフェイスのローカルでの有効化または無効化","Kaspersky Endpoint Security のグラフィカルユーザーインターフェイス（GUI）を、コマンドラインからローカルで有効化または無効化できます。","GUI を有効化または無効化するには、root 権限が必要です。","GUI を有効化または無効化するには：","製品設定スクリプトを実行します：/opt/kaspersky/kesl/bin/kesl-setup.pl –G","コマンドラインで、次のうちいずれかを行います：グラフィカルユーザーインターフェイスを有効にするには、「Y」を押します。GUI を有効化すると、root 権限のないユーザーがオンデマンドスキャンタスクを実行できるようになります。","ユーザーがログインしている場合、必要なライブラリがすべて使用可能であればそのユーザーに対して GUI が起動されます。タスクバーの通知領域に本製品のアイコンが出現し、ショートカットが作成されます。","GUI を無効化したい場合、N キーを押します。本製品はユーザーによる GUI の起動をブロックします。製品アイコンとショートカットが削除されます。"," &#x30B0;&#x30E9;&#x30D5;&#x30A3;&#x30AB;&#x30EB;&#x30E6;&#x30FC;&#x30B6;&#x30FC;&#x30A4;&#x30F3;&#x30BF;&#x30FC;&#x30D5;&#x30A7;&#x30A4;&#x30B9;&#x306E;&#x30ED;&#x30FC;&#x30AB;&#x30EB;&#x3067;&#x306E;&#x6709;&#x52B9;&#x5316;&#x307E;&#x305F;&#x306F;&#x7121;&#x52B9;&#x5316; ","161980.htm");
Page[144]=new Array("製品のインターフェイス","このセクションでは、製品のグラフィカルインターフェイス（GUI）の主要な要素について説明します。"," &#x88FD;&#x54C1;&#x306E;&#x30A4;&#x30F3;&#x30BF;&#x30FC;&#x30D5;&#x30A7;&#x30A4;&#x30B9; ","161988.htm");
Page[145]=new Array("通知領域の製品アイコン","Kaspersky Endpoint Security のグラフィカルユーザーインターフェイが有効になると、本製品のアイコンがタスクバーの右側にある通知領域に出現します。","このアイコンは、コンテキストメニューおよびメインウィンドウへのショートカットとして機能します。","製品アイコンのコンテキストメニューには、次の項目が含まれています：","Kaspersky Endpoint Security 10 SP1 for Linuxメインウィンドウが開きます。製品のメインウィンドウで、コンピュータの保護ステータスおよびオンデマンドスキャンタスクとアップデートタスクの状態を確認できます。また、［レポート］ウィンドウ、［保管領域］ウィンドウ、［設定］ウィンドウおよび［サポート］ウィンドウに移動できます。［終了］：Kaspersky Endpoint Security の GUI を終了します。 通知領域にある本製品のアイコンを右クリックすると、本製品のコンテキストメニューを開けます。"," &#x901A;&#x77E5;&#x9818;&#x57DF;&#x306E;&#x88FD;&#x54C1;&#x30A2;&#x30A4;&#x30B3;&#x30F3; ","161990.htm");
Page[146]=new Array("メインウィンドウ","Kaspersky Endpoint Security のメインウィンドウには、本製品の機能へアクセスするためのインターフェイス要素が含まれます。","メインウィンドウはいくつかのパートに分割されます：","ウィンドウの中央部には、コンピューターの保護ステータスが表示されます。メインウィンドウのこの部分をクリックすると、［プロテクションセンター］ウィンドウが開きます。［スキャン］タブには、オンデマンドスキャンタスクの状態と、検知した脅威の数が表示されます。このタブをクリックすると［スキャン］ウィンドウが開きます。このウィンドウでは、オンデマンドスキャンタスクやブートセクタースキャンタスク、メモリスキャンタスクを開始または停止できます。また、これらのタスクのレポートを表示することもできます。［アップデート］タブには、アップデートタスクと定義データベースの状態が表示されます。このタブをクリックすると［アップデート］ウィンドウが開きます。このウィンドウでは、アップデートタスクやアップデートのコピータスクを開始または停止できます。また、これらのタスクのレポートを表示することもできます。メインウィンドウの下部には、次の要素が含まれています：［レポート］ボタン。このボタンをクリックすると［レポート］ウィンドウが開き、タスクの統計情報などさまざまなレポートを表示できます。［保管領域］ボタン：このボタンをクリックすると［保管領域］ウィンドウが開きます。このウィンドウには、保管領域内のオブジェクトに関する情報が含まれます。［設定］ボタン。このボタンをクリックすると［設定］ウィンドウが開き、Kaspersky Security Network への参加、リアルタイム保護、ファイアウォール、アンチ暗号化、ファイル整合性監視タスクを有効化または無効化できます。［サポート］ボタン：このボタンをクリックすると［サポート］ウィンドウが開きます。このウィンドウでは、Kaspersky Endpoint Security に関する情報（現在のバージョン、ライセンス、ライセンスのステータス、定義データベースの状態、オペレーティングシステムなど）およびカスペルスキー製品の情報源へのリンクが含まれます。Kaspersky Endpoint Security のメインウィンドウを開くには、次のいずれかの操作を実行します：","タスクバーの通知領域にある本製品のアイコンをダブルクリックまたは右クリックします。本製品を右クリックして［Kaspersky Endpoint Security 10 SP 1 for Linux］を選択します。"," &#x30E1;&#x30A4;&#x30F3;&#x30A6;&#x30A3;&#x30F3;&#x30C9;&#x30A6; ","161987.htm");
Page[147]=new Array("タスクとコンポーネントの管理","既定では、Kaspersky Endpoint Security のグラフィカルユーザーインターフェイス（GUI）を使って次のタスクの開始と停止が行えます：","完全スキャンタスク（Scan_My_Computer）オンデマンドスキャンタスク（Scan_File, Boot_Scan, Memory_Scan）アップデートタスク（Update, Rollback, Retranslate）また、Kaspersky Endpoint Security の GUI を使って次のコンポーネントの有効化と無効化が行えます：","リアルタイム保護ファイアウォールアンチ暗号化ファイル整合性監視また、Kaspersky Security Network への参加を管理できます。"," &#x30BF;&#x30B9;&#x30AF;&#x3068;&#x30B3;&#x30F3;&#x30DD;&#x30FC;&#x30CD;&#x30F3;&#x30C8;&#x306E;&#x7BA1;&#x7406; ","165423.htm");
Page[148]=new Array("スキャンタスクの開始と停止","Kaspersky Endpoint Security の GUI を使用して、完全スキャン、オンデマンドスキャンタスク、ブートセクタースキャンタスク、メモリスキャンタスクの開始および停止ができます。","スキャンタスクを開始または停止するには、","メインウィンドウを開きます。メインウィンドウで［スキャン］をクリックして、［スキャン］ウィンドウを開きます。次のいずれかの操作を実行します：タスクを開始するには、開始するタスクの下にある［開始］をクリックします。実行中のタスクの進捗が表示されます。","タスクを停止するには、停止するタスクの下にある［停止］をクリックします。スキャンタスクが停止し、スキャンしたオブジェクトおよび検知された脅威に関する情報が表示されます。","必要に応じて、［レポートの表示］をクリックしてタスクレポートを表示できます。全般設定の［UIReportsForRootOnly］が［No］に設定されている場合のみ、root 権限のないユーザーが［レポート］ウィンドウを使用できます。それ以外の場合、［レポート］ウィンドウを使用できるのはルートユーザーのみです。"," &#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x958B;&#x59CB;&#x3068;&#x505C;&#x6B62; ","161997.htm");
Page[149]=new Array("アップデートタスクの開始と停止","Kaspersky Endpoint Security のグラフィカルユーザーインターフェイスを使用して、アップデートタスク、アップデートのロールバックタスク、およびアップデートのコピータスクを開始または停止できます。","アップデートタスク、またはアップデートのコピータスクを開始または停止するには：","メインウィンドウを開きます。メインウィンドウで［アップデート］をクリックして、［アップデート］ウィンドウを開きます。次のいずれかの操作を実行します：タスクを開始するには、開始するタスクの下にある［開始］をクリックします。実行中のタスクの進捗が表示されます。 ","アップデートタスクが正常に完了したら［アップデートのロールバック］のリンクが使用可能になり、最後に実行したアップデートをロールバックできます。","タスクを停止したい場合は、停止するタスクの下にある［停止］をクリックします。タスクが停止します。","必要に応じて、［レポートの表示］をクリックしてタスクレポートを表示できます。全般設定の［UIReportsForRootOnly］が［No］に設定されている場合のみ、root 権限のないユーザーが［レポート］ウィンドウを使用できます。それ以外の場合、［レポート］ウィンドウを使用できるのはルートユーザーのみです。","アップデートのロールバックタスクを実行するには、","メインウィンドウを開きます。メインウィンドウで［アップデート］をクリックして、［アップデート］ウィンドウを開きます。［アップデート］セクションで［アップデートのロールバック］をクリックして、最後に成功した定義データベースのアップデートにロールバックします。"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x958B;&#x59CB;&#x3068;&#x505C;&#x6B62; ","165426.htm");
Page[150]=new Array("製品コンポーネントの有効化または無効化","Kaspersky Endpoint Security のグラフィカルユーザーインターフェイスを使用して、リアルタイム保護、ファイアウォールマネージャー、アンチクリプター、ファイル変更監視コンポーネントをいつでも有効化または無効化できます。。","コンポーネントを有効にすると、［無効にする］ボタンが使用可能になります。既定では、リアルタイム保護のみが有効になっています。","コンポーネントを無効にすると、［有効］ボタンが使用可能になります。","コンポーネントを有効化または無効化するには、","メインウィンドウを開きます。メインウィンドウの下部で［設定］をクリックします。［設定］ウィンドウが開きます。","［設定］ウィンドウで、目的のコンポーネントに対して次の操作を実行します：コンポーネントを有効にするには、［有効］をクリックします。コンポーネントを無効にするには、［無効にする］をクリックします。"," &#x88FD;&#x54C1;&#x30B3;&#x30F3;&#x30DD;&#x30FC;&#x30CD;&#x30F3;&#x30C8;&#x306E;&#x6709;&#x52B9;&#x5316;&#x307E;&#x305F;&#x306F;&#x7121;&#x52B9;&#x5316; ","162000.htm");
Page[151]=new Array("Kaspersky Security Network への参加の管理","Kaspersky Security Network への参加はいつでも変更できます。","Kaspersky Security Network を有効化するには：","メインウィンドウを開きます。メインウィンドウの下部で［設定］をクリックします。［設定］ウィンドウが開きます。","［設定］ウィンドウで、次のいずれかのオプションを選択します：［Kaspersky Security Network (統計情報の送信あり)］- Kaspersky Security Network を有効にし、ナレッジベースから情報を受信します。また、新型の脅威や発生源に関する情報を匿名で送信します。［Kaspersky Security Network (統計情報の送信なし)］- ナレッジベースから情報を受信します。ただし、新型の脅威の種別や発生源に関する情報は送信しません。［有効にする］をクリックします。［Kaspersky Security Network への参加］ウィンドウで、Kaspersky Security Network に関する声明を注意深くお読みください。その後で次のいずれかのオプションを選択します：［この KSN の条項をすべて読み、理解した上で同意する］ - Kaspersky Security Network を有効にするには、このオプションを選択します。［Kaspersky Security Network の諸条件に同意しない］ - Kaspersky Security Network の使用を無効にするには、このオプションを選択します。［OK］をクリックします。［選択されていません］が選択さている場合、［OK］は使用できません。","Kaspersky Security Network を無効化するには：","メインウィンドウを開きます。メインウィンドウの下部で［設定］をクリックします。［設定］ウィンドウが開きます。","［設定］ウィンドウで、［無効にする］をクリックします。開いたウィンドウで、次のいずれかを行います：Kaspersky Security Network の無効化を確定するには［はい］をクリックします。Kaspersky Security Network へ引き続き参加するには［キャンセル］をクリックします。"," Kaspersky Security Network &#x3078;&#x306E;&#x53C2;&#x52A0;&#x306E;&#x7BA1;&#x7406; ","165428.htm");
Page[152]=new Array("レポート","このセクションでは、Kaspersky Endpoint Security のグラフィカルユーザーインターフェイスでレポートを表示する方法について説明します。"," &#x30EC;&#x30DD;&#x30FC;&#x30C8; ","161993.htm");
Page[153]=new Array("レポート管理の原則","全般設定の［UIReportsForRootOnly］が［No］に設定されている場合のみ、root 権限のないユーザーが［レポート］ウィンドウを使用できます。それ以外の場合、［レポート］ウィンドウを使用できるのはルートユーザーのみです。","Kaspersky Endpoint Security のタスクのパフォーマンスに関する情報は、レポートに記録されます。","レポートデータは表形式で、イベントの一覧が含まれます。表の各行ごとに異なるイベントに関する情報が含まれます。イベントの属性は表の各列にあります。各タスクの実行中に記録されたイベントは、属性のセットがそれぞれ異なります。","左側のメニューに表示される次のレポートが利用可能です：","［統計情報］：リアルタイム保護およびオンデマンドスキャンのタスクに関する統計情報が含まれます。［再読み込み］をクリックすると、表示されているレポートを更新できます。リアルタイム保護タスクが停止されると、タスクの統計情報がリセットされます。オンデマンドスキャンタスクの統計情報はリセットされません。本製品がコンピューターにインストールされている間、統計情報は増加していきます。","［システム監査］：このレポートには、ユーザーと製品とのやり取りで発生するイベントに関する情報が含まれています。また、製品の一般的な操作で発生するイベントに関する情報も含まれます。［脅威からの保護］：Kaspersky Endpoint Security の次の機能が実行されている間に記録されたイベントに関する情報が含まれます。アンチ暗号化ファイル整合性監視ファイアウォールファイルアンチウイルス［オンデマンドタスク］：Kaspersky Endpoint Security の次のタスクが実行されている間に記録されたイベントに関する情報が含まれます。スキャンタスクアップデート整合性チェックレポートでは、以下のイベント重要度が使用されます：","［情報イベント］：通常は重要な情報が含まれない形式的なイベントです。［重要イベント］：Kaspersky Endpoint Security の動作の重要な状況が反映されているため、注意が必要なイベントです。［緊急イベント］：Kaspersky Endpoint Security の動作の問題や、ユーザーのコンピューターの保護の脆弱性を示す、極めて重要なイベントです。レポートを効果的に処理するため、画面上のデータ表示を次のように変更できます：","イベントリストを時間でフィルタリングする。特定のイベントを見付けるため検索機能を使用する。選択したイベントを別のセクションで表示する。"," &#x30EC;&#x30DD;&#x30FC;&#x30C8;&#x7BA1;&#x7406;&#x306E;&#x539F;&#x5247; ","161992.htm");
Page[154]=new Array("レポートの表示","全般設定の［UIReportsForRootOnly］が［No］に設定されている場合のみ、root 権限のないユーザーが［レポート］ウィンドウを使用できます。それ以外の場合、［レポート］ウィンドウを使用できるのはルートユーザーのみです。","レポートを表示するには：","メインウィンドウを開きます。メインウィンドウの下部にある［レポート］をクリックします。［レポート］ウィンドウが開きます。","特定のレポートを表示するには、［レポート］ウィンドウ左側のタスクのリストから目的のタスクを選択します。ウィンドウの右側に、選択した Kaspersky Endpoint Security のタスクの動作中に発生したイベントのリストが含まれたレポートが表示されます。","初期設定ではイベントは［日付］列の値で昇順にソートされています。ソート時に優先したい列のヘッダーをクリックして並びを変更できます。","レポート内のそれぞれのイベントに関する詳細なサマリーを確認するには、レポートで関連するイベントを選択します。ウィンドウの下部に、イベントサマリーが表示されます。"," &#x30EC;&#x30DD;&#x30FC;&#x30C8;&#x306E;&#x8868;&#x793A; ","161994.htm");
Page[155]=new Array("保管領域にあるオブジェクトの表示","Kaspersky Endpoint Security が保管領域に移動したオブジェクトを表示するには：","メインウィンドウを開きます。［保管領域］をクリックします。開いたウィンドウに、保管領域内のオブジェクトに関する情報が表示されます。","保管領域内のオブジェクトに関する次の情報を表示できます：","脅威の名前。オブジェクトの絶対パス。オブジェクトが保管領域に移動された日付。オブジェクトが保管領域から削除される日付。このフィールドは、［DaysToLive］設定が指定されている場合に表示されます。オブジェクトのサイズ。オブジェクトは保管領域から元のディレクトリに復元できます。また、オブジェクトは保管領域から削除できます。削除されたオブジェクトをその後で復元することはできません。これらの操作に関する情報はイベントログに記録されます。 "," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x306B;&#x3042;&#x308B;&#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x306E;&#x8868;&#x793A; ","161999.htm");
Page[156]=new Array("トレースファイルの作成","トレースファイルを作成するには：","メインウィンドウを開きます。［サポート］をクリックします。［サポート］ウィンドウで、［トレース中］をクリックします。［レベル］ドロップダウンリストで、トレースレベルを選択します。テクニカルサポートの担当者に聞いたトレースレベルを指定してください。既定では、トレースレベルは［診断（300）］に設定されています。","トレース処理を開始するには、［有効］をクリックします。トレース処理を停止するには、［無効］をクリックします。作成されたトレースファイルは /var/log/kaspersky/kesl/ ディレクトリに保存されます。"," &#x30C8;&#x30EC;&#x30FC;&#x30B9;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x306E;&#x4F5C;&#x6210; ","166209.htm");
Page[157]=new Array("テクニカルサポートへのお問い合わせ","このセクションでは、テクニカルサポートのご利用方法とご利用条件について説明します。","このセクションの内容テクニカルサポートのご利用方法お電話でのお問い合わせカスペルスキーカンパニーアカウントによるテクニカルサポートトレースファイルと AVZ スクリプトの使用"," &#x30C6;&#x30AF;&#x30CB;&#x30AB;&#x30EB;&#x30B5;&#x30DD;&#x30FC;&#x30C8;&#x3078;&#x306E;&#x304A;&#x554F;&#x3044;&#x5408;&#x308F;&#x305B; ","70331.htm");
Page[158]=new Array("テクニカルサポートのご利用方法","製品のガイドや製品に関する情報源で問題の解決策が見つからなかった場合は、カスペルスキーのテクニカルサポートにお問い合わせください。テクニカルサポートの担当者が、製品のインストール方法または使用方法についての質問にお答えします。","テクニカルサポートに問い合わせる前に、サポートのルールをお読みください。","テクニカルサポートに問い合わせるには、次のいずれかの方法があります：","電話：ロシア語または国際テクニカルサポートの担当者に相談ができます。マイカスペルスキーポータルからリクエストを送信する：問い合わせフォームから担当者に問い合わせができます。テクニカルサポートは製品のライセンスを購入したユーザーのみ利用できます。テクニカルサポートは試用版のユーザーに提供されません。"," &#x30C6;&#x30AF;&#x30CB;&#x30AB;&#x30EB;&#x30B5;&#x30DD;&#x30FC;&#x30C8;&#x306E;&#x3054;&#x5229;&#x7528;&#x65B9;&#x6CD5; ","85903.htm");
Page[159]=new Array("お電話でのお問い合わせ","世界中のほぼすべての地域から、お電話でテクニカルサポートへお問い合わせいただくことができます。お住まいの地域でテクニカルサポートをご利用いただく方法とお問い合わせ先については、カスペルスキーのテクニカルサポートの Web サイトを参照してください。","テクニカルサポートに問い合わせる前に、サポートのルールをお読みください。"," &#x304A;&#x96FB;&#x8A71;&#x3067;&#x306E;&#x304A;&#x554F;&#x3044;&#x5408;&#x308F;&#x305B; ","70152.htm");
Page[160]=new Array("カスペルスキーカンパニーアカウントによるテクニカルサポート","カスペルスキーカンパニーアカウントは、カスペルスキー製品を使用する企業のためのポータルです。カスペルスキーカンパニーアカウントのポータルは、オンラインリクエストを経由して容易にユーザーと Kaspersky Lab 間のやり取りができるよう設計されています。カスペルスキーカンパニーアカウントを使用して、オンラインリクエストのステータスを追跡し、その履歴を保存できます。","組織内のすべての従業員をカスペルスキーカンパニーアカウントの 1 つのアカウントに登録することができます。1 つのカンパニーアカウントで、登録済みユーザーから Kaspersky Lab へのオンラインリクエストを一元的に管理することに加えて、カスペルスキーカンパニーアカウント経由でこのようなユーザーの権限を管理することもできます。","カスペルスキーカンパニーアカウントのポータルは、次の言語で利用できます：","英語スペイン語イタリア語ドイツ語ポーランド語ポルトガル語ロシア語フランス語日本語カスペルスキーカンパニーアカウントの詳細については、テクニカルサポートサイトを参照してください。"," &#x30AB;&#x30B9;&#x30DA;&#x30EB;&#x30B9;&#x30AD;&#x30FC;&#x30AB;&#x30F3;&#x30D1;&#x30CB;&#x30FC;&#x30A2;&#x30AB;&#x30A6;&#x30F3;&#x30C8;&#x306B;&#x3088;&#x308B;&#x30C6;&#x30AF;&#x30CB;&#x30AB;&#x30EB;&#x30B5;&#x30DD;&#x30FC;&#x30C8; ","68417.htm");
Page[161]=new Array("トレースファイルと AVZ スクリプトの使用","カスペルスキーのテクニカルサポートへ問題を報告すると、Kaspersky Endpoint Security の動作に関する情報を含むレポートを作成し、テクニカルサポートへ提出するよう依頼される場合があります。また、テクニカルサポートからトレースファイルの作成も依頼される場合があります。トレースファイルを使用すると、製品コマンドの実行を各ステップごとに検証し、エラーがいつ発生したのかを特定することができます。","お客様から提供されたデータの検証後、テクニカルサポートは AVZ スクリプトを作成し、お客様に送信します。AVZ スクリプトを実行すると、脅威に対して有効なプロセスの分析、コンピューターのスキャン、感染したファイルの駆除または削除、およびシステムスキャンレポートの作成が行えます。"," &#x30C8;&#x30EC;&#x30FC;&#x30B9;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x3068; AVZ &#x30B9;&#x30AF;&#x30EA;&#x30D7;&#x30C8;&#x306E;&#x4F7F;&#x7528; ","73375.htm");
Page[162]=new Array("付録","このセクションでは、ガイドの主なテキストの補足情報を説明します。","このセクションの内容既定のタスクの設定ファイルコラボレーションの設定：Kaspersky Anti-Virus for Linux Mail Serverコマンドラインの戻りコード"," &#x4ED8;&#x9332; ","161364.htm");
Page[163]=new Array("既定のタスクの設定ファイル","このセクションでは、Kaspersky Endpoint Security タスクの既定の設定ファイルについて説明します。","設定ファイルはいつでも変更できます。また、コマンドラインから設定値を変更することもできます。"," &#x65E2;&#x5B9A;&#x306E;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161365.htm");
Page[164]=new Array("Kaspersky Endpoint Security の設定ファイル編集のルール","設定ファイルを編集する場合は、次のルールを順守してください：","設定ファイル内の設定必須の項目はすべて指定する必要があります。コマンドラインを使用することで、個別のタスクの設定をファイルなしで指定できます。パラメータが特定のセクションに属している場合は、そのセクションのみに配置されます。1 つのセクションの範囲内で、設定項目を任意の順序で配置できます。セクションの名前は角括弧 [ ] で囲みます。パラメータ値を「パラメータ名=値」の形式で入力します（パラメータ名とその値の間のスペースは処理されません）。","例：","[ScanScope.item_0000]","AreaDesc=Home","AreaMask.item_0000=*doc","Path=/home","空白文字とタブ文字は、文字列値の最初の引用符の前と最後の引用符の後、および引用符で囲まれていない文字列値の最初と最後は無視されます。","パラメータに対していくつかの値を指定する必要がある場合は、指定する値の数と同じ数だけパラメータを繰り返します。","例：","AreaMask.item_0000=*xml","AreaMask.item_0001=*doc","次の種別のパラメータの値を入力するときは、大文字と小文字を区別します：スキャン済みのオブジェクトと除外されるオブジェクトの名前（マスク）。脅威の名前（マスク）。残りのパラメータ値は大文字と小文字が区別されません。","ブール型のパラメータ値は次のように指定します：Yes - No。空白文字を含む文字列値は引用符で囲みます（例：ファイル名、ディレクトリ名、パス名、YYYY-MM-DD HH:MM:SS 形式の日時を含む表現など）。それ以外の値は引用符の有無に関係なく入力できます。","例：","AreaDesc=\"Scan mail databases\"","文字列の最初または最後の一重引用符は、エラーとみなされます。"," Kaspersky Endpoint Security &#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x7DE8;&#x96C6;&#x306E;&#x30EB;&#x30FC;&#x30EB; ","161266.htm");
Page[165]=new Array("リアルタイム保護タスクの設定ファイル","ScanArchived=No","ScanSfxArchived=No","ScanMailBases=No","ScanPlainMail=No","TimeLimit=60","SizeLimit=0","FirstAction=Recommended","SecondAction=Block","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","ScanByAccessType=SmartCheck","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," &#x30EA;&#x30A2;&#x30EB;&#x30BF;&#x30A4;&#x30E0;&#x4FDD;&#x8B77;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161366.htm");
Page[166]=new Array("オンデマンドスキャンタスクの設定ファイル","ScanArchived=Yes","ScanSfxArchived=Yes","ScanMailBases=No","ScanPlainMail=No","TimeLimit=0","SizeLimit=0","FirstAction=Recommended","SecondAction=Skip","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," &#x30AA;&#x30F3;&#x30C7;&#x30DE;&#x30F3;&#x30C9;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161367.htm");
Page[167]=new Array("オブジェクトスキャンタスクの設定ファイル","ScanArchived=Yes","ScanSfxArchived=Yes","ScanMailBases=No","ScanPlainMail=No","TimeLimit=0","SizeLimit=0","FirstAction=Recommended","SecondAction=Skip","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportPackedObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","UseIChecker=Yes","[ScanScope.item_0000]","AreaDesc=All objects","UseScanArea=Yes","Path=/","AreaMask.item_0000=*"," &#x30AA;&#x30D6;&#x30B8;&#x30A7;&#x30AF;&#x30C8;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161368.htm");
Page[168]=new Array("ブートセクタースキャンタスクの設定ファイル","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportUnprocessedObjects=No","UseAnalyzer=Yes","HeuristicLevel=Recommended","Action=Cure"," &#x30D6;&#x30FC;&#x30C8;&#x30BB;&#x30AF;&#x30BF;&#x30FC;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161369.htm");
Page[169]=new Array("メモリスキャンタスクの設定ファイル","UseExcludeMasks=No","UseExcludeThreats=No","ReportCleanObjects=No","ReportUnprocessedObjects=No","Action=Cure"," &#x30E1;&#x30E2;&#x30EA;&#x30B9;&#x30AD;&#x30E3;&#x30F3;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161370.htm");
Page[170]=new Array("アップデートタスクの設定ファイル","SourceType=\"KLServers\"","UseKLServersWhenUnavailable=Yes","IgnoreProxySettingsForKLServers=No","IgnoreProxySettingsForCustomSources=No","ApplicationUpdateMode=DownloadOnly","ConnectionTimeout=10"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161371.htm");
Page[171]=new Array("アップデートの再変換タスクの設定ファイル","SourceType=KLServers","UseKLServersWhenUnavailable=Yes","ConnectionTimeout=10","ApplicationUpdateMode=DownloadOnly"," &#x30A2;&#x30C3;&#x30D7;&#x30C7;&#x30FC;&#x30C8;&#x306E;&#x518D;&#x5909;&#x63DB;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161372.htm");
Page[172]=new Array("保管領域の管理タスクの設定ファイル","DaysToLive=90","BackupSizeLimit=0","BackupFolder=/var/opt/kaspersky/kesl/common/objects-backup/"," &#x4FDD;&#x7BA1;&#x9818;&#x57DF;&#x306E;&#x7BA1;&#x7406;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161373.htm");
Page[173]=new Array("ファイアウォールマネージャータスクの設定ファイル","DefaultIncomingAction=Allow","DefaultIncomingPacketAction=Allow","[NetworkZonesTrusted]","[NetworkZonesLocal]","[NetworkZonesPublic]"," &#x30D5;&#x30A1;&#x30A4;&#x30A2;&#x30A6;&#x30A9;&#x30FC;&#x30EB;&#x30DE;&#x30CD;&#x30FC;&#x30B8;&#x30E3;&#x30FC;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161374.htm");
Page[174]=new Array("ファイル変更監視タスクの設定ファイル","UseExcludeMasks=No","[ScanScope.item_0000]","AreaDesc=Kaspersky internal objects","UseScanArea=Yes","Path=/opt/kaspersky/kesl/","AreaMask.item_0000=*"," &#x30D5;&#x30A1;&#x30A4;&#x30EB;&#x5909;&#x66F4;&#x76E3;&#x8996;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161375.htm");
Page[175]=new Array("アンチクリプタータスクの設定ファイル","UseHostBlocker=yes","BlockTime=30","UseExcludeMasks=no","[ScanScope.item_0000]","AreaDesc=AllSharedFolders","UseScanArea=yes","Path=AllShared","AreaMask.item_0000=*"," &#x30A2;&#x30F3;&#x30C1;&#x30AF;&#x30EA;&#x30D7;&#x30BF;&#x30FC;&#x30BF;&#x30B9;&#x30AF;&#x306E;&#x8A2D;&#x5B9A;&#x30D5;&#x30A1;&#x30A4;&#x30EB; ","161376.htm");
Page[176]=new Array("コラボレーションの設定：Kaspersky Anti-Virus for Linux Mail Server","Kaspersky Endpoint Security 10 と Kaspersky Anti-Virus for Linux Mail Server の共同作業を設定するには：","次のコマンドを使用して、リアルタイム保護タスクの設定を設定ファイルに保存します：kesl-control --get-settings 1 --file <ファイルの絶対パス>","作成した設定ファイルを編集のために開きます。作成したファイルに次のセクションを追加します：[ExcludedFromScanScope.item_#]","Path=</var/opt/kaspersky/klms>","Kaspersky Anti-Virus for Linux Mail Server と統合されているすべてのメールエージェントについて、前述の手順で指定したセクションを繰り返します。Kaspersky Anti-Virus for Linux Mail Server のフィルターおよびサービスの一時ディレクトリをスキャンから除外するには、作成したファイルに次のセクションを追加します：[ExcludedFromScanScope.item_#]","Path=/tmp/klmstmp","変更内容を設定ファイルに保存します。次のコマンドを使用して設定ファイルからリアルタイム保護タスクに設定を読み込みます：kesl-control --set-settings 1 --file <ファイルの絶対パス>"," &#x30B3;&#x30E9;&#x30DC;&#x30EC;&#x30FC;&#x30B7;&#x30E7;&#x30F3;&#x306E;&#x8A2D;&#x5B9A;&#xFF1A;Kaspersky Anti-Virus for Linux Mail Server ","161377.htm");
Page[177]=new Array("コマンドラインの戻りコード","このセクションでは、コマンドラインの戻りコードについて説明します。","0 - コマンド / タスクが正常に完了しました。","1 - コマンド引数の一般的なエラー。","2 - 渡された製品設定のエラー。","64 - Kaspersky Endpoint Security が動作していません。","66 - 定義データベースがダウンロードされていません（コマンド --app-info でのみ使用）。","67 - ネットワークの問題のため、アクティベーション 2.0 がエラーで終了しました。","68 - 製品がポリシーに従って動作しているため、コマンドを実行できません。","128 - 不明なエラー。","65 - その他のすべてのエラー。"," &#x30B3;&#x30DE;&#x30F3;&#x30C9;&#x30E9;&#x30A4;&#x30F3;&#x306E;&#x623B;&#x308A;&#x30B3;&#x30FC;&#x30C9; ","161378.htm");
Page[178]=new Array("AO Kaspersky Lab","Kaspersky Lab は、ウイルス、マルウェア、未承諾メール（スパム）、ネットワーク攻撃、ハッカー攻撃などの脅威からコンピューターを保護するシステムの開発企業として、世界各国で高く評価されています。","2008 年、Kaspersky Lab は、エンドユーザー向け情報セキュリティソフトウェアのソリューション開発企業として、世界第 4 位に選ばれました（2008 年 IDC 『Worldwide Endpoint Security Revenue by Vendor』）。また、コンピューター保護システムの開発企業としてロシアの個人ユーザーから高い支持を受けています（『IDC Endpoint Tracker 2014』）。","Kaspersky Lab は、1997 年にロシアで設立され、現在、33 か国に 38 の事業所を有する国際的な企業グループとなっています。3,000 名を超える有資格スペシャリストが働いています。","製品：Kaspersky Lab の製品は、家庭用 PC から大規模な企業ネットワークに至るまで、すべてのシステムを保護します。","個人向け製品では、デスクトップ PC、ノート PC、タブレット、スマートフォンなどのモバイル端末を含む、最新のあらゆる端末に対応するセキュリティ製品を提供しています。","また、ワークステーションやモバイル端末、仮想マシン、ファイルサーバー、Web サーバー、メールゲートウェイ、ファイアウォールなどのソリューションやテクノロジーに対する保護と管理を提供しています。さらに、DDoS 攻撃に対する保護、産業用制御システムの保護、金銭をねらう詐欺の防止に特化した製品も提供しています。これらの製品を Kaspersky Lab の一元管理システムで管理することにより、コンピューターに対する脅威からあらゆる規模の企業や組織を効率的に自動で保護するソリューションを実現しています。Kaspersky Lab の製品は主要な検査機関で認定されており、多数のアプリケーション開発元の製品と互換性があります。また、多くのハードウェアプラットフォーム向けに動作が最適化されています。","Kaspersky Lab のウイルスアナリストは 24 時間体制で活動しており、毎日発生する膨大な数のコンピューターの脅威を見つけ出し、駆除ツールを作成し、それらの脅威のシグネチャを Kaspersky Lab 製品で使用する定義データベースに登録しています。","技術：現在のアンチウイルスツールに不可欠な技術の多くは、Kaspersky Lab が最初に開発したものです。そのため、多くの開発企業が自社製品に Kaspersky Anti-Virus のエンジンを使用しています。例として、Alcatel-Lucent、Alt-N、Asus、BAE Systems、Blue Coat、Check Point、Cisco Meraki、Clearswift、D-Link、Facebook、General Dynamics、H3C、Juniper Networks、Lenovo、Microsoft、NETGEAR、Openwave Messaging、Parallels、Qualcomm、Samsung、Stormshield、Toshiba、Trustwave、Vertu、ZyXEL などが挙げられます。また、Kaspersky Lab の革新的な技術の多くは特許を受けています。","成果：長年にわたって、Kaspersky Lab はコンピューターに対する脅威に対抗する上で果たした貢献が評価され、数々の賞を受賞しております。2014 年には、定評あるオーストリアの検査機関 AV-Comparatives が実施するテストと調査で、Advanced+ 評価の数で上位 2 社のうちの 1 社となり、最高位となる Top Rated の評価を受けました。しかし、最も大きな成果は、世界各国のユーザーの信頼を獲得したことと言ってよいでしょう。Kaspersky Lab の製品と技術は、4 億人を超えるユーザーおよび 27 万社を超える法人の顧客を保護しています。"," ","Kaspersky Lab の Web サイト：","http://www.kaspersky.co.jp ","ウイルス百科事典（英語）：","https://securelist.com ","ウイルスラボ：","https://virusdesk.kaspersky.co.jp（疑わしいファイルと Web サイトの分析）","Kaspersky Lab の Web フォーラム：","https://forum.kaspersky.com "," "," AO Kaspersky Lab ","34744.htm");
Page[179]=new Array("サードパーティ製のコードに関する情報","サードパーティ製コードに関する情報は、製品のインストールディレクトリにある legal_notices.txt ファイルに記載されています。"," &#x30B5;&#x30FC;&#x30C9;&#x30D1;&#x30FC;&#x30C6;&#x30A3;&#x88FD;&#x306E;&#x30B3;&#x30FC;&#x30C9;&#x306B;&#x95A2;&#x3059;&#x308B;&#x60C5;&#x5831; ","161380.htm");
Page[180]=new Array("商標に関する通知","登録商標およびサービスマークは、それぞれ対応する所有者の所有財産です。","Core は、米国およびその他の国における Intel Corporation の商標です。","Linux は、米国およびその他の国における Linus Torvalds の商標です。","Microsoft、Outlook、Outlook Express、および Windows は、米国およびその他の国における Microsoft Corporation の商標または登録商標です。","Novell は、米国およびその他の国における Novell Inc. の登録商標です。","Oracle は、 Oracle および関連会社の登録商標です。","Red Hat、Red Hat Enterprise Linux、および CentOS は、米国およびその他の国における Red Hat Inc. の登録商標です。","Debian は、Software in the Public Interest, Inc. の登録商標です。","SUSE は、米国およびその他の国における SUSE LLC の登録商標です。"," &#x5546;&#x6A19;&#x306B;&#x95A2;&#x3059;&#x308B;&#x901A;&#x77E5; ","161381.htm");
Page[181]=new Array("Kaspersky Endpoint Security のライセンスの購入時に受け取るコード本製品のアクティベーションにはこのコードが必要です。","アクティベーションコードは、「XXXXX-XXXXX-XXXXX-XXXXX」形式の 20 桁の英数字の一意の並びです。","アクティベーションコード","95897.htm#o112627");
Page[182]=new Array("製品が現在使用しているライセンス。","現在のライセンス","95897.htm#o111595");
Page[183]=new Array("製品を使用する権限を認定する、現在使用されていないライセンス。","予備のライセンス","95897.htm#o111599");
Page[184]=new Array("インストールされているカスペルスキー製品の共通の機能と共通の設定を共有するコンピューターのグループ。コンピューターは管理しやすいように、1 つのユニットとしてグループにまとめられます。グループに他のグループを含めることができます。グループ内のインストールされている各製品に対してグループポリシーとグループタスクを作成することができます。","管理グループ","95897.htm#o112575");
Page[185]=new Array("企業ネットワークにインストールされているすべてのカスペルスキー製品に関する情報を一元的に保管する Kaspersky Security Center のコンポーネント。また、これらの製品を管理するために使用することもできます。","管理サーバー","95897.htm#o112576");
Page[186]=new Array("定義データベースの公開日時現在で Kaspersky Lab が把握しているコンピューターセキュリティの脅威に関する情報の入ったデータベース。定義データベースの内容を使用して、スキャンしたオブジェクトに含まれる悪意のあるコードを検知します。Kaspersky Lab のスペシャリストにより作成され、毎時アップデートされます。","定義データベース","95897.htm#o111582");
Page[187]=new Array("管理コンソールを使用した製品管理のためのインターフェイスを提供する特別なコンポーネント。各製品には固有のプラグインが存在します。Kaspersky Endpoint Security を使用して管理できるすべてのカスペルスキー製品に含まれています。","製品管理プラグイン","95897.htm#o112588");
Page[188]=new Array("ファイルのバックアップコピーのための特別な保管領域。バックアップコピーは、駆除または削除を行う前に作成されます。","バックアップ","95897.htm#o112592");
Page[189]=new Array("感染しているオブジェクトの処理方法のひとつ。駆除の結果、データが完全に復元するかまたは部分的に復元します。感染したすべてのオブジェクトを駆除できるわけではありません。","駆除","95897.htm#o112629");
Page[190]=new Array("除外はカスペルスキー製品によるスキャンから除外されるオブジェクトを指します。特定の形式のファイル、ファイルマスク、特定のエリア（フォルダーやプログラムなど）、アプリケーションプロセス、またはオブジェクトを、ウイルス百科事典の分類に基づいて決定された脅威の種別によってスキャンから除外することができます。それぞれのタスクに除外のセットを割り当てることができます。","信頼するオブジェクト","95897.htm#o112624");
Page[191]=new Array("感染していないオブジェクトがウイルスのコードに似たコードを持っているために、誤って感染したオブジェクトとして分類されること。","誤検知","95897.htm#o112631");
Page[192]=new Array("ワイルドカードを使用したファイル名の表示。ファイル名マスクで使用される標準的なワイルドカードは「*」と「?」です。「*」は任意の文字数の文字列を表し、「?」は任意の 1 文字を表します。","ファイルマスク","95897.htm#o111603");
Page[193]=new Array("管理グループに対して定義され、その管理グループ内のすべてのクライアントデバイスで実行されるタスク。","グループタスク","95897.htm#o112572");
Page[194]=new Array("ファイルの構造または形式により、侵入者が悪意のあるコードを保存して拡散させるための「コンテナー」として使用できるオブジェクト。一般的には、com、exe、dll などの拡張子を持つ実行ファイルです。これらは、悪意のあるコードが侵入する危険性がかなり高いファイルです。","感染源となる可能性のあるオブジェクト","95897.htm#o112644");
Page[195]=new Array("既知の悪意のあるソフトウェアのコードの一部と完全に一致するコードを含むオブジェクト。Kaspersky Lab では、このようなオブジェクトにアクセスすることを推奨していません。","感染したオブジェクト","95897.htm#o112621");
Page[196]=new Array("Kaspersky Lab の HTTP および FTP サーバーの一覧。本製品はこれらのサーバーから定義データベースのアップデートをモバイル端末へダウンロードします。","Kaspersky Lab のアップデートサーバー","95897.htm#o112658");
Page[197]=new Array("使用許諾契約書に基づいて提供される、製品を使用する期限付きの権利。","ライセンス","95897.htm#o135751");
Page[198]=new Array("ライセンス情報ファイルまたはアクティベーションコードとともに、Kaspersky Lab からユーザーに提供される文書。ユーザーに提供されたライセンスに関する情報が記載されています。","ライセンス証明書","95897.htm#o166042");
Page[199]=new Array("ポリシーは、アプリケーションの設定を決定し、管理グループ内のコンピューターにインストールされたアプリケーションの設定へのアクセスを管理します。各アプリケーションに対して個別のポリシーを作成する必要があります。各管理グループのコンピューターにインストールされたアプリケーションに対して作成できるポリシーの数に制限はありませんが、管理グループ内の各アプリケーションに対して一度に適用できるポリシーは 1 つだけです。","ポリシー","95897.htm#o111585");
Page[200]=new Array("あらゆる種別のタスクに共通し、アプリケーションの動作全体を管理するアプリケーション設定（アプリケーションパフォーマンス設定、レポート設定、バックアップ設定など）。","アプリケーションの設定","95897.htm#o112587");
Page[201]=new Array("ユーザーが他のネットワークサービスへ間接的なリクエストを行えるようにするコンピューターネットワークのサービス。ユーザーは最初にプロキシサーバーへ接続し、他のサーバー上にある特定のリソース（ファイルなど）をリクエストします。次に、プロキシサーバーは指定されたサーバーに接続しリソースを取得するか、自身のキャッシュからリソースを返します（プロキシサーバーが自身のキャッシュを持っている場合）。場合によっては、プロキシサーバーがユーザーのリクエストやサーバーの応答を修正する場合があります。","プロキシサーバー","95897.htm#o112649");
Page[202]=new Array("オブジェクト内の悪意のあるコードの有無をリアルタイムでスキャンする本製品の動作モード。","あらゆるオブジェクトを開こうとするすべての試行（読み取り、書き込み、または実行）を監視し、脅威がないかオブジェクトをスキャンします。感染していないオブジェクトはユーザーに渡されます。脅威を含むオブジェクトまたは感染している可能性のあるオブジェクトは、タスク設定に従って処理されます（駆除、削除、または隔離）。","リアルタイム保護 ","95897.htm#o112643");
Page[203]=new Array("選択したパラメータ（有効期限と端末数）内での本製品の使用を可能にします。定額制サービスは停止、再開、自動更新、およびキャンセルすることができます。","定額制サービス","95897.htm#o142586");
Page[204]=new Array("カスペルスキー製品によって実行される機能は、タスクとして実装されます。例：ファイルのリアルタイム保護、コンピューターの完全スキャン、定義データベースのアップデート。","タスク","95897.htm#o112579");
Page[205]=new Array("任意の管理グループのクライアントコンピューターのセットに割り当てられたタスク、およびこれらのホストで実行されたタスク。","特定のコンピューターに対するタスク","95897.htm#o112571");
Page[206]=new Array("各種のタスクに固有の製品設定。","タスク設定","95897.htm#o112586");
Page[207]=new Array("コンピューターの保護を最新の状態に保つために Kaspersky Lab 製品によって実行される機能。アップデート中、アプリケーションはそれぞれのデータベースからアップデートをダウンロードし、Kaspersky Lab のアップデートサーバーからモジュールをダウンロードします。また、これらを自動的にインストールし適用します。","アップデート","95897.htm#o111604");
var PageCount=208;
var parsedMainTitle = 'Kaspersky Endpoint Security 10 Service Pack 1 for Linux ';
(function () {
    var maxTextLength = 0;
    var fakeDiv = $('<div/>');
    var text;
    var pageSearch = _.map(Page, function (page) {
        return {
            link: page[page.length - 1],
            title: page[page.length - 2],
            text: _.map(page.slice(0, page.length - 2), function(item) {
                text = fakeDiv.html(item).text();
                maxTextLength = Math.max(maxTextLength, text.length);

                return text;
            })
        };
    });

    fakeDiv.remove();

    window.search = function (searchWord, searchWordMinLength) {
        //console.time('search');
        var result = {
            found: false,
            isInit: false,
            results: [],
            resultsCount: 0
        };

        if (searchWord !== '') {
            result.searchWord = searchWord;

            var searchLength = searchWord.length > 5 ? searchWord.length - 2 : searchWordMinLength;

            var fuseOptions = {
                //verbose: true,
                shouldSort: true,
                includeScore: true,
                includeMatches: true,
                minMatchCharLength: searchLength,
                tokenize: true,
                matchAllTokens: true,
                findAllMatches: true,
                threshold: 0.2,
                location: 0,
                distance: maxTextLength,
                keys: ['text', 'title']
            };

            var fuse = new Fuse(pageSearch, fuseOptions);
            var currentResults = fuse.search(searchWord);
            var searchRegExp = new RegExp(searchWord, 'gi');

            if (currentResults.length) {
                result.found = true;
                result.results = _.chain(currentResults)
                    // .filter(function(result) {
                    //     return result.matches.length;
                    // })
                    .map(function (result) {
                        var item = result.item;

                        return {
                            title: item.title.replace(searchRegExp, '<mark>$&</mark>'),
                            link: item.link,
                            texts: _.reduce(result.matches, function(previous, searchResult) {
                                if (searchResult.key === 'text') {
                                    previous.push(searchResult.value.replace(searchRegExp, '<mark>$&</mark>'));
                                }

                                return previous;
                            }, [])
                        }
                    })
                    .value();

                result.resultsCount = result.results.length;
            }
        }

        //console.timeEnd('search');
        return result;
    };

    /*
    #    result = {
    #        found: true
    #        isInit: false
    #        results: {
    #            "12345.htm": {
    #                {
    #                    title: 'Страница 1'
    #                    texts: [
    #                               "В этом тексте было найдено <mark>#{searchWord}</mark>",
    #                               "В этом тексте тоже было найдено <mark>#{searchWord}</mark>"
    #                           ]
    #                    link: '#'
    #                }
    #                {
    #                    title: 'Страница 8962'
    #                    texts: [
    #                               "Здесь текст, а в нём встречается <mark>#{searchWord}</mark>",
    #                               "Здесь тоже текст, и в нём тоже встречается <mark>#{searchWord}</mark>"
    #                           ]
    #                    link: '#'
    #                }
    #            }
    #        }
    #    }
    */
})();

if (typeof String.prototype.trim !== 'function') {
    String.prototype.trim = function () {
        return this.replace(/^\s+|\s+$/g, '');
    };
}

window.loadParent = function () {};

// hide content to avoid blink
window.document.documentElement.style.display = 'none';

$(function () {
    var $aside, $container, $content, $header, $modalContent, $modalHeader, $overlay, $pageTitle,
        $tooltip, $tooltipContent, tooltipButton;

    $.support.cors = true;
    $.fx.speeds._default = 200;

    var options = {
        helpers: {
            media_hv_min: 568,
            media_hv_middle: 874,
            media_mobile: 768
        },
        isMac: Boolean(window['IsMacVersion']),
        isMacProject: Boolean(window['isMacProject']),
        isIE7: Boolean(navigator.appVersion.match('MSIE 7.')),
        isIE8: Boolean(navigator.appVersion.match('MSIE 8.')),
        isIE9: Boolean(navigator.appVersion.match('MSIE 9.')),
        isIE10: Boolean(navigator.appVersion.match('MSIE 10.')),
        isOperaMini: Object.prototype.toString.call(window["operamini"]) === "[object OperaMini]",
        isFileProtocol: window.location.protocol === 'file:',
        isAllInOne: window.location.pathname.match(/(all-in-one\.htm)[l]?$/),
        searchWord: getParam('searchWord', true),
        searchWordMinLength: 3
    };

    if (window.Customization) {
        _.each(window.Localization, function(item, key) {
            if (_.isObject(window.Customization[key])) {
                window.Localization[key] = window.Customization[key].value;
            }
        });
    }

    setParam('searchWord', null, true);

    var HELP = window.HELP = $.extend(true, window.HELP, options);
    var $window = $(window);
    var html = document.documentElement;
    var $html = $(html);
    var $head = $(document.head);
    var $body = $(document.body);
    var title = $html.find('title').text();

    $body.removeClass("no-js");

    var ContainerTemplateFunction = _.template(ContainerTemplate);
    var HeaderTemplateFunction = _.template(HeaderTemplate);
    var FooterTemplateFunction = _.template(FooterTemplate);
    var AsideTemplateFunction = _.template(AsideTemplate);
    var SearchResultsTemplateFunction = _.template(SearchResultsTemplate);
    var MobileSearchResultsTemplateFunction = _.template(MobileSearchResultsTemplate);
    var LangListTemplateFunction = _.template(LangListTemplate);
    var VersionsTemplateFunction = _.template(VersionsTemplate);
    var IndexLiteralsTemplateFunction = _.template(IndexLiteralsTemplate);
    var MenuTemplateFunction = _.template(MenuTemplate);
    var AllInOneMenuTemplateFunction = _.template(AllInOneMenuTemplate);
    var CustomStylesTemplateFunction = _.template(CustomStylesTemplate);

    window.parsedMainTitle = window.parsedMainTitle || "Kaspersky Online Help";
    window.toggleBlock = toggleBlock;
    window.showAll = showAll;
    window.hideAll = hideAll;
    window.togglePopup = togglePopup;
    window.showPopup = showTooltip;
    window.hidePopup = hideTooltip;

    function getParam(param, inSession) {
        if (localStorageChecker()) {
            if (inSession && window.sessionStorage) {
                return window.sessionStorage.getItem(param);
            }

            return store(param);
        }

        return null;
    }

    function setParam(param, value, inSession) {
        if (localStorageChecker()) {
            if (value === void 0) {
                value = null;
            }

            if (inSession && window.sessionStorage) {
                if (value === null) {
                    window.sessionStorage.removeItem(param);
                } else {
                    window.sessionStorage.setItem(param, value);
                }
            } else {
                store(param, value);
            }
        }
    }

    function toggleBlock(id) {
        if (!HELP.isAllInOne) {
            var $block = $('#d' + id);
            var $toggler = $('#h' + id);

            if ($block.length > 0 && $toggler.length > 0) {
                $block.slideToggle();
                $toggler.toggleClass('is-expanded');
                $window.resize();
            }
        }
    }

    function showAll() {
        $('.expandingblock').slideDown();
        $('.expandingblocktemplate').addClass('is-expanded');
        $window.resize();
    }

    function hideAll() {
        $('.expandingblock').slideUp();
        $('.expandingblocktemplate').removeClass('is-expanded');
        $window.resize();
    }

    function togglePopup(id, legacyblockname, show) {
        switch (show) {
            case true:
                showTooltip(id, legacyblockname);
                break;
            case false:
                hideTooltip();
                break;
            default:
                toggleTooltip(id, legacyblockname);
        }
    }

    function calcTooltipPosition() {
        if (tooltipButton) {
            var body = document.body;
            var delta = 30;
            var offset = 10;

            if (options.isIE7 || options.isIE8) {
                offset = 0;
            }

            var bodyHeight = body.clientHeight;
            var bodyWidth = body.clientWidth;
            var linkRect = tooltipButton.getBoundingClientRect();
            var tooltip = $tooltip[0];
            var isToTop = linkRect.top > bodyHeight - linkRect.bottom;
            var isToLeft = linkRect.left > bodyWidth - linkRect.right;
            var coords = {
                top: isToTop ? "" : linkRect.bottom + offset,
                bottom: isToTop ? bodyHeight - linkRect.top + offset : "",
                left: isToLeft ? "" : linkRect.left - delta,
                right: isToLeft ? bodyWidth - linkRect.right - delta : ""
            };

            $tooltip.toggleClass("is-to-top", isToTop).toggleClass("is-to-left", isToLeft).css(coords);

            var tooltipRect = tooltip.getBoundingClientRect();
            coords = {};

            var isOverlapLeft = tooltipRect.left < delta;
            var isOverlapRight = tooltipRect.right > bodyWidth - delta;

            if (isOverlapLeft) {
                coords.left = delta;
            }

            if (isOverlapRight) {
                coords.right = delta;
            }

            if (isOverlapLeft || isOverlapRight) {
                coords.width = "auto";
            } else {
                coords.width = "";
            }

            $tooltip.css(coords);
            tooltipRect = tooltip.getBoundingClientRect();
            coords = {};

            var isOverlapTop = tooltipRect.top < delta;
            var isOverlapBottom = tooltipRect.bottom > bodyHeight - delta;

            if (isOverlapTop) {
                coords.top = delta;
            }

            if (isOverlapBottom) {
                coords.bottom = delta;
            }

            $tooltip.css(coords);
            if (options.isIE7 || options.isIE8) {
                return $tooltip.height(Math.min($tooltipContent[0] != null ? $tooltipContent[0].scrollHeight : void 0, 200));
            }
        }
    }

    function calcHomeBtnVisibility($viewport) {
        return setTimeout(function () {
            var $homeBtn = $viewport.find('.bt-home');

            var calcHeight;
            if ($homeBtn.hasClass('is-shown')) {
                var btn = $homeBtn[0];
                var style = btn.currentStyle || window.getComputedStyle(btn);
                calcHeight = btn.offsetHeight + parseInt(style.marginTop) + parseInt(style.marginBottom);
            } else {
                calcHeight = 0;
            }

            var showBtn = $viewport[0].offsetHeight < $viewport[0].scrollHeight - calcHeight;

            $homeBtn.toggleClass('is-shown', showBtn);
        }, 400);
    }

    function verifyMenuVisiblity($asidePlaceholder) {
        if (window.matchMedia) {
            var mq = window.matchMedia('screen and (max-width: 767px)');

            if (!mq.matches) {
                //$asidePlaceholder.removeClass('is-hidden');
            } else {
                $('.js-tab-link').eq(0).click();
            }
        }
    }

    function showTooltip(id, btnId) {
        if ($tooltip.data("id") !== id) {
            var content = document.getElementById("d" + id).innerHTML;
            $tooltip.data("id", id);
            $tooltipContent.html(content);
        }

        tooltipButton = document.getElementById(btnId);
        $tooltip.show();

        calcTooltipPosition();
    }

    function hideTooltip() {
        return $tooltip.hide();
    }

    function toggleTooltip(id, btnId) {
        if ($tooltip.data("id") !== id || $tooltip.css("display") === "none") {
            showTooltip(id, btnId);
        } else {
            hideTooltip();
        }
    }

    function bindEvents() {
        var $asidePlaceholder = $('.js_aside_placeholder');
        var $menuItems = $('.js_menu_item');
        var $mobileSearch = $('.js_mobile_search_result');
        var $viewport = $('.js_main');
        var mobileMenuToggle = function (button) {
            if (!$mobileSearch.hasClass('is-hidden')) {
                $mobileSearch.addClass('is-hidden');
            }

            $asidePlaceholder.toggleClass('is-active');
            $(button).toggleClass('is-active');
        };

        $('.js_burger').on('click', function (event) {
            event.preventDefault();
            mobileMenuToggle(this);
        });

        $body.on('click', '.js_mobile_menu_deeper', function (event) {
            event.preventDefault();
            mobileMenuShowItem($(this).data('id'));
        });

        $body.on('click', '.bt-home', function (event) {
            event.preventDefault();

            $(".js_content, .js_main").animate({
                scrollTop: 0
            }, '500', 'swing');
        });

        $body.on('click', '.js-tab-link', function () {
            if (!$(this).hasClass('js_search_tab')) {
                delete HELP.searchWord;
                setParam('searchWord', null, true);
            }
        });

        $window.on('resize', function () {
            calcTooltipPosition();
            calcHomeBtnVisibility($('.js_main'));
            verifyMenuVisiblity($asidePlaceholder);
            calcAsideWidth($asidePlaceholder);
        });

        $viewport.on("scroll", calcTooltipPosition);

        $body.on('click', 'a', function (event) {
            var $self = $(this);
            var url = $self.attr('href');

            if (HELP.isAllInOne) {
                if (url) {
                    var hash = url.match( /(.*)\.html?$/ );
                    if (hash && hash[1]) {
                        scrollToHash(hash[1]);

                        if (window.history && window.history.pushState) {
                            window.history.pushState({
                                url: url,
                                hash: hash[1]
                            }, document.title, location.pathname + '#' + hash[1]);
                        }

                        event.stopPropagation();
                        event.preventDefault();

                        trackPage();

                        return;
                    }
                }
            }

            if (window.matchMedia) {
                var mq = window.matchMedia('screen and (max-width: 767px)');
                if (mq.matches) {
                    var toggleSiblings = $self.siblings('.js_contents_toggle');
                    if (toggleSiblings.length > 0 && !$self.hasClass('js_menu_link_direct')) {
                        toggleSiblings.trigger('click');
                        event.preventDefault();
                        return;
                    }
                }
            }

            if (url && url !== '#') {
                var localUrlRegExp = /([\w_]+\.htm)[l]?(#[\w]+(.htm))?/i;
                var urlMatches = url.match(localUrlRegExp);
                var isLocalUrl = Boolean(urlMatches && urlMatches[2] && urlMatches[3]);
                var isLocalAnchor = urlMatches && urlMatches[2] && !urlMatches[3];

                if ($self.closest('.js_search_result_wrapper')) {
                    setParam('searchWord', HELP.searchWord, true);
                }

                if (localStorageChecker()) {
                    var $view = $('.js_tabs_viewport');

                    if ($view.length) {
                        window['localStorage']['asideScrollPosition'] = $view[0].scrollTop;
                    }

                    var $opened_menus = $('.js_contents_toggle.is-toggled+.js_menu_link');

                    if ($opened_menus.length) {
                        window['localStorage']['openedMenus'] = _.map($opened_menus, function (a) {
                            return $(a).attr('href');
                        });
                    }
                }

                if (isLocalUrl) {
                    if ($tooltip) {
                        $tooltip.hide();
                    }

                    var targetUrl = url;
                    var titlePageMatch = location.pathname.match(/(title\.htm)[l]?$/);

                    //if (titlePageMatch && titlePageMatch[1] === "title.htm") {
                    if (HELP.isMacProject) {
                        targetUrl = "./pgs/" + urlMatches[2].slice(1);
                        if (HELP.isFileProtocol) {
                            $self.attr('href', targetUrl);
                        }
                    }

                    if (!HELP.isFileProtocol) {
                        event.preventDefault();

                        setNavigation(HELP.isMacProject ? urlMatches[2].slice(1) : url);

                        loadContent(targetUrl, true, null, url);

                        if (window.matchMedia && mq && mq.matches) {
                            $('.js_aside_placeholder').removeClass('is-active');
                            $('.js_burger').removeClass('is-active');
                            $('.js_mobile_aside').addClass('is-hidden');
                        }

                        $('.js_home').toggleClass('is-active', HELP.nav.home.url === HELP.nav.currentPage.url);
                    }
                } else if (isLocalAnchor) {
                    if (window.matchMedia && mq && mq.matches) {
                        $('.js_aside_placeholder').removeClass('is-active');
                        $('.js_burger').removeClass('is-active');
                        $('.js_mobile_aside').addClass('is-hidden');
                    }
                } else if ($self.hasClass('hyperlinktemplate') && url.indexOf('mailto') !== 0) {
                    if (window.confirm(HELP.localization.ExternalLinkText)) {
                        return;
                    }

                    event.preventDefault();
                }
            } else {
                event.preventDefault();
            }
        });

        $body.on('click', '.js_menu_link, .js_menu_link_direct', function () {
            var $self = $(this);
            delete HELP.searchWord;
            setParam('searchWord', null, true);

            if (!$self.prev().hasClass('js_contents_toggle')) {
                $menuItems.removeClass('is-active');
            }

            $self.children('.js_contents_toggle').addClass('is-toggled').siblings('.js_contents_level').slideDown();
            $self.closest('.js_menu_item').addClass('is-active');

            var href = $self.attr('href');
            var topicRegExp = /[\w_]+\.htm/;
            var hashRegExp = /#([\w_]+)/;

            if (href.indexOf('#') > -1) {
                var locationMatch = location.pathname.match(topicRegExp);
                var hrefMatch = href.match(topicRegExp);
                var hash = href.match(hashRegExp)[1];
                event.preventDefault();

                if (!(locationMatch.length && hrefMatch.length && locationMatch[0] === hrefMatch[0])) {
                    loadContent(href, true, function() {
                        if (hash) {
                            scrollToHash(hash);
                        }
                    });
                }

                if (hash) {
                    scrollToHash(hash);

                    if (!HELP.isMacProject && window.history && window.history.pushState) {
                        window.history.pushState({
                            url: href,
                            hash: hash
                        }, document.title, href);
                    }
                }
            }
        });

        $body.on('click', '.js_home_link', function () {
            $('.js-tab-link').eq(0).trigger('click');
        });

        $(window).on('popstate', function (event) {
            var state = event.originalEvent.state;

            if (state && state.url) {
                if (!HELP.isAllInOne) {
                    loadContent(state.url, false, scroll, state.originalUrl);
                    setNavigation(state.url);
                } else {
                    scroll();
                    trackPage();
                }
            }

            function scroll() {
                if (state.hash) {
                    $(".js_menu_item").removeClass('is-active');
                    var $menuItem = $(".js_menu_link[href='" + state.hash + ".htm']").closest('.js_menu_item');
                    autoScrollContents($menuItem);

                    scrollToHash(state.hash);
                }
            }
        });

        $body.on('click', '.js_modal_close', function () {
            $overlay.removeClass('is-visible');
        }).on('click', '.js_overlay', function (event) {
            if (!$(event.target).closest('.js_modal').length) {
                $overlay.removeClass('is-visible');
            }
        });

        $body.on('click', '.js_print_section', function() {
            var currentUrl = window.location.pathname.match(/\/(\w+\.\w+)$/)[1];
            //window.location.href = 'all-in-one.htm?sectionUrl=' + currentUrl;
            window.open('all-in-one.htm?sectionUrl=' + currentUrl);
        });

        if (!HELP.isAllInOne) {
            var xStart = null;
            var yStart = null;

            $body.on('touchstart', '.js_content', function(event) {

                var tableInTopic = $(event.target).closest('.tableintopic');
                if (tableInTopic.length && tableInTopic.width() > tableInTopic.parent().width()) {
                    return;
                }

                var touch = event.originalEvent.touches[0];
                if (touch) {
                    xStart = touch.clientX;
                    yStart = touch.clientY;
                }
            });

            $body.on('touchmove', '.js_content', function(event) {
                if (!xStart || !yStart) {
                    return;
                }

                var touch = event.originalEvent.touches[0];
                var xEnd = touch.clientX;
                var yEnd = touch.clientY;
                var xDiff = xStart - xEnd ;
                var yDiff = yStart - yEnd;

                if (Math.abs(xDiff) > Math.abs(yDiff) && Math.abs(xDiff) > 50) {
                    if (xDiff > 0 && HELP.nav.nextPage) {
                        $('.js_container').addClass('is-loading');
                        $('.js_main').addClass('swipe-left');
                        setTimeout(function () {
                            $('.js_next_link').click();
                        }, 350);
                    } else if(xDiff < 0 && HELP.nav.prevPage) {
                        $('.js_container').addClass('is-loading');
                        $('.js_main').addClass('swipe-right');
                        setTimeout(function () {
                            $('.js_prev_link').click();
                        }, 350);
                    }

                    xStart = null;
                    yStart = null;
                }
            });
        }
    }

    /*
    #* Языки в хэдере --------------------------------------------------------------------------------------------------
     */
    function loadLangs() {
        if (!window.Langs) {
            $('.js_selector_mobile_langs').remove();
            return;
        }

        var currentId = 'no id';
        var currentName = 'no name';
        var locLangs = window.LangsLocalization;

        window.Langs.forEach(function(item) {
            if (locLangs && locLangs[item.id]) {
                item.name = locLangs[item.id];
            }

            if (item.id === document.documentElement.lang) {
                HELP.currentLangId = currentId = item.id;
                HELP.currentLangCode = currentName = item.name;

                if (~['ja-JP', 'ko-KR', 'zh-Hans', 'zh-Hant'].indexOf(HELP.currentLangId)) {
                    HELP.searchWordMinLength = 2;
                }
            }
        });

        if (window.Langs.length < 2) {
            $('.js_selector_mobile_langs').remove();
            return;
        }

        var isMac = Boolean(window.location.pathname.match(/pgs\/[\w_\.]+/));
        var isMacTitle = Boolean(window.location.pathname.match(/title\.html?$/));
        var LangListHtml = LangListTemplateFunction({
            langs: window.Langs,
            currentLang: {
                name: currentName,
                id: currentId
            },
            localization: HELP.localization,
            isMac: isMac,
            isMacTitle: isMacTitle
        });

        $header.find('.js_header_lang_list').html(LangListHtml);
        $('.js_selector_mobile_langs').html(LangListHtml).find('.js_dropdown').addClass('dropdown_large');

        $body.on('click', '.js_lang_item', function (event) {
            event.preventDefault();

            var $element = $(this);
            var langId = $element.data('lang-id');
            var path = window.location.pathname;
            var currentFolder = window.location.pathname.match(/([\w]+|[\w\.-]+)(\/pgs)?\/[\w_]+.html?/)[1];

            window.location.href  = path.replace("/" + currentFolder + "/", "/" + langId + "/");
        });
    }

    function triggerSearch() {
        if (HELP.helpers.searchTimeout) {
            clearTimeout(HELP.helpers.searchTimeout);
        }

        HELP.helpers.searchTimeout = setTimeout(function () {
            var searchWord = $('.js_search_text').val().trim();

            if (searchWord.length < HELP.searchWordMinLength) {
                delete HELP.searchWord;
                setParam('searchWord', null, true);

                searchWord = null;

                $('.js-menu-content, .js_search').show();
                $('.js-search-content, .js_search_clear').hide();
            } else {
                HELP.searchWord = searchWord;
                setParam('searchWord', searchWord, true);

                var resultObj = search(searchWord, HELP.searchWordMinLength);
                resultObj.localization = HELP.localization;
                resultObj.isMacProject = HELP.isMacProject;

                var searchResultsHtml = SearchResultsTemplateFunction(resultObj);

                $('.js-menu-content, .js_search').hide();
                $('.js-search-content, .js_search_clear').show();
                //$('.js_search_tab').trigger('click');

                $('.js_search_result_wrapper').html(searchResultsHtml);
            }
        }, 300);
    }

    /*
    #* Левое меню ------------------------------------------------------------------------------------------------------
     */
    function loadMenu(menu) {
        if (!window['Toc']) {
            return;
        }

        var flatMenu = [];
        var currentUrl = HELP.isAllInOne || HELP.isMacProject ?
            /#([\w_]+)/.exec(location.hash) : /\/([\w_]+\.\w+$)/.exec(location.pathname);
        var currentPage = {};
        var currentLevel, parentPage;

        if (currentUrl && currentUrl[1]) {
            currentUrl = currentUrl[1];
        }

        function buildMenu(menu, level, parentId) {
            var isCurrentMenuLevelActive;
            level = level || 0;

            _.each(menu, function (item) {
                item.level = level;
                if (item.url && item.url.match(/#|(title\.html?)/)) {
                    return;
                }

                if (item.hidden) {
                    return;
                }

                flatMenu.push(item);

                if (item.url === currentUrl || item.url === currentUrl + '.htm') {
                    item.isActive = true;
                    currentPage = item;
                    currentLevel = level;
                }

                if (item.children) {
                    item.childIsActive = buildMenu(item.children, level + 1, item.id);
                }

                if (item.isActive || item.childIsActive) {
                    isCurrentMenuLevelActive = true;
                }

                if (level > 0 && parentId) {
                    return item.parentId = parentId;
                }
            });

            return isCurrentMenuLevelActive;
        }

        buildMenu(menu);

        var i, j, ref, item, prevSection, nextSection;
        for (i = j = 0, ref = flatMenu.length - 1; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
            item = flatMenu[i];
            if (item.url === currentUrl || item.url === currentUrl + '.htm') {
                if (i > 0) {
                    prevSection = flatMenu[i - 1];
                }

                if (i !== flatMenu.length - 1) {
                    nextSection = flatMenu[i + 1];
                }
            }
        }

        if (!currentPage.url) {
            nextSection = flatMenu[0];
        }

        window.HELP = $.extend(true, window.HELP, {
            nav: {
                menu: menu,
                flatMenu: flatMenu,
                home: flatMenu[0],
                currentPage: currentPage,
                currentLevel: currentLevel,
                parentPage: parentPage,
                prevPage: prevSection,
                nextPage: nextSection
            }
        });

        var $homeBtn = $body.find('.js_home');
        var $homeBtnLink = $homeBtn.find('.js_home_link');

        if (HELP.nav.home) {
            $homeBtnLink.attr('href', HELP.nav.home.url);
        }

        if (HELP.isAllInOne) {
            $(window).on('load', function() {
                setTimeout(function() {
                    scrollToHash(currentUrl);
                });
            });
        }

        buildLinks($container);

        var MenuHtml = MenuTemplateFunction({
            menu: menu,
            localization: HELP.localization,
            isMacProject: HELP.isMacProject
        });

        $aside.find('.js_menu').html(MenuHtml);

        $('.js_search_text').on('keyup', function (event) {
            if (event.keyCode === 27) {
                $('.js-tab-link').eq(0).click();
                $(this).val('');
            } else {

            }
            triggerSearch();
        });

        $('.js_search_clear').on('click', function () {
            $('.js_search_text').val('');
            triggerSearch();
        });

        $('.js_mobile_search_button').on('click', function () {
            var $this = $(this);
            var $result = $('.js_mobile_search_result');
            var $input = $('.js_mobile_search_input');
            var $clearBtn = $('.js_mobile_search_clear');
            var isShow = !$input.hasClass('is-hidden');

            if (isShow) {
                if ($input.val().length > 0) {
                    var searchWord = $input.val().trim();
                    var resultObj = search(searchWord, HELP.searchWordMinLength);

                    resultObj.localization = HELP.localization;
                    resultObj.isMacProject = HELP.isMacProject;
                    var mobileSearchResultsHtml = MobileSearchResultsTemplateFunction(resultObj);

                    $result.html(mobileSearchResultsHtml).removeClass('is-hidden').addClass('is-active');

                    setTimeout(function () {
                        $('.js_aside_placeholder').removeClass('is-active');
                        $('.js_burger').removeClass('is-active');
                    });
                } else {
                    $result.removeClass('is-active').addClass('is-hidden');
                }

                /*$this.removeClass('is-active');
                $input.addClass('is-hidden');
                $clearBtn.addClass('is-hidden');*/
            } else {
                $input.removeClass('is-hidden');
                $clearBtn.removeClass('is-hidden');
                $this.addClass('is-active');

                if (!$result.is(':empty')) {
                    $result.removeClass('is-hidden').addClass('is-active');
                }

                setTimeout(function () {
                    $input.focus();
                }, 100);
            }
        });

        $('.js_mobile_search_clear').on('click', function () {
            var $searchBtn = $('.js_mobile_search_button');
            var $result = $('.js_mobile_search_result');
            var $input = $('.js_mobile_search_input');

            if ($input.val().length > 0) {
                $input.val('');
                HELP.searchWord = null;
                setParam('searchWord', null, true);

                $result.empty();
            }

            $searchBtn.removeClass('is-active');
            $result.addClass('is-hidden');
            $input.addClass('is-hidden');
            $(this).addClass('is-hidden');
        });

        var triggerMobileSearch = _.debounce(function() {
            $('.js_mobile_search_button').trigger('click');
        }, 350);

        $('.js_mobile_search_input').on('keyup', function (event) {
            if (event.keyCode === 13) {
                $('.js_mobile_search_button').trigger('click');
            // } else {
            //     triggerMobileSearch();
            }
        });

        $('.js_contents_toggle').on('click', function (event) {
            event.preventDefault();

            var $toggler = $(this);
            $toggler.toggleClass('is-toggled');

            if ($toggler.hasClass('is-toggled')) {
                $toggler.siblings('.contents').slideDown();
            } else {
                $toggler.siblings('.contents').slideUp();
            }
        });

        $('.js_dropdown_btn').on('click', function (event) {
            event.preventDefault();

            var $list = $(this).siblings('.js_dropdown_list');

            $list.css({
                maxHeight: html.clientHeight - $list.offset().top - this.clientHeight
            }).toggleClass('dropdown__list--opened');

            $body.on('click.dropdown', function (event) {
                if (!$(event.target).closest('.js_dropdown').length) {
                    $list.toggleClass('dropdown__list--opened');
                    $body.off('click.dropdown');
                }
            });
        });

        bindEvents();
    }

    function loadContent(url, saveToHistory, callback, originalUrl) {
        if (saveToHistory == null) {
            saveToHistory = true;
        }

        var loadingTimeout = setTimeout(function () {
            $('.js_container').addClass('is-loading');
        }, 300);

        $.ajax(url, {
            crossDomain: true,
            dataType: "html",
            success: function (response) {
                if (saveToHistory && window.history && window.history.pushState) {
                    window.history.pushState({
                        url: url,
                        originalUrl: originalUrl
                    }, null, originalUrl || url);
                }

                var frameHtml = processHtml(response);
                var langMatches = frameHtml.match(/\slang="(.+?)"/);

                if ((langMatches != null ? langMatches.length : void 0) > 1 && langMatches[1] !== HELP.currentLangId) {
                    window.location = HELP.isMacProject ? originalUrl : url;
                    return;
                }

                var $cont = $(frameHtml).filter('.cont');
                $content.html($cont);

                $(".js_content, .js_main").animate({
                    scrollTop: 0
                }, '200', 'swing');

                title = $cont.find('.heading1, .heading2, .heading3, .heading4').first().text();
                document.title = title;
                $(".js_menu_item").removeClass('is-active');

                var scrollToUrl = HELP.isMacProject ? originalUrl : url || HELP.nav.currentPage.url;
                var $menuItem = $(".js_menu_link[href='" + scrollToUrl + "']").closest('.js_menu_item');
                var $index = $('.js_index_literals');
                var $indexLinks = $index.find('.indexlink > a');
                $indexLinks.removeClass('is-active').filter("[href='" + url + "']").addClass('is-active');

                autoScrollContents($menuItem);
                processContent($container);

                if (loadingTimeout) {
                    clearTimeout(loadingTimeout);
                }

                if (callback && typeof callback === 'function') {
                    callback();
                }

                $('.js_container').removeClass('is-loading');
                $('.js_main').removeClass('swipe-left swipe-right');

                trackPage();
            },
            error: function () {
                window.history.back();
                return window.location = url;
            }
        });
    }

    function processHtml(content, menu) {
        if (menu) {
            var AllInOneMenuHtml = AllInOneMenuTemplateFunction({
                menu: menu,
                localization: HELP.localization
            });
            var resultContent = $();

            menu.forEach(getContent);

            function getContent(item) {
                resultContent = resultContent.add('#' + item.o + ', [name=' + item.o + ']');

                if (item.children) {
                    item.children.forEach(getContent);
                }
            }

            content = AllInOneMenuHtml + $('<div/>').html(resultContent).html();
        }

        if (typeof content === 'string') {
            content = content.replace(/[™®]|&reg;|&#8482;|&#174;/g, '');

            if (HELP.isMacProject) {
                content = content.replace(/"title.htm#([\w]+.htm)"/gi,'"index.htm#$1"');
            }

            if (HELP.searchWord) {
                var searchRegExp = new RegExp(escapeRegExp(HELP.searchWord) + '(?!([^<]+)?>)', "ig");
                content = content.replace(searchRegExp, "<mark>$&</mark>");
            }
        }

        return content;
    }

    function processContent($container) {
        $container.find('.links').remove();
        buildLinks($container);

        $container.find('.cont').toggleClass('mactitlepage', Boolean(location.pathname.match(/title\.htm/)));
        $container.find('style').remove();

        if (!HELP.isAllInOne) {
            $container.find('.popuponclick, .expandingblock').each(function () {
                var $self = $(this);
                var $toggler = $($self.attr('id').replace('d', '#h'));

                if ($toggler.length > 0) {
                    var $wrapper = $toggler.closest(".settingdescr");

                    if ($wrapper.length === 0) {
                        $wrapper = $toggler.parent();
                    }

                    $wrapper.append($self);

                    if ($self.hasClass('expandingblock')) {
                        $wrapper.addClass('expandingblock-wrapper');

                        var img = $toggler.next('img');

                        if (img.length) {
                            $toggler.append(img);
                        }
                    }
                }
            });
        }

        $container.find('.cont [title]').each(function(index, item) {
            var classes = item.className;
            var $item = $(item);

            if (!$item.is('img') &&
                classes.indexOf('hyperlinktemplate') === -1 &&
                classes.indexOf('crossreferencetemplate') === -1) {
                $item.removeAttr('title');
            }
        });

        $container.find('.hyperlinktemplate').each(function() {
            var $self = $(this);
            var $siblingLink = $self.next('span').find('.hyperlinktemplate');

            if ($siblingLink.length) {
                var text = $siblingLink.text();
                $self.append($siblingLink.parent().text(text));
            }
        });

        var $tables = $container.find(".tableintopic");
        $tables.wrap("<div class='tableintopic-wrapper'/>");
        var $tableRows = $tables.find('tr');
        $tableRows.filter(':nth-child(2n)').addClass('is-even');
        $tableRows.filter(':nth-child(2n+1)').addClass('is-odd');

        $container.find('.popuponhover, .popuponclick').each(function () {
            var $self = $(this);
            var $toggler = $($self.attr('id').replace('d', '#h'));

            if ($toggler.length > 0) {
                return $toggler.wrap("<div class='link-wrapper'/>").after($self);
            }
        });

        $container.find('.js_feedback_link').attr('href', getMailtoLink());

        $container.find('.program').each(function(index, item) {
            var $item = $(item);
            if (!$item.parent().hasClass('js_code')) {
                var siblings = $(item).nextUntil(':not(.program)').addBack();

                if (siblings.length > 1) {
                    siblings.wrapAll('<div class="js_code"></div>');
                    siblings.after('\n');
                }
            }
        });

        $container.find('.exampleheading, .examplebodytext, .exampleheadingblue2015, .examplebodytextblue2015')
            .parent().each(function(index, item) {
                $(item).addClass('example-wrapper');
            });

        setTimeout(function() {
            $container.find('.js_code').each(function(index, item) {
                window.hljs.highlightBlock(item);
            });
        });

        $window.resize();
    }

    function buildLinks($container) {
        $pageTitle = $container.find('.heading1, .heading2, .heading3, .heading4').first();
        var $homeBtn = $container.find('.bt-home');
        var $prevBtnPlaceholder = $container.find('.js_prev_btn_placeholder');
        var $nextBtnPlaceholder = $container.find('.js_next_btn_placeholder');
        var PageTitleTemplateFunction = _.template(PageTitleTemplate);
        var BottomLinksTemlateFunctions = _.template(BottomLinksTemplate);
        var NextLinkTemplateTemlateFunctions = _.template(NextLinkTemplate);
        var PrevLinkTemplateTemlateFunctions = _.template(PrevLinkTemplate);

        if (HELP.nav) {
            var PageTitleHtml = PageTitleTemplateFunction({
                titleHtml: $pageTitle.html(),
                localization: HELP.localization
            });

            $pageTitle.html(PageTitleHtml);

            if (!HELP.isAllInOne) {
                var NextLinkHtml = NextLinkTemplateTemlateFunctions({
                    nextPage: HELP.nav.nextPage,
                    isMacProject: HELP.isMacProject
                });

                var PrevLinkHtml = PrevLinkTemplateTemlateFunctions({
                    prevPage: HELP.nav.prevPage,
                    isMacProject: HELP.isMacProject
                });

                $prevBtnPlaceholder.html(PrevLinkHtml);
                $nextBtnPlaceholder.html(NextLinkHtml);

                if ($homeBtn.length === 1) {
                    $homeBtn = $homeBtn.first();

                    var BottomLinksHtmls = BottomLinksTemlateFunctions({
                        homeBtnHtml: $homeBtn[0].outerHTML,
                        localization: HELP.localization,
                        serviceInfo: {
                            id:  HELP.isMacProject ? window.location.hash.slice(1) : window.location.pathname.match(/\/(\w+)\.htm/)[1],
                            reviewDate: window.reviewDate ? (new Date(window.reviewDate)).toLocaleString(HELP.currentLangId, {
                                year: 'numeric',
                                month: 'short',
                                day: 'numeric'
                            }) : null
                        }
                    });

                    $homeBtn.replaceWith(BottomLinksHtmls);
                }
            } else {
                $('.js_all_in_one_header').text(HELP.localization.TableOfContents);
            }
        }
    }

    function autoScrollContents($target, animateSpeed) {
        if (animateSpeed == null) {
            animateSpeed = 2;
        }

        if (!$target || !$target.length) {
            return;
        }

        var $view = $('.js_tabs_viewport');
        var $menuItem = $view.find('.js-menu-content:not(.is-hidden)').find($target);

        if (!$menuItem.length || !$view.length) {
            return;
        }

        var targetTop;
        if (localStorageChecker() && window['localStorage']['asideScrollPosition'] !== void 0) {
            targetTop = window['localStorage']['asideScrollPosition'];
            setParam('asideScrollPosition', null);
            var isFromLocalStorage = true;
        } else {
            var view = $view[0];
            var delta1 = view.clientHeight / 5;
            var delta2 = view.clientHeight / 4;
            var isOverBottom = $menuItem.offset().top > view.clientHeight + $view.offset().top - delta1;
            var isOverTop = $menuItem.offset().top < $view.offset().top + delta1 + $menuItem[0].offsetHeight;
            var targetDelta;
            if (isOverBottom) {
                targetDelta = $menuItem.offset().top - $view.offset().top - view.clientHeight + delta2;
            } else if (isOverTop) {
                targetDelta = $menuItem.offset().top - $view.offset().top - delta2 - $menuItem[0].offsetHeight;
            }
            targetTop = view.scrollTop + targetDelta;
        }

        var scrollingDuration = Math.min(animateSpeed * Math.abs(targetDelta), 1500);
        if (isFromLocalStorage || isOverTop || isOverBottom) {
            $view.animate({
                scrollTop: targetTop
            }, scrollingDuration, 'swing');
        }

        $menuItem
            .addClass('is-active')
            .parents('.js_contents_level')
            .add($menuItem.children('.js_contents_level'))
            .slideDown()
            .siblings('.js_contents_toggle')
            .addClass('is-toggled');
    }

    function loadVersions() {
        var url = window.location.pathname.split('/');
        var productKey = url[1];
        var currentVersionUrl = url[2];
        var product =
            _.findWhere(HELP.localization.products_b2c, {url: productKey}) ||
            _.findWhere(HELP.localization.products_b2b, {url: productKey});
        var $productLogo = $('.js_product_logo');

        if (!product) {
            return;
        }

        $productLogo.addClass('top-bar__product_' + product.icon);

        var currentVersion;
        _.some(product.versions, function(item) {
            if (item.url.split('/')[0] === currentVersionUrl) {
                currentVersion = item;
                return true;
            }
            return false;
        });

        if (currentVersion && product.versions.length > 1) {
            var VersionsResultsHtml = VersionsTemplateFunction({
                currentVersion: currentVersion,
                versions: product.versions
            });

            $header.find('.js_header_versions_list').html(VersionsResultsHtml);
            $('.js_selector_mobile_versions')
                .html(VersionsResultsHtml).find('.js_dropdown').addClass('dropdown_large');

            $header.on('click', '.js_version_item', function (event) {
                event.preventDefault();

                var versionUrl = $(this).data('version-url');
                /*var path = window.location.pathname.split('/');
                var currentPage = path[path.length - 1];

                window.location.href  = '/' + productKey + '/' + versionUrl + '/' + currentPage;*/
                window.location.href = '/' + productKey + '/' + versionUrl;
            });
        } else {
            $('.js_selector_mobile_versions').remove();
        }
    }

    function calcAsideWidth(aside) {
        aside.children().width(aside.width());
    }

    function getMailtoLink() {
        return 'mailto://?subject=Shared from Kaspersky Online Help: "' +
            window.parsedMainTitle + ' - ' + window.document.title + '"&body=' + window.parsedMainTitle +
            ' - ' + window.document.title + '%0A' + window.location.href;
    }

    function findSection(menuList, sectionUrl) {
        var result =[];

        menuList.forEach(function(item) {
            if (item.url === sectionUrl) {
                result.push(item);
            } else if (item.children) {
                result = result.concat(findSection(item.children, sectionUrl));
            }
        });

        return result;
    }

    function scrollToHash(hash) {
        var $target = $("[name='" + hash + "'], #" + hash);
        var $main = $('.js_main');

        if ($target.length) {
            $main.animate({
                scrollTop: $target[0].offsetTop - $main[0].offsetTop
            }, '500', 'swing');

            document.documentElement.scrollTop = 0;
        }
    }

    function escapeRegExp(text) {
        return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    }

    function localStorageChecker() {
        // localstorage & sessionstorage falls with error in EDGE for local files
        try {
            return Boolean(window.localStorage);
        } catch (e) {
            return false;
        }
    }

    function trackPage() {
        if (window._gaq) {
            window._gaq.push(['_trackPageview', location.pathname + location.search + location.hash]);
        }
    }

    function setNavigation(url) {
        _.each(HELP.nav.flatMenu, function (item, index) {
            if (item.url === url) {
                HELP.nav.currentPage = item;

                if (index > 0) {
                    HELP.nav.prevPage = HELP.nav.flatMenu[index - 1];
                } else {
                    HELP.nav.prevPage = null;
                }

                if (index !== HELP.nav.flatMenu.length - 1) {
                    HELP.nav.nextPage = HELP.nav.flatMenu[index + 1];
                } else {
                    HELP.nav.nextPage = null;
                }
            }
        });
    }

    /*
    #* Первичный рендеринг --------------------------------------------------------------------------------------------------
     */
    function firstRender() {
        var $footer, $menuItem, arrOpenedMenus, i, j;
        var sectionUrl = location.search.split('sectionUrl=')[1];
        var menu = window['Toc'];

        if (sectionUrl) {
            menu = findSection(menu, sectionUrl);
        }

        HELP.localization = window.Localization || {};
        HELP.customization = window.Customization || {};
                
        $html.toggleClass('ie7', HELP.isIE7).toggleClass('ie8', HELP.isIE8)
             .toggleClass('ie9', HELP.isIE9).toggleClass('ie10', HELP.isIE10)
             .toggleClass('is-opera-mini', HELP.isOperaMini)
             .toggleClass('is-offline', HELP.isFileProtocol);

        if (window['HelpViewer'] !== void 0 && window.sessionStorage && JSON.parse && window.sessionStorage.getItem('isTOCHidden') && JSON.parse(window.sessionStorage.getItem('isTOCHidden'))) {
            $html.removeClass('is-menu-shown');
        }

        if (location.hostname === 'localhost' || location.hostname === 'stage.help.kaspersky.com') {
            $html.addClass('is-test-mode');
        }

        var containerHtml = ContainerTemplateFunction({
            localization: HELP.localization
        });

        var parsedMainTitle = window.parsedMainTitle;
        if (parsedMainTitle.indexOf('Kaspersky') === 0) {
            var titlePreffix = parsedMainTitle.slice(0, 9);
            parsedMainTitle = parsedMainTitle.slice(10, parsedMainTitle.length);
        }

        var headerHtml = HeaderTemplateFunction({
            titlePreffix: titlePreffix || '',
            title: parsedMainTitle,
            localization: HELP.localization,
            customization: HELP.customization,
            isAllInOne: HELP.isAllInOne,
            isOffline: HELP.isFileProtocol
        });

        var footerHtml = FooterTemplateFunction({
            localization: HELP.localization,
            customization: HELP.customization
        });

        var asideHtml = AsideTemplateFunction({
            localization: HELP.localization
        });

        if (window.Customization) {
            var customStyles = CustomStylesTemplateFunction({
                customization: HELP.customization
            });

            $head.append(customStyles);
        }

        $container = $(containerHtml);
        $header = $(headerHtml);
        $footer = $(footerHtml);
        $aside = $(asideHtml);

        var $headerPlaceholder = $container.find('.js_header_placeholder');
        var $asidePlaceholder = $container.find('.js_aside_placeholder');
        var $footerPlaceholder = $container.find('.js_footer_placeholder');

        $headerPlaceholder.append($header);
        $asidePlaceholder.append($aside);
        $footerPlaceholder.append($footer);
        $content = $container.find('.js_content');
        $content.append(processHtml($body.html(), sectionUrl ? menu : null));
        $body.html($container);
        processContent($container);
        $body.addClass('js_tabs');

        var $viewport = $('<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">');
        $head.append($viewport);
        $html.find('base').remove();

        if ($.inArray($html.attr('lang'), ['ar-AE', 'fa-IR']) > -1) {
            $html.attr('dir', 'rtl');
        } else {
            $html.attr('dir', 'ltr');
        }

        FastClick.attach(document.body);

        $overlay = $body.find('.js_overlay');
        loadLangs();
        loadVersions();
        loadMenu(menu);

        if (HELP.searchWord) {
            $body.find('.js_search_text').val(HELP.searchWord);
            triggerSearch();
        }

        if (HELP.nav.currentPage && HELP.nav.currentPage.url) {
            $menuItem = $(".js_menu_link[href='" + HELP.nav.currentPage.url + "']").closest('.js_menu_item');
            autoScrollContents($menuItem, 0);
        }

        var localUrlRegExp = /([\w_]+\.htm)[l]?(#[\w]+(.htm))?/i;
        var urlMatches = window.location.href.match(localUrlRegExp);
        if (HELP.isMacProject && urlMatches[2] && urlMatches[3]) {
            loadContent("./pgs/" + urlMatches[2].slice(1), false, null, urlMatches[0]);
        } else if (window.history && window.history.replaceState && !HELP.isAllInOne) {
            var initialUrl = /\/([\w_-]+\.\w+$)/.exec(location.pathname)[1];
            window.history.replaceState({
                url: initialUrl
            }, null, initialUrl);
        }

        $modalContent = $overlay.find('.js_modal_content');
        $modalHeader = $overlay.find('.js_modal_header');
        $tooltip = $body.find('.js_tooltip');
        $tooltipContent = $body.find('.js_tooltip_content');

        setTimeout(function () {
            $html.show();
            $window.resize();
        }, 100);

        if (HELP.isIE7 || HELP.isIE8) {
            setTimeout(function () {
                calcAsideWidth($asidePlaceholder);
            }, 500);
        }

        $(".downloadhyperlinktemplate").attr("download", "").addClass("hyperlinktemplate");
    }

    firstRender();
});